'use strict';function ba(a){var b=0;return function(){return b<a.length?{done:!1,value:a[b++]}:{done:!0}}}var da="function"==typeof Object.defineProperties?Object.defineProperty:function(a,b,c){if(a==Array.prototype||a==Object.prototype)return a;a[b]=c.value;return a};
function fa(a){a=["object"==typeof globalThis&&globalThis,a,"object"==typeof window&&window,"object"==typeof self&&self,"object"==typeof global&&global];for(var b=0;b<a.length;++b){var c=a[b];if(c&&c.Math==Math)return c}throw Error("Cannot find global object");}var ja=fa(this);function ma(a,b){if(b)a:{var c=ja;a=a.split(".");for(var d=0;d<a.length-1;d++){var e=a[d];if(!(e in c))break a;c=c[e]}a=a[a.length-1];d=c[a];b=b(d);b!=d&&null!=b&&da(c,a,{configurable:!0,writable:!0,value:b})}}
ma("Symbol.asyncIterator",function(a){return a?a:Symbol("Symbol.asyncIterator")});function ra(a){function b(d){return a.next(d)}function c(d){return a.throw(d)}return new Promise(function(d,e){function f(g){g.done?d(g.value):Promise.resolve(g.value).then(b,c).then(f,e)}f(a.next())})}function sa(a){return ra(a())}
function ta(a){this[Symbol.asyncIterator]=function(){return this};this[Symbol.iterator]=function(){return a};this.next=function(b){return Promise.resolve(a.next(b))};void 0!==a["throw"]&&(this["throw"]=function(b){return Promise.resolve(a["throw"](b))});void 0!==a["return"]&&(this["return"]=function(b){return Promise.resolve(a["return"](b))})}ma("Object.values",function(a){return a?a:function(b){var c=[],d;for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&c.push(b[d]);return c}});
ma("Array.prototype.includes",function(a){return a?a:function(b,c){var d=this;d instanceof String&&(d=String(d));var e=d.length;c=c||0;for(0>c&&(c=Math.max(c+e,0));c<e;c++){var f=d[c];if(f===b||Object.is(f,b))return!0}return!1}});function ua(a,b){a instanceof String&&(a+="");var c=0,d=!1,e={next:function(){if(!d&&c<a.length){var f=c++;return{value:b(f,a[f]),done:!1}}d=!0;return{done:!0,value:void 0}}};e[Symbol.iterator]=function(){return e};return e}
ma("Array.prototype.values",function(a){return a?a:function(){return ua(this,function(b,c){return c})}});ma("globalThis",function(a){return a||ja});ma("Array.prototype.flat",function(a){return a?a:function(b){b=void 0===b?1:b;var c=[];Array.prototype.forEach.call(this,function(d){Array.isArray(d)&&0<b?(d=Array.prototype.flat.call(d,b-1),c.push.apply(c,d)):c.push(d)});return c}});
ma("Object.entries",function(a){return a?a:function(b){var c=[],d;for(d in b)Object.prototype.hasOwnProperty.call(b,d)&&c.push([d,b[d]]);return c}});function va(a){a=Math.trunc(a)||0;0>a&&(a+=this.length);if(!(0>a||a>=this.length))return this[a]}ma("Array.prototype.at",function(a){return a?a:va});function wa(a){return a?a:va}ma("Int8Array.prototype.at",wa);ma("Uint8Array.prototype.at",wa);ma("Uint8ClampedArray.prototype.at",wa);ma("Int16Array.prototype.at",wa);ma("Uint16Array.prototype.at",wa);
ma("Int32Array.prototype.at",wa);ma("Uint32Array.prototype.at",wa);ma("Float32Array.prototype.at",wa);ma("Float64Array.prototype.at",wa);ma("String.prototype.at",function(a){return a?a:va});ma("String.prototype.padStart",function(a){return a?a:function(b,c){if(null==this)throw new TypeError("The 'this' value for String.prototype.padStart must not be null or undefined");b-=this.length;c=void 0!==c?String(c):" ";return(0<b&&c?c.repeat(Math.ceil(b/c.length)).substring(0,b):"")+this}});
ma("Object.fromEntries",function(a){return a?a:function(b){var c={};if(!(Symbol.iterator in b))throw new TypeError(""+b+" is not iterable");b=b[Symbol.iterator].call(b);for(var d=b.next();!d.done;d=b.next()){d=d.value;if(Object(d)!==d)throw new TypeError("iterable for fromEntries should yield objects");c[d[0]]=d[1]}return c}});/*

 Copyright The Closure Library Authors.
 SPDX-License-Identifier: Apache-2.0
*/
var xa=this||self;function ya(a){var b=typeof a;b="object"!=b?b:a?Array.isArray(a)?"array":b:"null";return"array"==b||"object"==b&&"number"==typeof a.length}function Ca(a){var b=typeof a;return"object"==b&&null!=a||"function"==b}function Da(a){return a};var Ea,La;a:{for(var Oa=["CLOSURE_FLAGS"],Pa=xa,Ta=0;Ta<Oa.length;Ta++)if(Pa=Pa[Oa[Ta]],null==Pa){La=null;break a}La=Pa}var Ua=La&&La[610401301];Ea=null!=Ua?Ua:!1;var Xa;const Ya=xa.navigator;Xa=Ya?Ya.userAgentData||null:null;function $a(a){return Ea?Xa?Xa.brands.some(({brand:b})=>b&&-1!=b.indexOf(a)):!1:!1}function ab(a){var b;a:{if(b=xa.navigator)if(b=b.userAgent)break a;b=""}return-1!=b.indexOf(a)};function bb(){return Ea?!!Xa&&0<Xa.brands.length:!1}function cb(){return bb()?$a("Chromium"):(ab("Chrome")||ab("CriOS"))&&!(bb()?0:ab("Edge"))||ab("Silk")};const eb=Array.prototype.map?function(a,b,c){return Array.prototype.map.call(a,b,c)}:function(a,b,c){const d=a.length,e=Array(d),f="string"===typeof a?a.split(""):a;for(let g=0;g<d;g++)g in f&&(e[g]=b.call(c,f[g],g,a));return e};!ab("Android")||cb();cb();ab("Safari")&&(cb()||(bb()?0:ab("Coast"))||(bb()?0:ab("Opera"))||(bb()?0:ab("Edge"))||(bb()?$a("Microsoft Edge"):ab("Edg/"))||bb()&&$a("Opera"));class fb{}class gb{}Object.freeze(new fb);Object.freeze(new gb);/*

 Copyright Google LLC All Rights Reserved.

 Use of this source code is governed by an MIT-style license that can be
 found in the LICENSE file at https://angular.io/license
 @param {!tsickle_zone_impl_1.ZonePrivate} api
 @param {?} target
 @param {string} targetName
 @param {string} method
 @param {!Array<string>} callbacks
 @return {void}
*/
function hb(a,b,c,d,e){const f=Zone.__symbol__(d);if(!b[f]){var g=b[f]=b[d];b[d]=function(k,m,p){m&&m.prototype&&e.forEach(function(t){const v=`${c}.${d}::`+t,B=m.prototype;try{if(B.hasOwnProperty(t)){const G=a.ObjectGetOwnPropertyDescriptor(B,t);G&&G.value?(G.value=a.wrapWithCurrentZone(G.value,v),a._redefineProperty(m.prototype,t,G)):B[t]&&(B[t]=a.wrapWithCurrentZone(B[t],v))}else B[t]&&(B[t]=a.wrapWithCurrentZone(B[t],v))}catch(G){}});return g.call(b,k,m,p)};a.attachOriginToPatched(b[d],g)}};/*

 Copyright Google LLC All Rights Reserved.

 Use of this source code is governed by an MIT-style license that can be
 found in the LICENSE file at https://angular.io/license
*/
const jb=globalThis;function kb(a){return(jb.__Zone_symbol_prefix||"__zone_symbol__")+a}
function lb(){function a(F){g&&g.mark&&g.mark(F)}function b(F,M){g&&g.measure&&g.measure(F,M)}function c(F){aa||jb[B]&&(aa=jb[B].resolve(0));if(aa){let M=aa[G];M||(M=aa.then);M.call(aa,F)}else jb[v](F,0)}function d(F){0===la&&0===K.length&&c(e);F&&K.push(F)}function e(){if(!N){for(N=!0;K.length;){const F=K;K=[];for(let M=0;M<F.length;M++){const W=F[M];try{W.zone.runTask(W,null,null)}catch(Aa){O.onUnhandledError(Aa)}}}O.microtaskDrainDone();N=!1}}function f(){}const g=jb.performance;a("Zone");class k{static assertZonePatched(){if(jb.Promise!==
ia.ZoneAwarePromise)throw Error("Zone.js has detected that ZoneAwarePromise `(window|global).Promise` has been overwritten.\nMost likely cause is that a Promise polyfill has been loaded after Zone.js (Polyfilling Promise api is not necessary when zone.js is loaded. If you must load one, do so before loading zone.js.)");}static get root(){let F=k.current;for(;F.parent;)F=F.parent;return F}static get current(){return U.zone}static get currentTask(){return Q}static __load_patch(F,M,W=!1){if(ia.hasOwnProperty(F)){if(M=
!0===jb[kb("forceDuplicateZoneCheck")],!W&&M)throw Error("Already loaded patch: "+F);}else jb["__Zone_disable_"+F]||(W="Zone:"+F,a(W),ia[F]=M(jb,k,O),b(W,W))}get parent(){return this.Pa}get name(){return this.qh}constructor(F,M){this.Pa=F;this.qh=M?M.name||"unnamed":"<root>";this.C=M&&M.properties||{};this.i=new p(this,this.Pa&&this.Pa.i,M)}get(F){const M=this.getZoneWith(F);if(M)return M.C[F]}getZoneWith(F){let M=this;for(;M;){if(M.C.hasOwnProperty(F))return M;M=M.Pa}return null}fork(F){if(!F)throw Error("ZoneSpec required!");
return this.i.fork(this,F)}wrap(F,M){if("function"!==typeof F)throw Error("Expecting function got: "+F);const W=this.i.intercept(this,F,M),Aa=this;return function(){return Aa.runGuarded(W,this,arguments,M)}}run(F,M,W,Aa){U={parent:U,zone:this};try{return this.i.invoke(this,F,M,W,Aa)}finally{U=U.parent}}runGuarded(F,M=null,W,Aa){U={parent:U,zone:this};try{try{return this.i.invoke(this,F,M,W,Aa)}catch(qb){if(this.i.handleError(this,qb))throw qb;}}finally{U=U.parent}}runTask(F,M,W){if(F.zone!=this)throw Error("A task can only be run in the zone of creation! (Creation: "+
(F.zone||ca).name+"; Execution: "+this.name+")");if("notScheduled"!==F.state||"eventTask"!==F.type&&"macroTask"!==F.type){var Aa="running"!=F.state;Aa&&F.ud("running","scheduled");F.runCount++;var qb=Q;Q=F;U={parent:U,zone:this};try{"macroTask"==F.type&&F.data&&!F.data.isPeriodic&&(F.cancelFn=void 0);try{return this.i.invokeTask(this,F,M,W)}catch(wb){if(this.i.handleError(this,wb))throw wb;}}finally{"notScheduled"!==F.state&&"unknown"!==F.state&&("eventTask"==F.type||F.data&&F.data.isPeriodic?Aa&&
F.ud("scheduled","running"):(F.runCount=0,this.Ek(F,-1),Aa&&F.ud("notScheduled","running","notScheduled"))),U=U.parent,Q=qb}}}scheduleTask(F){if(F.zone&&F.zone!==this)for(var M=this;M;){if(M===F.zone)throw Error(`can not reschedule task to ${this.name} which is descendants of the original zone ${F.zone.name}`);M=M.parent}F.ud("scheduling","notScheduled");M=[];F.Qi=M;F.xb=this;try{F=this.i.scheduleTask(this,F)}catch(W){throw F.ud("unknown","scheduling","notScheduled"),this.i.handleError(this,W),W;
}F.Qi===M&&this.Ek(F,1);"scheduling"==F.state&&F.ud("scheduled","scheduling");return F}scheduleMicroTask(F,M,W,Aa){return this.scheduleTask(new t("microTask",F,M,W,Aa,void 0))}scheduleMacroTask(F,M,W,Aa,qb){return this.scheduleTask(new t("macroTask",F,M,W,Aa,qb))}scheduleEventTask(F,M,W,Aa,qb){return this.scheduleTask(new t("eventTask",F,M,W,Aa,qb))}cancelTask(F){if(F.zone!=this)throw Error("A task can only be cancelled in the zone of creation! (Creation: "+(F.zone||ca).name+"; Execution: "+this.name+
")");if("scheduled"===F.state||"running"===F.state){F.ud("canceling","scheduled","running");try{this.i.cancelTask(this,F)}catch(M){throw F.ud("unknown","canceling"),this.i.handleError(this,M),M;}this.Ek(F,-1);F.ud("notScheduled","canceling");F.runCount=0;return F}}Ek(F,M){const W=F.Qi;-1==M&&(F.Qi=null);for(let Aa=0;Aa<W.length;Aa++)W[Aa].Ek(F.type,M)}}k.__symbol__=kb;const m={name:"",onHasTask:(F,M,W,Aa)=>F.hasTask(W,Aa),onScheduleTask:(F,M,W,Aa)=>F.scheduleTask(W,Aa),onInvokeTask:(F,M,W,Aa,qb,wb)=>
F.invokeTask(W,Aa,qb,wb),onCancelTask:(F,M,W,Aa)=>F.cancelTask(W,Aa)};class p{get zone(){return this.xb}constructor(F,M,W){this.LA={microTask:0,macroTask:0,eventTask:0};this.xb=F;this.uF=M;this.pp=W&&(W&&W.onFork?W:M.pp);this.Bt=W&&(W.onFork?M:M.Bt);this.Pz=W&&(W.onFork?this.xb:M.Pz);this.xp=W&&(W.onIntercept?W:M.xp);this.Ut=W&&(W.onIntercept?M:M.Ut);this.Tt=W&&(W.onIntercept?this.xb:M.Tt);this.Ap=W&&(W.onInvoke?W:M.Ap);this.Xt=W&&(W.onInvoke?M:M.Xt);this.Vt=W&&(W.onInvoke?this.xb:M.Vt);this.rp=W&&
(W.onHandleError?W:M.rp);this.It=W&&(W.onHandleError?M:M.It);this.Ht=W&&(W.onHandleError?this.xb:M.Ht);this.Km=W&&(W.onScheduleTask?W:M.Km);this.Jp=W&&(W.onScheduleTask?M:M.Jp);this.Ip=W&&(W.onScheduleTask?this.xb:M.Ip);this.Am=W&&(W.onInvokeTask?W:M.Am);this.zp=W&&(W.onInvokeTask?M:M.zp);this.yp=W&&(W.onInvokeTask?this.xb:M.yp);this.rm=W&&(W.onCancelTask?W:M.rm);this.ip=W&&(W.onCancelTask?M:M.ip);this.hp=W&&(W.onCancelTask?this.xb:M.hp);this.Kt=this.Mt=this.Lt=this.qk=null;F=W&&W.onHasTask;const Aa=
M&&M.qk;if(F||Aa)this.qk=F?W:m,this.Lt=M,this.Mt=this,this.Kt=this.xb,W.onScheduleTask||(this.Km=m,this.Jp=M,this.Ip=this.xb),W.onInvokeTask||(this.Am=m,this.zp=M,this.yp=this.xb),W.onCancelTask||(this.rm=m,this.ip=M,this.hp=this.xb)}fork(F,M){return this.pp?this.pp.onFork(this.Bt,this.zone,F,M):new k(F,M)}intercept(F,M,W){return this.xp?this.xp.onIntercept(this.Ut,this.Tt,F,M,W):M}invoke(F,M,W,Aa,qb){return this.Ap?this.Ap.onInvoke(this.Xt,this.Vt,F,M,W,Aa,qb):M.apply(W,Aa)}handleError(F,M){return this.rp?
this.rp.onHandleError(this.It,this.Ht,F,M):!0}scheduleTask(F,M){let W=M;if(this.Km)this.qk&&W.Qi.push(this.Mt),(W=this.Km.onScheduleTask(this.Jp,this.Ip,F,M))||(W=M);else if(M.scheduleFn)M.scheduleFn(M);else if("microTask"==M.type)d(M);else throw Error("Task is missing scheduleFn.");return W}invokeTask(F,M,W,Aa){return this.Am?this.Am.onInvokeTask(this.zp,this.yp,F,M,W,Aa):M.callback.apply(W,Aa)}cancelTask(F,M){if(this.rm)F=this.rm.onCancelTask(this.ip,this.hp,F,M);else{if(!M.cancelFn)throw Error("Task is not cancelable");
F=M.cancelFn(M)}return F}hasTask(F,M){try{this.qk&&this.qk.onHasTask(this.Lt,this.Kt,F,M)}catch(W){this.handleError(F,W)}}Ek(F,M){const W=this.LA,Aa=W[F];M=W[F]=Aa+M;if(0>M)throw Error("More tasks executed then were scheduled.");0!=Aa&&0!=M||this.hasTask(this.xb,{NC:0<W.microTask,IC:0<W.macroTask,LF:0<W.eventTask,vb:F})}}class t{constructor(F,M,W,Aa,qb,wb){this.xb=null;this.runCount=0;this.Qi=null;this.nc="notScheduled";this.type=F;this.source=M;this.data=Aa;this.scheduleFn=qb;this.cancelFn=wb;if(!W)throw Error("callback is not defined");
this.callback=W;const Ja=this;this.invoke="eventTask"===F&&Aa&&Aa.Ls?t.invokeTask:function(){return t.invokeTask.call(jb,Ja,this,arguments)}}static invokeTask(F,M,W){F||(F=this);la++;try{return F.runCount++,F.zone.runTask(F,M,W)}finally{1==la&&e(),la--}}get zone(){return this.xb}get state(){return this.nc}cancelScheduleRequest(){this.ud("notScheduled","scheduling")}ud(F,M,W){if(this.nc===M||this.nc===W)this.nc=F,"notScheduled"==F&&(this.Qi=null);else throw Error(`${this.type} '${this.source}': can not transition to '${F}', expecting state '${M}'${W?
" or '"+W+"'":""}, was '${this.nc}'.`);}toString(){return this.data&&"undefined"!==typeof this.data.handleId?this.data.handleId.toString():Object.prototype.toString.call(this)}toJSON(){return{type:this.type,state:this.state,source:this.source,zone:this.zone.name,runCount:this.runCount}}}const v=kb("setTimeout"),B=kb("Promise"),G=kb("then");let K=[],N=!1,aa;const ca={name:"NO ZONE"},ia={},O={symbol:kb,currentZoneFrame:()=>U,onUnhandledError:f,microtaskDrainDone:f,scheduleMicroTask:d,showUncaughtError:()=>
!k[kb("ignoreConsoleErrorUncaughtError")],patchEventTarget:()=>[],patchOnProperties:f,patchMethod:()=>f,bindArguments:()=>[],patchThen:()=>f,patchMacroTask:()=>f,patchEventPrototype:()=>f,isIEOrEdge:()=>!1,getGlobalObjects:()=>{},ObjectDefineProperty:()=>f,ObjectGetOwnPropertyDescriptor:()=>{},ObjectCreate:()=>{},ArraySlice:()=>[],patchClass:()=>f,wrapWithCurrentZone:()=>f,filterProperties:()=>[],attachOriginToPatched:()=>f,_redefineProperty:()=>f,patchCallbacks:()=>f,nativeScheduleMicroTask:c};let U=
{parent:null,zone:new k(null,null)},Q=null,la=0;b("Zone","Zone");return k};var mb=Object.getOwnPropertyDescriptor,nb=Object.defineProperty,ob=Object.getPrototypeOf,rb=Object.create,sb=Array.prototype.slice,xb=kb("addEventListener"),yb=kb("removeEventListener"),zb=kb("");function Ab(a,b){return Zone.current.wrap(a,b)}const Bb="undefined"!==typeof window,Cb=Bb?window:void 0,Eb=Bb&&Cb||globalThis;function Gb(a,b){for(let c=a.length-1;0<=c;c--)"function"===typeof a[c]&&(a[c]=Ab(a[c],b+"_"+c));return a}
function Hb(a){var b=["getCurrentPosition","watchPosition"];const c=a.constructor.name;for(let d=0;d<b.length;d++){const e=b[d],f=a[e];if(f){const g=mb(a,e);Ib(g)&&(a[e]=(k=>{function m(){return k.apply(this,Gb(arguments,c+"."+e))}Jb(m,k);return m})(f))}}}function Ib(a){return a?!1===a.writable?!1:!("function"===typeof a.get&&"undefined"===typeof a.set):!0}
var Kb="undefined"!==typeof WorkerGlobalScope&&self instanceof WorkerGlobalScope,Lb=!("nw"in Eb)&&"undefined"!==typeof Eb.process&&"[object process]"===Eb.process.toString(),Mb=!Lb&&!Kb&&!(!Bb||!Cb.HTMLElement),Nb="undefined"!==typeof Eb.process&&"[object process]"===Eb.process.toString()&&!Kb&&!(!Bb||!Cb.HTMLElement);const Ob={};
function Pb(a){if(a=a||Eb.event){var b=Ob[a.type];b||(b=Ob[a.type]=kb("ON_PROPERTY"+a.type));var c=this||a.target||Eb;b=c[b];Mb&&c===Cb&&"error"===a.type?(c=a,c=b&&b.call(this,c.message,c.filename,c.lineno,c.colno,c.error),!0===c&&a.preventDefault()):(c=b&&b.apply(this,arguments),void 0==c||c||a.preventDefault());return c}}
function Sb(a,b,c){let d=mb(a,b);!d&&c&&mb(c,b)&&(d={enumerable:!0,configurable:!0});if(d&&d.configurable&&(c=kb("on"+b+"patched"),!a.hasOwnProperty(c)||!a[c])){delete d.writable;delete d.value;var e=d.get,f=d.set,g=b.slice(2),k=Ob[g];k||(k=Ob[g]=kb("ON_PROPERTY"+g));d.set=function(m){let p=this;p||a!==Eb||(p=Eb);p&&("function"===typeof p[k]&&p.removeEventListener(g,Pb),f&&f.call(p,null),p[k]=m,"function"===typeof m&&p.addEventListener(g,Pb,!1))};d.get=function(){let m=this;m||a!==Eb||(m=Eb);if(!m)return null;
var p=m[k];return p?p:e&&(p=e.call(this))?(d.set.call(this,p),"function"===typeof m.removeAttribute&&m.removeAttribute(b),p):null};nb(a,b,d);a[c]=!0}}function Tb(a,b,c){if(b)for(var d=0;d<b.length;d++)Sb(a,"on"+b[d],c);else{b=[];for(d in a)"on"==d.slice(0,2)&&b.push(d);for(d=0;d<b.length;d++)Sb(a,b[d],c)}}const Yb=kb("originalInstance");
function Zb(a){const b=Eb[a];if(b){Eb[kb(a)]=b;Eb[a]=function(){const e=Gb(arguments,a);switch(e.length){case 0:this[Yb]=new b;break;case 1:this[Yb]=new b(e[0]);break;case 2:this[Yb]=new b(e[0],e[1]);break;case 3:this[Yb]=new b(e[0],e[1],e[2]);break;case 4:this[Yb]=new b(e[0],e[1],e[2],e[3]);break;default:throw Error("Arg list too long.");}};Jb(Eb[a],b);var c=new b(function(){}),d;for(d in c)"XMLHttpRequest"===a&&"responseBlob"===d||function(e){"function"===typeof c[e]?Eb[a].prototype[e]=function(){return this[Yb][e].apply(this[Yb],
arguments)}:nb(Eb[a].prototype,e,{set:function(f){"function"===typeof f?(this[Yb][e]=Ab(f,a+"."+e),Jb(this[Yb][e],f)):this[Yb][e]=f},get:function(){return this[Yb][e]}})}(d);for(d in b)"prototype"!==d&&b.hasOwnProperty(d)&&(Eb[a][d]=b[d])}}
function $b(a,b,c){let d=a;for(;d&&!d.hasOwnProperty(b);)d=ob(d);!d&&a[b]&&(d=a);a=kb(b);let e=null;if(d&&(!(e=d[a])||!d.hasOwnProperty(a))){e=d[a]=d[b];const f=d&&mb(d,b);if(Ib(f)){const g=c(e,a,b);d[b]=function(){return g(this,arguments)};Jb(d[b],e)}}return e}
function ac(a,b,c){function d(f){const g=f.data;g.Xe[g.Ym]=function(){f.invoke.apply(this,arguments)};e.apply(g.target,g.Xe);return f}let e=null;e=$b(a,b,f=>function(g,k){const m=c(g,k);return 0<=m.Ym&&"function"===typeof k[m.Ym]?Zone.current.scheduleMacroTask(m.name,k[m.Ym],m,d,void 0):f.apply(g,k)})}function Jb(a,b){a[kb("OriginalDelegate")]=b}let bc=!1,cc=!1;
function dc(){if(bc)return cc;bc=!0;try{const a=Cb.navigator.userAgent;if(-1!==a.indexOf("MSIE ")||-1!==a.indexOf("Trident/")||-1!==a.indexOf("Edge/"))cc=!0}catch(a){}return cc};function fc(a,b,c){if(!c||0===c.length)return b;c=c.filter(e=>e.target===a);if(!c||0===c.length)return b;const d=c[0].kC;return b.filter(e=>-1===d.indexOf(e))}function gc(a){return Object.getOwnPropertyNames(a).filter(b=>b.startsWith("on")&&2<b.length).map(b=>b.substring(2))};let hc=!1;if("undefined"!==typeof window)try{const a=Object.defineProperty({},"passive",{get:function(){hc=!0}});window.addEventListener("test",a,a);window.removeEventListener("test",a,a)}catch(a){hc=!1}const ic={Ls:!0};var kc={},nc={};const oc=new RegExp("^"+zb+"(\\w+)(true|false)$"),qc=kb("propagationStopped");function rc(a,b){var c=(b?b(a):a)+"false";b=(b?b(a):a)+"true";c=zb+c;b=zb+b;kc[a]={};kc[a]["false"]=c;kc[a]["true"]=b}
function sc(a,b,c,d){function e(aa){return k(this,aa,!0)}function f(aa){return k(this,aa,!1)}function g(aa,ca,ia){if(!aa.hr){var O=aa.callback;"object"===typeof O&&O.handleEvent&&(aa.callback=la=>O.handleEvent(la),aa.hf=O);try{aa.invoke(aa,ca,[ia])}catch(la){var U=la}var Q=aa.options;Q&&"object"===typeof Q&&Q.once&&ca[t].call(ca,ia.type,aa.hf?aa.hf:aa.callback,Q);return U}}function k(aa,ca,ia){if(ca=ca||a.event){aa=aa||ca.target||a;var O=aa[kc[ca.type][ia?"true":"false"]];if(O){ia=[];if(1===O.length)(ca=
g(O[0],aa,ca))&&ia.push(ca);else{O=O.slice();for(let U=0;U<O.length&&(!ca||!0!==ca[qc]);U++){const Q=g(O[U],aa,ca);Q&&ia.push(Q)}}if(1===ia.length)throw ia[0];for(ca=0;ca<ia.length;ca++){const U=ia[ca];b.nativeScheduleMicroTask(()=>{throw U;})}}}}function m(aa,ca){function ia(pa,Ga,Sa,db,Xb=!1,od=!1){return function(){const vc=this||a;let ec=arguments[0];ca&&ca.Xg&&(ec=ca.Xg(ec));let pc=arguments[1];if(!pc||Lb&&"uncaughtException"===ec)return pa.apply(this,arguments);let Ud=!1;if("function"!==typeof pc){if(!pc.handleEvent)return pa.apply(this,
arguments);Ud=!0}if(!Aa||Aa(pa,pc,vc,arguments)){var Dc=hc&&!!ib&&-1!==ib.indexOf(ec),jc=M(arguments[2],Dc),re=null==jc?void 0:jc.signal;if(null==re||!re.aborted){if(Ia)for(var Ze=0;Ze<Ia.length;Ze++)if(ec===Ia[Ze])return Dc?pa.call(vc,ec,pc,jc):pa.apply(this,arguments);Dc=jc?"boolean"===typeof jc?!0:jc.capture:!1;Ze=jc&&"object"===typeof jc?jc.once:!1;var Mk=Zone.current,Sc=kc[ec];Sc||(rc(ec,Ub),Sc=kc[ec]);var Vb=Sc[Dc?"true":"false"];Sc=vc[Vb];var pd=!1;if(Sc){if(pd=!0,qb)for(Vb=0;Vb<Sc.length;Vb++)if(Qa(Sc[Vb],
pc))return}else Sc=vc[Vb]=[];var zg;Vb=vc.constructor.name;var Bn=nc[Vb];Bn&&(zg=Bn[ec]);zg||(zg=Vb+Ga+(Ub?Ub(ec):ec));Na.options=jc;Ze&&(Na.options.once=!1);Na.target=vc;Na.capture=Dc;Na.Ih=ec;Na.vC=pd;if(pd=W?ic:void 0)pd.uE=Na;re&&(Na.options.signal=void 0);var fd=Mk.scheduleEventTask(zg,pc,pd,Sa,db);if(re){Na.options.signal=re;const qd=()=>fd.zone.cancelTask(fd);pa.call(re,"abort",qd,{once:!0});pd&&(pd.Yr=()=>re.removeEventListener("abort",qd))}Na.target=null;pd&&(pd.uE=null);Ze&&(jc.once=!0);
if(hc||"boolean"!==typeof fd.options)fd.options=jc;fd.target=vc;fd.capture=Dc;fd.Ih=ec;Ud&&(fd.hf=pc);od?Sc.unshift(fd):Sc.push(fd);if(Xb)return vc}}}}function O(pa,Ga){const Sa=typeof Ga;return"function"===Sa&&pa.callback===Ga||"object"===Sa&&pa.hf===Ga}function U(pa){return T.call(pa.target,pa.Ih,pa.invoke,pa.options)}function Q(pa){return na.call(Na.target,Na.Ih,pa.invoke,Na.options)}function la(pa){return qa.call(Na.target,Na.Ih,pa.invoke,Na.options)}function F(pa){if(!pa.hr){var Ga=kc[pa.Ih];
let Sa;Ga&&(Sa=Ga[pa.capture?"true":"false"]);if(Ga=Sa&&pa.target[Sa])for(let db=0;db<Ga.length;db++)if(Ga[db]===pa){Ga.splice(db,1);pa.hr=!0;0===Ga.length&&(pa.Cu=!0,pa.target[Sa]=null);break}}if(pa.Cu)return T.call(pa.target,pa.Ih,pa.capture?e:f,pa.options)}function M(pa,Ga){return!hc&&"object"===typeof pa&&pa?!!pa.capture:hc&&Ga?"boolean"===typeof pa?{capture:pa,passive:!0}:pa?"object"===typeof pa&&!1!==pa.passive?Object.assign({},pa,{passive:!0}):pa:{passive:!0}:pa}if(!aa)return!1;let W=!0;ca&&
void 0!==ca.Ls&&(W=ca.Ls);const Aa=ca&&ca.RE;let qb=!0;ca&&void 0!==ca.eB&&(qb=ca.eB);let wb=!1;ca&&void 0!==ca.MD&&(wb=ca.MD);let Ja=aa;for(;Ja&&!Ja.hasOwnProperty(p);)Ja=ob(Ja);!Ja&&aa[p]&&(Ja=aa);if(!Ja||Ja[G])return!1;const Ub=ca&&ca.KF,Na={},qa=Ja[G]=Ja[p],T=Ja[kb(t)]=Ja[t];aa=Ja[kb(v)]=Ja[v];const ea=Ja[kb(B)]=Ja[B];let na;ca&&ca.prepend&&(na=Ja[kb(ca.prepend)]=Ja[ca.prepend]);const Ka=W?F:U,Qa=ca&&ca.ln?ca.ln:O,Ia=Zone[kb("UNPATCHED_EVENTS")],ib=a[kb("PASSIVE_EVENTS")];Ja[p]=ia(qa,K,W?function(){if(!Na.vC)return qa.call(Na.target,
Na.Ih,Na.capture?e:f,Na.options)}:la,Ka,wb);na&&(Ja.prependListener=ia(na,".prependListener:",Q,Ka,wb,!0));Ja[t]=function(){const pa=this||a;var Ga=arguments[0];ca&&ca.Xg&&(Ga=ca.Xg(Ga));var Sa=arguments[2];Sa=Sa?"boolean"===typeof Sa?!0:Sa.capture:!1;const db=arguments[1];if(!db)return T.apply(this,arguments);if(!Aa||Aa(T,db,pa,arguments)){var Xb=kc[Ga],od;Xb&&(od=Xb[Sa?"true":"false"]);var vc=od&&pa[od];if(vc)for(let ec=0;ec<vc.length;ec++)if(Xb=vc[ec],Qa(Xb,db)){vc.splice(ec,1);Xb.hr=!0;0===vc.length&&
(Xb.Cu=!0,pa[od]=null,Sa||"string"!==typeof Ga||(pa[zb+"ON_PROPERTY"+Ga]=null));Ga=Xb.data;let pc;if(null==(pc=Ga)?0:pc.Yr)Ga.Yr(),Ga.Yr=null;Xb.zone.cancelTask(Xb);if(wb)return pa;return}return T.apply(this,arguments)}};Ja[v]=function(pa){var Ga=this||a,Sa=pa;ca&&ca.Xg&&(Sa=ca.Xg(Sa));pa=[];Ga=tc(Ga,Ub?Ub(Sa):Sa);for(Sa=0;Sa<Ga.length;Sa++){const db=Ga[Sa];pa.push(db.hf?db.hf:db.callback)}return pa};Ja[B]=function(pa){var Ga=this||a;if(pa){ca&&ca.Xg&&(pa=ca.Xg(pa));var Sa=kc[pa];if(Sa){var db=Ga[Sa["false"]];
Ga=Ga[Sa["true"]];if(db)for(db=db.slice(),Sa=0;Sa<db.length;Sa++){const Xb=db[Sa];this[t].call(this,pa,Xb.hf?Xb.hf:Xb.callback,Xb.options)}if(Ga)for(Ga=Ga.slice(),db=0;db<Ga.length;db++)Sa=Ga[db],this[t].call(this,pa,Sa.hf?Sa.hf:Sa.callback,Sa.options)}}else{pa=Object.keys(Ga);for(Ga=0;Ga<pa.length;Ga++)(db=(db=oc.exec(pa[Ga]))&&db[1])&&"removeListener"!==db&&this[B].call(this,db);this[B].call(this,"removeListener")}if(wb)return this};Jb(Ja[p],qa);Jb(Ja[t],T);ea&&Jb(Ja[B],ea);aa&&Jb(Ja[v],aa);return!0}
const p=d&&d.add||"addEventListener",t=d&&d.qG||"removeEventListener",v=d&&d.VF||"eventListeners",B=d&&d.rG||"removeAllListeners",G=kb(p),K="."+p+":";let N=[];for(let aa=0;aa<c.length;aa++)N[aa]=m(c[aa],d);return N}function tc(a,b){if(!b){var c=[];for(let e in a){var d=oc.exec(e);if((d=d&&d[1])&&(!b||d===b)&&(d=a[e]))for(let f=0;f<d.length;f++)c.push(d[f])}return c}c=kc[b];c||(rc(b),c=kc[b]);b=a[c["false"]];a=a[c["true"]];return b?a?b.concat(a):b.slice():a?a.slice():[]}
function wc(a,b){(a=a.Event)&&a.prototype&&b.patchMethod(a.prototype,"stopImmediatePropagation",c=>function(d,e){d[qc]=!0;c&&c.apply(d,e)})};function xc(){yc.__load_patch("util",(a,b,c)=>{const d=gc(a);c.patchOnProperties=Tb;c.patchMethod=$b;c.bindArguments=Gb;c.patchMacroTask=ac;const e=b.__symbol__("BLACK_LISTED_EVENTS"),f=b.__symbol__("UNPATCHED_EVENTS");a[f]&&(a[e]=a[f]);a[e]&&(b[e]=b[f]=a[e]);c.patchEventPrototype=wc;c.patchEventTarget=sc;c.isIEOrEdge=dc;c.ObjectDefineProperty=nb;c.ObjectGetOwnPropertyDescriptor=mb;c.ObjectCreate=rb;c.ArraySlice=sb;c.patchClass=Zb;c.wrapWithCurrentZone=Ab;c.filterProperties=fc;c.attachOriginToPatched=
Jb;c._redefineProperty=Object.defineProperty;c.patchCallbacks=hb;c.getGlobalObjects=()=>({globalSources:nc,zoneSymbolEventNames:kc,eventNames:d,isBrowser:Mb,isMix:Nb,isNode:Lb,TRUE_STR:"true",FALSE_STR:"false",ZONE_SYMBOL_PREFIX:zb,ADD_EVENT_LISTENER_STR:"addEventListener",REMOVE_EVENT_LISTENER_STR:"removeEventListener"})})};let zc,Ac,Bc,Cc,Ec;
function Fc(){zc=Zone.__symbol__;Ac=Object[zc("defineProperty")]=Object.defineProperty;Bc=Object[zc("getOwnPropertyDescriptor")]=Object.getOwnPropertyDescriptor;Cc=Object.create;Ec=zc("unconfigurables");Object.defineProperty=function(a,b,c){if(a&&a[Ec]&&a[Ec][b])throw new TypeError("Cannot assign to read only property '"+b+"' of "+a);const d=c.configurable;"prototype"!==b&&(c=Gc(a,b,c));return Hc(a,b,c,d)};Object.defineProperties=function(a,b){Object.keys(b).forEach(function(c){Object.defineProperty(a,c,
b[c])});for(const c of Object.getOwnPropertySymbols(b)){let d;(null==(d=Object.getOwnPropertyDescriptor(b,c))?0:d.enumerable)&&Object.defineProperty(a,c,b[c])}return a};Object.create=function(a,b){"object"!==typeof b||Object.isFrozen(b)||Object.keys(b).forEach(function(c){b[c]=Gc(a,c,b[c])});return Cc(a,b)};Object.getOwnPropertyDescriptor=function(a,b){const c=Bc(a,b);c&&a&&a[Ec]&&a[Ec][b]&&(c.configurable=!1);return c}}function Ic(a,b,c){const d=c.configurable;c=Gc(a,b,c);return Hc(a,b,c,d)}
function Gc(a,b,c){Object.isFrozen(c)||(c.configurable=!0);c.configurable||(a[Ec]||Object.isFrozen(a)||Ac(a,Ec,{writable:!0,value:{}}),a[Ec]&&(a[Ec][b]=!0));return c}
function Hc(a,b,c,d){try{return Ac(a,b,c)}catch(e){if(c.configurable){"undefined"==typeof d?delete c.configurable:c.configurable=d;try{return Ac(a,b,c)}catch(f){d=!1;if("createdCallback"===b||"attachedCallback"===b||"detachedCallback"===b||"attributeChangedCallback"===b)d=!0;if(!d)throw f;d=null;try{d=JSON.stringify(c)}catch(g){d=c.toString()}console.log(`Attempting to configure '${b}' with descriptor '${d}' on object '${a}' and got error, giving up: ${f}`)}}else throw e;}};function Lc(a,b){const {eventNames:c,globalSources:d,zoneSymbolEventNames:e,TRUE_STR:f,FALSE_STR:g,ZONE_SYMBOL_PREFIX:k}=b.getGlobalObjects();var m="ApplicationCache EventSource FileReader InputMethodContext MediaController MessagePort Node Performance SVGElementInstance SharedWorker TextTrack TextTrackCue TextTrackList WebKitNamedFlow Window Worker WorkerGlobalScope XMLHttpRequest XMLHttpRequestEventTarget XMLHttpRequestUpload IDBRequest IDBOpenDBRequest IDBDatabase IDBTransaction IDBCursor DBIndex WebSocket".split(" ");
let p=[];var t="Anchor Area Audio BR Base BaseFont Body Button Canvas Content DList Directory Div Embed FieldSet Font Form Frame FrameSet HR Head Heading Html IFrame Image Input Keygen LI Label Legend Link Map Marquee Media Menu Meta Meter Mod OList Object OptGroup Option Output Paragraph Pre Progress Quote Script Select Source Span Style TableCaption TableCell TableCol Table TableRow TableSection TextArea Title Track UList Unknown Video".split(" ");a.wtf?p=t.map(ia=>"HTML"+ia+"Element").concat(m):
a.EventTarget?p.push("EventTarget"):p=m;const v=a.__Zone_disable_IE_check||!1,B=a.__Zone_enable_cross_context_check||!1,G=b.isIEOrEdge(),K={MSPointerCancel:"pointercancel",MSPointerDown:"pointerdown",MSPointerEnter:"pointerenter",MSPointerHover:"pointerhover",MSPointerLeave:"pointerleave",MSPointerMove:"pointermove",MSPointerOut:"pointerout",MSPointerOver:"pointerover",MSPointerUp:"pointerup"};for(m=0;m<c.length;m++){var N=c[m],aa=k+(N+g),ca=k+(N+f);e[N]={};e[N][g]=aa;e[N][f]=ca}for(m=0;m<t.length;m++)for(N=
t[m],aa=d[N]={},ca=0;ca<c.length;ca++){const ia=c[ca];aa[ia]=N+".addEventListener:"+ia}t=[];for(m=0;m<p.length;m++)N=a[p[m]],t.push(N&&N.prototype);b.patchEventTarget(a,b,t,{RE:function(ia,O,U,Q){if(!v&&G)if(B)try{const la=O.toString();if("[object FunctionWrapper]"===la||"function __BROWSERTOOLS_CONSOLE_SAFEFUNC() { [native code] }"==la)return ia.apply(U,Q),!1}catch(la){return ia.apply(U,Q),!1}else{if(O=O.toString(),"[object FunctionWrapper]"===O||"function __BROWSERTOOLS_CONSOLE_SAFEFUNC() { [native code] }"==
O)return ia.apply(U,Q),!1}else if(B)try{O.toString()}catch(la){return ia.apply(U,Q),!1}return!0},Xg:ia=>K[ia]||ia});Zone[b.symbol("patchEventTarget")]=!!a.EventTarget};function Mc(a,b){const {ADD_EVENT_LISTENER_STR:c,REMOVE_EVENT_LISTENER_STR:d}=a.getGlobalObjects(),e=b.WebSocket;b.EventTarget||a.patchEventTarget(b,a,[e.prototype]);b.WebSocket=function(g,k){const m=1<arguments.length?new e(g,k):new e(g);let p,t;const v=a.ObjectGetOwnPropertyDescriptor(m,"onmessage");v&&!1===v.configurable?(p=a.ObjectCreate(m),t=m,[c,d,"send","close"].forEach(function(B){p[B]=function(){const G=a.ArraySlice.call(arguments);if(B===c||B===d){var K=0<G.length?G[0]:void 0;K&&(K=Zone.__symbol__("ON_PROPERTY"+
K),m[K]=p[K])}return m[B].apply(m,G)}})):p=m;a.patchOnProperties(p,["close","error","message","open"],t);return p};const f=b.WebSocket;for(const g in e)f[g]=e[g]};function Nc(a,b){const {isBrowser:c,isMix:d}=a.getGlobalObjects();if((c||d)&&!a.ObjectGetOwnPropertyDescriptor(HTMLElement.prototype,"onclick")&&"undefined"!==typeof Element){var e=a.ObjectGetOwnPropertyDescriptor(Element.prototype,"onclick");if(e&&!e.configurable)return!1;if(e){a.ObjectDefineProperty(Element.prototype,"onclick",{enumerable:!0,configurable:!0,get:function(){return!0}});var f=!!document.createElement("div").onclick;a.ObjectDefineProperty(Element.prototype,"onclick",e);return f}}var g=
b.XMLHttpRequest;if(!g)return!1;e=g.prototype;if(f=a.ObjectGetOwnPropertyDescriptor(e,"onreadystatechange"))return a.ObjectDefineProperty(e,"onreadystatechange",{enumerable:!0,configurable:!0,get:function(){return!0}}),g=!!(new g).onreadystatechange,a.ObjectDefineProperty(e,"onreadystatechange",f||{}),g;const k=a.symbol("fake");a.ObjectDefineProperty(e,"onreadystatechange",{enumerable:!0,configurable:!0,get:function(){return this[k]},set:function(m){this[k]=m}});a=new g;e=()=>{};a.onreadystatechange=
e;e=a[k]===e;a.onreadystatechange=null;return e}const Oc="abort animationcancel animationend animationiteration auxclick beforeinput blur cancel canplay canplaythrough change compositionstart compositionupdate compositionend cuechange click close contextmenu curechange dblclick drag dragend dragenter dragexit dragleave dragover drop durationchange emptied ended error focus focusin focusout gotpointercapture input invalid keydown keypress keyup load loadstart loadeddata loadedmetadata lostpointercapture mousedown mouseenter mouseleave mousemove mouseout mouseover mouseup mousewheel orientationchange pause play playing pointercancel pointerdown pointerenter pointerleave pointerlockchange mozpointerlockchange webkitpointerlockerchange pointerlockerror mozpointerlockerror webkitpointerlockerror pointermove pointout pointerover pointerup progress ratechange reset resize scroll seeked seeking select selectionchange selectstart show sort stalled submit suspend timeupdate volumechange touchcancel touchmove touchstart touchend transitioncancel transitionend waiting wheel webglcontextrestored webglcontextlost webglcontextcreationerror autocomplete autocompleteerror toggle afterscriptexecute beforescriptexecute DOMContentLoaded freeze fullscreenchange mozfullscreenchange webkitfullscreenchange msfullscreenchange fullscreenerror mozfullscreenerror webkitfullscreenerror msfullscreenerror readystatechange visibilitychange resume absolutedeviceorientation afterinput afterprint appinstalled beforeinstallprompt beforeprint beforeunload devicelight devicemotion deviceorientation deviceorientationabsolute deviceproximity hashchange languagechange message mozbeforepaint offline online paint pageshow pagehide popstate rejectionhandled storage unhandledrejection unload userproximity vrdisplayconnected vrdisplaydisconnected vrdisplaypresentchange beforecopy beforecut beforepaste copy cut paste dragstart loadend animationstart search transitionrun transitionstart webkitanimationend webkitanimationiteration webkitanimationstart webkittransitionend activate afterupdate ariarequest beforeactivate beforedeactivate beforeeditfocus beforeupdate cellchange controlselect dataavailable datasetchanged datasetcomplete errorupdate filterchange layoutcomplete losecapture move moveend movestart propertychange resizeend resizestart rowenter rowexit rowsdelete rowsinserted command compassneedscalibration deactivate help mscontentzoom msmanipulationstatechanged msgesturechange msgesturedoubletap msgestureend msgesturehold msgesturestart msgesturetap msgotpointercapture msinertiastart mslostpointercapture mspointercancel mspointerdown mspointerenter mspointerhover mspointerleave mspointermove mspointerout mspointerover mspointerup pointerout mssitemodejumplistitemremoved msthumbnailclick stop storagecommit".split(" ");
function Pc(a){const b=a.symbol("unbound");for(let c=0;c<Oc.length;c++){const d=Oc[c],e="on"+d;self.addEventListener(d,function(f){f=f.target;let g,k;for(k=f?f.constructor.name+"."+e:"unknown."+e;f;)f[e]&&!f[e][b]&&(g=a.wrapWithCurrentZone(f[e],k),g[b]=f[e],f[e]=g),f=f.parentElement},!0)}};function Qc(){const a="undefined"!==typeof window?window:"undefined"!==typeof global?global:"undefined"!==typeof self?self:{};a[(a.__Zone_symbol_prefix||"__zone_symbol__")+"legacyPatch"]=function(){const b=a.Zone;b.__load_patch("defineProperty",(c,d,e)=>{e._redefineProperty=Ic;Fc()});b.__load_patch("registerElement",(c,d,e)=>{const {isBrowser:f,isMix:g}=e.getGlobalObjects();(f||g)&&"registerElement"in c.document&&e.patchCallbacks(e,document,"Document","registerElement",["createdCallback","attachedCallback",
"detachedCallback","attributeChangedCallback"])});b.__load_patch("EventTargetLegacy",(c,d,e)=>{Lc(c,e);const {isNode:f,isMix:g}=e.getGlobalObjects();f&&!g||Nc(e,c)||(d="undefined"!==typeof WebSocket,Pc(e),e.patchClass("XMLHttpRequest"),d&&Mc(e,c),Zone[e.symbol("patchEvents")]=!0)})}};function Tc(a,b){b.patchMethod(a,"queueMicrotask",()=>function(c,d){Zone.current.scheduleMicroTask("queueMicrotask",d[0])})};const Uc=kb("zoneTask");
function Vc(a,b,c,d){function e(p){const t=p.data;t.Xe[0]=function(){return p.invoke.apply(this,arguments)};t.handleId=g.apply(a,t.Xe);return p}function f(p){return k.call(a,p.data.handleId)}let g=null,k=null;b+=d;c+=d;const m={};g=$b(a,b,p=>function(t,v){if("function"===typeof v[0]){const B={isPeriodic:"Interval"===d,delay:"Timeout"===d||"Interval"===d?v[1]||0:void 0,Xe:v},G=v[0];v[0]=function(){try{return G.apply(this,arguments)}finally{B.isPeriodic||("number"===typeof B.handleId?delete m[B.handleId]:
B.handleId&&(B.handleId[Uc]=null))}};t=Zone.current.scheduleMacroTask(b,v[0],B,e,f);if(!t)return t;v=t.data.handleId;"number"===typeof v?m[v]=t:v&&(v[Uc]=t);v&&v.Hj&&v.Js&&"function"===typeof v.Hj&&"function"===typeof v.Js&&(t.Hj=v.Hj.bind(v),t.Js=v.Js.bind(v));return"number"===typeof v||v?v:t}return p.apply(a,v)});k=$b(a,c,p=>function(t,v){t=v[0];let B;"number"===typeof t?B=m[t]:(B=t&&t[Uc])||(B=t);B&&"string"===typeof B.type?"notScheduled"!==B.state&&(B.cancelFn&&B.data.isPeriodic||0===B.runCount)&&
("number"===typeof t?delete m[t]:t&&(t[Uc]=null),B.zone.cancelTask(B)):p.apply(a,v)})};function Wc(){var a=yc;a.__load_patch("legacy",b=>{(b=b[a.__symbol__("legacyPatch")])&&b()});a.__load_patch("timers",b=>{Vc(b,"set","clear","Timeout");Vc(b,"set","clear","Interval");Vc(b,"set","clear","Immediate")});a.__load_patch("requestAnimationFrame",b=>{Vc(b,"request","cancel","AnimationFrame");Vc(b,"mozRequest","mozCancel","AnimationFrame");Vc(b,"webkitRequest","webkitCancel","AnimationFrame")});a.__load_patch("blocking",(b,c)=>{const d=["alert","prompt","confirm"];for(let e=0;e<d.length;e++)$b(b,
d[e],(f,g,k)=>function(m,p){return c.current.run(f,b,p,k)})});a.__load_patch("EventTarget",(b,c,d)=>{d.patchEventPrototype(b,d);if(!Zone[d.symbol("patchEventTarget")]){var {eventNames:e,zoneSymbolEventNames:f,TRUE_STR:g,FALSE_STR:k,ZONE_SYMBOL_PREFIX:m}=d.getGlobalObjects();for(c=0;c<e.length;c++){const p=e[c],t=m+(p+k),v=m+(p+g);f[p]={};f[p][k]=t;f[p][g]=v}(c=b.EventTarget)&&c.prototype&&d.patchEventTarget(b,d,[c&&c.prototype])}(c=b.XMLHttpRequestEventTarget)&&c.prototype&&d.patchEventTarget(b,d,
[c.prototype])});a.__load_patch("MutationObserver",()=>{Zb("MutationObserver");Zb("WebKitMutationObserver")});a.__load_patch("IntersectionObserver",()=>{Zb("IntersectionObserver")});a.__load_patch("FileReader",()=>{Zb("FileReader")});a.__load_patch("on_property",(b,c,d)=>{if((!Lb||Nb)&&!Zone[d.symbol("patchEvents")]){c=b.__Zone_ignore_on_properties;d=[];if(Mb){var e=window;d=d.concat("Document SVGElement Element HTMLElement HTMLBodyElement HTMLMediaElement HTMLFrameSetElement HTMLFrameElement HTMLIFrameElement HTMLMarqueeElement Worker".split(" "));
a:{try{var f=Cb.navigator.userAgent;if(-1!==f.indexOf("MSIE ")||-1!==f.indexOf("Trident/")){var g=!0;break a}}catch(m){}g=!1}var k=g?[{target:e,kC:["error"]}]:[];g=e;f=gc(e);k=c?c.concat(k):c;e=ob(e);g&&(f=fc(g,f,k),Tb(g,f,e))}d=d.concat("XMLHttpRequest XMLHttpRequestEventTarget IDBIndex IDBRequest IDBOpenDBRequest IDBDatabase IDBTransaction IDBCursor WebSocket".split(" "));for(e=0;e<d.length;e++)(f=b[d[e]])&&f.prototype&&(g=f.prototype,f=gc(f.prototype),g&&(f=fc(g,f,c),Tb(g,f,void 0)))}});a.__load_patch("customElements",
(b,c,d)=>{const {isBrowser:e,isMix:f}=d.getGlobalObjects();(e||f)&&b.customElements&&"customElements"in b&&d.patchCallbacks(d,b.customElements,"customElements","define","connectedCallback disconnectedCallback adoptedCallback attributeChangedCallback formAssociatedCallback formDisabledCallback formResetCallback formStateRestoreCallback".split(" "))});a.__load_patch("XHR",(b,c)=>{(function(p){function t(Q){const la=Q.data,F=la.target;F[g]=!1;F[m]=!1;var M=F[f];K||(K=F[xb],N=F[yb]);M&&N.call(F,"readystatechange",
M);M=F[f]=()=>{if(F.readyState===F.DONE)if(!la.aborted&&F[g]&&"scheduled"===Q.state){const W=F[c.__symbol__("loadfalse")];if(0!==F.status&&W&&0<W.length){const Aa=Q.invoke;Q.invoke=function(){const qb=F[c.__symbol__("loadfalse")];for(let wb=0;wb<qb.length;wb++)qb[wb]===Q&&qb.splice(wb,1);la.aborted||"scheduled"!==Q.state||Aa.call(Q)};W.push(Q)}else Q.invoke()}else la.aborted||!1!==F[g]||(F[m]=!0)};K.call(F,"readystatechange",M);F[d]||(F[d]=Q);O.apply(F,la.Xe);F[g]=!0;return Q}function v(){}function B(Q){Q=
Q.data;Q.aborted=!0;return U.apply(Q.target,Q.Xe)}var G=p.XMLHttpRequest;if(G){G=G.prototype;var K=G[xb],N=G[yb];!K&&(p=p.XMLHttpRequestEventTarget)&&(p=p.prototype,K=p[xb],N=p[yb]);var aa=$b(G,"open",()=>function(Q,la){Q[e]=0==la[2];Q[k]=la[1];return aa.apply(Q,la)}),ca=kb("fetchTaskAborting"),ia=kb("fetchTaskScheduling"),O=$b(G,"send",()=>function(Q,la){if(!0===c.current[ia]||Q[e])return O.apply(Q,la);la={target:Q,url:Q[k],isPeriodic:!1,Xe:la,aborted:!1};const F=Zone.current.scheduleMacroTask("XMLHttpRequest.send",
v,la,t,B);Q&&!0===Q[m]&&!la.aborted&&"scheduled"===F.state&&F.invoke()}),U=$b(G,"abort",()=>function(Q,la){const F=Q[d];if(F&&"string"==typeof F.type)null==F.cancelFn||F.data&&F.data.aborted||F.zone.cancelTask(F);else if(!0===c.current[ca])return U.apply(Q,la)})}})(b);const d=kb("xhrTask"),e=kb("xhrSync"),f=kb("xhrListener"),g=kb("xhrScheduled"),k=kb("xhrURL"),m=kb("xhrErrorBeforeScheduled")});a.__load_patch("geolocation",b=>{b.navigator&&b.navigator.geolocation&&Hb(b.navigator.geolocation)});a.__load_patch("PromiseRejectionEvent",
(b,c)=>{function d(e){return function(f){tc(b,e).forEach(g=>{var k=b.PromiseRejectionEvent;k&&(k=new k(e,{promise:f.promise,reason:f.rejection}),g.invoke(k))})}}b.PromiseRejectionEvent&&(c[kb("unhandledPromiseRejectionHandler")]=d("unhandledrejection"),c[kb("rejectionHandledHandler")]=d("rejectionhandled"))});a.__load_patch("queueMicrotask",(b,c,d)=>{Tc(b,d)})};function Xc(){yc.__load_patch("canvas",(a,b,c)=>{a=a.HTMLCanvasElement;"undefined"!==typeof a&&a.prototype&&a.prototype.toBlob&&c.patchMacroTask(a.prototype,"toBlob",(d,e)=>({name:"HTMLCanvasElement.toBlob",target:d,Ym:0,Xe:e}))})};function Yc(a,b,c){const d={};for(const e in a)d[e]=b.call(c,a[e],e,a);return d};var Zc;var ad=class{constructor(a){this.i=a}toString(){return this.i+""}};function bd(a){return a instanceof ad&&a.constructor===ad?a.i:"type_error:TrustedResourceUrl"}var cd={};function gd(a){if(void 0===Zc){var b=null;var c=xa.trustedTypes;if(c&&c.createPolicy){try{b=c.createPolicy("goog#html",{createHTML:Da,createScript:Da,createScriptURL:Da})}catch(d){xa.console&&xa.console.error(d.message)}Zc=b}else Zc=b}a=(b=Zc)?b.createScriptURL(a):a;return new ad(a,cd)};/*

 SPDX-License-Identifier: Apache-2.0
*/
var hd=class{constructor(a){this.i=a}toString(){return this.i}};function id(a){if(a instanceof hd)return a.i;throw Error("");};class jd{constructor(a){this.ir=a}}function kd(a){return new jd(b=>b.substr(0,a.length+1).toLowerCase()===a+":")}const ld=[kd("data"),kd("http"),kd("https"),kd("mailto"),kd("ftp"),new jd(a=>/^[^:]*([/?#]|$)/.test(a))];function rd(a){if(a instanceof hd)return a;for(let b=0;b<ld.length;++b){const c=ld[b];if(c instanceof jd&&c.ir(a))return new hd(a)}}var sd=/^\s*(?!javascript:)(?:[\w+.-]+:|[^:/?#]*(?:[/?#]|$))/i;function td(a){a instanceof hd?a=id(a):a=sd.test(a)?a:void 0;return a};function ud(a,b){b=td(b);void 0!==b&&(a.href=b)};function vd(a,b){a.src=bd(b);var c;let d;(c=(b=null==(d=(c=(a.ownerDocument&&a.ownerDocument.defaultView||window).document).querySelector)?void 0:d.call(c,"script[nonce]"))?b.nonce||b.getAttribute("nonce")||"":"")&&a.setAttribute("nonce",c)};var wd=String.prototype.repeat?function(a,b){return a.repeat(b)}:function(a,b){return Array(b+1).join(a)};function xd(a){throw Error("Data "+a.C+" not defined.");}function yd(){var a=Ad;if(null==a.i)return null;if("boolean"===typeof a.i)return a.i;if("string"===typeof a.i){const b=a.i.toLowerCase();if("true"===b||"1"===b)return!0;if("false"===b||"0"===b)return!1}throw new TypeError(`Invalid boolean data <${a.C}>: ${a.i} (typeof ${typeof a.i})`);}function Bd(a,b){return eb(b,function(c,d){return new Cd(this.C+"["+d+"]",c)},a)}function Dd(a){a=a.D();return""==a.trim()?[]:a.split(",").map(b=>b.trim())}
class Cd{constructor(a,b){this.C=a;this.i=b}D(a){if(null==this.i)return 0==arguments.length&&xd(this),a;if("string"===typeof this.i)return this.i;throw new TypeError("Invalid string data <"+this.C+">: "+this.i+"-"+typeof this.i);}number(a){if(null==this.i)return 0==arguments.length&&xd(this),a;if("number"===typeof this.i)return this.i;if("string"===typeof this.i){const b=Number(this.i);if(!isNaN(b)&&!/^[\s\xa0]*$/.test(this.i))return b}throw new TypeError("Invalid numeric data <"+this.C+">: "+this.i+
"-"+typeof this.i);}toString(){if(null==this.i)var a=null;else if("string"===typeof this.i)a=this.i;else throw new TypeError(`Invalid string data <${this.C}>: ${this.i} (typeof ${typeof this.i})`);null===a&&xd(this);return a}array(a){if(null==this.i){if(0==arguments.length)throw Error("Data "+this.C+" not defined.");return a}return Bd(this,ya(this.i)?this.i:"string"!==typeof this.i?[this.i]:Dd(this))}object(a){if(null==this.i){if(0==arguments.length)throw Error("Data "+this.C+" not defined.");return a}if(!ya(this.i)&&
Ca(this.i))return Yc(this.i,function(b,c){return new Cd(this.C+"."+c,b)},this);throw new TypeError("Invalid object data <"+this.C+">: "+this.i+"-"+typeof this.i);}};function Ed(a=window){return a.WIZ_global_data}function Fd(a=window){return(a=Ed(a))&&"mXaIFf"in a?a.mXaIFf:null};function Gd(){yc.__load_patch("Error",(a,b,c)=>{function d(O){let U={Ry:O.zone.name},Q=U;for(;O.parent;){O=O.parent;const la={Ry:O.zone.name};U=U.parent=la}return Q}function e(O,U,Q=!0){O=O.split("\n");let la=0;for(;O[la]!==t&&O[la]!==v&&O[la]!==B&&O[la]!==G&&O[la]!==K&&la<O.length;)la++;for(;la<O.length&&U;la++){let F=O[la];if(F.trim())switch(p[F]){case g.Ts:O.splice(la,1);la--;break;case g.transition:U.parent?U=U.parent:U=null;O.splice(la,1);la--;break;default:O[la]+=Q?` [${U.zone.name}]`:` [${U.Ry}]`}}return O.join("\n")}
function f(){let O=m.apply(this,arguments);const U=O.originalStack=O.stack;if(f.stackRewrite&&U){let Q=c.currentZoneFrame();if("lazy"===N)O[c.symbol("zoneFrameNames")]=d(Q);else if("default"===N)try{O.stack=O.zoneAwareStack=e(U,Q)}catch(la){}}return this instanceof m&&this.constructor!=m?(Object.keys(O).concat("stack","message").forEach(Q=>{const la=O[Q];if(void 0!==la)try{this[Q]=la}catch(F){}}),this):O}const g={Ts:0,transition:1},k=c.symbol("zoneJsInternalStackFrames"),m=a[c.symbol("Error")]=a.Error,
p={};let t,v,B,G,K;a.Error=f;const N=a.__Zone_Error_BlacklistedStackFrames_policy||a.__Zone_Error_ZoneJsInternalStackFrames_policy||"default";f.prototype=m.prototype;f[k]=p;f.stackRewrite=!1;const aa=c.symbol("zoneAwareStack");"lazy"===N&&Object.defineProperty(f.prototype,"zoneAwareStack",{configurable:!0,enumerable:!0,get:function(){this[aa]||(this[aa]=e(this.originalStack,this[c.symbol("zoneFrameNames")],!1));return this[aa]},set:function(O){this.originalStack=O;this[aa]=e(this.originalStack,this[c.symbol("zoneFrameNames")],
!1)}});const ca=["stackTraceLimit","captureStackTrace","prepareStackTrace"];(a=Object.keys(m))&&a.forEach(O=>{0===ca.filter(U=>U===O).length&&Object.defineProperty(f,O,{get:function(){return m[O]},set:function(U){m[O]=U}})});m.hasOwnProperty("stackTraceLimit")&&(m.stackTraceLimit=Math.max(m.stackTraceLimit,15),Object.defineProperty(f,"stackTraceLimit",{get:function(){return m.stackTraceLimit},set:function(O){return m.stackTraceLimit=O}}));m.hasOwnProperty("captureStackTrace")&&Object.defineProperty(f,
"captureStackTrace",{value:function(O,U){m.captureStackTrace(O,U)}});Object.defineProperty(f,"prepareStackTrace",{get:function(){return m.hx},set:function(O){return O&&"function"===typeof O?m.hx=function(U,Q){if(Q)for(let la=0;la<Q.length;la++)if("zoneCaptureStackTrace"===Q[la].getFunctionName()){Q.splice(la,1);break}return O.call(this,U,Q)}:m.hx=O}});if("disable"!==N){var ia=b.current.fork({name:"detect",onHandleError:function(O,U,Q,la){if(la.originalStack&&Error===f)for(O=la.originalStack.split(/\n/),
la=Q=U=!1;O.length;){let F=O.shift();if(/:\d+:\d+/.test(F)||"ZoneAwareError"===F){let M=F.split("(")[0].split("@")[0],W=g.transition;-1!==M.indexOf("ZoneAwareError")&&(-1!==M.indexOf("new ZoneAwareError")?(t=F,v=F.replace("new ZoneAwareError","new Error.ZoneAwareError")):(B=F,G=F.replace("Error.",""),-1===F.indexOf("Error.ZoneAwareError")&&(K=F.replace("ZoneAwareError","Error.ZoneAwareError"))),p[v]=g.Ts);-1!==M.indexOf("runGuarded")?Q=!0:-1!==M.indexOf("runTask")?la=!0:-1!==M.indexOf("run")?U=!0:
W=g.Ts;p[F]=W;if(U&&Q&&la){f.stackRewrite=!0;break}}}return!1}}).fork({name:"child",onScheduleTask:function(O,U,Q,la){return O.scheduleTask(Q,la)},onInvokeTask:function(O,U,Q,la,F,M){return O.invokeTask(Q,la,F,M)},onCancelTask:function(O,U,Q,la){return O.cancelTask(Q,la)},onInvoke:function(O,U,Q,la,F,M,W){return O.invoke(Q,la,F,M,W)}});b=Error.stackTraceLimit;Error.stackTraceLimit=100;ia.run(()=>{ia.runGuarded(()=>{const O=()=>{};ia.scheduleEventTask(k,()=>{ia.scheduleMacroTask(k,()=>{ia.scheduleMicroTask(k,
()=>{throw Error();},void 0,U=>{U.ud=O;U.invoke()});ia.scheduleMicroTask(k,()=>{throw Error();},void 0,U=>{U.ud=O;U.invoke()})},void 0,U=>{U.ud=O;U.invoke()},()=>{})},void 0,U=>{U.ud=O;U.invoke()},()=>{})})});Error.stackTraceLimit=b}})};function Hd(){yc.__load_patch("ZoneAwarePromise",(a,b,c)=>{function d(){}function e(){let T=!1;return function(ea){return function(){T||(T=!0,ea.apply(null,arguments))}}}function f(T){if(T&&T.toString===Object.prototype.toString){const ea=T.constructor&&T.constructor.name;return(ea?ea:"")+": "+JSON.stringify(T)}return T?T.toString():Object.prototype.toString.call(T)}function g(T){c.onUnhandledError(T);try{const ea=b[la];"function"===typeof ea&&ea.call(this,T)}catch(ea){}}function k(T){return T}function m(T){return Na.reject(T)}
function p(T,ea){return na=>{try{t(T,ea,na)}catch(Ka){t(T,!1,Ka)}}}function t(T,ea,na){var Ka=e();if(T===na)throw new TypeError("Promise resolved with itself");if(null===T[F]){var Qa=null;try{if("object"===typeof na||"function"===typeof na)Qa=na&&na.then}catch(Ia){return Ka(()=>{t(T,!1,Ia)})(),T}if(!1!==ea&&na instanceof Na&&na.hasOwnProperty(F)&&na.hasOwnProperty(M)&&null!==na[F])v(na),t(T,na[F],na[M]);else if(!1!==ea&&"function"===typeof Qa)try{Qa.call(na,Ka(p(T,ea)),Ka(p(T,!1)))}catch(Ia){Ka(()=>
{t(T,!1,Ia)})()}else{T[F]=ea;Ka=T[M];T[M]=na;T[W]===W&&!0===ea&&(T[F]=T[qb],T[M]=T[Aa]);!1===ea&&na instanceof Error&&(Qa=b.currentTask&&b.currentTask.data&&b.currentTask.data.__creationTrace__)&&aa(na,wb,{configurable:!0,enumerable:!1,writable:!0,value:Qa});for(Qa=0;Qa<Ka.length;)B(T,Ka[Qa++],Ka[Qa++],Ka[Qa++],Ka[Qa++]);if(0==Ka.length&&0==ea){T[F]=0;ea=na;try{throw Error("Uncaught (in promise): "+f(na)+(na&&na.stack?"\n"+na.stack:""));}catch(Ia){ea=Ia}O&&(ea.throwOriginal=!0);ea.rejection=na;ea.promise=
T;ea.zone=b.current;ea.task=b.currentTask;ia.push(ea);c.scheduleMicroTask()}}}return T}function v(T){if(0===T[F]){try{var ea=b[Ja];ea&&"function"===typeof ea&&ea.call(this,{rejection:T[M],promise:T})}catch(na){}T[F]=!1;for(ea=0;ea<ia.length;ea++)T===ia[ea].promise&&ia.splice(ea,1)}}function B(T,ea,na,Ka,Qa){v(T);const Ia=T[F],ib=Ia?"function"===typeof Ka?Ka:k:"function"===typeof Qa?Qa:m;ea.scheduleMicroTask("Promise.then",()=>{try{const pa=T[M],Ga=!!na&&W===na[W];Ga&&(na[Aa]=pa,na[qb]=Ia);const Sa=
ea.run(ib,void 0,Ga&&ib!==m&&ib!==k?[]:[pa]);t(na,!0,Sa)}catch(pa){t(na,!1,pa)}},na)}function G(T){const ea=T.prototype,na=N(ea,"then");if(!na||!1!==na.writable&&na.configurable){var Ka=ea.then;ea[Q]=Ka;T.prototype.then=function(Qa,Ia){return(new Na((ib,pa)=>{Ka.call(this,ib,pa)})).then(Qa,Ia)};T[qa]=!0}}function K(T){return function(ea,na){ea=T.apply(ea,na);if(ea instanceof Na)return ea;na=ea.constructor;na[qa]||G(na);return ea}}const N=Object.getOwnPropertyDescriptor,aa=Object.defineProperty,ca=
c.symbol,ia=[],O=!1!==a[ca("DISABLE_WRAPPING_UNCAUGHT_PROMISE_REJECTION")];var U=ca("Promise");const Q=ca("then");c.onUnhandledError=T=>{if(c.showUncaughtError()){const ea=T&&T.rejection;ea?console.error("Unhandled Promise rejection:",ea instanceof Error?ea.message:ea,"; Zone:",T.zone.name,"; Task:",T.task&&T.task.source,"; Value:",ea,ea instanceof Error?ea.stack:void 0):console.error(T)}};c.microtaskDrainDone=()=>{for(;ia.length;){const T=ia.shift();try{T.zone.runGuarded(()=>{if(T.throwOriginal)throw T.rejection;
throw T;})}catch(ea){g(ea)}}};const la=ca("unhandledPromiseRejectionHandler"),F=ca("state"),M=ca("value"),W=ca("finally"),Aa=ca("parentPromiseValue"),qb=ca("parentPromiseState"),wb=ca("currentTaskTrace"),Ja=ca("rejectionHandledHandler"),Ub=a.AggregateError;class Na{static toString(){return"function ZoneAwarePromise() { [native code] }"}static resolve(T){return T instanceof Na?T:t(new this(null),!0,T)}static reject(T){return t(new this(null),!1,T)}static any(T){if(!T||"function"!==typeof T[Symbol.iterator])return Promise.reject(new Ub([],
"All promises were rejected"));const ea=[];let na=0;try{for(let Ia of T)na++,ea.push(Na.resolve(Ia))}catch(Ia){return Promise.reject(new Ub([],"All promises were rejected"))}if(0===na)return Promise.reject(new Ub([],"All promises were rejected"));let Ka=!1;const Qa=[];return new Na((Ia,ib)=>{for(let pa=0;pa<ea.length;pa++)ea[pa].then(Ga=>{Ka||(Ka=!0,Ia(Ga))},Ga=>{Qa.push(Ga);na--;0===na&&(Ka=!0,ib(new Ub(Qa,"All promises were rejected")))})})}static race(T){function ea(ib){Ka(ib)}function na(ib){Qa(ib)}
let Ka,Qa,Ia=new this((ib,pa)=>{Ka=ib;Qa=pa});for(let ib of T)ib&&ib.then||(ib=this.resolve(ib)),ib.then(ea,na);return Ia}static all(T){return Na.Fu(T)}static allSettled(T){return(this&&this.prototype instanceof Na?this:Na).Fu(T,{vE:ea=>({status:"fulfilled",value:ea}),JB:ea=>({status:"rejected",reason:ea})})}static Fu(T,ea){let na,Ka,Qa=new this((Ga,Sa)=>{na=Ga;Ka=Sa}),Ia=2,ib=0;const pa=[];for(let Ga of T){Ga&&Ga.then||(Ga=this.resolve(Ga));const Sa=ib;try{Ga.then(db=>{pa[Sa]=ea?ea.vE(db):db;Ia--;
0===Ia&&na(pa)},db=>{ea?(pa[Sa]=ea.JB(db),Ia--,0===Ia&&na(pa)):Ka(db)})}catch(db){Ka(db)}Ia++;ib++}Ia-=2;0===Ia&&na(pa);return Qa}constructor(T){if(!(this instanceof Na))throw Error("Must be an instanceof Promise.");this[F]=null;this[M]=[];try{const ea=e();T&&T(ea(p(this,!0)),ea(p(this,!1)))}catch(ea){t(this,!1,ea)}}get [Symbol.toStringTag](){return"Promise"}get [Symbol.species](){return Na}then(T,ea){var na,Ka=null==(na=this.constructor)?void 0:na[Symbol.species];Ka&&"function"===typeof Ka||(Ka=
this.constructor||Na);na=new Ka(d);Ka=b.current;null==this[F]?this[M].push(Ka,na,T,ea):B(this,Ka,na,T,ea);return na}catch(T){return this.then(null,T)}finally(T){var ea,na=null==(ea=this.constructor)?void 0:ea[Symbol.species];na&&"function"===typeof na||(na=Na);ea=new na(d);ea[W]=W;na=b.current;null==this[F]?this[M].push(na,ea,T,T):B(this,na,ea,T,T);return ea}}Na.resolve=Na.resolve;Na.reject=Na.reject;Na.race=Na.race;Na.all=Na.all;U=a[U]=a.Promise;a.Promise=Na;const qa=ca("thenPatched");c.patchThen=
G;U&&(G(U),$b(a,"fetch",T=>K(T)));Promise[b.__symbol__("uncaughtPromiseErrors")]=ia;return Na})};function Id(){yc.__load_patch("toString",a=>{function b(){if("function"===typeof this){var k=this[d];if(k)return"function"===typeof k?c.call(k):Object.prototype.toString.call(k);if(this===Promise&&(k=a[e])||this===Error&&(k=a[f]))return c.call(k)}return c.call(this)}const c=Function.prototype.toString,d=kb("OriginalDelegate"),e=kb("Promise"),f=kb("Error");b[d]=c;Function.prototype.toString=b;const g=Object.prototype.toString;Object.prototype.toString=function(){return"function"===typeof Promise&&
this instanceof Promise?"[object Promise]":g.call(this)}})};var Jd;if(!(Jd="undefined"===typeof window)){var Ad=new Cd("mXaIFf",Fd(window));const a=yd();Jd=null===a?!0:a}if(Jd){var yc;const a=globalThis,b=!0===a[kb("forceDuplicateZoneCheck")];if(a.Zone&&(b||"function"!==typeof a.Zone.__symbol__))throw Error("Zone already loaded.");null!=a.Zone||(a.Zone=lb());yc=a.Zone;Gd();Hd();Id();xc();Qc();Wc();Xc()};function Kd(a){for(let b in a)if(a[b]===Kd)return b;throw Error("Could not find renamed property on target object.");};function Ld(a){return{la:a.la,da:a.da||null,aa:a.aa,value:void 0}}function Md(a){return{Ua:a.Ua||[],imports:a.imports||[]}}function Nd(a){var b;(b=a.hasOwnProperty(Od)?a[Od]:null)||(b=a.hasOwnProperty(Sd)?a[Sd]:null);return b}function Td(a){return(a=a&&(a[Od]||a[Sd]))?a:null}function Vd(a){return a&&(a.hasOwnProperty(Wd)||a.hasOwnProperty(Xd))?a[Wd]:null}var Od=Kd({oa:Kd}),Wd=Kd({Va:Kd}),Sd=Kd({YF:Kd}),Xd=Kd({ZF:Kd});var Yd=class extends Error{constructor(a,b){super(`${`NG0${Math.abs(a)}`}${b?": "+b:""}`);this.code=a}};var Zd=Kd({Ca:Kd}),$d=Kd({Ea:Kd}),ae=Kd({HG:Kd}),be=Kd({Wa:Kd}),ce=Kd({J:Kd}),de=Kd({vf:Kd}),ee=Kd({wz:Kd});function fe(a){return"string"===typeof a?a:null==a?"":String(a)};function ge(a){if("string"===typeof a)return a;if(Array.isArray(a))return"["+a.map(ge).join(", ")+"]";if(null==a)return""+a;if(a.pD)return`${a.pD}`;if(a.name)return`${a.name}`;a=a.toString();if(null==a)return""+a;const b=a.indexOf("\n");return-1===b?a:a.substring(0,b)}function he(a,b){return null==a||""===a?null===b?"":b:null==b||""===b?a:a+" "+b};/*

 The MIT License

 Copyright (c) 2014-2016 Google, Inc. http://angular.io

 Permission is hereby granted, free of charge, to any person obtaining a copy
 of this software and associated documentation files (the "Software"), to deal
 in the Software without restriction, including without limitation the rights
 to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 copies of the Software, and to permit persons to whom the Software is
 furnished to do so, subject to the following conditions:

 The above copyright notice and this permission notice shall be included in
 all copies or substantial portions of the Software.

 THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN
 THE SOFTWARE.
*/
function je(){throw new Yd(-201,!1);};function ke(a,b){return Object.is(a,b)};let le=null,me=!1,ne=1;var oe=Symbol("SIGNAL");function pe(a){const b=le;le=a;return b}var qe={version:0,yw:0,pc:!1,lc:void 0,bi:void 0,je:void 0,co:0,gd:void 0,Cg:void 0,hq:!1,iq:!1,kx:()=>!1,lx:()=>{},jq:()=>{},hv:()=>{}};function se(a){if(me)throw Error("");if(null!==le){le.hv(a);var b=le.co++;te(le);b<le.lc.length&&le.lc[b]!==a&&ue(le)&&ve(le.lc[b],le.je[b]);le.lc[b]!==a&&(le.lc[b]=a,le.je[b]=ue(le)?we(a,le,b):0);le.bi[b]=a.version}}
function xe(a){if(!ue(a)||a.pc)if(a.pc||a.yw!==ne)(a.kx(a)||ye(a))&&a.lx(a),a.pc=!1,a.yw=ne}function ze(a){if(void 0!==a.gd){var b=me;me=!0;try{for(const c of a.gd)c.pc||Ae(c)}finally{me=b}}}function Be(){let a;return!1!==(null==(a=le)?void 0:a.hq)}function Ae(a){a.pc=!0;ze(a);let b;null==(b=a.jq)||b.call(a,a)}function Ce(a){a&&(a.co=0);return pe(a)}
function De(a,b){pe(b);if(a&&void 0!==a.lc&&void 0!==a.je&&void 0!==a.bi){if(ue(a))for(b=a.co;b<a.lc.length;b++)ve(a.lc[b],a.je[b]);for(;a.lc.length>a.co;)a.lc.pop(),a.bi.pop(),a.je.pop()}}function ye(a){te(a);for(let b=0;b<a.lc.length;b++){const c=a.lc[b],d=a.bi[b];if(d!==c.version)return!0;xe(c);if(d!==c.version)return!0}return!1}function Ee(a){te(a);if(ue(a))for(let b=0;b<a.lc.length;b++)ve(a.lc[b],a.je[b]);a.lc.length=a.bi.length=a.je.length=0;a.gd&&(a.gd.length=a.Cg.length=0)}
function we(a,b,c){Fe(a);te(a);if(0===a.gd.length)for(let d=0;d<a.lc.length;d++)a.je[d]=we(a.lc[d],a,d);a.Cg.push(c);return a.gd.push(b)-1}function ve(a,b){Fe(a);te(a);if(1===a.gd.length)for(var c=0;c<a.lc.length;c++)ve(a.lc[c],a.je[c]);c=a.gd.length-1;a.gd[b]=a.gd[c];a.Cg[b]=a.Cg[c];a.gd.length--;a.Cg.length--;b<a.gd.length&&(c=a.Cg[b],a=a.gd[b],te(a),a.je[c]=b)}function ue(a){let b,c;return a.iq||0<(null!=(c=null==a?void 0:null==(b=a.gd)?void 0:b.length)?c:0)}
function te(a){null!=a.lc||(a.lc=[]);null!=a.je||(a.je=[]);null!=a.bi||(a.bi=[])}function Fe(a){null!=a.gd||(a.gd=[]);null!=a.Cg||(a.Cg=[])};function Ge(a){const b=Object.create(He);b.kB=a;a=()=>{xe(b);se(b);if(b.value===Ie)throw b.error;return b.value};a[oe]=b;return a}
const Je=Symbol("UNSET"),Ke=Symbol("COMPUTING"),Ie=Symbol("ERRORED"),He=Object.assign({},qe,{value:Je,pc:!0,error:null,Cq:ke,kx(a){return a.value===Je||a.value===Ke},lx(a){if(a.value===Ke)throw Error("Detected cycle in computations.");const b=a.value;a.value=Ke;const c=Ce(a);let d;try{d=a.kB()}catch(e){d=Ie,a.error=e}finally{De(a,c)}b!==Je&&b!==Ie&&d!==Ie&&a.Cq(b,d)?a.value=b:(a.value=d,a.version++)}});function Le(){throw Error();};function Me(a){const b=Object.create(Re);b.value=a;a=()=>{se(b);return b.value};a[oe]=b;return a}function Se(a,b){Be()||Le();a.Cq(a.value,b)||(a.value=b,a.version++,ne++,ze(a))}var Re=Object.assign({},qe,{Cq:ke,value:void 0});function Te(a,b,c){const d=Object.create(Ue);c&&(d.hq=!0);d.xn=a;d.Mc=b;const e=f=>{d.Zi=f};d.Hj={notify:()=>Ae(d),run:()=>{if(null!==d.xn){if(me)throw Error("Schedulers cannot synchronously execute watches while scheduling.");d.pc=!1;if(!d.cw||ye(d)){d.cw=!0;var f=Ce(d);try{d.Zi(),d.Zi=Ve,d.xn(e)}finally{De(d,f)}}}},ae:()=>d.Zi(),destroy:()=>{if(null!==d.xn||null!==d.Mc)Ee(d),d.Zi(),d.xn=null,d.Mc=null,d.Zi=Ve},[oe]:d};return d.Hj}
const Ve=()=>{},Ue=Object.assign({},qe,{iq:!0,hq:!1,jq:a=>{null!==a.Mc&&a.Mc(a.Hj)},cw:!1,Zi:Ve});let We;function Xe(a){const b=We;We=a;return b}function Ye(a,b,c){if((a=Nd(a))&&"root"==a.da)return void 0===a.value?a.value=a.aa():a.value;if(c&8)return null;if(void 0!==b)return b;je()};const $e=Kd({gt:Kd});function af(a){a.gt=af;a.toString=function(){return ge(this())};return a}function bf(a){return cf(a)?a():a}function cf(a){return"function"===typeof a&&a.hasOwnProperty($e)&&a.gt===af};var df=class{constructor(a,b){this.i=a;this.oa=void 0;"number"==typeof b?this.vf=b:void 0!==b&&(this.oa=Ld({la:this,da:b.da||"root",aa:b.aa}))}get Db(){return this}toString(){return`InjectionToken ${this.i}`}};var ef=globalThis;var ff={};const gf=/\n/gm;let hf=void 0;function jf(a){const b=hf;hf=a;return b}function kf(a,b=0){if(void 0===hf)throw new Yd(-203,!1);return null===hf?Ye(a,void 0,b):hf.get(a,b&8?null:void 0,b)}function q(a,b=0){return(We||kf)(bf(a),b)}function lf(a,b=0){return q(a,mf(b))}function mf(a){return"undefined"===typeof a||"number"===typeof a?a:0|(a.optional&&8)|(a.host&&1)|(a.self&&2)|(a.vG&&4)}
function nf(a){const b=[];for(let c=0;c<a.length;c++){const d=bf(a[c]);if(Array.isArray(d)){if(0===d.length)throw new Yd(900,!1);let e=void 0,f=0;for(let g=0;g<d.length;g++){const k=d[g],m=k.__NG_DI_FLAG__;"number"===typeof m?-1===m?e=k.la:f|=m:e=k}b.push(q(e,f))}else b.push(q(d))}return b}function of(a,b){a.__NG_DI_FLAG__=b;a.prototype.__NG_DI_FLAG__=b;return a}
function pf(a,b,c=null){a=a&&"\n"===a.charAt(0)&&"\u0275"==a.charAt(1)?a.slice(2):a;var d=ge(b);if(Array.isArray(b))d=b.map(ge).join(" -> ");else if("object"===typeof b){d=[];for(let e in b)if(b.hasOwnProperty(e)){let f=b[e];d.push(e+":"+("string"===typeof f?JSON.stringify(f):ge(f)))}d=`{${d.join(", ")}}`}return`${"R3InjectorError"}${c?"("+c+")":""}[${d}]: ${a.replace(gf,"\n  ")}`};var qf=new df("");var rf=new df("",-1);var sf=new df("");var tf=class{get(a,b=ff){if(b===ff)throw a=Error(`NullInjectorError: No provider for ${ge(a)}!`),a.name="NullInjectorError",a;return b}};function uf(a,b,c){let d=0;for(;d<c.length;){var e=c[d];if("number"===typeof e){if(0!==e)break;d++;e=c[d++];var f=c[d++];const g=c[d++];a.setAttribute(b,f,g,e)}else f=c[++d],64===e.charCodeAt(0)?a.setProperty(b,e,f):a.setAttribute(b,e,f),d++}}function vf(a,b){if(null!==b&&0!==b.length)if(null===a||0===a.length)a=b.slice();else{let c=-1;for(let d=0;d<b.length;d++){const e=b[d];"number"===typeof e?c=e:0!==c&&(-1===c||2===c?wf(a,c,e,b[++d]):wf(a,c,e,null))}}return a}
function wf(a,b,c,d){let e=0,f=a.length;if(-1===b)f=-1;else for(;e<a.length;){var g=a[e++];if("number"===typeof g)if(g===b){f=-1;break}else if(g>b){f=e-1;break}}for(;e<a.length;){g=a[e];if("number"===typeof g)break;else if(g===c){null!==d&&(a[e+1]=d);return}e++;null!==d&&e++}-1!==f&&(a.splice(f,0,b),e=f+1);a.splice(e++,0,c);null!==d&&a.splice(e++,0,d)};function xf(a){return 4===a.type&&"ng-template"!==a.value}
function yf(a,b,c){let d=4;const e=a.attrs;if(null!==e)a:{for(var f=0;f<e.length;f++){var g=e[f];if(3===g||4===g||6===g){g=f;break a}}g=e.length}else g=0;f=!1;for(let G=0;G<b.length;G++){var k=b[G];if("number"===typeof k){if(!f&&0!==(d&1)&&0!==(k&1))return!1;f&&0===(k&1)||(f=!1,d=k|d&1)}else if(!f)if(d&4){if(d=2|d&1,""!==k&&k!==(4!==a.type||c?a.value:"ng-template")||""===k&&1===b.length){if(0===(d&1))return!1;f=!0}}else if(d&8){var m;if(!(m=null===e)){a:{m=void 0;var p=a,t=0;if(c)for(;t<e.length&&
"string"===typeof e[t];t+=2){if(p="class"===e[t]){b:{p=e[t+1].toLowerCase();for(var v=0,B=p.length;;){v=p.indexOf(k,v);if(-1===v){p=v;break b}if(0===v||32>=p.charCodeAt(v-1)){const K=k.length;if(v+K===B||32>=p.charCodeAt(v+K)){p=v;break b}}v+=1}}p=-1!==p}if(p){k=!0;break a}}else if(xf(p)){k=!1;break a}t=e.indexOf(1,t);if(-1<t)for(;++t<e.length&&"string"===typeof(m=e[t]);)if(m.toLowerCase()===k){k=!0;break a}k=!1}m=!k}if(m){if(0===(d&1))return!1;f=!0}}else{m=b[++G];a:if(null===e)k=-1;else if(t=0,c||
!xf(a)){for(p=!1;t<e.length;){B=e[t];if(B===k){k=t;break a}if(3===B||6===B)p=!0;else if(1===B||2===B){for(B=e[++t];"string"===typeof B;)B=e[++t];continue}else if(4===B)break;else if(0===B){t+=4;continue}t+=p?1:2}k=-1}else b:{t=e.indexOf(4);if(-1<t)for(t++;t<e.length;){p=e[t];if("number"===typeof p)break;if(p===k){k=t;break b}t++}k=-1}if(-1===k){if(0===(d&1))return!1;f=!0}else if(""!==m&&(k=k>g?"":e[k+1].toLowerCase(),d&2&&m!==k)){if(0===(d&1))return!1;f=!0}}}return 0===(d&1)||f}
function Af(a,b,c=!1){for(let d=0;d<b.length;d++)if(yf(a,b[d],c))return!0;return!1}function Bf(a,b){return a?":not("+b.trim()+")":b}function Cf(a){let b=a[0],c=1,d=2,e="",f=!1;for(;c<a.length;){let g=a[c];if("string"===typeof g)if(d&2){const k=a[++c];e+="["+g+(0<k.length?'="'+k+'"':"")+"]"}else d&8?e+="."+g:d&4&&(e+=" "+g);else""!==e&&0!==(g&1)&&(b+=Bf(f,e),e=""),d=g,f=f||0!==(d&1);c++}""!==e&&(b+=Bf(f,e));return b};function Df(a){return{toString:a}.toString()};var Ef={},Ff=[];function Gf(a){return Df(()=>{var b=Hf(a),c;b=Object.assign({},b,{ya:a.ya,za:a.za,sa:a.sa,Ba:a.Ba||null,Yb:a.Yb,Br:0===a.Qa,Dv:null,ax:null,Ga:b.ja&&a.Ga||null,Iq:null,ii:null!=(c=a.ii)?c:!1,data:a.data||{},ob:a.ob||0,styles:a.styles||Ff,Fb:null,Pj:a.Pj||null,tb:null,id:""});If(b);c=a.Ga;b.Dv=Jf(c,!1);b.ax=Jf(c,!0);c=0;const d=[b.ga,b.Yb,b.Xa,b.Ja,b.Ba,b.za,b.ya,b.ob,b.ja,b.ii,b.hb,JSON.stringify(b.inputs),JSON.stringify(b.outputs),Object.getOwnPropertyNames(b.type.prototype),!!b.cc,!!b.eb].join("|");
for(const e of d)c=Math.imul(31,c)+e.charCodeAt(0)<<0;b.id="c"+(c+2147483648);return b})}function Kf(a){return a[Zd]||a[$d]||null}function Lf(a){return null!==a}function Mf(a){return Df(()=>({type:a.type,Kk:a.Kk||Ff,wB:a.wB||Ff,imports:a.imports||Ff,exports:a.exports||Ff,BG:null,Pj:a.Pj||null,id:a.id||null}))}
function Nf(a,b){if(null==a)return Ef;const c={};for(const e in a)if(a.hasOwnProperty(e)){var d=a[e];let f,g=0;if(Array.isArray(d)){g=d[0];f=d[1];let k;d=null!=(k=d[2])?k:f}else f=d;b?(c[f]=0!==g?[e,g]:e,b[f]=d):c[f]=e}return c}function Of(a){return Df(()=>{const b=Hf(a);If(b);return b})}function Pf(a){return a[ae]||null}
function Hf(a){const b={};return{type:a.type,Vr:null,aa:null,Ha:a.Ha||null,Xa:a.Xa||0,Ja:a.Ja||null,cc:a.cc||null,ej:b,Ce:null,qC:a.inputs||Ef,hb:a.hb||null,ja:!0===a.ja,ii:!0===a.ii,ga:a.ga||Ff,eb:a.eb||null,features:a.features||null,Ao:null,nj:null,ol:null,inputs:Nf(a.inputs,b),outputs:Nf(a.outputs),AF:null}}function If(a){let b;null==(b=a.features)||b.forEach(c=>c(a))}function Jf(a,b){if(!a)return null;const c=b?Pf:Kf;return()=>("function"===typeof a?a():a).map(d=>c(d)).filter(Lf)};function Qf(a){return a.hasOwnProperty(ce)?a[ce]:null};function Rf(a,b){a.forEach(c=>Array.isArray(c)?Rf(c,b):b(c))}function Sf(a,b){return b>=a.length-1?a.pop():a.splice(b,1)[0]}function Tf(a,b,c){let d=Uf(a,b);if(0<=d)a[d|1]=c;else{var e=d=~d;let f=a.length;if(f==e)a.push(b,c);else if(1===f)a.push(c,a[0]),a[0]=b;else{f--;for(a.push(a[f-1],a[f]);f>e;)a[f]=a[f-2],f--;a[e]=b;a[e+1]=c}}return d}function Vf(a,b){b=Uf(a,b);if(0<=b)return a[b|1]}
function Uf(a,b){let c=0,d=a.length>>1;for(;d!==c;){const e=c+(d-c>>1),f=a[e<<1];if(b===f)return e<<1;f>b?d=e:c=e+1}return~(d<<1)};function Wf(...a){return{Zj:Xf(a),GG:!0}}function Xf(...a){const b=[],c=new Set;let d;const e=f=>{b.push(f)};Rf(a,f=>{Yf(f,e,[],c)&&(d||(d=[]),d.push(f))});void 0!==d&&Zf(d,e);return b}function Zf(a,b){for(let c=0;c<a.length;c++){const {Aj:d,Ua:e}=a[c];$f(e,f=>{b(f,d)})}}
function Yf(a,b,c,d){a=bf(a);if(!a)return!1;let e=null;var f=Vd(a);const g=!f&&(a[Zd]||null);if(f||g){if(g&&!g.ja)return!1;e=a}else{var k=a.Aj;if(f=Vd(k))e=k;else return!1}k=d.has(e);if(g){if(k)return!1;d.add(e);if(g.Ga){f="function"===typeof g.Ga?g.Ga():g.Ga;for(var m of f)Yf(m,b,c,d)}}else if(f){if(null!=f.imports&&!k){d.add(e);let p;Rf(f.imports,t=>{Yf(t,b,c,d)&&(p||(p=[]),p.push(t))});void 0!==p&&Zf(p,b)}k||(m=Qf(e)||(()=>new e),b({na:e,Ec:m,zc:Ff},e),b({na:sf,mb:e,Db:!0},e),b({na:qf,mb:()=>q(e),
Db:!0},e));f=f.Ua;if(null!=f&&!k){const p=a;$f(f,t=>{b(t,p)})}}else return!1;return e!==a&&void 0!==a.Ua}function $f(a,b){for(let c of a)c&&c.Zj&&(c=c.Zj),Array.isArray(c)?$f(c,b):b(c)}var ag=Kd({na:String,mb:Kd});function bg(a){return null!==a&&"object"==typeof a&&ag in a}function cg(a){return"function"===typeof a};var dg=new df("");const eg={},fg={};let gg=void 0;function hg(){void 0===gg&&(gg=new tf);return gg}var ig=class{};function jg(a,b){b=bf(b);let c=cg(b)?b:bf(b&&b.na);const d=kg(b);if(!cg(b)&&!0===b.Db){let e=a.C.get(c);e||(e=lg(void 0,eg,!0),e.aa=()=>nf(e.Db),a.C.set(c,e));c=b;e.Db.push(b)}a.C.set(c,d)}function mg(a){if(a.Fa)throw new Yd(205,!1);}function ng(a){const b=pe(null),c=jf(a),d=Xe();try{const e=a.get(qf,Ff,2);for(const f of e)f()}finally{jf(c),Xe(d),pe(b)}}
var tg=class extends ig{get i(){return this.Fa}constructor(a,b,c,d){super();this.parent=b;this.source=c;this.K=d;this.C=new Map;this.F=new Set;this.D=[];this.Fa=!1;og(a,e=>jg(this,e));this.C.set(rf,lg(void 0,this));d.has("environment")&&this.C.set(ig,lg(void 0,this));a=this.C.get(dg);null!=a&&"string"===typeof a.value&&this.K.add(a.value);this.G=new Set(this.get(sf,Ff,2))}destroy(){mg(this);this.Fa=!0;const a=pe(null);try{for(const c of this.F)c.ua();const b=this.D;this.D=[];for(const c of b)c()}finally{this.C.clear(),
this.F.clear(),this.G.clear(),pe(a)}}nb(a){mg(this);this.D.push(a);return()=>{const b=this.D.indexOf(a);-1!==b&&this.D.splice(b,1)}}get(a,b=ff,c=0){mg(this);if(a.hasOwnProperty(ee))return a[ee](this);c=mf(c);const d=jf(this),e=Xe();try{if(!(c&4)){let B=this.C.get(a);if(void 0===B){const G=("function"===typeof a||"object"===typeof a&&a instanceof df)&&Nd(a);var f;if(f=G)if(G.da){var g=bf(G.da);f="string"===typeof g?"any"===g||this.K.has(g):this.G.has(g)}else f=!1;f?B=lg(sg(a),eg):B=null;this.C.set(a,
B)}if(null!=B){a:{b=B;const G=pe(null);try{b.value===eg&&(b.value=fg,b.value=b.aa());var k;if(k="object"===typeof b.value&&b.value){var m=b.value;k=null!==m&&"object"===typeof m&&"function"===typeof m.ua}k&&this.F.add(b.value);var p=b.value;break a}finally{pe(G)}p=void 0}return p}}const v=c&2?hg():this.parent;b=c&8&&b===ff?null:b;return v.get(a,b)}catch(v){if("NullInjectorError"===v.name){(v.ngTempTokenPath=v.ngTempTokenPath||[]).unshift(ge(a));if(d)throw v;p=v;var t=this.source;const B=p.ngTempTokenPath;
a.__source&&B.unshift(a.__source);p.message=pf("\n"+p.message,B,t);p.ngTokenPath=B;p.ngTempTokenPath=null;throw p;}throw v;}finally{Xe(e),jf(d)}}toString(){const a=[],b=this.C;for(const c of b.keys())a.push(ge(c));return`R3Injector[${a.join(", ")}]`}};function sg(a){var b=Nd(a);b=null!==b?b.aa:Qf(a);if(null!==b)return b;if(a instanceof df)throw new Yd(204,!1);if(a instanceof Function)return ug(a);throw new Yd(204,!1);}
function ug(a){if(0<a.length)throw new Yd(204,!1);const b=Td(a);return null!==b?()=>b.aa(a):()=>new a}function kg(a){if(bg(a))return lg(void 0,a.mb);a=vg(a);return lg(a,eg)}function vg(a){var b=void 0;if(cg(a))return b=bf(a),Qf(b)||sg(b);if(bg(a))b=()=>bf(a.mb);else if(a&&a.Ec)b=()=>a.Ec(...nf(a.zc||[]));else if(a&&a.zb)b=()=>q(bf(a.zb));else{const c=bf(a&&(a.Dc||a.na));if(a.zc)b=()=>new c(...nf(a.zc));else return Qf(c)||sg(c)}return b}function lg(a,b,c=!1){return{aa:a,value:b,Db:c?[]:void 0}}
function og(a,b){for(const c of a)Array.isArray(c)?og(c,b):c&&c&&c.Zj?og(c.Zj,b):b(c)};function wg(a,b){a instanceof tg&&mg(a);a=jf(a);const c=Xe();try{return b()}finally{jf(a),Xe(c)}}function xg(){if(void 0===We&&null==hf)throw new Yd(-203,!1);};function yg(a){return Array.isArray(a)&&"object"===typeof a[1]}function Ag(a){return Array.isArray(a)&&!0===a[1]};var Bg=class{constructor(a,b,c){this.jx=a;this.pq=b;this.vn=c}};function Cg(){return Dg}function Dg(a){a.type.prototype.rc&&(a.Ao=Eg);return Fg}Cg.Mw=!0;function Fg(){const a=this.__ngSimpleChanges__||null,b=null==a?void 0:a.current;if(b){const c=a.Rr;if(c===Ef)a.Rr=b;else for(let d in b)c[d]=b[d];a.current=null;this.rc(b)}}function Eg(a,b,c,d,e){d=this.ej[d];var f;(f=a.__ngSimpleChanges__||null)||(f=a.__ngSimpleChanges__={Rr:Ef,current:null});var g=f;f=g.current||(g.current={});g=g.Rr;const k=g[d];f[d]=new Bg(k&&k.pq,c,g===Ef);null!==b?b.Iu(b,c):a[e]=c};function Gg(a){for(;Array.isArray(a);)a=a[0];return a}function Hg(a,b){return Gg(b[a.index])}function Ig(a,b){a=b[a];return yg(a)?a:a[0]}function Jg(a,b){return null===b||void 0===b?null:a[b]}function Kg(a){let b;return!!(a[2]&9216||(null==(b=a[23])?0:b.pc))}function Lg(a){let b;null==(b=a[10].Xi)||b.notify(7);a[2]&64&&(a[2]|=1024);Kg(a)&&Mg(a)}function Mg(a){let b;null==(b=a[10].Xi)||b.notify(0);for(a=Ng(a);null!==a&&!(a[2]&8192);){a[2]|=8192;if(128!==(a[2]&128))break;a=Ng(a)}}
function Og(a,b){if(256===(a[2]&256))throw new Yd(911,!1);null===a[21]&&(a[21]=[]);a[21].push(b)}function Ng(a){a=a[3];return Ag(a)?a[3]:a};var Qg=Pg(null),Rg=null;let Sg=!1;function Tg(){return Qg.Sf}function u(a){Qg.Bh=a;return a[8]}function x(a){Qg.Bh=null;return a}function Ug(){let a=Qg.Eh;for(;null!==a&&64===a.type;)a=a.parent;return a}function Vg(a,b){const c=Qg;c.Eh=a;c.Rf=b}function Wg(){const a=Qg;let b=a.Vm;-1===b&&(b=a.Vm=a.tb.aq);return b}function Xg(a){const b=Qg,c=b.cd;b.cd+=a;return c}function Yg(a){const b=Qg.dj;return-1===b?null:a[b]}
function Zg(a,b,c){if(c&4){for(;!(b=b.parent,null!==b||c&1);){b=a[1];b=2===b.type?b.zv:1===b.type?a[5]:null;if(null===b)break;a=a[14];if(b.type&10)break}if(null===b)return!1}c=Qg=$g();c.Eh=b;c.Sf=a;return!0}function ah(a){const b=$g(),c=a[1];Qg=b;b.Eh=c.firstChild;b.Sf=a;b.tb=c;b.Bh=a;b.cd=c.aq;b.fw=!1}function $g(){const a=Qg,b=null===a?null:a.Gf;return null===b?Pg(a):b}
function Pg(a){const b={Eh:null,Rf:!0,Sf:null,tb:null,selectedIndex:-1,Bh:null,pn:0,Vk:null,dj:-1,Vm:-1,cd:-1,be:0,parent:a,Gf:null,fw:!1};null!==a&&(a.Gf=b);return b}function bh(){const a=Qg;Qg=a.parent;a.Eh=null;a.Sf=null;return a}function ch(){const a=bh();a.Rf=!0;a.tb=null;a.selectedIndex=-1;a.Bh=null;a.pn=0;a.dj=-1;a.Vk=null;a.Vm=-1;a.cd=-1;a.be=0}function dh(){const a=Qg;return a.tb.data[a.selectedIndex]}function eh(){Qg.Vk="svg"}let fh=!0;function gh(a,b){for(let d=b.ld,e=b.ve;d<e;d++){var c=a.data[d].type.prototype;b=c.yj;const f=c.Kw,g=c.nd,k=c.Lw;c=c.ua;if(b){let m,p;(null!=(p=(m=a).Sk)?p:m.Sk=[]).push(-d,b)}if(f){let m,p;(null!=(p=(m=a).Sk)?p:m.Sk=[]).push(d,f);let t,v;(null!=(v=(t=a).kq)?v:t.kq=[]).push(d,f)}if(g){let m,p;(null!=(p=(m=a).km)?p:m.km=[]).push(-d,g)}if(k){let m,p;(null!=(p=(m=a).km)?p:m.km=[]).push(d,k);let t,v;(null!=(v=(t=a).Ns)?v:t.Ns=[]).push(d,k)}if(null!=c){let m,p;(null!=(p=(m=a).Wk)?p:m.Wk=[]).push(d,c)}}}
function hh(a,b,c,d){(a[2]&3)===c&&ih(a,b,c,d)}function jh(a,b){let c=a[2];(c&3)===b&&(a[2]=(c&16383)+1)}function ih(a,b,c,d){var e=void 0!==d?a[17]&65535:0;const f=null!=d?d:-1,g=b.length-1;let k=0;for(;e<g;e++)if("number"===typeof b[e+1]){if(k=b[e],null!=d&&k>=d)break}else{0>b[e]&&(a[17]+=65536);if(k<f||-1==f){const m=0>b[e],p=b[e+1],t=a[m?-b[e]:b[e]];m?a[2]>>14<a[17]>>16&&(a[2]&3)===c&&(a[2]+=16384,kh(t,p)):kh(t,p);a[17]=(a[17]&4294901760)+e+2}e++}}
function kh(a,b){const c=pe(null);try{b.call(a)}finally{pe(c)}};var lh=class{constructor(a,b){var c=y;this.aa=a;this.D=!1;this.G=b;this.F=c}};function mh(a,b){for(a>>=16;0<a;)b=b[14],a--;return b};let nh=!0;function oh(a){const b=nh;nh=a;return b}let ph=0;const qh={};function rh(a,b,c){let d;"string"===typeof c?d=c.charCodeAt(0)||0:c.hasOwnProperty(de)&&(d=c[de]);null==d&&(d=c[de]=ph++);c=d&255;b.data[a+(c>>5)]|=1<<c}function sh(a,b){var c=th(a,b);if(-1!==c)return c;c=b[1];c.Ac&&(a.xd=b.length,uh(c.data,a),uh(b,null),uh(c.qg,null));c=vh(a,b);a=a.xd;if(-1!==c){const d=c&32767,e=mh(c,b),f=e[1].data;for(let g=0;8>g;g++)b[a+g]=e[d+g]|f[d+g]}b[a+8]=c;return a}
function uh(a,b){a.push(0,0,0,0,0,0,0,0,b)}function th(a,b){return-1===a.xd||a.parent&&a.parent.xd===a.xd||null===b[a.xd+8]?-1:a.xd}function vh(a,b){if(a.parent&&-1!==a.parent.xd)return a.parent.xd;a=0;let c=b;for(;null!==c;){b=wh(c);if(null===b)break;a++;c=c[14];if(-1!==b.xd)return b.xd|a<<16}return-1}
function xh(a){var b=Ug();if("class"===a)return b.Yi;if("style"===a)return b.styles;if(b=b.attrs){const c=b.length;let d=0;for(;d<c;){const e=b[d];if(3===e||4===e||6===e)break;if(0===e)d+=2;else if("number"===typeof e)for(d++;d<c&&"string"===typeof b[d];)d++;else{if(e===a)return b[d+1];d+=2}}}return null}function yh(a,b,c,d){c&8&&void 0===d&&(d=null);if(0===(c&3)){a=a[9];const e=Xe();try{return a?a.get(b,d,c&8):Ye(b,d,c&8)}finally{Xe(e)}}c&8||void 0!==d?b=d:(je(),b=void 0);return b}
function zh(a,b,c,d=0,e){if(null!==a){if(b[2]&2048&&!(d&2)){a:{var f=qh;var g=a;let k=b;for(;null!==g&&null!==k&&k[2]&2048&&!(k[2]&512);){const m=Ah(g,k,c,d|2);if(m!==qh){f=m;break a}g=g.parent;if(!g){if(g=k[20])if(g=g.get(c,qh,d),g!==qh){f=g;break a}g=wh(k);k=k[14]}}}if(f!==qh)return f}a=Ah(a,b,c,d);if(a!==qh)return a}return yh(b,c,d,e)}
function Ah(a,b,c,d){var e=qh;if("string"===typeof c)var f=c.charCodeAt(0)||0;else f=c.hasOwnProperty(de)?c[de]:void 0,f="number"===typeof f?0<=f?f&255:Bh:f;if("function"===typeof f){if(!Zg(b,a,d))return d&1?d&8||void 0!==e?b=e:(je(),b=void 0):b=yh(b,c,d,e),b;try{var g=f(d);if(null!=g||d&8)return g;je()}finally{bh()}}else if("number"===typeof f){g=null;let m=th(a,b);let p=d&1?b[15][5]:null;if(-1===m||d&4){var k=-1===m?vh(a,b):b[m+8];-1===k||d&2?m=-1:(g=b[1],m=k&32767,b=mh(k,b))}for(;-1!==m;){a=b[1];
if(a.data[m+(f>>5)]&1<<f){k=b[1];const t=k.data[m+8],v=Ch(t,k,c,null==g?-1<t.If&&nh:g!=k&&0!==(t.type&3),d&1&&p===t);k=null!==v?Dh(b,k,v,t):qh;if(k!==qh)return k}k=b[m+8];-1!==k&&!(d&2||d&1&&b[1].data[m+8]===p)&&b[m+(f>>5)]&1<<f?(g=a,m=k&32767,b=mh(k,b)):m=-1}}return e}function Ch(a,b,c,d,e){var f=a.Jg;const g=b.data;var k=f&1048575;b=a.ld;a=a.ve;f>>=20;d=d?k:k+f;for(k=e?k+f:a;d<k;d++)if(f=g[d],d<b&&c===f||d>=b&&f.type===c)return d;return e&&(e=g[b])&&e.sa&&e.type===c?b:null}
function Dh(a,b,c,d){let e=a[c];const f=b.data;if(e instanceof lh){const k=e;if(k.D)throw a=f[c],new Yd(-200,"function"===typeof a?a.name||a.toString():"object"===typeof a&&null!=a&&"function"===typeof a.type?a.type.name||a.type.toString():fe(a));const m=oh(k.G);k.D=!0;const p=k.F?Xe(k.F):null;Zg(a,d,0);try{if(e=a[c]=k.aa(void 0,f,a,d),b.Ac&&c>=d.ld){var g=f[c];const t=g.type.prototype.Eb,v=g.type.prototype.zj;if(g.type.prototype.rc){const B=Dg(g);let G;(null!=(G=b.kf)?G:b.kf=[]).push(c,B);let K;
(null!=(K=b.Ig)?K:b.Ig=[]).push(c,B)}if(t){let B;(null!=(B=b.kf)?B:b.kf=[]).push(-c,t)}if(v){let B;(null!=(B=b.kf)?B:b.kf=[]).push(c,v);let G;(null!=(G=b.Ig)?G:b.Ig=[]).push(c,v)}}}finally{null!==p&&Xe(p),oh(m),k.D=!1,bh()}}return e}var Eh=class{constructor(a,b){this.D=a;this.C=b}get(a,b,c){return zh(this.D,this.C,a,mf(c),b)}};function Bh(){return new Eh(Ug(),Tg())}
function Lh(a){return Df(()=>{var b=a.prototype.constructor;b=b[ce]||Mh(b);const c=Object.prototype;let d=Object.getPrototypeOf(a.prototype).constructor;for(;d&&d!==c;){const e=d[ce]||Mh(d);if(e&&e!==b)return e;d=Object.getPrototypeOf(d)}return e=>new e})}function Mh(a){return cf(a)?()=>{const b=Mh(bf(a));return b&&b()}:Qf(a)}function wh(a){const b=a[1],c=b.type;return 2===c?b.zv:1===c?a[5]:null};(new df("")).vf=a=>{const b=Ug();if(null===b)throw new Yd(204,!1);if(b.type&2)return b.value;if(a&8)return null;throw new Yd(204,!1);};function Nh(a){return function(...b){if(a){b=a(...b);for(const c in b)this[c]=b[c]}}}function Oh(a){return Df(()=>{function b(...d){if(this instanceof b)return c.apply(this,d),this;const e=new b(...d);return function(f,g,k){for(g=f.hasOwnProperty("__parameters__")?f.__parameters__:Object.defineProperty(f,"__parameters__",{value:[]}).__parameters__;g.length<=k;)g.push(null);(g[k]=g[k]||[]).push(e);return f}}const c=Nh(a);return b})};var Ph=of(Oh(a=>({la:a})),-1),Qh=of(Oh(),8);of(Oh(),2);var Rh=of(Oh(),4);of(Oh(),1);Kd({na:String,mb:Kd});function Sh(a,b=null,c=null,d){a=Th(a,b,c,d);ng(a);return a}function Th(a,b=null,c=null,d,e=new Set){c=[c||Ff,Wf(a)];d=d||("object"===typeof a?void 0:ge(a));return new tg(c,b||hg(),d||null,e)};function Uh(a){if(Array.isArray(a))return Sh({name:""},void 0,a,"");let b;const c=null!=(b=a.name)?b:"";return Sh({name:c},a.parent,a.Ua,c)}var Vh=class{},Wh=new tf;Vh.oa=Ld({la:Vh,da:"any",aa:()=>q(rf)});Vh.vf=-1;var Xh=class{};var Yh=class{},Zh=class{};var $h=class{},ai=new df("",{da:"root",aa:()=>!1}),bi=new df("");let ci=void 0;const di=new Map;let ei=0;function fi(a,b){yg(b)?(a.__ngContext__=b[19],di.set(b[19],b)):a.__ngContext__=b};function gi(a){for(;null!==a&&!Ag(a);)a=a[4];return a};var hi=new df("",{da:"root",aa:()=>"ng"}),ii=new df(""),ji=new df("",{da:"platform",aa:()=>"unknown"});new df("");var ki=new df(""),li=new df("",{da:"root",aa:()=>{let a,b;if(void 0!==ci)var c=ci;else if("undefined"!==typeof document)c=document;else throw new Yd(210,!1);return(null==(a=c.body)?void 0:null==(b=a.querySelector("[ngCspNonce]"))?void 0:b.getAttribute("ngCspNonce"))||null}}),mi={Nu:[16,32,48,64,96,128,256,384,640,750,828,1080,1200,1920,2048,3840],jG:30,DF:!1,CF:!1};
new df("",{da:"root",aa:()=>mi});var ni=class{},oi=class{};function pi(a,b){return new qi(Hg(a,b))}var qi=class{constructor(a){this.P=a}};qi.vf=function(){return pi(Ug(),Tg())};function ri(a){return a instanceof qi?a.P:a};var si=class{},ti=class{constructor(){this.Xk=null}};ti.vf=()=>{const a=Tg(),b=Ig(Ug().index,a);return(yg(b)?b:a)[11]};var ui=class{constructor(){this.st=console}handleError(a){const b=this.Oz(a);this.st.error("ERROR",a);b&&this.st.error("ORIGINAL ERROR",b)}Oz(a){for(a=a&&a.ngOriginalError;a&&a.ngOriginalError;)a=a.ngOriginalError;return a||null}},vi=new df("",{da:"root",aa:()=>lf(ui).handleError.bind(this)});var wi=class{};wi.vf=xi;wi.wz=a=>a;class yi extends wi{constructor(){var a=Tg();super();this.C=a}nb(a){Og(this.C,a);return()=>{var b=this.C;if(null!==b[21]){var c=b[21].indexOf(a);-1!==c&&b[21].splice(c,1)}}}}function xi(){return new yi};function zi(a){return a.ownerDocument.defaultView}function Ai(a){return a.ownerDocument};const Bi=new Set;function Ci(a){if(!Bi.has(a)){Bi.add(a);var b,c;null==(b=performance)||null==(c=b.mark)||c.call(b,"mark_feature_usage",{detail:{NF:a}})}};/*


 Copyright (c) 2015-2018 Google, Inc., Netflix, Inc., Microsoft Corp. and contributors
 Licensed under the Apache License, Version 2.0 (the "License");
 you may not use this file except in compliance with the License.
 You may obtain a copy of the License at
     http://www.apache.org/licenses/LICENSE-2.0
 Unless required by applicable law or agreed to in writing, software
 distributed under the License is distributed on an "AS IS" BASIS,
 WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 See the License for the specific language governing permissions and
 limitations under the License.
*/
let Di=!1,Ei=!1;
var Fi={set Xj(a){this.CD||(a?console.warn("DEPRECATED! RxJS was set to use deprecated synchronous error handling behavior by code at: \n"+Error().stack):Di&&console.log("RxJS: Back to a better error behavior. Thank you. <3"));Di=a},get Xj(){return Di},set zy(a){this.CD||(a?console.warn("DEPRECATED! RxJS was set to use deprecated next context. This will result in deoptimizations when creating any new subscription. \n"+Error().stack):Ei&&console.log("RxJS: back to more optimized subscription creation. Thank you. <3"));Ei=
a},get zy(){return Ei}};function Gi(a){setTimeout(()=>{throw a;},0)};var Hi={closed:!0,next(){},error(a){if(Fi.Xj)throw a;Gi(a)},complete(){}};function Ii(a){a=a(b=>{b.name=b.constructor.name;b.stack=Error().stack});a.prototype=Object.create(Error.prototype);return a.prototype.constructor=a};var Ji=Ii(a=>function(b){a(this);this.message=b?`${b.length} errors occurred during unsubscription:
${b.map((c,d)=>`${d+1}) ${c.toString()}`).join("\n  ")}`:"";this.name="UnsubscriptionError";this.errors=b});function Ki(a){return"function"===typeof a};var Li=class{constructor(){this.pC=void 0;this.closed=!1;this.Oi=this.ac=this.lg=null}unsubscribe(){let a;if(!this.closed){this.closed=!0;const c=this.lg;let d;if(c)this.lg=null,c.remove(this);else if(d=this.ac){this.ac=null;for(var b of d)b.remove(this)}b=this.pC;if(Ki(b))try{b()}catch(f){a=f instanceof Ji?f.errors:[f]}const e=this.Oi;this.Oi=null;if(e)for(const f of e)try{"function"===typeof f?f():f.unsubscribe()}catch(g){let k;a=null!=(k=a)?k:[];g instanceof Ji?a=[...a,...g.errors]:a.push(g)}if(a)throw new Ji(a);
}}add(a){if(a&&a!==this)if(this.closed)"function"===typeof a?a():a.unsubscribe();else{if(a instanceof Li){if(a.closed||a.dA(this))return;a.yz(this)}let b;this.Oi=null!=(b=this.Oi)?b:[];this.Oi.push(a)}}dA(a){let b;return this.lg===a||(null==(b=this.ac)?void 0:b.includes(a))||!1}yz(a){const b=this.lg;let c;b?(this.ac=[b,a],this.lg=null):(c=this.ac)?c.push(a):this.lg=a}BA(a){const b=this.lg;let c;if(b)b===a&&(this.lg=null);else if(c=this.ac)a=c.indexOf(a),0<=a&&c.splice(a,1)}remove(a){const b=this.Oi;
if(b){const c=b.indexOf(a);0<=c&&b.splice(c,1)}a instanceof Li&&a.BA(this)}},Mi=new Li;Mi.closed=!0;Li.EMPTY=Mi;function Ni(a){return a instanceof Li||a&&"closed"in a&&"function"===typeof a.remove&&"function"===typeof a.add&&"function"===typeof a.unsubscribe};var Oi=class extends Li{static create(a,b,c){a=new Oi(a,b,c);a.ag=!1;return a}constructor(a,b,c){super();this.Es=null;this.Qb=this.ag=this.Ds=!1;switch(arguments.length){case 0:this.destination=Hi;break;case 1:if(!a){this.destination=Hi;break}if("object"===typeof a){a instanceof Oi?(this.ag=a.ag,this.destination=a,a.add(this)):(this.ag=!0,this.destination=new Pi(this,a));break}default:this.ag=!0,this.destination=new Pi(this,a,b,c)}}next(a){this.Qb||this.Na(a)}error(a){this.Qb||(this.Qb=!0,this.oe(a))}complete(){this.Qb||
(this.Qb=!0,this.mc())}unsubscribe(){this.closed||(this.Qb=!0,super.unsubscribe())}Na(a){this.destination.next(a)}oe(a){this.destination.error(a);this.unsubscribe()}mc(){this.destination.complete();this.unsubscribe()}},Pi=class extends Oi{constructor(a,b,c,d){super();this.C=a;let e;if(Ki(b))e=b;else if(b&&(e=b.next,c=b.error,d=b.complete,b!==Hi)){let f;Fi.zy?(f=Object.create(b),f.unsubscribe=this.unsubscribe.bind(this)):f=b;e=e&&e.bind(f);c=c&&c.bind(f);d=d&&d.bind(f);Ni(b)&&b.add(this.unsubscribe.bind(this))}this.Na=
e;this.oe=c;this.mc=d}next(a){if(!this.Qb&&this.Na)try{this.Na(a)}catch(b){this.i(b)}}error(a){if(!this.Qb)if(this.oe){try{this.oe(a)}catch(b){this.i(b);return}this.unsubscribe()}else this.i(a)}i(a){this.unsubscribe();if(Fi.Xj){const b=this.C;if(null==b?0:b.ag)b.Es=a,b.Ds=!0;else throw a;}else Gi(a)}complete(){if(!this.Qb){if(this.mc)try{this.mc()}catch(a){this.i(a);return}this.unsubscribe()}}unsubscribe(){if(!this.closed){const a=this.C;this.C=null;a.unsubscribe();super.unsubscribe()}}};var Qi="function"===typeof Symbol&&Symbol.observable||"@@observable";function Ri(a){return a};function Si(a){return 0===a.length?Ri:1===a.length?a[0]:function(b){return a.reduce((c,d)=>d(c),b)}};function Ti(a){return a&&"function"===typeof a.next&&"function"===typeof a.error&&"function"===typeof a.complete}class Ui extends Oi{constructor(a){super();this.destination=a}};function C(a,...b){return 0===b.length?a:Si(b)(a)}
var Vi=class{constructor(a){a&&(this.re=a)}Vn(a){const b=new Vi;b.source=this;b.operator=a;return b}subscribe(a,b,c){const d=this.operator;a:{if(a){if(a instanceof Oi||Ti(a)&&Ni(a))break a;if(Ti(a)){a=new Ui(a);break a}}a=a||b||c?new Oi(a,b,c):new Oi(Hi)}d?a.add(d.call(a,this.source)):a.add(this.source||Fi.Xj&&!a.ag?this.re(a):this.C(a));if(Fi.Xj&&a.ag&&(a.ag=!1,a.Ds))throw a.Es;return a}C(a){try{return this.re(a)}catch(c){if(Fi.Xj)a.Ds=!0,a.Es=c;else{var b;a:{for(b=a;b;){const d=b.destination,e=
b.Qb;if(b.closed||e){b=!1;break a}d&&d instanceof Oi?b=d:b=null}b=!0}b?a.error(c):console.warn(c)}}}forEach(a,b){b=Wi(b);return new b((c,d)=>{let e;e=this.subscribe(f=>{try{a(f)}catch(g){d(g),e&&e.unsubscribe()}},d,c)})}re(a){const b=this.source;return b&&b.subscribe(a)}[Qi](){return this}};Vi.create=a=>new Vi(a);function Wi(a){a||(a=Promise);if(!a)throw Error("no Promise impl found");return a};var Xi=class extends Li{constructor(a,b){super();this.Tg=a;this.Bs=b;this.closed=!1}unsubscribe(){if(!this.closed){this.closed=!0;var a=this.Tg,b=a.kc;this.Tg=null;!b||0===b.length||a.Qb||a.closed||(a=b.indexOf(this.Bs),-1!==a&&b.splice(a,1))}}};var Yi=Ii(a=>function(){a(this);this.message="object unsubscribed"});function Zi(a){const b=new Vi;b.source=a;return b}
var aj=class extends Vi{constructor(){super();this.kc=[];this.ye=this.Qb=this.closed=!1;this.i=null}Vn(a){const b=new $i(this,this);b.operator=a;return b}next(a){if(this.closed)throw new Yi;if(!this.Qb){var b=this.kc;const c=b.length;b=b.slice();for(let d=0;d<c;d++)b[d].next(a)}}error(a){if(this.closed)throw new Yi;this.ye=!0;this.i=a;this.Qb=!0;var b=this.kc;const c=b.length;b=b.slice();for(let d=0;d<c;d++)b[d].error(a);this.kc.length=0}complete(){if(this.closed)throw new Yi;this.Qb=!0;var a=this.kc;
const b=a.length;a=a.slice();for(let c=0;c<b;c++)a[c].complete();this.kc.length=0}unsubscribe(){this.closed=this.Qb=!0;this.kc=null}C(a){if(this.closed)throw new Yi;return super.C(a)}re(a){if(this.closed)throw new Yi;if(this.ye)return a.error(this.i),Li.EMPTY;if(this.Qb)return a.complete(),Li.EMPTY;this.kc.push(a);return new Xi(this,a)}};aj.create=(a,b)=>new $i(a,b);
var $i=class extends aj{constructor(a,b){super();this.destination=a;this.source=b}next(a){const b=this.destination;b&&b.next&&b.next(a)}error(a){this.destination&&this.destination.error(a)}complete(){this.destination&&this.destination.complete()}re(a){return this.source?this.source.subscribe(a):Li.EMPTY}};function bj(a){if(a.ye)throw a.i;if(a.closed)throw new Yi;return a.kd}var cj=class extends aj{constructor(a){super();this.kd=a}get value(){return bj(this)}re(a){const b=super.re(a);b&&!b.closed&&a.next(this.kd);return b}next(a){super.next(this.kd=a)}};var dj=new Vi(a=>a.complete());function ej(a,b){return new Vi(c=>{const d=new Li;let e=0;d.add(b.Mc(function(){e===a.length?c.complete():(c.next(a[e++]),c.closed||d.add(this.Mc()))}));return d})};var fj=a=>b=>{for(let c=0,d=a.length;c<d&&!b.closed;c++)b.next(a[c]);b.complete()};function gj(a){return a&&"function"===typeof a.Mc};function hj(...a){let b=a[a.length-1];return gj(b)?(a.pop(),ej(a,b)):new Vi(fj(a))};function ij(a){return new Vi(b=>b.error("function"===typeof a?a():a))};var jj={now(){return(jj.qb||Date).now()},qb:void 0};var kj=class extends aj{constructor(a=Infinity,b=Infinity,c=jj){super();this.T=c;this.Ab=[];this.G=!1;this.D=1>a?1:a;this.N=1>b?1:b;Infinity===b?(this.G=!0,this.next=this.O):this.next=this.R}O(a){if(!this.Qb){const b=this.Ab;b.push(a);b.length>this.D&&b.shift()}super.next(a)}R(a){this.Qb||(this.Ab.push({time:this.F(),value:a}),this.K());super.next(a)}re(a){const b=this.G,c=b?this.Ab:this.K(),d=c.length;let e;if(this.closed)throw new Yi;this.Qb||this.ye?e=Li.EMPTY:(this.kc.push(a),e=new Xi(this,a));
if(b)for(var f=0;f<d&&!a.closed;f++)a.next(c[f]);else for(f=0;f<d&&!a.closed;f++)a.next(c[f].value);this.ye?a.error(this.i):this.Qb&&a.complete();return e}F(){const a=this.T;return a?a.now():jj.now()}K(){const a=this.F(),b=this.D,c=this.N,d=this.Ab,e=d.length;let f=0;for(;f<e&&!(a-d[f].time<c);)f++;e>b&&(f=Math.max(f,e-b));0<f&&d.splice(0,f);return d}};var mj=class{constructor(a,b=lj){this.C=a;this.now=b}Mc(a,b=0,c){return(new this.C(this,a)).Mc(c,b)}},lj=jj.now;var nj=Ii(a=>function(){a(this);this.message="no elements in sequence"});var oj=class extends Oi{constructor(a,b,c,d){super(a);this.i=d;b&&(this.Na=function(e){try{null==b||b(e)}catch(f){this.error(f)}});c&&(this.mc=function(){try{c()}catch(e){this.destination.error(e)}this.unsubscribe()})}unsubscribe(){let a;this.closed||null!=(a=this.i)&&a.call(this);super.unsubscribe()}};function pj(a,b){if(a&&"function"===typeof a.Vn)return a.Vn(b);throw new TypeError("Unable to lift unknown Observable type");};function qj(){return a=>pj(a,function(b){const c=this;let d=null;b.zk++;const e=new oj(c,void 0,void 0,()=>{if(!b||0>=b.zk||0<--b.zk)d=null;else{var g=b.Ci,k=d;d=null;!g||k&&g!==k||g.unsubscribe();c.unsubscribe()}}),f=b.subscribe(e);e.closed||(d=b.connect());return f})};var sj=class extends Vi{constructor(a,b){super();this.source=a;this.hy=b;this.zk=0;this.Bm=!1}re(a){return this.Dn().subscribe(a)}Dn(){const a=this.wh;if(!a||a.Qb)this.wh=this.hy();return this.wh}connect(){let a=this.Ci;a||(this.Bm=!1,a=this.Ci=new Li,a.add(this.source.subscribe(new rj(this.Dn(),this))),a.closed&&(this.Ci=null,a=Li.EMPTY));return a}Ql(){return qj()(this)}},tj;const uj=sj.prototype;
tj={operator:{value:null},zk:{value:0,writable:!0},wh:{value:null,writable:!0},Ci:{value:null,writable:!0},re:{value:uj.re},Bm:{value:uj.Bm,writable:!0},Dn:{value:uj.Dn},connect:{value:uj.connect},Ql:{value:uj.Ql}};
class rj extends Oi{constructor(a,b){super();this.destination=a;this.C=b}oe(a){this.i();super.oe(a)}mc(){this.C.Bm=!0;this.i();super.mc()}i(){const a=this.C;if(a){this.C=null;const b=a.Ci;a.zk=0;a.wh=null;a.Ci=null;b&&b.unsubscribe()}}unsubscribe(){this.closed||(this.i(),super.unsubscribe())}};function vj(a){return function(b){if("function"!==typeof a)throw new TypeError("argument is not a function. Are you looking for `mapTo()`?");return pj(b,new wj(a))}}var wj=class{constructor(a){this.project=a}call(a,b){return b.subscribe(new xj(a,this.project))}};class xj extends Oi{constructor(a,b){super(a);this.project=b;this.count=0;this.i=this}Na(a){let b;try{b=this.project.call(this.i,a,this.count++)}catch(c){this.destination.error(c);return}this.destination.next(b)}};var yj=Array.isArray||(a=>a&&"number"===typeof a.length);var zj="function"===typeof Symbol&&Symbol.iterator?Symbol.iterator:"@@iterator";function Aj(a){return null!==a&&"object"===typeof a};function Bj(a){return b=>{Cj(a,b).catch(c=>b.error(c))}}
function Cj(a,b){return sa(function*(){var c;try{var d,e=a[Symbol.asyncIterator];if(void 0!==e)var f=e.call(a);else{var g="undefined"!=typeof Symbol&&Symbol.iterator&&a[Symbol.iterator];if(g)var k=g.call(a);else if("number"==typeof a.length)k={next:ba(a)};else throw Error(String(a)+" is not an iterable or ArrayLike");f=new ta(k)}for(d=f;;){var m=yield d.next();if(m.done)break;b.next(m.value)}}catch(t){var p={error:t}}finally{try{m&&!m.done&&(c=d.return)&&(yield c.call(d))}finally{if(p)throw p.error;
}}b.complete()})};var Dj=a=>b=>{const c=a[zj]();do{let d;try{d=c.next()}catch(e){b.error(e);return}if(d.done){b.complete();break}b.next(d.value);if(b.closed)break}while(1);"function"===typeof c.return&&b.add(()=>{c.return&&c.return()});return b};var Ej=a=>b=>{const c=a[Qi]();if("function"!==typeof c.subscribe)throw new TypeError("Provided object does not correctly implement Symbol.observable");return c.subscribe(b)};var Fj=a=>b=>{a.then(c=>{b.closed||(b.next(c),b.complete())},c=>b.error(c)).then(null,Gi);return b};var Gj=a=>{if(a&&"function"===typeof a[Qi])return Ej(a);if(a&&"number"===typeof a.length&&"function"!==typeof a)return fj(a);if(a&&"function"!==typeof a.subscribe&&"function"===typeof a.then)return Fj(a);if(a&&"function"===typeof a[zj])return Dj(a);if(Symbol&&Symbol.asyncIterator&&a&&"function"===typeof a[Symbol.asyncIterator])return Bj(a);throw new TypeError(`You provided ${Aj(a)?"an invalid object":`'${a}'`} where a stream was expected.`+" You can provide an Observable, Promise, Array, or Iterable.");
};var Hj=class extends Oi{constructor(a){super();this.parent=a}Na(a){this.parent.Eg(a)}oe(a){this.parent.zr(a);this.unsubscribe()}mc(){this.parent.Dg();this.unsubscribe()}},Ij=class extends Oi{constructor(a,b){super();this.parent=a;this.i=b}Na(a){this.parent.Eg(null,a,this.i)}oe(a){this.parent.zr(a);this.unsubscribe()}mc(){this.parent.Dg();this.unsubscribe()}},Jj=class extends Oi{Eg(a){this.destination.next(a)}zr(a){this.destination.error(a)}Dg(){this.destination.complete()}},Kj=class extends Oi{Eg(a,
b){this.destination.next(b)}zr(a){this.destination.error(a)}Dg(){this.destination.complete()}};function Lj(a,b){if(!b.closed)return a instanceof Vi?a.subscribe(b):Gj(a)(b)};const Mj={};function Nj(...a){let b=void 0,c=void 0,d=void 0;gj(a[a.length-1])&&(c=a.pop());"function"===typeof a[a.length-1]&&(b=a.pop());if(1===a.length){const e=a[0];yj(e)&&(a=e);Aj(e)&&Object.getPrototypeOf(e)===Object.prototype&&(d=Object.keys(e),a=d.map(f=>e[f]))}return pj(c?ej(a,c):new Vi(fj(a)),new Oj(b,d))}
var Oj=class{constructor(a,b){this.i=a;this.keys=b}call(a,b){return b.subscribe(new Pj(a,this.i,this.keys))}},Pj=class extends Kj{constructor(a,b,c){super(a);this.C=b;this.keys=c;this.active=0;this.values=[];this.D=[]}Na(a){this.values.push(Mj);this.D.push(a)}mc(){const a=this.D,b=a.length;if(0===b)this.destination.complete();else{this.i=this.active=b;for(let c=0;c<b;c++)this.add(Lj(a[c],new Ij(this,c)))}}Dg(){0===--this.active&&this.destination.complete()}Eg(a,b,c){const d=this.values;var e=d[c];
e=this.i?e===Mj?--this.i:this.i:0;d[c]=b;0===e&&(this.C?this.F(d):this.destination.next(this.keys?this.keys.reduce((f,g,k)=>(f[g]=d[k],f),{}):d.slice()))}F(a){let b;try{b=this.C.apply(this,a)}catch(c){this.destination.error(c);return}this.destination.next(b)}};function Qj(a){return a instanceof Vi?a:new Vi(Gj(a))};function Rj(a,b){var c=Infinity;if("function"===typeof b)return d=>C(d,Rj((e,f)=>C(Qj(a(e,f)),vj((g,k)=>b(e,g,f,k))),c));"number"===typeof b&&(c=b);return d=>pj(d,new Sj(a,c))}
var Sj=class{constructor(a,b=Infinity){this.project=a;this.i=b}call(a,b){return b.subscribe(new Tj(a,this.project,this.i))}},Tj=class extends Jj{constructor(a,b,c=Infinity){super(a);this.destination=a;this.project=b;this.D=c;this.C=!1;this.i=[];this.index=this.active=0}Na(a){if(this.active<this.D){let b;const c=this.index++;try{b=this.project(a,c)}catch(d){this.destination.error(d);return}this.active++;a=new Hj(this);this.destination.add(a);Lj(b,a)}else this.i.push(a)}mc(){this.C=!0;0===this.active&&
0===this.i.length&&this.destination.complete();this.unsubscribe()}Eg(a){this.destination.next(a)}Dg(){const a=this.i;this.active--;0<a.length?this.Na(a.shift()):0===this.active&&this.C&&this.destination.complete()}};function ek(a=Infinity){return Rj(Ri,a)};function fk(...a){return ek(1)(hj(...a))};function gk(a){return new Vi(b=>{let c;try{c=a()}catch(d){b.error(d);return}return Qj(c).subscribe(b)})};function hk(...a){if(1===a.length){const b=a[0];if(yj(b))return ik(b,null);if(Aj(b)&&Object.getPrototypeOf(b)===Object.prototype)return a=Object.keys(b),ik(a.map(c=>b[c]),a)}if("function"===typeof a[a.length-1]){const b=a.pop();a=1===a.length&&yj(a[0])?a[0]:a;return C(ik(a,null),vj(c=>b(...c)))}return ik(a,null)}
function ik(a,b){return new Vi(c=>{const d=a.length;if(0===d)c.complete();else{var e=Array(d),f=0,g=0;for(let k=0;k<d;k++){const m=Qj(a[k]);let p=!1;c.add(m.subscribe({next:t=>{p||(p=!0,g++);e[k]=t},error:t=>c.error(t),complete:()=>{f++;f!==d&&p||(g===d&&c.next(b?b.reduce((t,v,B)=>(t[v]=e[B],t),{}):e),c.complete())}}))}}})};function jk(a,b,c){if(Ki(c)){var d=c;c=void 0}return d?C(jk(a,b,c),vj(e=>yj(e)?d(...e):d(e))):new Vi(e=>{kk(a,b,function(f){1<arguments.length?e.next(Array.prototype.slice.call(arguments)):e.next(f)},e,c)})}
function kk(a,b,c,d,e){let f;if(a&&"function"===typeof a.addEventListener&&"function"===typeof a.removeEventListener)a.addEventListener(b,c,e),f=()=>a.removeEventListener(b,c,e);else if(a&&"function"===typeof a.on&&"function"===typeof a.off)a.on(b,c),f=()=>a.off(b,c);else if(a&&"function"===typeof a.addListener&&"function"===typeof a.removeListener)a.addListener(b,c),f=()=>a.removeListener(b,c);else if(a&&a.length)for(let g=0,k=a.length;g<k;g++)kk(a[g],b,c,d,e);else throw new TypeError("Invalid event target");
d.add(f)};var lk=class extends Li{Mc(){return this}};var mk=class extends lk{constructor(a,b){super();this.scheduler=a;this.D=b;this.pending=!1}Mc(a,b=0){if(this.closed)return this;this.state=a;a=this.id;const c=this.scheduler;null!=a&&(this.id=this.i(c,a,b));this.pending=!0;this.delay=b;this.id=this.id||this.C(c,this.id,b);return this}C(a,b,c=0){a=a.flush.bind(a,this);return setInterval(a,c)}i(a,b,c=0){if(null!=c&&this.delay===c&&!1===this.pending)return b;clearInterval(b)}lj(a,b){if(this.closed)return Error("executing a cancelled action");this.pending=
!1;if(a=this.F(a,b))return a;!1===this.pending&&null!=this.id&&(this.id=this.i(this.scheduler,this.id,null))}F(a){let b=!1,c=void 0;try{this.D(a)}catch(d){b=!0,c=!!d&&d||Error(d)}if(b)return this.unsubscribe(),c}unsubscribe(){if(!this.closed){const a=this.id,b=this.scheduler,c=b.actions,d=c.indexOf(this);this.state=this.D=null;this.pending=!1;this.scheduler=null;-1!==d&&c.splice(d,1);null!=a&&(this.id=this.i(b,a,null));this.delay=null;super.unsubscribe()}}};var nk=class extends mj{constructor(a,b=lj){super(a,b);this.actions=[];this.active=!1;this.i=void 0}flush(a){const b=this.actions;if(this.active)b.push(a);else{var c;this.active=!0;do if(c=a.lj(a.state,a.delay))break;while(a=b.shift());this.active=!1;if(c){for(;a=b.shift();)a.unsubscribe();throw c;}}}};var ok=new nk(mk);function pk(...a){let b=Infinity,c=void 0,d=a[a.length-1];gj(d)?(c=a.pop(),1<a.length&&"number"===typeof a[a.length-1]&&(b=a.pop())):"number"===typeof d&&(b=a.pop());return!c&&1===a.length&&a[0]instanceof Vi?a[0]:ek(b)(c?ej(a,c):new Vi(fj(a)))};function qk(){};function rk(a){return function(b){return pj(b,new sk(a))}}class sk{constructor(a){this.lf=a}call(a,b){return b.subscribe(new tk(a,this.lf))}}class tk extends Oi{constructor(a,b){super(a);this.lf=b;this.count=0}Na(a){let b;try{b=this.lf.call(void 0,a,this.count++)}catch(c){this.destination.error(c);return}b&&this.destination.next(a)}};function uk(a=0){var b;let c=-1;null!=ok&&(gj(ok)?b=ok:c=ok);gj(b)||(b=ok);return new Vi(d=>{const e=Math.max(0,a instanceof Date&&!isNaN(a)?+a-b.now():a);return b.Mc(vk,e,{counter:0,rD:c,Bs:d})})}function vk(a){const b=a.rD,c=a.Bs,d=a.counter++;c.next(d);if(!c.closed){if(0>b)return c.complete();this.Mc(a,b)}};Ii(a=>function(b=null){a(this);this.message="Timeout has occurred";this.name="TimeoutError";this.info=b});let wk=1,xk;const yk={};function zk(a){return a in yk?(delete yk[a],!0):!1}function Ak(a){const b=wk++;yk[b]=!0;xk||(xk=Promise.resolve());xk.then(()=>zk(b)&&a());return b};var Bk=new class extends nk{flush(a){this.active=!0;this.i=void 0;const b=this.actions;let c,d=-1;a=a||b.shift();let e=b.length;do if(c=a.lj(a.state,a.delay))break;while(++d<e&&(a=b.shift()));this.active=!1;if(c){for(;++d<e&&(a=b.shift());)a.unsubscribe();throw c;}}}(class extends mk{constructor(a,b){super(a,b);this.scheduler=a;this.D=b}C(a,b,c=0){if(null!==c&&0<c)return super.C(a,b,c);a.actions.push(this);return a.i||(a.i=Ak(a.flush.bind(a,void 0)))}i(a,b,c=0){if(null!=c&&0<c||null==c&&0<this.delay)return super.i(a,
b,c);0===a.actions.length&&(zk(b),a.i=void 0)}});Ii(a=>function(){a(this);this.message="argument out of range"});Ii(a=>function(b){a(this);this.message=b});Ii(a=>function(b){a(this);this.message=b});function Ck(a){return!!a&&(a instanceof Vi||"function"===typeof a.Vn&&"function"===typeof a.subscribe)};class Dk extends aj{constructor(a=!1){super();this.F=void 0;this.D=a;if(void 0!==We||null!=hf){let b;this.F=null!=(b=lf(wi,{optional:!0}))?b:void 0}}emit(a){const b=pe(null);try{super.next(a)}finally{pe(b)}}subscribe(a,b,c){var d=a;b=b||(()=>null);if(a&&"object"===typeof a){let e;d=null==(e=a.next)?void 0:e.bind(a);let f;b=null==(f=a.error)?void 0:f.bind(a);let g;c=null==(g=a.complete)?void 0:g.bind(a)}this.D&&(b=Ek(b),d&&(d=Ek(d)),c&&(c=Ek(c)));d=super.subscribe({next:d,error:b,complete:c});a instanceof
Li&&a.add(d);return d}}function Ek(a){return b=>{setTimeout(a,void 0,b)}};function Fk(a){let b=!0;setTimeout(()=>{b&&(b=!1,a())});"function"===typeof ef.requestAnimationFrame&&ef.requestAnimationFrame(()=>{b&&(b=!1,a())});return()=>{b=!1}}function Gk(a){let b=!0;queueMicrotask(()=>{b&&a()});return()=>{b=!1}};function Hk(){};function Ik(){return"undefined"!==typeof Zone&&!0===Zone.current.get("isAngularZone")}function Jk(){if(Ik())throw new Yd(909,!1);}function Kk(a,b){return a.uA.run(b)}
var Ok=class{constructor({HB:a=!1,Bo:b=!1,Wl:c=!1}){this.kl=this.Hn=!1;this.isStable=!0;this.ko=new Dk(!1);this.Ow=new Dk(!1);this.jo=new Dk(!1);this.onError=new Dk(!1);if("undefined"==typeof Zone)throw new Yd(908,!1);Zone.assertZonePatched();this.Ji=0;this.uA=this.Af=Zone.current;Zone.TaskTrackingZoneSpec&&(this.Af=this.Af.fork(new Zone.TaskTrackingZoneSpec));a&&Zone.longStackTraceZoneSpec&&(this.Af=this.Af.fork(Zone.longStackTraceZoneSpec));this.Bo=!c&&b;this.Wl=c;this.Lk=!1;Lk(this)}run(a,b,c){return this.Af.run(a,
b,c)}runTask(a,b,c,d){const e=this.Af;a=e.scheduleEventTask("NgZoneEvent: "+d,a,Nk,Hk,Hk);try{return e.runTask(a,b,c)}finally{e.cancelTask(a)}}runGuarded(a,b,c){return this.Af.runGuarded(a,b,c)}};const Nk={};function Pk(a){if(0==a.Ji&&!a.kl&&!a.isStable)try{a.Ji++,a.Ow.emit(null)}finally{if(a.Ji--,!a.kl)try{Kk(a,()=>a.jo.emit(null))}finally{a.isStable=!0}}}function Qk(a){a.pw||a.Lk||(a.Lk=!0,Zone.root.run(()=>{Fk(()=>{a.Lk=!1;Rk(a);a.pw=!0;Pk(a);a.pw=!1})}),Rk(a))}
function Lk(a){a.Af=a.Af.fork({name:"angular",properties:{isAngularZone:!0},onInvokeTask:(b,c,d,e,f,g)=>{if(Sk(g,"__ignore_ng_zone__"))return b.invokeTask(d,e,f,g);try{return Tk(a),b.invokeTask(d,e,f,g)}finally{(a.Bo&&"eventTask"===e.type||a.Wl)&&Qk(a),a.Ji--,Pk(a)}},onInvoke:(b,c,d,e,f,g,k)=>{try{return Tk(a),b.invoke(d,e,f,g,k)}finally{!a.Wl||a.Lk||Sk(g,"__scheduler_tick__")||Qk(a),a.Ji--,Pk(a)}},onHasTask:(b,c,d,e)=>{b.hasTask(d,e);c===d&&("microTask"==e.vb?(a.eA=e.NC,Rk(a),Pk(a)):"macroTask"==
e.vb&&(a.Hn=e.IC))},onHandleError:(b,c,d,e)=>{b.handleError(d,e);Kk(a,()=>a.onError.emit(e));return!1}})}function Rk(a){a.kl=a.eA||(a.Bo||a.Wl)&&!0===a.Lk?!0:!1}function Tk(a){a.Ji++;a.isStable&&(a.isStable=!1,a.ko.emit(null))}function Sk(a,b){if(!Array.isArray(a)||1!==a.length)return!1;let c,d;return!0===(null==(c=a[0])?void 0:null==(d=c.data)?void 0:d[b])};const Uk={destroy(){}};function Vk(a,b){!b&&xg();let c;const d=null!=(c=null==b?void 0:b.wa)?c:lf(Vh);if("browser"!==(null!=d?d:lf(Vh)).get(ji))return Uk;Ci("NgAfterRender");let e,f;const g=null!=(f=(e=d.get(Wk)).handler)?f:e.handler=new Xk;let k;const m=null!=(k=null==b?void 0:b.Xh)?k:2;b=()=>{g.unregister(t);p()};const p=d.get(wi).nb(b),t=wg(d,()=>new Yk(m,a));g.register(t);return{destroy:b}}
function Zk(a,b){!b&&xg();let c;const d=null!=(c=null==b?void 0:b.wa)?c:lf(Vh);if("browser"!==(null!=d?d:lf(Vh)).get(ji))return Uk;Ci("NgAfterNextRender");let e,f;const g=null!=(f=(e=d.get(Wk)).handler)?f:e.handler=new Xk;let k;const m=null!=(k=null==b?void 0:b.Xh)?k:2,p=()=>{g.unregister(v);t()},t=d.get(wi).nb(p),v=wg(d,()=>new Yk(m,()=>{p();a()}));g.register(v);return{destroy:p}}
class Yk{constructor(a,b){this.Xh=a;this.i=b;this.zone=lf(Ok);this.sn=lf(ui,{optional:!0});let c;null==(c=lf($h,{optional:!0}))||c.notify(6)}invoke(){try{Kk(this.zone,this.i)}catch(a){let b;null==(b=this.sn)||b.handleError(a)}}}
class Xk{constructor(){this.D=!1;this.i={[0]:new Set,[1]:new Set,[2]:new Set,[3]:new Set};this.C=new Set}register(a){(this.D?this.C:this.i[a.Xh]).add(a)}unregister(a){this.i[a.Xh].delete(a);this.C.delete(a)}lj(){this.D=!0;for(const a of Object.values(this.i))for(const b of a)b.invoke();this.D=!1;for(const a of this.C)this.i[a.Xh].add(a);this.C.clear()}destroy(){for(const a of Object.values(this.i))a.clear();this.C.clear()}}function $k(a){const b=[...a.i];a.i.length=0;for(const c of b)c()}
var Wk=class{constructor(){this.handler=null;this.i=[]}lj(){$k(this);let a;null==(a=this.handler)||a.lj()}ua(){let a;null==(a=this.handler)||a.destroy();this.handler=null;this.i.length=0}};Wk.oa=Ld({la:Wk,da:"root",aa:()=>new Wk});function al(a,b){const c=Sg?64:1088;let d;for(null==(d=a[10].Xi)||d.notify(b);a;){a[2]|=c;b=Ng(a);if(0!==(a[2]&512)&&!b)break;a=b}};new df("");var bl=new df("",{da:"root",aa:()=>!1});new df("");new df("");function D(a=1){cl(Qg.tb,Tg(),Qg.selectedIndex+a)}function cl(a,b,c){3===(b[2]&3)?(a=a.Ig,null!==a&&ih(b,a,3,c)):(a=a.kf,null!==a&&hh(b,a,0,c));Qg.selectedIndex=c};function y(a,b=0){const c=Tg();return null===c?q(a,b):zh(Ug(),c,bf(a),b)};function dl(a,b,c,d,e,f){const g=pe(null);try{let k=null;0!==(e&1)&&(k=b[d][oe]);null!==k&&void 0!==k.py&&(f=k.py(f));0!==(e&2)&&(f=a.Ce[d].call(b,f));null!==a.Ao?a.Ao(b,k,f,c,d):(a=k,null!==a?a.Iu(a,f):b[d]=f)}finally{pe(g)}};const el=/^>|^->|\x3c!--|--\x3e|--!>|<!-$/g,fl=/(<|>)/g;function gl(){return"".replace(el,a=>a.replace(fl,"\u200b$1\u200b"))};function hl(a,b,c,d,e){if(null!=d){var f=!1;if(Ag(d))var g=d;else yg(d)&&(f=!0,d=d[0]);d=Gg(d);if(0===a&&null!==c)null==e?b.appendChild(c,d):b.insertBefore(c,d,e||null,!0);else if(1===a&&null!==c)b.insertBefore(c,d,e||null,!0);else if(2===a){const k=b.parentNode(d);k&&b.removeChild(k,d,f)}else 3===a&&b.Xk(d);if(null!=g)for(d=g[7],d!==Gg(g)&&hl(a,b,c,d,e),e=10;e<g.length;e++)f=g[e],il(b,a,f[1].firstChild,f,c,d,!1)}}
function jl(a,b){let c;null==(c=b[10].Xi)||c.notify(8);il(b[11],2,a.firstChild,b,null,null,!1)}function kl(a,b){const c=a[9],d=b[3];yg(d)?a[2]|=2:b[15]!==d[3][15]&&(a[2]|=2);null===c?a[9]=[b]:c.push(b)}function ll(a,b){a=a[9];a.splice(a.indexOf(b),1)}function ml(a,b){if(!(10>=a.length)){var c=10+b,d=a[c];if(d){const e=d[16];null!==e&&e!==a&&ll(e,d);0<b&&(a[c-1][4]=d[4]);a=Sf(a,10+b);jl(d[1],d);d[0]=null;d[5]=null;b=a[18];null!==b&&b.fj(a[1]);d[3]=null;d[4]=null;d[2]&=-129}return d}}
function nl(a,b){if(!(b[2]&256)){var c=b[11];c.Xk&&il(c,3,a.firstChild,b,null,null,!1);if(a=b[12])for(;a;){c=null;if(yg(a))c=a[12];else{const d=a[10];d&&(c=d)}if(!c){for(;a&&!a[4]&&a!==b;)yg(a)&&ol(a[1],a),a=a[3];null===a&&(a=b);yg(a)&&ol(a[1],a);c=a&&a[4]}a=c}else ol(b[1],b)}}
function ol(a,b){if(!(b[2]&256)){var c=pe(null);try{b[2]&=-129;b[2]|=256;b[23]&&Ee(b[23]);var d;if(null!=a&&null!=(d=a.Wk))for(let m=0;m<d.length;m+=2){const p=b[d[m]];if(!(p instanceof lh)){const t=d[m+1];if(Array.isArray(t))for(let v=0;v<t.length;v+=2)t[v+1].call(p[t[v]]);else t.call(p)}}var e=a.ae;const f=b[7];if(null!==e)for(d=0;d<e.length-1;d+=2)if("string"===typeof e[d]){const m=e[d+3];if(0<=m)f[m]();else f[-m].unsubscribe();d+=2}else e[d].call(f[e[d+1]]);null!==f&&(b[7]=null);const g=b[21];
if(null!==g)for(b[21]=null,e=0;e<g.length;e++)(0,g[e])();1===b[1].type&&b[11].destroy();const k=b[16];if(null!==k&&Ag(b[3])){k!==b[3]&&ll(k,b);const m=b[18];null!==m&&m.fj(a)}di.delete(b[19])}finally{pe(c)}}}function pl(a,b,c){for(;null!==b&&b.type&40;)b=b.parent;if(null===b)return c[0];const d=b.If;return-1<d&&({ob:a}=a.data[b.ld+d],2===a||0===a)?null:Hg(b,c)}
function ql(a,b,c,d){a=pl(a,d.parent,b);const e=b[11];d=d.parent||b[5];b=d.type&40?Hg(d,b):null;if(null!=a)if(Array.isArray(c))for(let k=0;k<c.length;k++){d=e;var f=a,g=c[k];null!==b?d.insertBefore(f,g,b,!1):d.appendChild(f,g)}else null!==b?e.insertBefore(a,c,b,!1):e.appendChild(a,c)}
function rl(a,b){if(null!==b){var c=b.type;if(c&3)return Hg(b,a);if(c&4)return sl(-1,a[b.index]);if(c&8){c=b.Gf;if(null!==c)return rl(a,c);a=a[b.index];return Ag(a)?sl(-1,a):Gg(a)}if(c&32)return(void 0)(b,a)()||Gg(a[b.index]);c=null!==b?a[15][5].Ie[b.Ie]:null;if(null!==c){if(Array.isArray(c))return c[0];a=Ng(a[15]);return rl(a,c)}return rl(a,b.next)}return null}function sl(a,b){a+=11;if(a<b.length){a=b[a];const c=a[1].firstChild;if(null!==c)return rl(a,c)}return b[7]}
function il(a,b,c,d,e,f,g){for(;null!=c;){const m=d[c.index];var k=c.type;g&&0===b&&(m&&fi(Gg(m),d),c.flags|=2);if(32!==(c.flags&32))if(k&8)il(a,b,c.Gf,d,e,f,!1),hl(b,a,e,m,f);else if(k&32){k=(void 0)(c,d);let p;for(;p=k();)hl(b,a,e,p,f);hl(b,a,e,m,f)}else k&16?tl(a,b,d,c,e,f):hl(b,a,e,m,f);c=g?c.Ur:c.next}}function tl(a,b,c,d,e,f){var g=c[15];c=g[5].Ie[d.Ie];if(Array.isArray(c))for(d=0;d<c.length;d++)hl(b,a,e,c[d],f);else g=g[3],128===(d.flags&128)&&(c.flags|=128),il(a,b,c,g,e,f,!0)}
function ul(a,b,c){const d=c.Fe,e=c.Yi;c=c.styles;null!==d&&uf(a,b,d);null!==e&&(""===e?a.removeAttribute(b,"class"):a.setAttribute(b,"class",e));null!==c&&a.setAttribute(b,"style",c)};var vl={};class wl{constructor(a){this.i=a}toString(){return`SafeValue must use [property]=binding: ${this.i}`+" (see https://g.co/ng/security#xss)"}}class xl extends wl{Ys(){return"URL"}}class yl extends wl{Ys(){return"ResourceURL"}}function zl(a){return a instanceof wl?a.i:a}function Al(a,b){a=a instanceof wl&&a.Ys()||null;if(null!=a&&a!==b){if("ResourceURL"===a&&"URL"===b)return!0;throw Error(`Required a safe ${b}, got a ${a} (see ${"https://g.co/ng/security#xss"})`);}return a===b};let Bl;function Cl(){if(void 0===Bl&&(Bl=null,ef.trustedTypes))try{Bl=ef.trustedTypes.createPolicy("angular",{createHTML:a=>a,createScript:a=>a,createScriptURL:a=>a})}catch(a){}return Bl}function Dl(a){let b;return(null==(b=Cl())?void 0:b.createHTML(a))||a};class El{constructor(a){this.i=a}Cn(a){a="<body><remove></remove>"+a;try{const b=(new window.DOMParser).parseFromString(Dl(a),"text/html").body;if(null===b)return this.i.Cn(a);b.removeChild(b.firstChild);return b}catch(b){return null}}}class Fl{constructor(a){this.i=a;this.C=this.i.implementation.createHTMLDocument("sanitization-inert")}Cn(a){const b=this.C.createElement("template");b.innerHTML=Dl(a);return b}};const Gl=/^(?!javascript:)(?:[a-z0-9+.-]+:|[^&:\/?#]*(?:[\/?#]|$))/i;function Hl(a){a=String(a);return a.match(Gl)?a:"unsafe:"+a};function Il(a){const b={};for(const c of a.split(","))b[c]=!0;return b}function Jl(...a){const b={};for(const c of a)for(const d in c)c.hasOwnProperty(d)&&(b[d]=!0);return b}
const Kl=Il("area,br,col,hr,img,wbr"),Ll=Il("colgroup,dd,dt,li,p,tbody,td,tfoot,th,thead,tr"),Ml=Il("rp,rt"),Nl=Jl(Ml,Ll),Ol=Jl(Ll,Il("address,article,aside,blockquote,caption,center,del,details,dialog,dir,div,dl,figure,figcaption,footer,h1,h2,h3,h4,h5,h6,header,hgroup,hr,ins,main,map,menu,nav,ol,pre,section,summary,table,ul")),Pl=Jl(Ml,Il("a,abbr,acronym,audio,b,bdi,bdo,big,br,cite,code,del,dfn,em,font,i,img,ins,kbd,label,map,mark,picture,q,ruby,rp,rt,s,samp,small,source,span,strike,strong,sub,sup,time,track,tt,u,var,video"));
var Ql=Jl(Kl,Ol,Pl,Nl),Rl=Il("background,cite,href,itemtype,longdesc,poster,src,xlink:href");
const Sl=Il("abbr,accesskey,align,alt,autoplay,axis,bgcolor,border,cellpadding,cellspacing,class,clear,color,cols,colspan,compact,controls,coords,datetime,default,dir,download,face,headers,height,hidden,hreflang,hspace,ismap,itemscope,itemprop,kind,label,lang,language,loop,media,muted,nohref,nowrap,open,preload,rel,rev,role,rows,rowspan,rules,scope,scrolling,shape,size,sizes,span,srclang,srcset,start,summary,tabindex,target,title,translate,type,usemap,valign,value,vspace,width"),Tl=Il("aria-activedescendant,aria-atomic,aria-autocomplete,aria-busy,aria-checked,aria-colcount,aria-colindex,aria-colspan,aria-controls,aria-current,aria-describedby,aria-details,aria-disabled,aria-dropeffect,aria-errormessage,aria-expanded,aria-flowto,aria-grabbed,aria-haspopup,aria-hidden,aria-invalid,aria-keyshortcuts,aria-label,aria-labelledby,aria-level,aria-live,aria-modal,aria-multiline,aria-multiselectable,aria-orientation,aria-owns,aria-placeholder,aria-posinset,aria-pressed,aria-readonly,aria-relevant,aria-required,aria-roledescription,aria-rowcount,aria-rowindex,aria-rowspan,aria-selected,aria-setsize,aria-sort,aria-valuemax,aria-valuemin,aria-valuenow,aria-valuetext");
var Ul=Jl(Rl,Sl,Tl);const Vl=Il("script,style,template");class Wl{constructor(){this.i=[]}chars(a){this.i.push(Xl(a))}}function Yl(a){a=a.nodeName;return"string"===typeof a?a:"FORM"}function Zl(a){return Error(`Failed to sanitize html because the element is clobbered: ${a.outerHTML}`)}const $l=/[\uD800-\uDBFF][\uDC00-\uDFFF]/g,am=/([^#-~ |!])/g;
function Xl(a){return a.replace(/&/g,"&amp;").replace($l,function(b){return"&#"+(1024*(b.charCodeAt(0)-55296)+(b.charCodeAt(1)-56320)+65536)+";"}).replace(am,function(b){return"&#"+b.charCodeAt(0)+";"}).replace(/</g,"&lt;").replace(/>/g,"&gt;")}let pm;function qm(a){return"content"in a&&a.nodeType===Node.ELEMENT_NODE&&"TEMPLATE"===a.nodeName?a.content:null};var rm={NONE:0,bF:1,jF:2,iF:3,URL:4,gF:5,0:"NONE",1:"HTML",2:"STYLE",3:"SCRIPT",4:"URL",5:"RESOURCE_URL"};function sm(a,b,c,d,e,f,g,k,m,p,t){const v=b.qg.slice();v[0]=e;v[2]=d|204;if(null!==p||a&&a[2]&2048)v[2]|=2048;v[17]=0;v[3]=v[14]=a;v[8]=c;v[10]=g||a&&a[10];v[11]=k||a&&a[11];v[9]=m||a&&a[9]||null;v[5]=f;v[19]=ei++;v[6]=t;v[20]=p;v[15]=2==b.type?a[15]:v;return v}
function tm(a,b,c,d,e){var f=a.data[b];if(null===f){f=Qg.Eh;const m=Qg.Rf;var g=a.data,k=m?f:f&&f.parent;let p=k?k.xd:-1,t=0;null!==Rg&&(t|=128);b=g[b]={type:c,index:b,UF:null,xd:p,ld:-1,ve:-1,mn:-1,If:-1,lG:null,flags:t,Jg:0,value:d,attrs:e,Fe:null,kr:null,iw:void 0,inputs:null,outputs:null,tb:null,next:null,zD:null,Ur:null,Gf:null,parent:k,Ie:null,styles:null,zs:null,yo:void 0,Yi:null,cn:null,xo:void 0,Ok:0,bm:0};null===a.firstChild&&(a.firstChild=b);null!==f&&(m?null==f.Gf&&null!==b.parent&&(f.Gf=
b):null===f.next&&(f.next=b,b.zD=f));f=b;Qg.fw&&(f.flags|=32)}else f.type&64&&(f.type=c,f.value=d,f.attrs=e,a=Qg,b=a.Eh,a=a.Rf?b:b.parent,f.xd=null===a?-1:a.xd);Vg(f,!0);return f}function um(a,b,c,d){if(0===c)return-1;const e=b.length;for(let f=0;f<c;f++)b.push(d),a.qg.push(d),a.data.push(null);return e}function vm(a,b,c,d,e){const f=Qg.selectedIndex;try{Qg.selectedIndex=-1,d&2&&25<b.length&&cl(a,b,25),c(d,e)}finally{Qg.selectedIndex=f}}
function wm(a,b,c){if(0!==(b.flags&4)){const d=pe(null);try{const e=b.ld,f=b.ve;for(b=e;b<f;b++){const g=a.data[b];g.cc&&g.cc(1,c[b],b)}}finally{pe(d)}}}
function xm(a,b,c){var d=Hg(c,b);const e=c.ld,f=c.ve;if(-1<c.If){var g=a.data[e+c.If],k=Hg(c,b),m=ym(g),p=b[10].ds,t=16;g.ii?t=4096:g.Br&&(t=64);g=zm(b,sm(b,m,null,t,k,c,null,p.Uk(k,g),null,null,null));b[c.index]=g}a.Ac||sh(c,b);fi(d,b);d=c.iw;for(g=e;g<f;g++){k=a.data[g];m=Dh(b,a,g,c);fi(m,b);if(null!==d&&(p=d[g-e],null!==p))for(t=0;t<p.length;){const v=p[t++],B=p[t++],G=p[t++],K=p[t++];dl(k,m,v,B,G,K)}k.sa&&(Ig(c.index,b)[8]=Dh(b,a,g,c))}64===(c.flags&64)&&Am(a,b,c)}
function Bm(a,b,c=Hg){const d=b.kr;if(null!==d){let f=b.index+1;for(let g=0;g<d.length;g+=2){var e=d[g+1];e=-1===e?c(b,a):a[e];a[f++]=e}}}function ym(a){const b=a.tb;return null===b||b.gw?a.tb=Cm(1,null,a.sa,a.ya,a.za,a.Dv,a.ax,a.eb,a.Pj,a.Ba,a.id):b}
function Cm(a,b,c,d,e,f,g,k,m,p,t){d=25+d;e=d+e;const v=[];for(let B=0;B<e;B++)v.push(B<d?null:vl);p="function"===typeof p?p():p;return v[1]={type:a,qg:v,sa:c,queries:null,eb:k,zv:b,data:v.slice().fill(null,d),aq:d,Pv:e,Sq:null,Ac:!0,wn:!0,by:!1,ay:!1,kf:null,Ig:null,Sk:null,kq:null,km:null,Ns:null,Wk:null,ae:null,cc:null,Jf:null,Ev:"function"===typeof f?f():f,uD:"function"===typeof g?g():g,firstChild:null,Pj:m,Ba:p,gw:!1,Zx:t}}
function Dm(a,b,c,d,e){for(let g in b){if(!b.hasOwnProperty(g))continue;var f=b[g];if(void 0===f)continue;null!=d||(d={});let k,m=0;Array.isArray(f)?(k=f[0],m=f[1]):k=f;f=g;if(null!==e){if(!e.hasOwnProperty(g))continue;f=e[g]}0===a?Em(d,c,f,k,m):Em(d,c,f,k)}return d}function Em(a,b,c,d,e){let f;a.hasOwnProperty(c)?(f=a[c]).push(b,d):f=a[c]=[b,d];void 0!==e&&f.push(e)}
function Fm(a,b,c,d,e,f,g,k){const m=Hg(b,c);let p=b.inputs,t;!k&&null!=p&&(t=p[d])?(Gm(a,c,t,d,e),-1<b.If&&(a=Ig(b.index,c),a[2]&16||(a[2]|=64))):b.type&3&&(d="class"===d?"className":"for"===d?"htmlFor":"formaction"===d?"formAction":"innerHtml"===d?"innerHTML":"readonly"===d?"readOnly":"tabindex"===d?"tabIndex":d,e=null!=g?g(e,b.value||"",d):e,f.setProperty(m,d,e))}
function Hm(a,b,c,d){const e=null===d?null:{"":-1};var f=a.Ev;let g=null,k=null;if(f)for(let t=0;t<f.length;t++){const v=f[t];if(Af(c,v.ga,!1))if(g||(g=[]),v.sa)if(null!==v.nj){const B=[];k=k||new Map;v.nj(v,B,k);g.unshift(...B,v);Im(a,c,B.length)}else g.unshift(v),Im(a,c,0);else{k=k||new Map;let B,G;null==(G=(B=v).nj)||G.call(B,v,g,k);g.push(v)}}f=null===g?null:[g,k];var m;let p;null===f?m=p=null:[m,p]=f;null!==m&&Jm(a,b,c,m,e,p);if(e&&d)for(a=c.kr=[],b=0;b<d.length;b+=2){m=e[d[b+1]];if(null==m)throw new Yd(-301,
!1);a.push(d[b],m)}c.Fe=vf(c.Fe,c.attrs)}
function Jm(a,b,c,d,e,f){for(var g=0;g<d.length;g++){var k=sh(c,b);rh(k,a,d[g].type)}k=a.data.length;g=d.length;c.flags|=1;c.ld=k;c.ve=k+g;c.Jg=k;for(k=0;k<d.length;k++)g=d[k],g.Vr&&g.Vr(g);g=k=!1;var m=um(a,b,d.length,null);for(var p=0;p<d.length;p++){var t=d[p];c.Fe=vf(c.Fe,t.Ja);var v=a,B=c,G=b,K=m;v.data[K]=t;var N=t.aa||(t.aa=Qf(t.type));N=new lh(N,!!t.sa);v.qg[K]=N;G[K]=N;N=v;var aa=B;v=um(v,G,t.Xa,vl);if(G=t.Ha){B=N.Sq;null===B&&(B=N.Sq=[]);N=~aa.index;a:{for(aa=B.length;0<aa;){const Q=B[--aa];
if("number"===typeof Q&&0>Q){aa=Q;break a}}aa=0}aa!=N&&B.push(N);B.push(K,v,G)}K=m;N=t;if(v=e){if(N.hb)for(G=0;G<N.hb.length;G++)v[N.hb[G]]=K;N.sa&&(v[""]=K)}null!==t.cc&&(c.flags|=4);if(null!==t.Ha||null!==t.Ja||0!==t.Xa)c.flags|=64;t=t.type.prototype;if(!k&&(t.rc||t.Eb||t.zj)){var ca=void 0,ia=void 0;(null!=(ia=(ca=a).kf)?ia:ca.kf=[]).push(c.index);k=!0}if(!g&&(t.rc||t.zj)){var O=void 0,U=void 0;(null!=(U=(O=a).Ig)?U:O.Ig=[]).push(c.index);g=!0}m++}O=c.ld;b=c.ve;a=a.data;d=c.attrs;e=[];for(ia=ca=
null;O<b;O++){U=a[O];g=(k=f?f.get(U):null)?k.outputs:null;ca=Dm(0,U.inputs,O,ca,k?k.inputs:null);ia=Dm(1,U.outputs,O,ia,g);if(null===ca||null===d||xf(c))U=null;else{U=ca;k=O;g=null;for(m=0;m<d.length;)if(p=d[m],0===p)m+=4;else{if(5!==p){if("number"===typeof p)break;if(U.hasOwnProperty(p))for(null===g&&(g=[]),t=U[p],K=0;K<t.length;K+=3)if(t[K]===k){g.push(p,t[K+1],t[K+2],d[m+1]);break}}m+=2}U=g}e.push(U)}null!==ca&&(ca.hasOwnProperty("class")&&(c.flags|=8),ca.hasOwnProperty("style")&&(c.flags|=16));
c.iw=e;c.inputs=ca;c.outputs=ia}function Am(a,b,c){var d=c.ld;const e=c.ve,f=c.index;c=Qg.dj;try{for(Qg.selectedIndex=f;d<e;d++){const g=a.data[d],k=b[d];Qg.dj=d;null===g.Ha&&0===g.Xa&&null===g.Ja||null===g.Ha||g.Ha(1,k)}}finally{Qg.selectedIndex=-1,Qg.dj=c}}function Im(a,b,c){b.If=c;let d;(null!=(d=a.Jf)?d:a.Jf=[]).push(b.index)}
function Km(a,b){const c=a.cc;if(null!==c){const d=pe(null);try{for(let e=0;e<c.length;e+=2){const f=c[e],g=c[e+1];if(-1!==g){const k=a.data[g];Qg.be=f;k.cc(2,b[g],g)}}}finally{pe(d)}}}function zm(a,b){a[12]?a[13][4]=b:a[12]=b;return a[13]=b}function Lm(a,b,c){Qg.be=0;const d=pe(null);try{b(a,c)}finally{pe(d)}}function Mm(a,b,c){if(null===a||a.sa)a:{for(a=c[b.index];Array.isArray(a);){if("object"===typeof a[1]){c=a;break a}a=a[0]}c=null}return c[11]}
function Nm(a,b){(a=(a=a[9])?a.get(ui,null):null)&&a.handleError(b)}function Gm(a,b,c,d,e){for(let f=0;f<c.length;){const g=c[f++],k=c[f++],m=c[f++];dl(a.data[g],b[g],d,k,m,e)}}function Om(a,b){a[11].setValue(Gg(a[Qg.selectedIndex]),b)};function Pm(a,b,c){ah(b);try{var d=a.eb;null!==d&&Lm(1,d,c);var e=a.sa;null!==e&&vm(a,b,e,1,c);a.Ac&&(a.Ac=!1);let f;null!=(f=b[18])&&Qm(f,a);a.ay&&Km(a,b);a.by&&Lm(2,a.eb,c);const g=a.Jf;if(null!==g)for(e=0;e<g.length;e++){const k=Ig(g[e],b),m=k[1];c=m;d=k;for(let p=d.length;p<c.qg.length;p++)d.push(c.qg[p]);null!==k[0]&&null===k[6]&&(k[6]=null);Pm(m,k,k[8])}}catch(f){throw a.Ac&&(a.gw=!0,a.Ac=!1),f;}finally{b[2]&=-5,ch()}};function Rm(a,b,c){let d=c?a.styles:null,e=c?a.Yi:null,f=0;if(null!==b)for(let k=0;k<b.length;k++){var g=b[k];if("number"===typeof g)f=g;else if(1==f)e=he(e,g);else if(2==f){const m=b[++k];d=he(d,g+": "+m+";")}}c?a.styles=d:a.zs=d;c?a.Yi=e:a.cn=e};function Sm(a,b,c,d,e=!1){for(;null!==c;){var f=b[c.index];null!==f&&d.push(Gg(f));if(Ag(f)){var g=d;for(let k=10;k<f.length;k++){const m=f[k],p=m[1].firstChild;null!==p&&Sm(m[1],m,p,g)}f[7]!==f[0]&&g.push(f[7])}f=c.type;if(f&8)Sm(a,b,c.Gf,d);else if(f&32)for(f=(void 0)(c,b);g=f();)d.push(g);else f&16&&(f=null!==c?b[15][5].Ie[c.Ie]:null,Array.isArray(f)?d.push(...f):(g=Ng(b[15]),Sm(g[1],g,f,d,!0)));c=e?c.Ur:c.next}return d};let Tm=[];const Um=Object.assign({},qe,{iq:!0,jq:a=>{Mg(a.Sf)},hv(){this.Sf[23]=this}});function Vm(a,b=!0,c=0){const d=a[10],e=d.ds;var f;null==(f=e.Um)||f.call(e);try{f=Sg;try{for(Sg=!0,Wm(a,c),c=0;Kg(a);){if(100===c)throw new Yd(103,!1);c++;Wm(a,1)}}finally{Sg=f}}catch(g){throw b&&Nm(a,g),g;}finally{let g;null==(g=e.end)||g.call(e);let k;null==(k=d.jw)||k.flush()}}function Xm(a,b){for(let c=gi(a[12]);null!==c;c=gi(c[4]))for(let d=10;d<c.length;d++)a=c[d],128===(a[2]&128)&&Wm(a,b)}
function Wm(a,b){var c=a[1],d=a[2],e=a[23],f=!!(0===b&&d&16);f||(f=!!(d&64&&0===b));f||(f=!!(d&1024));f||(f=!!((null==e?0:e.pc)&&ye(e)));f||(f=!1);e&&(e.pc=!1);a[2]&=-9217;if(f){if(e=c.sa,b=a[8],f=a[2],256!==(f&256)){var g;null!=(g=a[10].jw)&&g.flush();ah(a);d=g=null;if(2!==c.type){if(null!=(g=a[23]))var k=g;else g=null!=(k=Tm.pop())?k:Object.create(Um),g.Sf=a,k=g;d=k;g=Ce(d)}try{a[17]=0;Qg.cd=c.aq;null!==e&&vm(c,a,e,2,b);if(k=3===(f&3)){var m=c.Ig;null!==m&&ih(a,m,3,null)}else{const N=c.kf;null!==
N&&hh(a,N,0,null);jh(a,0)}for(var p=gi(a[12]);null!==p;p=gi(p[4]))if(p[2]&2){var t=p[9];for(m=0;m<t.length;m++){var v=t[m];v[2]&1024||(v[2]|=1024,128===(v[2]&128)&&Mg(v))}}Xm(a,0);null!==c.cc&&Km(c,a);if(k){const N=c.kq;null!==N&&ih(a,N,3)}else{const N=c.Sk;null!==N&&hh(a,N,1);jh(a,1)}const B=c.Sq;if(null!==B)try{for(v=0;v<B.length;v++){const N=B[v];if(0>N)Qg.selectedIndex=~N;else{p=N;const aa=B[++v],ca=B[++v];t=Qg;t.cd=t.Vm=aa;Qg.dj=p;ca(2,a[p])}}}finally{Qg.selectedIndex=-1}const G=c.Jf;null!==
G&&Ym(a,G,0);const K=c.eb;null!==K&&Lm(2,K,b);if(k){const N=c.Ns;null!==N&&ih(a,N,3)}else{const N=c.km;null!==N&&hh(a,N,2);jh(a,2)}!0===c.wn&&(c.wn=!1);if(a[22]){for(const N of a[22])N();a[22]=null}a[2]&=-73}catch(B){throw Mg(a),B;}finally{null!==d&&(De(d,g),a=d,a.Sf[23]!==a&&(a.Sf=null,Tm.push(a))),ch()}}}else d&8192&&(Xm(a,1),c=c.Jf,null!==c&&Ym(a,c,1))}function Ym(a,b,c){for(let e=0;e<b.length;e++){var d=c;const f=Ig(b[e],a);128===(f[2]&128)&&Wm(f,d)}};function Zm(a){al(a.K||a.C,4)}function $m(a){a.C[2]|=1024;Vm(a.C,a.G)}
var an=class{get rootNodes(){const a=this.C,b=a[1];return Sm(b,a,b.firstChild,[])}constructor(a,b,c=!0){this.C=a;this.K=b;this.G=c;this.D=null;this.F=!1}get context(){return this.C[8]}set context(a){this.C[8]=a}get i(){return 256===(this.C[2]&256)}destroy(){if(this.D)this.D.fj(this);else if(this.F){const a=this.C[3];if(Ag(a)){const b=a[8],c=b?b.indexOf(this):-1;-1<c&&(ml(a,c),Sf(b,c))}this.F=!1}nl(this.C[1],this.C)}nb(a){Og(this.C,a)}detach(){this.C[2]&=-129}};var bn=class{};bn.oa=Ld({la:bn,da:"root",aa:()=>null});var cn={};function dn(a,b){return new en(b[Zd]||null,a.Aj)}var fn=class extends Xh{constructor(a){super();this.Aj=a}};function gn(a){const b=[];for(const c in a){if(!a.hasOwnProperty(c))continue;const d=a[c];void 0!==d&&b.push({mx:Array.isArray(d)?d[0]:d,xG:c})}return b}
var hn=class{constructor(a,b){this.wa=a;this.Cj=b}get(a,b,c){c=mf(c);const d=this.wa.get(a,cn,c);return d!==cn||b===cn?d:this.Cj.get(a,b,c)}},en=class extends oi{get inputs(){var a=this.i;const b=a.Ce;a=gn(a.inputs);if(null!==b)for(const c of a)b.hasOwnProperty(c.mx)&&(c.transform=b[c.mx]);return a}get outputs(){return gn(this.i.outputs)}constructor(a,b){super();this.i=a;this.Aj=b;this.fq=a.type;this.Vl=a.ga.map(Cf).join(",");this.Yb=a.Yb?a.Yb:[];this.sC=!!b}create(a,b,c,d){const e=pe(null);try{d=
d||this.Aj;let la,F=d instanceof ig?d:null==(la=d)?void 0:la.wa;F&&null!==this.i.Iq&&(F=this.i.Iq(F)||F);var f=F?new hn(a,F):a,g=f.get(si,null);if(null===g)throw new Yd(407,!1);const M=f.get(bn,null),W=f.get(Wk,null),Aa=f.get($h,null);a={ds:g,tG:M,jw:null,wF:W,Xi:Aa};var k=g.Uk(null,this.i);const qb=this.i.ga[0][0]||"div";if(c){g=k;var m=this.i.ob,p=f.get(bl,!1)||3===m;var t=g.ns(c,p)}else{const qa=qb.toLowerCase();t=k.createElement(qb,"svg"===qa?"svg":"math"===qa?"math":null)}m=512;this.i.ii?m|=
4096:this.i.Br||(m|=16);p=null;null!==t&&(p=null);const wb=Cm(0,null,null,1,0,null,null,null,null,null,null),Ja=sm(null,wb,null,m,null,null,a,k,f,null,p);ah(Ja);let Ub,Na;try{var v=this.i;f=null;if(v.nj){var B=[];f=new Map;v.nj(v,B,f);B.push(v)}else B=[v];var G=Ja[1];Ja[25]=t;var K=tm(G,25,2,"#host",null);p=t;G=v;m=B;var N=Ja[1];for(var aa of m)K.Fe=vf(K.Fe,aa.Ja);null!==K.Fe&&(Rm(K,K.Fe,!0),null!==p&&ul(k,p,K));aa=null;null!==p&&(aa=null);var ca=a.ds.Uk(p,G);p=16;G.ii?p=4096:G.Br&&(p=64);const qa=
sm(Ja,ym(G),null,p,Ja[K.index],K,a,ca,null,null,aa);N.Ac&&Im(N,K,m.length-1);zm(Ja,qa);var ia=Ja[K.index]=qa;Na=wb.data[25];if(t)if(c)uf(k,t,["ng-version","0.0.0-PLACEHOLDER"]);else{var O=v.ga[0];c=[];K=[];N=1;for(ca=2;N<O.length;){let ib=O[N];if("string"===typeof ib)2===ca?""!==ib&&c.push(ib,O[++N]):8===ca&&K.push(ib);else{if(0!==(ca&1))break;ca=ib}N++}const {attrs:Qa,Yi:Ia}={attrs:c,Yi:K};Qa&&uf(k,t,Qa);if(Ia&&0<Ia.length){O=k;k=t;var U=Ia.join(" ");""===U?O.removeAttribute(k,"class"):O.setAttribute(k,
"class",U)}}if(void 0!==b){var Q=this.Yb;const Qa=Na.Ie=[];for(U=0;U<Q.length;U++){const Ia=b[U];Qa.push(null!=Ia?Array.from(Ia):null)}}b=v;v=f;Q=[jn];const T=Ug(),ea=Ja[1],na=Hg(T,Ja);Jm(ea,Ja,T,B,null,v);for(v=0;v<B.length;v++){const Qa=Dh(Ja,ea,T.ld+v,T);fi(Qa,Ja)}Am(ea,Ja,T);na&&fi(na,Ja);const Ka=Dh(Ja,ea,T.ld+T.If,T);ia[8]=Ja[8]=Ka;if(null!==Q)for(const Qa of Q)Qa(Ka,b);wm(ea,T,Ja);Ub=Ka;Pm(wb,Ja,null)}finally{ch()}return new kn(this.fq,Ub,pi(Na,Ja),Ja,Na)}finally{pe(e)}}},kn=class extends ni{constructor(a,
b,c,d,e){super();this.location=c;this.F=d;this.D=e;this.C=null;this.instance=b;this.i=new an(d,void 0,!1);this.fq=a}Ao(a,b){var c=this.D.inputs;let d;null!==c&&(d=c[a])&&(null!=this.C||(this.C=new Map),this.C.has(a)&&Object.is(this.C.get(a),b)||(c=this.F,Gm(c[1],c,d,a,b),this.C.set(a,b),a=Ig(this.D.index,c),al(a,1)))}get wa(){return new Eh(this.D,this.F)}destroy(){this.i.destroy()}nb(a){this.i.nb(a)}};function jn(){gh(Tg()[1],Ug())};var ln=class extends Yh{constructor(a,b){super();this.Pa=b;this.fp=[];this.D=[];this.i=new fn(this);var c=(a[be]||null).Kk;this.fp=c instanceof Function?c():c;this.C=Th(a,b,[{na:Yh,mb:this},{na:Xh,mb:this.i}],ge(a),new Set(["environment"]));ng(this.C);this.instance=this.C.get(a)}get wa(){return this.C}destroy(){const a=this.C;!a.i&&a.destroy();this.D.forEach(b=>b());this.D=null}nb(a){this.D.push(a)}},mn=class extends Zh{constructor(a){super();this.i=a}create(a){return new ln(this.i,a)}},nn=class extends Yh{constructor(a){super();
this.i=new fn(this);this.instance=null;const b=new tg([...a.Ua,{na:Yh,mb:this},{na:Xh,mb:this.i}],a.parent||hg(),a.yv,new Set(["environment"]));this.wa=b;a.zx&&ng(b)}destroy(){this.wa.destroy()}nb(a){this.wa.nb(a)}};function on(a,b,c=null){return(new nn({Ua:a,parent:b,yv:c,zx:!0})).wa};function pn(a){return!!a&&"function"===typeof a.then};var qn=new df("");function rn(a){if(!a.i){var b=[];for(const d of a.C){const e=d();if(pn(e))b.push(e);else if(e&&"function"===typeof e.subscribe){const f=new Promise((g,k)=>{e.subscribe({complete:g,error:k})});b.push(f)}}var c=()=>{a.done=!0;a.resolve()};Promise.all(b).then(()=>{c()}).catch(d=>{a.reject(d)});0===b.length&&c();a.i=!0}}var sn=class{constructor(){this.done=this.i=!1;this.D=new Promise((b,c)=>{this.resolve=b;this.reject=c});let a;this.C=null!=(a=lf(qn,{optional:!0}))?a:[]}};
sn.J=function(a){return new (a||sn)};sn.oa=Ld({la:sn,aa:sn.J,da:"root"});var tn=class{log(a){console.log(a)}warn(a){console.warn(a)}};tn.J=function(a){return new (a||tn)};tn.oa=Ld({la:tn,aa:tn.J,da:"platform"});var un=class{constructor(){this.D=0;this.i=new Set;this.ll=new cj(!1)}get C(){return this.ll.value}add(){this.C||this.ll.next(!0);const a=this.D++;this.i.add(a);return a}remove(a){this.i.delete(a);0===this.i.size&&this.C&&this.ll.next(!1)}ua(){this.i.clear();this.C&&this.ll.next(!1)}};un.J=function(a){return new (a||un)};un.oa=Ld({la:un,aa:un.J,da:"root"});function vn(a){return"function"===typeof a&&void 0!==a[oe]};var wn=new df(""),xn=new df("");function yn(a){return a.C?a.C.WF.map(b=>({source:b.source,nB:b.nB,data:b.data})):[]}function zn(a,b,c,d){let e=-1;c&&0<c&&(e=setTimeout(()=>{a.i=a.i.filter(f=>f.Gs!==e);b()},c));a.i.push({EB:b,Gs:e,yy:d})}
var Dn=class{constructor(a,b,c){this.pa=a;this.F=b;this.D=!0;this.i=[];this.C=null;An||(An=c,Cn(b));this.K();a.run(()=>{this.C="undefined"==typeof Zone?null:Zone.current.get("TaskTrackingZone")})}K(){this.pa.ko.subscribe({next:()=>{this.D=!1}});Kk(this.pa,()=>{this.pa.jo.subscribe({next:()=>{Jk();queueMicrotask(()=>{this.D=!0;this.G()})}})})}isStable(){return this.D&&!this.pa.Hn}G(){if(this.isStable())queueMicrotask(()=>{for(;0!==this.i.length;){let a=this.i.pop();clearTimeout(a.Gs);a.EB()}});else{let a=
yn(this);this.i=this.i.filter(b=>b.yy&&b.yy(a)?(clearTimeout(b.Gs),!1):!0)}}whenStable(a,b,c){if(c&&!this.C)throw Error('Task tracking zone is required when passing an update callback to whenStable(). Is "zone.js/plugins/task-tracking" loaded?');zn(this,a,b,c);this.G()}findProviders(){return[]}};Dn.J=function(a){return new (a||Dn)(q(Ok),q(En),q(xn))};Dn.oa=Ld({la:Dn,aa:Dn.J});var En=class{constructor(){this.i=new Map}fl(a,b=!0){let c,d;return null!=(d=null==(c=An)?void 0:c.fl(this,a,b))?d:null}};
En.J=function(a){return new (a||En)};En.oa=Ld({la:En,aa:En.J,da:"platform"});let An;function Fn(a){return function(b){return pj(b,new Gn(a))}}class Gn{constructor(a){this.i=a}call(a,b){return b.subscribe(new Hn(a,this.i))}}function In(a){const b=a.value,c=a.C,d=a.i;d&&(a.remove(d),a.i=null,d.unsubscribe());c&&(a.value=null,a.C=!1,a.destination.next(b))}
class Hn extends Jj{constructor(a,b){super(a);this.D=b;this.value=null;this.C=!1;this.i=null}Na(a){this.value=a;this.C=!0;if(!this.i){let b;try{const c=this.D;b=c(a)}catch(c){return this.destination.error(c)}a=Lj(b,new Hj(this));!a||a.closed?In(this):this.add(this.i=a)}}Eg(){In(this)}Dg(){In(this)}};function Jn(a){return Fn(()=>uk(a))};function Kn(a){return b=>pj(b,function(c){const d=this,e=new Li;let f=null,g=!1,k;f=c.subscribe(new Ln(d,m=>{try{k=Qj(a(m,Kn(a)(c)))}catch(p){d.error(p)}k&&(f?(f.unsubscribe(),f=null,e.add(k.subscribe(d))):g=!0)}));g?(f.unsubscribe(),f=null,e.add(k.subscribe(d))):e.add(f);return e})}class Ln extends Oi{constructor(a,b){super(a);this.onError=b}oe(a){this.onError(a);this.unsubscribe()}};function Mn(a){return b=>pj(b,new Nn(a))}class Nn{constructor(a){this.i=a;this.scheduler=ok}call(a,b){return b.subscribe(new On(a,this.i,this.scheduler))}}function Pn(a){const b=a.C;null!==b&&(a.remove(b),b.unsubscribe(),a.C=null)}function Qn(a){Pn(a);if(a.i){const b=a.D;a.D=null;a.i=!1;a.destination.next(b)}}
class On extends Oi{constructor(a,b,c){super(a);this.F=b;this.scheduler=c;this.D=this.C=null;this.i=!1}Na(a){Pn(this);this.D=a;this.i=!0;this.add(this.C=this.scheduler.Mc(Rn,this.F,this))}mc(){Qn(this);this.destination.complete()}}function Rn(a){Qn(a)};function Sn(a=null){return b=>pj(b,new Tn(a))}class Tn{constructor(a){this.defaultValue=a}call(a,b){return b.subscribe(new Un(a,this.defaultValue))}}class Un extends Oi{constructor(a,b){super(a);this.defaultValue=b;this.i=!0}Na(a){this.i=!1;this.destination.next(a)}mc(){this.i&&this.destination.next(this.defaultValue);this.destination.complete()}};function Vn(a=ok){return b=>pj(b,new Wn(a))}class Wn{constructor(a){this.delay=0;this.scheduler=a}call(a,b){return b.subscribe(new Xn(a,this.delay,this.scheduler))}}function Yn(a){var b=a.source;const c=b.i,d=a.scheduler,e=a.destination;for(;0<c.length&&0>=c[0].time-d.now();)e.next(c.shift().value);0<c.length?(b=Math.max(0,c[0].time-d.now()),this.Mc(a,b)):(b.Qb?b.destination.complete():this.unsubscribe(),b.active=!1)}
class Xn extends Oi{constructor(a,b,c){super(a);this.destination=a;this.delay=b;this.scheduler=c;this.i=[];this.active=!1}C(a){this.active=!0;const b=this.destination;b.add(a.Mc(Yn,this.delay,{source:this,destination:b,scheduler:a}))}Na(a){const b=this.scheduler;a=new Zn(b.now()+this.delay,a);this.i.push(a);!1===this.active&&this.C(b)}oe(a){this.i.length=0;this.destination.error(a);this.unsubscribe()}mc(){0===this.i.length&&this.destination.complete();this.unsubscribe()}}
class Zn{constructor(a,b){this.time=a;this.value=b}};function $n(){return a=>pj(a,new ao)}class ao{call(a,b){return b.subscribe(new bo(a))}}class bo extends Oi{constructor(a){super(a);this.i=!1}C(a,b){return a===b}Na(a){let b;try{b=a}catch(d){return this.destination.error(d)}let c=!1;if(this.i)try{const d=this.C;c=d(this.key,b)}catch(d){return this.destination.error(d)}else this.i=!0;c||(this.key=b,this.destination.next(a))}};function co(){if(isNaN(1))throw new TypeError("'count' is not a number");return a=>pj(a,new eo)}class eo{constructor(){this.count=1}call(a,b){return b.subscribe(new fo(a,this.count))}}class fo extends Oi{constructor(a,b){super(a);this.count=b;this.i=0}Na(a){const b=this.count,c=++this.i;c<=b&&(this.destination.next(a),c===b&&(this.destination.complete(),this.unsubscribe()))}};function go(a=ho){return b=>pj(b,new io(a))}class io{constructor(a){this.i=a}call(a,b){return b.subscribe(new jo(a,this.i))}}class jo extends Oi{constructor(a,b){super(a);this.C=b;this.i=!1}Na(a){this.i=!0;this.destination.next(a)}mc(){if(this.i)return this.destination.complete();let a;try{a=this.C()}catch(b){a=b}this.destination.error(a)}}function ho(){return new nj};function ko(a){return b=>pj(b,new lo(a))}class lo{constructor(a){this.callback=a}call(a,b){a=b.subscribe(a);a.add(this.callback);return a}};function mo(a,b){const c=2<=arguments.length;return d=>C(d,a?rk((e,f)=>a(e,f,d)):Ri,co(),c?Sn(b):go(()=>new nj))};function no(){if(isNaN(1))throw new TypeError("'count' is not a number");return function(a){return pj(a,new oo)}}class oo{constructor(){this.total=1}call(a,b){return b.subscribe(new po(a,this.total))}}
class po extends Oi{constructor(a,b){super(a);this.total=b;this.i=[];this.count=0}Na(a){const b=this.i,c=this.total,d=this.count++;b.length<c?b.push(a):b[d%c]=a}mc(){const a=this.destination;let b=this.count;if(0<b){const c=this.count>=this.total?this.total:this.count,d=this.i;for(let e=0;e<c;e++){const f=b++%c;a.next(d[f])}}a.complete()}};function qo(a,b){const c=2<=arguments.length;return d=>C(d,a?rk((e,f)=>a(e,f,d)):Ri,no(),c?Sn(b):go(()=>new nj))};function ro(a){return b=>pj(b,new so(a))}class so{constructor(a){this.value=a}call(a,b){return b.subscribe(new to(a,this.value))}}class to extends Oi{constructor(a,b){super(a);this.value=b}Na(){this.destination.next(this.value)}};function uo(a,b){let c=!1;2<=arguments.length&&(c=!0);return function(d){return pj(d,new vo(a,b,c))}}class vo{constructor(a,b,c=!1){this.i=a;this.C=b;this.D=c}call(a,b){return b.subscribe(new wo(a,this.i,this.C,this.D))}}class wo extends Oi{constructor(a,b,c,d){super(a);this.C=b;this.nc=c;this.i=d;this.index=0}Na(a){const b=this.destination;if(this.i){const c=this.index++;let d;try{d=this.C(this.nc,a,c)}catch(e){b.error(e);return}this.nc=d;b.next(d)}else this.nc=a,this.i=!0,b.next(a)}};function xo(){var a=yo;return function(b){let c;c="function"===typeof a?a:function(){return a};const d=Object.create(b,tj);d.source=b;d.hy=c;return d}};function yo(){return new aj}function zo(){return a=>qj()(xo()(a))};function Ao(){var a={bufferSize:1,Ql:!0};let b;a&&"object"===typeof a?b=a:b={bufferSize:a,TE:void 0,Ql:!1,scheduler:void 0};return c=>pj(c,Bo(b))}
function Bo({bufferSize:a=Infinity,TE:b=Infinity,Ql:c,scheduler:d}){let e,f=0,g;return function(k){f++;let m;e?m=e.subscribe(this):(e=new kj(a,b,d),m=e.subscribe(this),g=k.subscribe({next(p){e.next(p)},error(p){const t=e;e=g=void 0;t.error(p)},complete(){g=void 0;e.complete()}}),g.closed&&(g=void 0));this.add(()=>{f--;m.unsubscribe();c&&0===f&&g&&(g.unsubscribe(),e=g=void 0)})}};function Co(){return a=>pj(a,new Do)}class Do{constructor(){this.total=1}call(a,b){return b.subscribe(new Eo(a,this.total))}}class Eo extends Oi{constructor(a,b){super(a);this.total=b;this.count=0}Na(a){++this.count>this.total&&this.destination.next(a)}};function Fo(...a){const b=a[a.length-1];return gj(b)?(a.pop(),c=>fk(a,c,b)):c=>fk(a,c)};function Go(a){return b=>pj(b,new Ho(a))}class Ho{constructor(a){this.project=a}call(a,b){return b.subscribe(new Io(a,this.project))}}
class Io extends Jj{constructor(a,b){super(a);this.destination=a;this.project=b;this.index=0}Na(a){let b;const c=this.index++;try{b=this.project(a,c)}catch(d){this.destination.error(d);return}(a=this.i)&&a.unsubscribe();a=new Hj(this);this.destination.add(a);this.i=a;Lj(b,a)}mc(){const a=this.i;a&&!a.closed||super.mc();this.i=void 0;this.unsubscribe()}Dg(){this.i=void 0;this.Qb&&super.mc()}Eg(a){this.destination.next(a)}};function Jo(a){return b=>pj(b,function(c){const d=this;Qj(a).subscribe(new oj(d,()=>d.complete(),qk));!d.closed&&c.subscribe(d)})};function Ko(a){return b=>pj(b,new Lo(a))}class Lo{constructor(a){this.lf=a}call(a,b){return b.subscribe(new Mo(a,this.lf))}}class Mo extends Oi{constructor(a,b){super(a);this.lf=b;this.index=0}Na(a){var b=this.destination;let c;try{c=this.lf(a,this.index++)}catch(d){b.error(d);return}b=this.destination;c?b.next(a):b.complete()}};function No(a){return function(b){return pj(b,new Oo(a))}}class Oo{constructor(a){this.i=a;this.complete=this.error=void 0}call(a,b){return b.subscribe(new Po(a,this.i,this.error,this.complete))}}
class Po extends Oi{constructor(a,b,c,d){super(a);this.i=this.C=this.D=qk;this.C=c||qk;this.i=d||qk;Ki(b)?(this.Cb=this,this.D=b):b&&(this.Cb=b,this.D=b.next||qk,this.C=b.error||qk,this.i=b.complete||qk)}Na(a){try{this.D.call(this.Cb,a)}catch(b){this.destination.error(b);return}this.destination.next(a)}oe(a){try{this.C.call(this.Cb,a)}catch(b){this.destination.error(b);return}this.destination.error(a)}mc(){try{this.i.call(this.Cb)}catch(a){this.destination.error(a);return}return this.destination.complete()}}
;var Qo={jr:!0,Is:!1};function Ro(a){return b=>pj(b,new So(a))}class So{constructor(a){var b=!!Qo.jr,c=!!Qo.Is;this.i=a;this.jr=b;this.Is=c}call(a,b){return b.subscribe(new To(a,this.i,this.jr,this.Is))}}function Uo(a){const b=a.C;a.i&&(a.destination.next(b),Vo(a,b));a.i=!1;a.C=null}function Vo(a,b){let c;try{c=a.F(b)}catch(d){a.destination.error(d);return}a.add(a.D=Lj(c,new Hj(a)))}function Wo(a){const b=a.D,c=a.K;b&&b.unsubscribe();a.D=null;c&&Uo(a)}
class To extends Jj{constructor(a,b,c,d){super(a);this.destination=a;this.F=b;this.G=c;this.K=d;this.C=null;this.i=!1}Na(a){this.i=!0;this.C=a;this.D||(this.G?Uo(this):Vo(this,a))}Eg(){Wo(this)}Dg(){Wo(this)}};var Xo=new df("");function Yo(){Le=()=>{throw new Yd(600,!1);}}function Zo(a,b,c){try{const d=c();return pn(d)?d.catch(e=>{Kk(b,()=>a.handleError(e));throw e;}):d}catch(d){throw Kk(b,()=>a.handleError(d)),d;}}
function $o(a,b){let c=null;a.Ya.i||(c=a.Ya.get(si,null,{optional:!0}));let d=0;const e=a.ea;for(;10>d;){const f=0===d;if(b||!f){a.ia.next(f);for(let {C:g,G:k}of a.C)ap(g,k,f,a.T)}else{let g,k,m;null==(g=c)||null==(m=(k=g).Um)||m.call(k);let p,t,v;null==(p=c)||null==(v=(t=p).end)||v.call(t)}d++;$k(e);if(!a.O.some(({C:g})=>Kg(g))&&(e.lj(),!a.O.some(({C:g})=>Kg(g))))break}}
function bp(a,b){a.C.push(b);if(b.F)throw new Yd(902,!1);b.D=a;a=0!==(b.C[2]&512);const c=b.C[16];null===c||a||kl(c,b.C);Lg(b.C)}
var dp=class{constructor(){this.K=[];this.Fa=this.F=!1;this.D=[];this.C=[];this.ra=lf(vi);this.ea=lf(Wk);this.T=lf(ai);this.ma=new Set;this.ia=new aj;this.N=new aj;this.R=[];this.Jf=[];this.isStable=C(lf(un).ll,vj(a=>!a));this.Ya=lf(ig)}get O(){return[...this.ma.keys(),...this.C]}get i(){return this.Fa}get wa(){return this.Ya}Kk(a,b){const c=a instanceof oi;if(!this.Ya.get(sn).done)throw new Yd(405,!1);let d;c?d=a:d=dn(this.Ya.get(Xh),a);this.R.push(d.fq);a=d.sC?void 0:this.Ya.get(Yh);const e=d.create(Wh,
[],b||d.Vl,a),f=e.location.P,g=e.wa.get(wn,null);null!=g&&g.F.i.set(f,g);e.nb(()=>{this.fj(e.i);cp(this.Jf,e);null!=g&&g.F.i.delete(f)});this.ba(e);return e}G(a){if(this.F)throw new Yd(101,!1);const b=pe(null);try{this.F=!0,$o(this,a)}catch(c){this.ra(c)}finally{this.F=!1,pe(b),this.N.next()}}fj(a){cp(this.C,a);a.D=null;const b=0!==(a.C[2]&512),c=a.C[16];null===c||b||ll(c,a.C);jl(a.C[1],a.C)}ba(a){bp(this,a.i);this.G(!0);this.Jf.push(a);const b=this.Ya.get(Xo,[]);[...this.K,...b].forEach(c=>c(a))}ua(){if(!this.Fa)try{this.D.forEach(a=>
a()),this.C.slice().forEach(a=>a.destroy())}finally{this.Fa=!0,this.C=[],this.K=[],this.D=[]}}nb(a){this.D.push(a);return()=>cp(this.D,a)}destroy(){if(this.Fa)throw new Yd(406,!1);const a=this.Ya;a.destroy&&!a.i&&a.destroy()}get ta(){return this.C.length}};dp.J=function(a){return new (a||dp)};dp.oa=Ld({la:dp,aa:dp.J,da:"root"});function cp(a,b){b=a.indexOf(b);-1<b&&a.splice(b,1)}function ap(a,b,c,d){(c||Kg(a))&&Vm(a,b,c&&!d?0:1)};function ep(a,b,c,d){const e=pe(null);try{const f=b.tb;let g,k,m;const p=sm(a,f,c,a[2]&4096?4096:16,null,b,null,null,null!=(g=null==d?void 0:d.wa)?g:null,null!=(k=null==d?void 0:d.GB)?k:null,null!=(m=null==d?void 0:d.qq)?m:null);p[16]=a[b.index];const t=a[18];null!==t&&(p[18]=t.vd(f));Pm(f,p,c);return p}finally{pe(e)}}function fp(a,b){b=10+b;if(b<a.length)return a[b]}function gp(a,b){return!b||null===b.firstChild||128===(a.flags&128)}
function hp(a,b,c,d=!0){const e=b[1];var f=10+c;const g=a.length;0<c&&(a[f-1][4]=b);c<g-10?(b[4]=a[f],f=10+c,f>=a.length?a.push(b):a.splice(f,0,b)):(a.push(b),b[4]=null);b[3]=a;f=b[16];null!==f&&a!==f&&kl(f,b);f=b[18];null!==f&&Qm(f,e);Lg(b);b[2]|=128;d&&(c=sl(c,a),f=b[11],d=f.parentNode(a[7]),null!==d&&(a=a[5],b[0]=d,b[5]=a,il(f,1,e.firstChild,b,d,c,!1)));b=b[6];null!==b&&null!==b.firstChild&&(b.firstChild=null)};var ip=class{};ip.vf=jp;function jp(){return kp(Ug(),Tg())}function lp(a,b,c,d){const e=b.C;if(Ag(e[3])){var f=a.indexOf(b);-1!==f?a.detach(f):(f=e[3],f=new mp(f,f[5],f[3]),f.detach(f.indexOf(b)))}c=a.Zo(c);a=a.jg;hp(a,e,c,d);if(b.D)throw new Yd(902,!1);b.F=!0;d=np(a);c>=d.length?d.push(b):d.splice(c,0,b);return b}
function op(a,b,c,d,e){var f=b&&"function"!==typeof b;if(!f){var g=c||{};c=g.index;d=g.wa;e=g.uo;g=g.Nf||g.aG}b=f?b:new en(b[Zd]||null);d=d||a.Cj;g||null!=b.Aj||(f=(f?d:a.Cj).get(ig,null))&&(g=f);e=b.create(d,e,null,g);lp(a,e.i,c,gp(a.tk,null));return e}
const mp=class extends ip{constructor(a,b,c){super();this.jg=a;this.tk=b;this.sk=c}get element(){return pi(this.tk,this.sk)}get wa(){return new Eh(this.tk,this.sk)}get Cj(){const a=vh(this.tk,this.sk);if(-1!==a){const b=mh(a,this.sk);return new Eh(b[1].data[(a&32767)+8],b)}return new Eh(null,this.sk)}clear(){for(;0<this.length;)this.remove(this.length-1)}get(a){const b=this.jg[8];return null!==b&&b[a]||null}get length(){return this.jg.length-10}vd(a,b,c){let d,e;"number"===typeof c?d=c:null!=c&&(d=
c.index,e=c.wa);a=pp(a,b||{},e,null);lp(this,a,d,gp(this.tk,null));return a}ar(a,b){return lp(this,a,b,!0)}move(a,b){return this.ar(a,b)}indexOf(a){const b=this.jg[8];return null!==b?b.indexOf(a):-1}remove(a){a=this.Zo(a,-1);const b=ml(this.jg,a);b&&(Sf(np(this.jg),a),nl(b[1],b))}detach(a){a=this.Zo(a,-1);const b=ml(this.jg,a);return b&&null!=Sf(np(this.jg),a)?new an(b):null}Zo(a,b=0){return null==a?this.length+b:a}};function np(a){return a[8]||(a[8]=[])}
function kp(a,b){let c;const d=b[a.index];Ag(d)?c=d:(c=[d,!0,0,b,null,a,null,null,null,null],b[a.index]=c,zm(b,c));qp(c,b,a,d);return new mp(c,a,b)}let qp=rp;function rp(a,b,c,d){if(!a[7]){if(c.type&8)d=Gg(d);else{var e=b[11];d=e.createComment("");const g=Hg(c,b);c=e.parentNode(g);b=e;var f=d;e=e.nextSibling(g);b.insertBefore(c,f,e,!1)}a[7]=d}};function sp(a){return null===a||"function"!==typeof a&&"object"!==typeof a?!1:Array.isArray(a)||!(a instanceof Map)&&Symbol.iterator in a}function tp(a,b){if(Array.isArray(a))for(var c=0;c<a.length;c++)b(a[c]);else for(a=a[Symbol.iterator]();!(c=a.next()).done;)b(c.value)};function up(a,b,c){if(Object.is(a[b],c))return!1;a[b]=c;return!0}function vp(a,b,c,d){c=up(a,b,c);return up(a,b+1,d)||c};function wp(a,b,c,d,e,f,g,k,m,p){const t=c+25;if(b.Ac){const v=b.Ba;g=tm(b,t,4,g||null,k||null);Hm(b,a,g,Jg(v,m));gh(b,g);d=g.tb=Cm(2,g,d,e,f,b.Ev,b.uD,null,b.Pj,v,null);null!==b.queries&&(b.queries.sa(b,g),d.queries=b.queries.Aq(g));d=g}else d=b.data[t];Vg(d,!1);c=xp(b,a,d,c);fh&&ql(b,a,c,d);fi(c,a);c=[c,!0,0,a,null,d,null,c,null,null];a[t]=c;zm(a,c);1===(d.flags&1)&&xm(b,a,d);null!=m&&Bm(a,d,p)}function yp(a,b,c,d,e,f,g,k){const m=Tg(),p=Qg.tb;f=Jg(p.Ba,f);wp(m,p,a,b,c,d,e,f,g,k);return yp}
let xp=zp;function zp(a,b){fh=!0;return b[11].createComment("")};new df("DEFER_BLOCK_DEPENDENCY_INTERCEPTOR");new df("");function Ap(a){var b=Object.getPrototypeOf(a.type.prototype).constructor,c=!0;const d=[a];for(;b;){var e=void 0;if(a.sa)e=b.Ca||b.Ea;else{if(b.Ca)throw new Yd(903,!1);e=b.Ea}if(e){if(c){d.push(e);var f=a;f.inputs=Bp(a.inputs);f.Ce=Bp(a.Ce);f.ej=Bp(a.ej);f.outputs=Bp(a.outputs);(f=e.Ha)&&Cp(a,f);f=e.eb;var g=e.cc;f&&Dp(a,f);g&&Ep(a,g);f=a;g=e;for(var k in g.inputs)if(g.inputs.hasOwnProperty(k)&&!f.inputs.hasOwnProperty(k)){var m=g.inputs[k];if(void 0!==m&&(f.inputs[k]=m,f.ej[k]=g.ej[k],null!==g.Ce)){m=
Array.isArray(m)?m[0]:m;if(!g.Ce.hasOwnProperty(m))continue;let p;null!=(p=f).Ce||(p.Ce={});f.Ce[m]=g.Ce[m]}}f=a.outputs;g=e.outputs;for(const p in g)g.hasOwnProperty(p)&&!f.hasOwnProperty(p)&&(f[p]=g[p]);e.sa&&e.data.animation&&(f=a.data,f.animation=(f.animation||[]).concat(e.data.animation))}if(e=e.features)for(f=0;f<e.length;f++)(g=e[f])&&g.Mw&&g(a),g===Ap&&(c=!1)}b=Object.getPrototypeOf(b)}a=0;b=null;for(c=d.length-1;0<=c;c--)k=d[c],k.Xa=a+=k.Xa,k.Ja=vf(k.Ja,b=vf(b,k.Ja))}
function Bp(a){return a===Ef?{}:a===Ff?[]:a}function Dp(a,b){const c=a.eb;a.eb=c?(d,e)=>{b(d,e);c(d,e)}:b}function Ep(a,b){const c=a.cc;a.cc=c?(d,e,f)=>{b(d,e,f);c(d,e,f)}:b}function Cp(a,b){const c=a.Ha;a.Ha=c?(d,e)=>{b(d,e);c(d,e)}:b};function Fp(a,b,c){if(null!==a.ol)for(const e of a.ol){const f=e.rq[$d]||null;a=f.ej;var d=e.inputs;for(const g in d)d.hasOwnProperty(g)&&(a[d[g]]=a[g]);Fp(f,b,c);c.set(f,e);b.push(f)}}function Gp(a){if(void 0===a||0===a.length)return Ef;const b={};for(let c=0;c<a.length;c+=2)b[a[c]]=a[c+1];return b};function Hp(a){const b=a.qC,c={};for(const d in b)if(b.hasOwnProperty(d)){const e=b[d];Array.isArray(e)&&e[3]&&(c[d]=e[3])}a.Ce=c};function Ip(a,b,c,d){var e=Tg(),f=Qg.cd++;if(up(e,f,b)){f=dh();var g=Hg(f,e);e=e[11];f=f.value;null==b?e.removeAttribute(g,a,d):(b=null==c?fe(b):c(b,f||"",a),e.setAttribute(g,a,b,d))}return Ip};function H(a,b,c){const d=Tg();var e=Qg.cd++;if(up(d,e,b)){e=Qg.tb;const f=dh();Fm(e,f,d,a,b,d[11],c,!1)}return H}function cq(a,b,c,d,e){e=e?"class":"style";Gm(a,c,b.inputs[e],e,d)};function dq(a,b,c,d){const e=a[c+1],f=null===b;let g=d?e>>17&32767:(e&131068)>>2,k=!1;for(;0!==g&&(!1===k||f);){const p=a[g+1];var m=a[g];if(null===m||null==b||(Array.isArray(m)?m[1]:m)===b||Array.isArray(m)&&"string"===typeof b&&0<=Uf(m,b))k=!0,a[g+1]=d?p|1:p|2;g=d?p>>17&32767:(p&131068)>>2}k&&(a[c+1]=d?e|2:e|1)};var eq=0,fq=0,gq=0;function hq(a,b){const c=eq;if(c===b)return-1;for(b=fq=b;b<c&&32<a.charCodeAt(b);)b++;b=gq=b;return iq(a,b,c)}function iq(a,b,c){for(;b<c&&32>=a.charCodeAt(b);)b++;return b};function jq(a,b,c){kq(a,b,c,!1);return jq}function lq(a,b){kq(a,b,null,!0);return lq}function kq(a,b,c,d){const e=Tg(),f=Qg.tb,g=Xg(2);f.wn&&mq(f,a,g,d);if(b!==vl&&up(e,g,b)){var k=f.data[Qg.selectedIndex],m=e[11];null!=b&&""!==b&&("string"===typeof c?b+=c:"object"===typeof b&&(b=ge(zl(b))));nq(f,k,e,m,a,e[g+1]=b,d,g)}}
function oq(a,b){const c=Qg.tb;var d=Xg(2);c.wn&&mq(c,null,d,!0);const e=Tg();if(b!==vl&&up(e,d,b)){var f=c.data[Qg.selectedIndex];if(0===(f.flags&8)||d>=c.Pv){var g=e[11],k=e[d+1];if(null==b||""===b)var m=Ff;else if(m=[],b=zl(b),Array.isArray(b))for(var p=0;p<b.length;p++)a(m,b[p],!0);else if("object"===typeof b)for(p in b)b.hasOwnProperty(p)&&a(m,p,b[p]);else if("string"===typeof b)for(gq=fq=0,eq=b.length,a=hq(b,iq(b,0,eq));0<=a;a=hq(b,a))Tf(m,b.substring(fq,gq),!0);m=e[d+1]=m;k===vl&&(k=Ff);a=
b=0;p=0<k.length?k[0]:null;let t=0<m.length?m[0]:null;for(;null!==p||null!==t;){const v=b<k.length?k[b+1]:void 0,B=a<m.length?m[a+1]:void 0;let G=null,K=void 0;p===t?(b+=2,a+=2,v!==B&&(G=t,K=B)):null===t||null!==p&&p<t?(b+=2,G=p):(a+=2,G=t,K=B);null!==G&&nq(c,f,e,g,G,K,!0,d);p=b<k.length?k[b]:null;t=a<m.length?m[a]:null}}else d=f.cn,null!==d&&(b=he(d,b?b:"")),cq(c,f,e,b,!0)}}
function mq(a,b,c,d){const e=a.data;if(null===e[c+1]){var f=e[Qg.selectedIndex];a=c>=a.Pv;0!==(f.flags&(d?8:16))&&null===b&&!a&&(b=!1);var g=f,k=Yg(e),m=d?g.xo:g.yo;if(null===k)0===(d?g.Ok:g.bm)&&(b=pq(null,e,g,b,d),b=qq(b,g.attrs,d),m=null);else{var p=g.mn;if(-1===p||e[p]!==k)if(b=pq(k,e,g,b,d),null===m)k=d?g.Ok:g.bm,k=0!==(k&131068)>>2?e[k>>17&32767]:void 0,void 0!==k&&Array.isArray(k)&&(k=pq(null,e,g,k[1],d),k=qq(k,g.attrs,d),e[(d?g.Ok:g.bm)>>17&32767]=k);else{m=void 0;k=g.ve;for(p=1+g.mn;p<k;p++)m=
qq(m,e[p].Ja,d);m=qq(m,g.attrs,d)}}void 0!==m&&(d?g.xo=m:g.yo=m);m=a;g=d?f.Ok:f.bm;a=g>>17&32767;g=(g&131068)>>2;e[c]=b;k=!1;if(Array.isArray(b)){if(p=b[1],null===p||0<Uf(b,p))k=!0}else p=b;m?0!==g?(b=e[a+1]>>17&32767,e[c+1]=b<<17|a<<2,0!==b&&(e[b+1]=e[b+1]&-131069|c<<2),e[a+1]=e[a+1]&131071|c<<17):(e[c+1]=a<<17|0,0!==a&&(e[a+1]=e[a+1]&-131069|c<<2),a=c):(e[c+1]=g<<17|0,0===a?a=c:e[g+1]=e[g+1]&-131069|c<<2,g=c);k&&(e[c+1]|=2);dq(e,p,c,!0);dq(e,p,c,!1);b=p;m=d?f.xo:f.yo;null!=m&&"string"==typeof b&&
0<=Uf(m,b)&&(e[c+1]|=1);g=a<<17|g<<2;d?f.Ok=g:f.bm=g}}function pq(a,b,c,d,e){let f;const g=c.ve;let k=c.mn;for(-1===k?k=c.ld:k++;k<g;){f=b[k];d=qq(d,f.Ja,e);if(f===a)break;k++}null!==a&&(c.mn=k);return d}function qq(a,b,c){const d=c?1:2;let e=-1;if(null!==b)for(let f=0;f<b.length;f++){const g=b[f];"number"===typeof g?e=g:e===d&&(Array.isArray(a)||(a=void 0===a?[]:["",a]),Tf(a,g,c?!0:b[++f]))}return void 0===a?null:a}function rq(a,b,c){b=String(b);""===b||b.includes(" ")||Tf(a,b,c)}
function nq(a,b,c,d,e,f,g,k){if(b.type&3){a=a.data;var m=a[k+1];void 0===(1===(m&1)?sq(a,b,c,e,(m&131068)>>2,g):void 0)&&(void 0!==f||2==(m&2)&&(f=sq(a,null,c,e,k,g)),b=Gg(c[Qg.selectedIndex]),g?f?d.Ri(b,e):d.wo(b,e):(g=-1===e.indexOf("-")?void 0:2,null==f?d.Zr(b,e,g):("string"===typeof f&&f.endsWith("!important")&&(f=f.slice(0,-10),g|=1),d.setStyle(b,e,f,g))))}}
function sq(a,b,c,d,e,f){const g=null===b;let k=void 0;for(;0<e;){const p=a[e],t=Array.isArray(p);var m=t?p[1]:p;const v=null===m;let B=c[e+1];B===vl&&(B=v?Ff:void 0);m=v?Vf(B,d):m===d?B:void 0;t&&void 0===m&&(m=Vf(p,d));if(void 0!==m&&(k=m,g))return k;e=a[e+1];e=g?e>>17&32767:(e&131068)>>2}null!==b&&(a=f?b.xo:b.yo,null!=a&&(k=Vf(a,d)));return k};function tq(a){a=up(Tg(),Qg.cd++,a)?"mat-mdc-select-panel mdc-menu-surface mdc-menu-surface--open "+fe(a):vl;oq(Tf,a)};function uq(a,b,c){const d=Math.min(b,c);b=Math.max(b,c);c=a.detach(b);if(1<b-d){const e=a.detach(d);a.attach(d,c);a.attach(b,e)}else a.attach(d,c)}var vq=class{destroy(){}i(){}move(a,b){this.attach(b,this.detach(a))}};function wq(a,b,c,d,e){return a===c&&Object.is(b,d)?1:Object.is(e(a,b),e(c,d))?-1:0}
function xq(a,b,c){let d=void 0,e=void 0,f=0,g=a.length-1;if(Array.isArray(b)){for(var k=b.length-1;f<=g&&f<=k;){var m=a.at(f),p=b[f],t=wq(f,m,f,p,c);if(0!==t)0>t&&a.i(f,p),f++;else{var v=a.at(g);t=b[k];var B=wq(g,v,k,t,c);0!==B?(0>B&&a.i(g,t),g--,k--):(m=c(f,m),v=c(g,v),B=c(f,p),Object.is(B,v)?(v=c(k,t),Object.is(v,m)?(uq(a,f,g),a.i(g,t),k--,g--):a.move(g,f),a.i(f,p),f++):(null!=d||(d=new yq),null!=e||(e=zq(a,f,g,c)),Aq(a,d,f,B)?(a.i(f,p),f++,g++):e.has(B)?(d.set(m,a.detach(f)),g--):(p=a.create(f,
b[f]),a.attach(f,p),f++,g++)))}}for(;f<=k;)Bq(a,d,c,f,b[f]),f++}else if(null!=b){b=b[Symbol.iterator]();for(k=b.next();!k.done&&f<=g;)p=a.at(f),t=k.value,m=wq(f,p,f,t,c),0!==m?(0>m&&a.i(f,t),f++,k=b.next()):(null!=d||(d=new yq),null!=e||(e=zq(a,f,g,c)),m=c(f,t),Aq(a,d,f,m)?(a.i(f,t),f++,g++,k=b.next()):e.has(m)?(p=c(f,p),d.set(p,a.detach(f)),g--):(a.attach(f,a.create(f,t)),f++,g++,k=b.next()));for(;!k.done;)Bq(a,d,c,a.length,k.value),k=b.next()}for(;f<=g;)a.destroy(a.detach(g--));let G;null==(G=d)||
G.forEach(K=>{a.destroy(K)})}function Aq(a,b,c,d){return void 0!==b&&b.has(d)?(a.attach(c,b.get(d)),b.delete(d),!0):!1}function Bq(a,b,c,d,e){Aq(a,b,d,c(d,e))?a.i(d,e):(b=a.create(d,e),a.attach(d,b))}function zq(a,b,c,d){const e=new Set;for(;b<=c;b++)e.add(d(b,a.at(b)));return e}
var yq=class{constructor(){this.C=new Map;this.i=void 0}has(a){return this.C.has(a)}delete(a){if(!this.has(a))return!1;const b=this.C.get(a);void 0!==this.i&&this.i.has(b)?(this.C.set(a,this.i.get(b)),this.i.delete(b)):this.C.delete(a);return!0}get(a){return this.C.get(a)}set(a,b){if(this.C.has(a)){a=this.C.get(a);void 0===this.i&&(this.i=new Map);const c=this.i;for(;c.has(a);)a=c.get(a);c.set(a,b)}else this.C.set(a,b)}forEach(a){for(let [b,c]of this.C){let d=b,e=c;a(e,d);if(void 0!==this.i){const f=
this.i;for(;f.has(e);)e=f.get(e),a(e,d)}}}};function Cq(a){Ci("NgControlFlow");var b=Tg(),c=Qg.cd++,d=b[c]!==vl?b[c]:-1;d=-1!==d?b[25+d]:void 0;if(up(b,c,a)){c=pe(null);try{if(void 0!==d){const e=ml(d,0);void 0!==e&&nl(e[1],e)}if(-1!==a){a=25+a;const e=b[a],f=b[1].data[a],g=ep(b,f,void 0,{qq:null});hp(e,g,0,gp(f,null))}}finally{pe(c)}}else void 0!==d&&(b=fp(d,0),void 0!==b&&(b[8]=void 0))}var Dq=class{constructor(a,b,c){this.i=a;this.ca=b;this.Bb=c}get Ty(){return this.i.length-10}};function Eq(a){return a}function Fq(a,b){return b}
class Gq{constructor(a){this.C=a;this.i=void 0}}function Hq(a,b,c,d,e,f,g){Ci("NgControlFlow");const k=Tg(),m=Qg.tb;Tg()[25+a]=new Gq(g);wp(k,m,a+1,b,c,d,e,Jg(m.Ba,f))}
class Iq extends vq{constructor(a,b,c){super();this.C=a;this.K=b;this.G=c;this.F=void 0;this.D=!1}get length(){return this.C.length-10}at(a){return fp(this.C,a)[8].ca}attach(a,b){const c=b[6];this.D||(this.D=a!==this.length);hp(this.C,b,a,gp(this.G,c))}detach(a){this.D||(this.D=a!==this.length-1);return ml(this.C,a)}create(a,b){a=ep(this.K,this.G,new Dq(this.C,b,a),{qq:null});let c;null==(c=this.F)||c.i();return a}destroy(a){nl(a[1],a);let b;null==(b=this.F)||b.C()}i(a,b){fp(this.C,a)[8].ca=b}reset(){this.D=
!1;let a;null==(a=this.F)||a.reset()}}function Jq(a){const b=pe(null);var c=Qg.selectedIndex;try{const d=Tg(),e=d[1],f=d[c];c+=1;const g=d[c];void 0===f.i?f.i=new Iq(g,d,e.data[c]):f.i.reset();const k=f.i;xq(k,a,f.C);if(k.D)for(a=0;a<k.length;a++)fp(k.C,a)[8].Bb=a}finally{pe(b)}};function R(a,b,c,d){const e=Tg(),f=Qg.tb;var g=25+a;a=e[11];if(f.Ac){var k=f.Ba;c=Jg(k,c);c=tm(f,g,2,b,c);Hm(f,e,c,Jg(k,d));null!==c.attrs&&Rm(c,c.attrs,!1);null!==c.Fe&&Rm(c,c.Fe,!0);null!==f.queries&&f.queries.bl(f,c);k=c}else k=f.data[g];fh=!0;b=a.createElement(b,Qg.Vk);e[g]=b;g=1===(k.flags&1);Vg(k,!0);ul(a,b,k);32!==(k.flags&32)&&fh&&ql(f,e,b,k);0===Qg.pn&&fi(b,e);Qg.pn++;g&&(xm(f,e,k),wm(f,k,e));null!==d&&Bm(e,k);return R}
function S(){let a=Ug();Qg.Rf?Qg.Rf=!1:(a=a.parent,Vg(a,!1));const b=a;Rg===b&&(Rg=null);Qg.pn--;const c=Qg.tb;c.Ac&&(gh(c,a),0!==(a.flags&4)&&c.queries.qn(a));null!=b.cn&&0!==(b.flags&8)&&cq(c,b,Tg(),b.cn,!0);null!=b.zs&&0!==(b.flags&16)&&cq(c,b,Tg(),b.zs,!1);return S}function Kq(a,b,c,d){R(a,b,c,d);S();return Kq};function Lq(a,b,c){const d=Tg(),e=Qg.tb;a+=25;if(e.Ac){var f=e.Ba;const g=Jg(f,b);b=tm(e,a,8,"ng-container",g);null!==g&&Rm(b,g,!0);f=Jg(f,c);Hm(e,d,b,f);null!==e.queries&&e.queries.bl(e,b);f=b}else f=e.data[a];Vg(f,!0);fh=!0;b=d[11].createComment(gl());d[a]=b;fh&&ql(e,d,b,f);fi(b,d);1===(f.flags&1)&&(xm(e,d,f),wm(e,f,d));null!=c&&Bm(d,f);return Lq}function Mq(){let a=Ug();const b=Qg.tb;Qg.Rf?Qg.Rf=!1:(a=a.parent,Vg(a,!1));b.Ac&&(gh(b,a),0!==(a.flags&4)&&b.queries.qn(a));return Mq}
function Nq(a,b,c){Lq(a,b,c);Mq();return Nq};function Oq(a,b,c){const d=Tg();var e=Qg.cd++;if(up(d,e,b)){e=Qg.tb;const f=dh();Fm(e,f,d,a,b,d[11],c,!0)}return Oq}function Pq(a,b,c){const d=Tg();var e=Qg.cd++;if(up(d,e,b)){e=Qg.tb;const f=dh();Fm(e,f,d,a,b,Mm(Yg(e.data),f,d),c,!0)}return Pq};function V(a,b,c,d){c=Tg();Qq(Qg.tb,c,c[11],Ug(),a,b,d);return V}function Rq(a,b){const c=Ug(),d=Tg(),e=Qg.tb;Qq(e,d,Mm(Yg(e.data),c,d),c,a,b);return Rq}function Sq(a,b,c,d){a=a.ae;if(null!=a)for(let e=0;e<a.length-1;e+=2){const f=a[e];if(f===c&&a[e+1]===d)return b=b[7],c=a[e+2],b.length>c?b[c]:null;"string"===typeof f&&(e+=2)}return null}
function Qq(a,b,c,d,e,f,g){var k=1===(d.flags&1);const m=a.Ac&&(a.ae||(a.ae=[])),p=b[7]||(b[7]=[]);var t=!0;if(d.type&3||g){var v=Hg(d,b);const G=g?g(v):v;v=p.length;const K=g?aa=>g(Gg(aa[d.index])):d.index;let N=null;!g&&k&&(N=Sq(a,b,e,d.index));null!==N?((N.xz||N).ht=f,N.xz=f,t=!1):(f=Tq(d,b,f),a=c.Ed(G,e,f),p.push(f,a),m&&m.push(e,K,v,v+1))}else f=Tq(d,b,f);a=d.outputs;let B;if(t&&null!==a&&(B=a[e])&&(t=B.length))for(a=0;a<t;a+=2)c=b[B[a]][B[a+1]].subscribe(f),k=p.length,p.push(f,c),m&&m.push(e,
d.index,k,-(k+1))}function Uq(a,b,c){const d=pe(null);try{return!1!==b(c)}catch(e){return Nm(a,e),!1}finally{pe(d)}}function Tq(a,b,c){return function f(e){if(e===Function)return c;var g=-1<a.If?Ig(a.index,b):b;al(g,5);g=Uq(b,c,e);let k=f.ht;for(;k;)g=Uq(b,k,e)&&g,k=k.ht;return g}};function Y(a=1){for(var b=Qg,c=Qg.Bh;0<a;)c=c[14],a--;return(b.Bh=c)[8]};function Vq(a){var b=Tg()[15][5];if(!b.Ie){var c=a?a.length:1,d=[];for(var e=0;e<c;e++)d.push(null);c=b.Ie=d;d=c.slice();for(b=b.Gf;null!==b;){if(a)a:{e=b;var f=a;let p=null;b:{var g=e.attrs;if(null!=g){var k=g.indexOf(5);if(0===(k&1)){g=g[k+1];break b}}g=null}for(k=0;k<f.length;k++){var m=f[k];if("*"===m)p=k;else{if(null===g)m=Af(e,m,!0);else b:{c:for(let t=0;t<m.length;t++){const v=m[t];if(g.length===v.length){for(let B=0;B<g.length;B++)if(g[B]!==v[B])continue c;m=!0;break b}}m=!1}if(m){e=k;break a}}}e=
p}else e=0;null!==e&&(d[e]?d[e].Ur=b:c[e]=b,d[e]=b);b=b.next}}}function Wq(a,b=0){const c=Tg();var d=Qg.tb;a=tm(d,25+a,16,null,null);null===a.Ie&&(a.Ie=b);Qg.Rf=!1;if((!c[6]||null!==Rg)&&32!==(a.flags&32)){b=c[11];d=pl(d,a.parent,c);var e=a.parent||c[5];e=e.type&40?Hg(e,c):null;tl(b,0,c,a,d,e)}};function Xq(){return this.C[Symbol.iterator]()}function Yq(a){void 0===a.D||!a.F&&a.G||a.D.emit(a)}
var Zq=class{get i(){let a;return null!=(a=this.D)?a:this.D=new Dk}constructor(a=!1){this.G=a;this.pc=!0;this.K=void 0;this.C=[];this.F=!1;this.D=void 0;this.length=0;this.first=void 0;const b=Zq.prototype;b[Symbol.iterator]||(b[Symbol.iterator]=Xq)}get(a){return this.C[a]}map(a){return this.C.map(a)}filter(a){return this.C.filter(a)}find(a){return this.C.find(a)}reduce(a,b){return this.C.reduce(a,b)}forEach(a){this.C.forEach(a)}some(a){return this.C.some(a)}toArray(){return this.C.slice()}toString(){return this.C.toString()}reset(a,b){this.pc=
!1;a=a.flat(Number.POSITIVE_INFINITY);a:{var c=this.C;if(c.length!==a.length)b=!1;else{for(let d=0;d<c.length;d++){let e=c[d],f=a[d];b&&(e=b(e),f=b(f));if(f!==e){b=!1;break a}}b=!0}}if(this.F=!b)this.C=a,this.length=a.length,this.first=a[0]}rs(){this.pc=!0;let a;null==(a=this.K)||a.call(this)}destroy(){void 0!==this.D&&(this.D.complete(),this.D.unsubscribe())}};Symbol.iterator;var $q=class{};$q.vf=ar;function pp(a,b,c,d){a=ep(a.Jz,a.ut,b,{GB:c,qq:d});return new an(a)}const br=class extends $q{constructor(a,b,c){super();this.Jz=a;this.ut=b;this.dc=c}get Zx(){let a;return(null==(a=this.ut.tb)?void 0:a.Zx)||null}vd(a,b){return pp(this,a,b)}};function ar(){return cr(Ug(),Tg())}function cr(a,b){return a.type&4?new br(b,a,pi(a,b)):null};class dr{constructor(a){this.Wr=a;this.matches=null}clone(){return new dr(this.Wr)}rs(){this.Wr.rs()}}function Qm(a,b){for(let c=0;c<a.queries.length;c++)null!==b.queries.queries[c].matches&&a.queries[c].rs()}class er{constructor(a=[]){this.queries=a}vd(a){const b=a.queries;if(null!==b){a=null!==a.cc?a.cc[0]:b.length;const c=[];for(let d=0;d<a;d++)c.push(this.queries[b.queries[d].hw].clone());return new er(c)}return null}fj(a){Qm(this,a)}}
var gr=class{constructor(a,b){this.flags=b;this.read=null;"string"===typeof a?this.lf=fr(a):this.lf=a}};
class hr{constructor(a=[]){this.queries=a}bl(a,b){for(let c=0;c<this.queries.length;c++)this.queries[c].bl(a,b)}qn(a){for(let b=0;b<this.queries.length;b++)this.queries[b].qn(a)}Aq(a){let b=null;for(let c=0;c<this.length;c++){const d=this.queries[c].Aq(a,null!==b?b.length:0);d&&(d.hw=c,null!==b?b.push(d):b=[d])}return null!==b?new hr(b):null}sa(a,b){for(let c=0;c<this.queries.length;c++)this.queries[c].sa(a,b)}get length(){return this.queries.length}track(a){this.queries.push(a)}}
function ir(a,b){if(a.i&&1!==(a.metadata.flags&1)){a=a.C;for(b=b.parent;null!==b&&b.type&8&&b.index!==a;)b=b.parent;return a===(null!==b?b.index:-1)}return a.i}function jr(a,b,c){null===a.matches?a.matches=[b,c]:a.matches.push(b,c)}function kr(a,b,c,d){if(null!==d){const e=a.metadata.read;null!==e?e===qi||e===ip||e===$q&&c.type&4?jr(a,c.index,-2):(b=Ch(c,b,e,!1,!1),null!==b&&jr(a,c.index,b)):jr(a,c.index,d)}}
class lr{constructor(a,b=-1){this.metadata=a;this.matches=null;this.hw=-1;this.kv=!1;this.i=!0;this.C=b}bl(a,b){if(ir(this,b)){const d=this.metadata.lf;if(Array.isArray(d))for(let e=0;e<d.length;e++){const f=d[e];a:{var c=b.kr;if(null!==c)for(let g=0;g<c.length;g+=2)if(c[g]===f){c=c[g+1];break a}c=null}kr(this,a,b,c);kr(this,a,b,Ch(b,a,f,!1,!1))}else d===$q?b.type&4&&kr(this,a,b,-1):kr(this,a,b,Ch(b,a,d,!1,!1))}}qn(a){this.C===a.index&&(this.i=!1)}sa(a,b){this.bl(a,b)}Aq(a,b){return ir(this,a)?(this.kv=
!0,jr(this,-a.index,b),new lr(this.metadata)):null}}function mr(a,b,c,d){d=b[18].queries[d];if(null===d.matches){const p=a.data,t=c.matches,v=[];for(let B=0;null!==t&&B<t.length;B+=2){var e=t[B];if(0>e)v.push(null);else{a=v;var f=a.push,g=b,k=p[e],m=t[B+1];e=c.metadata.read;-1===m?(e=k,g=e.type&11?pi(e,g):e.type&4?cr(e,g):null):-2===m?g=e===qi?pi(k,g):e===$q?cr(k,g):e===ip?kp(k,g):void 0:g=Dh(g,g[1],m,k);f.call(a,g)}}d.matches=v}return d.matches}
function nr(a,b,c,d){var e=a.queries.queries[c];const f=e.matches;if(null!==f)for(a=mr(a,b,e,c),c=0;c<f.length;c+=2){var g=f[c];if(0<g)d.push(a[c/2]);else{e=f[c+1];g=b[-g];for(var k=10;k<g.length;k++){var m=g[k];m[16]===m[3]&&nr(m[1],m,e,d)}if(null!==g[9])for(g=g[9],k=0;k<g.length;k++)m=g[k],nr(m[1],m,e,d)}}return d}
function or(a,b){var c=Tg();b=new Zq(4===(b&4));var d=b.destroy;const e=c[7]||(c[7]=[]);e.push(b);a.Ac&&(a.ae||(a.ae=[])).push(d,e.length-1);let f;(null!=(f=c[18])?f:c[18]=new er).queries.push(new dr(b))}function fr(a){return a.split(",").map(b=>b.trim())}function pr(a,b,c){null===a.queries&&(a.queries=new hr);a.queries.track(new lr(b,c))};function qr(a,b,c){const d=Qg.tb;if(d.Ac){const e=Ug();pr(d,new gr(b,c),e.index);b=d.cc||(d.cc=[]);a!==(b.length?b[b.length-1]:-1)&&b.push(d.queries.length-1,a);2===(c&2)&&(d.ay=!0)}or(d,c)}function rr(a,b){const c=Qg.tb;c.Ac&&(pr(c,new gr(a,b),-1),2===(b&2)&&(c.by=!0));or(c,b)}
function sr(a){var b=Tg(),c=Qg.tb;const d=Qg.be;Qg.be=d+1;c=c.queries.queries[d];if(a.pc&&4===(b[2]&4)===(2===(c.metadata.flags&2))){if(null===c.matches)a.reset([]);else{c=b[1];const e=c.queries.queries[d];b=e.kv?nr(c,b,d,[]):mr(c,b,e,d);a.reset(b,ri);Yq(a)}return!0}return!1}function tr(){return Tg()[18].queries[Qg.be].Wr};function ur(a){Ci("NgSignals");a=Me(a);const b=a[oe];a.set=c=>Se(b,c);a.update=c=>{Be()||Le();Se(b,c(b.value))};a.xF=vr.bind(a);return a}function vr(){const a=this[oe];if(void 0===a.sx){const b=()=>this();b[oe]=a;a.sx=b}return a.sx};function wr(a){return Qg.Bh[25+a]};function Z(a,b=""){const c=Tg(),d=Qg.tb;a+=25;const e=d.Ac?tm(d,a,1,b,null):d.data[a];fh=!0;b=c[11].lq(b);c[a]=b;fh&&ql(d,c,b,e);Vg(e,!1)};function xr(a){yr("",a,"");return xr}function yr(a,b,c){const d=Tg();a=up(d,Qg.cd++,b)?a+fe(b)+c:vl;a!==vl&&Om(d,a);return yr}function zr(a,b,c,d,e){const f=Tg(),g=vp(f,Qg.cd,b,d);Xg(2);a=g?a+fe(b)+c+fe(d)+e:vl;a!==vl&&Om(f,a);return zr}function Ar(a,b,c,d,e,f,g,k,m){const p=Tg();var t=Qg.cd;const v=vp(p,t,b,d);t=vp(p,t+2,f,k)||v;Xg(4);a=t?a+fe(b)+c+fe(d)+e+fe(f)+g+fe(k)+m:vl;a!==vl&&Om(p,a);return Ar};function Br(a,b,c,d,e){a=bf(a);if(Array.isArray(a))for(var f=0;f<a.length;f++)Br(a[f],b,c,d,e);else{f=Qg.tb;const v=Tg(),B=Ug();let G=cg(a)?a:bf(a.na);var g=vg(a),k=B.Jg&1048575,m=B.ld,p=B.Jg>>20;if(cg(a)||!a.Db)d=new lh(g,e),g=Cr(G,b,e?k:k+p,m),-1===g?(g=sh(B,v),rh(g,f,G),Dr(f,a,b.length),b.push(G),B.ld++,B.ve++,e&&(B.Jg+=1048576),c.push(d),v.push(d)):(c[g]=d,v[g]=d);else{m=Cr(G,b,k+p,m);k=Cr(G,b,k,k+p);var t=0<=m&&c[m];p=0<=k&&c[k];e&&!p||!e&&!t?(m=sh(B,v),rh(m,f,G),m=c.length,t=new lh(e?Er:Fr,
e),t.Db=[],t.index=m,t.i=0,d&&!e&&t.i++,t.Db.push(g),g=t,!e&&p&&(c[k].C=g),Dr(f,a,b.length,0),b.push(G),B.ld++,B.ve++,e&&(B.Jg+=1048576),c.push(g),v.push(g)):(b=c[e?k:m],!e&&d&&b.i++,b=b.Db.push(g)-1,Dr(f,a,-1<m?m:k,b));!e&&d&&p&&c[k].i++}}}function Dr(a,b,c,d){const e=cg(b);var f=!!b.Dc;if(e||f)if(f=(f?bf(b.Dc):b).prototype.ua)a=a.Wk||(a.Wk=[]),!e&&b.Db?(b=a.indexOf(c),-1===b?a.push(c,[d,f]):a[b+1].push(d,f)):a.push(c,f)}function Cr(a,b,c,d){for(;c<d;c++)if(b[c]===a)return c;return-1}
function Fr(){return Gr(this.Db,[])}function Er(a,b,c,d){b=this.Db;if(this.C){const e=this.C.i;d=Dh(c,c[1],this.C.index,d);c=d.slice(0,e);Gr(b,c);for(b=e;b<d.length;b++)c.push(d[b])}else c=[],Gr(b,c);return c}function Gr(a,b){for(let c=0;c<a.length;c++)b.push((0,a[c])());return b};function Hr(a){var b=[];return c=>{c.Vr=(d,e)=>{e=e?e(a):a;const f=Qg.tb;f.Ac&&(d=!!d.sa,Br(b,f.data,f.qg,d,!0),Br(e,f.data,f.qg,d,!1))}}};class Ir{constructor(a){this.Ya=a;this.i=new Map}ua(){try{for(const a of this.i.values())null!==a&&a.destroy()}finally{this.i.clear()}}}Ir.oa=Ld({la:Ir,da:"environment",aa:()=>new Ir(q(ig))});function Jr(a){Ci("NgStandalone");a.Iq=b=>{b=b.get(Ir);if(a.ja){if(!b.i.has(a)){var c=Xf(a.type);c=0<c.length?on([c],b.Ya,`Standalone[${a.type.name}]`):null;b.i.set(a,c)}b=b.i.get(a)}else b=null;return b}};function Kr(){var a=Lr,b=Wg()+6;const c=Tg();c[b]===vl?(a=a(),b=c[b]=a):b=c[b];return b}function Mr(a,b){var c=Tg(),d=Wg()+2;up(c,d,b)?(d+=1,a=a(b),c=c[d]=a):(c=c[d+1],c=c===vl?void 0:c);return c};function Nr(a,b){return cr(a,b)};var Or=class{};Or.J=function(a){return new (a||Or)(q(dp))};Or.Wa=Mf({type:Or});Or.Va=Md({});Object.assign({},Re,{py:void 0,Iu(a,b){Se(a,b)}});var Pr=class{};Pr.vf=Qr;function Qr(a){var b=Ug(),c=Tg();-1<b.If&&16!==(a&16)?(a=Ig(b.index,c),a=new an(a,a)):a=b.type&47?new an(c[15],c):null;return a};var Sr=class{supports(a){return sp(a)}create(a){return new Rr(a)}};const Tr=(a,b)=>b;function Ur(a,b){let c=a.K;a=a.O;let d=0,e=null;for(;c||a;){const f=!a||c&&c.dd<Vr(a,d,e)?c:a,g=Vr(f,d,e),k=f.dd;if(f===a)d--,a=a.C;else if(c=c.Na,null==f.He)d++;else{e||(e=[]);const m=g-d,p=k-d;if(m!=p){for(let t=0;t<m;t++){const v=t<e.length?e[t]:e[t]=0,B=v+t;p<=B&&B<m&&(e[t]=v+1)}e[f.He]=p-m}}g!==k&&b(f,g,k)}}function Wr(a,b){for(a=a.ea;null!==a;a=a.O)b(a)}
function Xr(a,b){Yr(a);let c=a.K,d=!1,e,f,g;if(Array.isArray(b)){a.length=b.length;for(let k=0;k<a.length;k++)f=b[k],g=a.va(k,f),null!==c&&Object.is(c.F,g)?(d&&(c=a.Ra(c,f,g,k)),Object.is(c.item,f)||a.ba(c,f)):(c=a.Ia(c,f,g,k),d=!0),c=c.Na}else e=0,tp(b,k=>{g=a.va(e,k);null!==c&&Object.is(c.F,g)?(d&&(c=a.Ra(c,k,g,e)),Object.is(c.item,k)||a.ba(c,k)):(c=a.Ia(c,k,g,e),d=!0);c=c.Na;e++}),a.length=e;a.rb(c);a.collection=b;return a.Sn}
function Yr(a){if(a.Sn){let b;for(b=a.fb=a.K;null!==b;b=b.Na)b.T=b.Na;for(b=a.T;null!==b;b=b.N)b.He=b.dd;a.T=a.F=null;for(b=a.ia;null!==b;b=b.R)b.He=b.dd;a.ia=a.N=null;a.O=a.C=null;a.ea=a.G=null}}
var Rr=class{constructor(a){this.length=0;this.G=this.ea=this.C=this.O=this.N=this.ia=this.F=this.T=this.R=this.K=this.fb=this.i=this.D=null;this.va=a||Tr}ln(a){null==a&&(a=[]);if(!sp(a))throw new Yd(900,!1);return Xr(this,a)?this:null}nb(){}get Sn(){return null!==this.T||null!==this.ia||null!==this.O||null!==this.ea}Ia(a,b,c,d){let e;null===a?e=this.R:(e=a.D,this.kb(a));a=null===this.i?null:this.i.get(c,null);null!==a?(Object.is(a.item,b)||this.ba(a,b),this.Oa(a,e,d)):(a=null===this.D?null:this.D.get(c,
d),null!==a?(Object.is(a.item,b)||this.ba(a,b),this.ab(a,e,d)):a=this.Ta(new Zr(b,c),e,d));return a}Ra(a,b,c,d){b=null===this.i?null:this.i.get(c,null);null!==b?a=this.Oa(b,a.D,d):a.dd!=d&&(a.dd=d,this.ma(a,d));return a}rb(a){for(;null!==a;){const b=a.Na;this.Da(this.ta(a));a=b}null!==this.i&&this.i.clear();null!==this.F&&(this.F.N=null);null!==this.N&&(this.N.R=null);null!==this.R&&(this.R.Na=null);null!==this.C&&(this.C.C=null);null!==this.G&&(this.G.O=null)}Oa(a,b,c){null!==this.i&&this.i.remove(a);
const d=a.K,e=a.C;null===d?this.O=e:d.C=e;null===e?this.C=d:e.K=d;this.ra(a,b,c);this.ma(a,c);return a}ab(a,b,c){this.ta(a);this.ra(a,b,c);this.ma(a,c);return a}Ta(a,b,c){this.ra(a,b,c);this.F=null===this.F?this.T=a:this.F.N=a;return a}ra(a,b,c){const d=null===b?this.K:b.Na;a.Na=d;a.D=b;null===d?this.R=a:d.D=a;null===b?this.K=a:b.Na=a;null===this.D&&(this.D=new $r);as(this.D,a);a.dd=c;return a}kb(a){return this.Da(this.ta(a))}ta(a){null!==this.D&&this.D.remove(a);const b=a.D,c=a.Na;null===b?this.K=
c:b.Na=c;null===c?this.R=b:c.D=b;return a}ma(a,b){if(a.He===b)return a;this.N=null===this.N?this.ia=a:this.N.R=a;return a}Da(a){null===this.i&&(this.i=new $r);as(this.i,a);a.dd=null;a.C=null;null===this.C?(this.C=this.O=a,a.K=null):(a.K=this.C,this.C=this.C.C=a);return a}ba(a,b){a.item=b;this.G=null===this.G?this.ea=a:this.G.O=a;return a}},Zr=class{constructor(a,b){this.item=a;this.F=b;this.O=this.R=this.N=this.C=this.K=this.i=this.G=this.Na=this.D=this.T=this.He=this.dd=null}};
class bs{constructor(){this.C=this.i=null}add(a){null===this.i?(this.i=this.C=a,a.i=null,a.G=null):(this.C.i=a,a.G=this.C,a.i=null,this.C=a)}get(a,b){let c;for(c=this.i;null!==c;c=c.i)if((null===b||b<=c.dd)&&Object.is(c.F,a))return c;return null}remove(a){const b=a.G;a=a.i;null===b?this.i=a:b.i=a;null===a?this.C=b:a.G=b;return null===this.i}}function as(a,b){const c=b.F;let d=a.map.get(c);d||(d=new bs,a.map.set(c,d));d.add(b)}
class $r{constructor(){this.map=new Map}get(a,b){const c=this.map.get(a);return c?c.get(a,b):null}remove(a){const b=a.F;this.map.get(b).remove(a)&&this.map.delete(b);return a}clear(){this.map.clear()}}function Vr(a,b,c){a=a.He;if(null===a)return a;let d=0;c&&a<c.length&&(d=c[a]);return a+b+d};var cs=class{constructor(a){this.i=a}find(a){const b=this.i.find(c=>c.supports(a));if(null!=b)return b;throw new Yd(901,!1);}};cs.oa=Ld({la:cs,da:"root",aa:function(){return new cs([new Sr])}});function ds(a,b){if(!a.i&&!a.F.i){var c=a.D.add();try{a.ea.run(()=>{a.i=!0;a.F.G(b)},void 0,a.ia)}catch(d){throw a.D.remove(c),d;}finally{a.ae()}a.T=!0;Gk(()=>{a.T=!1;a.D.remove(c)})}}
var es=class{constructor(){this.F=lf(dp);this.D=lf(un);this.ea=lf(Ok);this.N=lf(ai);let a;this.O=null!=(a=lf(bi,{optional:!0}))?a:!1;this.ba="undefined"!==typeof Zone&&!!Zone.root.run;this.ia=[{data:{__scheduler_tick__:!0}}];this.R=new Li;this.G=null;this.i=this.T=this.K=!1;this.C=null;this.R.add(this.F.N.subscribe(()=>{this.i||this.ae()}));this.R.add(this.ea.ko.subscribe(()=>{this.i||this.ae()}));this.O||(this.O=!this.N&&!this.ba)}notify(a){if(this.N||5!==a){switch(a){case 3:case 2:case 0:case 4:case 5:case 1:this.K=
!0}if(!(this.O||null!==this.C||this.i||this.F.F||!this.N&&this.ba&&Ik())){var b=this.T?Gk:Fk;this.C=this.D.add();this.ba?Zone.root.run(()=>{this.G=b(()=>{ds(this,this.K)})}):this.G=b(()=>{ds(this,this.K)})}}}ua(){this.R.unsubscribe();this.ae()}ae(){this.i=this.K=!1;var a;null==(a=this.G)||a.call(this);this.G=null;null!==this.C&&(a=this.C,this.C=null,this.D.remove(a))}};es.J=function(a){return new (a||es)};es.oa=Ld({la:es,aa:es.J,da:"root"});function fs(a){a.i||(a.i=a.zone.Ow.subscribe({next:()=>{let b;(null==(b=a.Xi)?0:b.i)||a.zone.run(()=>{a.C.G(!0)})}}))}var gs=class{constructor(){this.zone=lf(Ok);this.Xi=lf($h,{optional:!0});this.C=lf(dp);lf(ai)}ua(){let a;null==(a=this.i)||a.unsubscribe()}};gs.J=function(a){return new (a||gs)};gs.oa=Ld({la:gs,aa:gs.J,da:"root"});new df("");
function hs(){var {bG:a,SF:b}={};null!=a||(a=()=>new Ok({HB:!1,Bo:!1,Wl:!1}));return[{na:Ok,Ec:a},{na:qf,Db:!0,Ec:()=>{const c=lf(gs,{optional:!0});return()=>fs(c)}},{na:qf,Db:!0,Ec:()=>{const c=lf(is);return()=>{js(c)}}},{na:vi,Ec:ks},!0===b?{na:bi,mb:!0}:[],{na:$h,zb:es}]}function ks(){const a=lf(Ok),b=lf(ui);return c=>Kk(a,()=>b.handleError(c))}
function js(a){if(!a.D){a.D=!0;var b=null;a.zone.isStable||a.zone.Hn||a.zone.kl||(b=a.i.add());Kk(a.zone,()=>{a.C.add(a.zone.jo.subscribe(()=>{Jk();queueMicrotask(()=>{null===b||a.zone.Hn||a.zone.kl||(a.i.remove(b),b=null)})}))});a.C.add(a.zone.ko.subscribe(()=>{if(!Ik())throw new Yd(909,!1);null!=b||(b=a.i.add())}))}}var is=class{constructor(){this.C=new Li;this.D=!1;this.zone=lf(Ok);this.i=lf(un)}ua(){this.C.unsubscribe()}};is.J=function(a){return new (a||is)};is.oa=Ld({la:is,aa:is.J,da:"root"});var ls=new df("",{da:"root",aa:()=>lf(ls,12)||"undefined"!==typeof $localize&&$localize.locale||"en-US"});new df("",{da:"root",aa:()=>"USD"});new df("");new df("");var ms=class{};ms.J=function(a){return new (a||ms)};ms.oa=Ld({la:ms,aa:ms.J,da:"root"});new df("");var ns=new df(""),os=class{constructor(a){this.Ya=a;this.D=[];this.C=[];this.Fa=!1}F(a){const b=a.wa.get(dp);if(0<a.fp.length)a.fp.forEach(c=>b.Kk(c));else if(a.instance.VC)a.instance.VC(b);else throw new Yd(-403,!1);this.D.push(a)}nb(a){this.C.push(a)}get wa(){return this.Ya}destroy(){if(this.Fa)throw new Yd(404,!1);this.D.slice().forEach(b=>b.destroy());this.C.forEach(b=>b());const a=this.Ya.get(ns,null);a&&(a.forEach(b=>b()),a.clear());this.Fa=!0}get i(){return this.Fa}};
os.J=function(a){return new (a||os)(q(Vh))};os.oa=Ld({la:os,aa:os.J,da:"platform"});let ps=null;var qs=new df("");function rs(a,b,c=[]){const d=`Platform: ${b}`,e=new df(d);return(f=[])=>{let g=ss();if(!g||g.wa.get(qs,!1))if(f=[...c,...f,{na:e,mb:!0}],a)a(f);else{f=ts(f,d);if(ps&&!ps.get(qs,!1))throw new Yd(400,!1);Yo();ps=f;f.get(os);us(f)}f=ss();if(!f)throw new Yd(401,!1);return f}}function ts(a=[],b){return Uh({name:b,Ua:[{na:dg,mb:"platform"},{na:ns,mb:new Set([()=>ps=null])},...a]})}function ss(){let a,b;return null!=(b=null==(a=ps)?void 0:a.get(os))?b:null}
function vs(a=[]){if(ps)return ps;ps=a=ts(a);Yo();us(a);return a}function us(a){let b;null==(b=a.get(ii,null))||b.forEach(c=>c())};function ws(a){return"boolean"===typeof a?a:null!=a&&"false"!==a}function xs(a,b=NaN){return isNaN(parseFloat(a))||isNaN(Number(a))?b:Number(a)};function ys(a){Ci("NgSignals");return Ge(a)};var As=new df("",{da:"root",aa:()=>lf(zs)}),zs=class{};zs.oa=Ld({la:zs,da:"root",aa:()=>new Bs});function Cs(a,b){var c=b.oB;a.i.has(c)||a.i.set(c,new Set);c=a.i.get(c);c.has(b)||(a.D++,c.add(b))}function Ds(a,b){Cs(a,b);if(null===a.C){const c=a.C=a.F.add();queueMicrotask(()=>{a.flush();a.F.remove(c);a.C=null})}}function Es(a,b){for(const c of b)b.delete(c),a.D--,c.run()}
var Bs=class{constructor(){this.D=0;this.i=new Map;this.F=lf(un);this.C=null}flush(){for(;0<this.D;)for(const [a,b]of this.i){const c=a,d=b;null===c?Es(this,d):c.run(()=>Es(this,d))}}};
class Fs{constructor(a,b,c,d,e,f){this.scheduler=a;this.C=b;this.oB=c;this.wa=e;this.i=Te(g=>{try{this.C(g)}catch(k){let m;null==(m=this.wa.get(ui,null,{optional:!0}))||m.handleError(k)}},()=>this.Mc(),f);this.D=null==d?void 0:d.nb(()=>this.destroy())}run(){this.i.run()}Mc(){Ds(this.scheduler,this)}destroy(){this.i.destroy();let a;null==(a=this.D)||a.call(this)}}
function Gs(a,b){Ci("NgSignals");(null==b?0:b.wa)||xg();var c,d=null!=(c=null==b?void 0:b.wa)?c:lf(Vh);c=!0!==(null==b?void 0:b.KC)?d.get(wi):null;let e;a=new Fs(d.get(As),a,"undefined"===typeof Zone?null:Zone.current,c,d,null!=(e=null==b?void 0:b.Wp)?e:!1);if((d=d.get(Pr,null,{optional:!0}))&&d.C[2]&8){let f,g;(null!=(g=(f=d.C)[22])?g:f[22]=[]).push(a.i.notify)}else a.i.notify();return a};function Hs(a){const b=pe(null);try{return a()}finally{pe(b)}};var Is=rs(null,"core",[]);function Js(a){const b=Ks[Zd]||null,c=a.HF||hg();return(new en(b)).create(c,a.uo,a.cf,a.Nf)};var Ls=new df("GMAT_AUTOCOMPLETE_OPTIONS",{da:"root",aa:()=>({qc:!1})});function Ms(a){return Array.isArray(a)?a:[a]};function Ns(a){return null!=a&&"false"!==`${a}`};function Os(a){return null==a?"":"string"===typeof a?a:`${a}px`};function Ps(a){return a instanceof qi?a.P:a};function Qs(a){return isNaN(parseFloat(a))||isNaN(Number(a))?0:Number(a)};const Rs=/\s+/,Ss=[];
var Ts=class{constructor(a,b){this.D=a;this.F=b;this.K=Ss;this.i=new Map}set FC(a){this.K=null!=a?a.trim().split(Rs):Ss}set UC(a){this.O="string"===typeof a?a.trim().split(Rs):a}zj(){for(var a of this.K)this.C(a,!0);a=this.O;if(Array.isArray(a)||a instanceof Set)for(const b of a)this.C(b,!0);else if(null!=a)for(const b of Object.keys(a))this.C(b,!!a[b]);this.N()}C(a,b){const c=this.i.get(a);void 0!==c?(c.enabled!==b&&(c.Ah=!0,c.enabled=b),c.Tc=!0):this.i.set(a,{enabled:b,Ah:!0,Tc:!0})}N(){for(const a of this.i){const b=
a[0],c=a[1];c.Ah?(this.G(b,c.enabled),c.Ah=!1):c.Tc||(c.enabled&&this.G(b,!1),this.i.delete(b));c.Tc=!1}}G(a,b){a=a.trim();0<a.length&&a.split(Rs).forEach(c=>{b?this.F.Ri(this.D.P,c):this.F.wo(this.D.P,c)})}};Ts.J=function(a){return new (a||Ts)(y(qi),y(ti))};Ts.Ea=Of({type:Ts,ga:[["","ngClass",""]],inputs:{FC:[0,"class","klass"],UC:"ngClass"},ja:!0});var Us=class{constructor(a,b){this.ca=a;this.rr=b;this.count=this.index=-1}get first(){return 0===this.index}};function Vs(a,b){const c=a.N;Ur(b,(d,e,f)=>{null==d.He?c.vd(a.F,new Us(d.item,a.i),null===f?void 0:f):null==f?c.remove(null===e?void 0:e):null!==e&&(e=c.get(e),c.move(e,f),e.context.ca=d.item)});for(let d=0,e=c.length;d<e;d++){const f=c.get(d).context;f.index=d;f.count=e;f.rr=a.i}Wr(b,d=>{c.get(d.dd).context.ca=d.item})}
var Ws=class{set rr(a){this.i=a;this.D=!0}set sr(a){this.K=a}get sr(){return this.K}constructor(a,b,c){this.N=a;this.F=b;this.G=c;this.i=null;this.D=!0;this.C=null}set WC(a){a&&(this.F=a)}zj(){if(this.D){this.D=!1;var a=this.i;!this.C&&a&&(this.C=this.G.find(a).create(this.sr))}this.C&&(a=this.C.ln(this.i))&&Vs(this,a)}};Ws.J=function(a){return new (a||Ws)(y(ip),y($q),y(cs))};Ws.Ea=Of({type:Ws,ga:[["","ngFor","","ngForOf",""]],inputs:{rr:"ngForOf",sr:"ngForTrackBy",WC:"ngForTemplate"},ja:!0});function Xs(a){a.Cb.ca?a.D||(a.i.clear(),a.C=null,a.G&&(a.D=a.i.vd(a.G,a.Cb))):a.C||(a.i.clear(),a.D=null,a.F&&(a.C=a.i.vd(a.F,a.Cb)))}var $s=class{constructor(a,b){this.i=a;this.Cb=new Ys;this.C=this.D=this.F=null;this.G=b}set tr(a){this.Cb.ca=this.Cb.tr=a;Xs(this)}set YC(a){Zs("ngIfThen",a);this.G=a;this.D=null;Xs(this)}set XC(a){Zs("ngIfElse",a);this.F=a;this.C=null;Xs(this)}};$s.J=function(a){return new (a||$s)(y(ip),y($q))};
$s.Ea=Of({type:$s,ga:[["","ngIf",""]],inputs:{tr:"ngIf",YC:"ngIfThen",XC:"ngIfElse"},ja:!0});var Ys=class{constructor(){this.tr=this.ca=null}};function Zs(a,b){if(b&&!b.vd)throw Error(`${a} must be a TemplateRef, but received '${ge(b)}'.`);};var at=class{constructor(a,b){this.C=a;this.D=b;this.i=!1}create(){this.i=!0;this.C.vd(this.D)}destroy(){this.i=!1;this.C.clear()}},bt=class{constructor(){this.D=[];this.G=!1;this.F=this.C=0;this.i=!1}set ur(a){this.R=a;0===this.C&&this.K(!0)}N(){return this.C++}T(a){this.D.push(a)}O(a){a=a==this.R;this.i||(this.i=a);this.F++;this.F===this.C&&(this.K(!this.i),this.F=0,this.i=!1);return a}K(a){if(0<this.D.length&&a!==this.G){this.G=a;for(const d of this.D){var b=d,c=a;c&&!b.i?b.create():!c&&b.i&&b.destroy()}}}};
bt.J=function(a){return new (a||bt)};bt.Ea=Of({type:bt,ga:[["","ngSwitch",""]],inputs:{ur:"ngSwitch"},ja:!0});var ct=class{constructor(a,b,c){this.ur=c;c.N();this.i=new at(a,b)}zj(){var a=this.i,b=this.ur.O(this.ZC);b&&!a.i?a.create():!b&&a.i&&a.destroy()}};ct.J=function(a){return new (a||ct)(y(ip),y($q),y(bt,9))};ct.Ea=Of({type:ct,ga:[["","ngSwitchCase",""]],inputs:{ZC:"ngSwitchCase"},ja:!0});var dt=class{constructor(a){this.C=a;this.Nw=this.wr=this.Il=this.i=null}rc(a){if(this.F(a)){const c=this.C;this.i&&c.remove(c.indexOf(this.i));if(this.wr){a=this.D();var b;this.i=c.vd(this.wr,a,{wa:null!=(b=this.Nw)?b:void 0})}else this.i=null}}F(a){return!!a.ngTemplateOutlet||!!a.ngTemplateOutletInjector}D(){return new Proxy({},{set:(a,b,c)=>this.Il?Reflect.set(this.Il,b,c):!1,get:(a,b,c)=>{if(this.Il)return Reflect.get(this.Il,b,c)}})}};dt.J=function(a){return new (a||dt)(y(ip))};
dt.Ea=Of({type:dt,ga:[["","ngTemplateOutlet",""]],inputs:{Il:"ngTemplateOutletContext",wr:"ngTemplateOutlet",Nw:"ngTemplateOutletInjector"},ja:!0,features:[Cg]});new df("");new df("");var et=class{};et.J=function(a){return new (a||et)};et.Wa=Mf({type:et});et.Va=Md({});var ft=a=>a.src;new df("",{da:"root",aa:()=>ft});var gt=new df("");new df("");new df("NG_OPTIMIZED_PRELOADED_IMAGES",{da:"root",aa:()=>new Set});let ht=null;var it=class{};var jt=class{D(){throw Error("");}};jt.J=function(a){return new (a||jt)};jt.oa=Ld({la:jt,aa:()=>lf(kt),da:"platform"});new df("");function lt(a,b){const c=mt(a.G,"window");c.addEventListener("popstate",b,!1);return()=>c.removeEventListener("popstate",b)}function nt(a,b){const c=mt(a.G,"window");c.addEventListener("hashchange",b,!1);return()=>c.removeEventListener("hashchange",b)}
var kt=class extends jt{constructor(){super();this.G=lf(gt);this.i=window.location;this.C=window.history}get port(){return this.i.port}get F(){return this.i.pathname}get K(){return this.i.search}get hash(){return this.i.hash}set F(a){this.i.pathname=a}D(a=0){this.C.go(a)}getState(){return this.C.state}};kt.J=function(a){return new (a||kt)};kt.oa=Ld({la:kt,aa:()=>new kt,da:"platform"});function ot(a,b){if(0==a.length)return b;if(0==b.length)return a;let c=0;a.endsWith("/")&&c++;b.startsWith("/")&&c++;return 2==c?a+b.substring(1):1==c?a+b:a+"/"+b}function pt(a){var b=a.match(/#|\?|$/);b=b&&b.index||a.length;return a.slice(0,b-("/"===a[b-1]?1:0))+a.slice(b)}function qt(a){return a&&"?"!==a[0]?"?"+a:a};var rt=class{F(){throw Error("");}};rt.J=function(a){return new (a||rt)};rt.oa=Ld({la:rt,aa:()=>lf(st),da:"root"});var tt=new df("");function ut(a,b){a.D.push(lt(a.i,b),nt(a.i,b))}
var st=class extends rt{constructor(a,b){super();this.i=a;this.D=[];let c,d,e;null==b&&(b=(vt=vt||document.querySelector("base"))?vt.getAttribute("href"):null,b=null==b?null:(new URL(b,document.baseURI)).pathname);this.C=null!=(e=null!=(d=b)?d:null==(c=lf(gt).location)?void 0:c.origin)?e:""}ua(){for(;this.D.length;)this.D.pop()()}path(a=!1){const b=this.i.F+qt(this.i.K),c=this.i.hash;return c&&a?`${b}${c}`:b}getState(){return this.i.getState()}F(a=0){let b,c;null==(c=(b=this.i).D)||c.call(b,a)}};
st.J=function(a){return new (a||st)(q(jt),q(tt,8))};st.oa=Ld({la:st,aa:st.J,da:"root"});function wt(a,b){b&&"/"!==b[0]&&(b="/"+b);return ot(a.i.C,b)}function xt(a,b,c=null){var d=a.i;d.i.C.pushState(c,"",ot(d.C,b+qt("")));a.C(wt(a,b+qt("")),c)}function yt(a,b,c=null){var d=a.i;d.i.C.replaceState(c,"",ot(d.C,b+qt("")));a.C(wt(a,b+qt("")),c)}function zt(a,b=0){let c,d;null==(d=(c=a.i).F)||d.call(c,b)}
var Bt=class{constructor(a){this.wh=new Dk;this.D=[];this.G=null;this.i=a;this.F=At(pt(this.i.C.replace(/\/index.html$/,"")));ut(this.i,b=>{this.wh.emit({url:this.path(!0),pop:!0,state:b.state,type:b.type})})}ua(){let a;null==(a=this.G)||a.unsubscribe();this.D=[]}path(a=!1){return this.normalize(this.i.path(a))}getState(){return this.i.getState()}normalize(a){var b=this.F;a=a.replace(/\/index.html$/,"");b&&a.startsWith(b)?(b=a.substring(b.length),b=""===b||["/",";","?","#"].includes(b[0])?b:a):b=
a;return pt(b)}C(a="",b){this.D.forEach(c=>c(a,b))}subscribe(a,b,c){return this.wh.subscribe({next:a,error:b,complete:c})}};Bt.J=function(a){return new (a||Bt)(q(rt))};Bt.oa=Ld({la:Bt,aa:()=>new Bt(q(rt)),da:"root"});function At(a){return RegExp("^(https?:)?//").test(a)?([,a]=a.split(/\/\/[^\/]+/),a):a};var Ct=class{};var Dt=class{constructor(a){this.C=[];this.ha=a}ua(){this.detach()}add(a){this.remove(a);this.C.push(a)}remove(a){a=this.C.indexOf(a);-1<a&&this.C.splice(a,1);0===this.C.length&&this.detach()}};Dt.J=function(a){return new (a||Dt)(q(gt))};Dt.oa=Ld({la:Dt,aa:Dt.J,da:"root"});var Et=class extends Dt{constructor(a,b){super(a);this.pa=b;this.D=c=>{const d=this.C;for(let e=d.length-1;-1<e;e--)if(0<d[e].T.kc.length){const f=d[e].T;this.pa?this.pa.run(()=>f.next(c)):f.next(c);break}}}add(a){super.add(a);this.i||(this.pa?Kk(this.pa,()=>this.ha.body.addEventListener("keydown",this.D)):this.ha.body.addEventListener("keydown",this.D),this.i=!0)}detach(){this.i&&(this.ha.body.removeEventListener("keydown",this.D),this.i=!1)}};Et.J=function(a){return new (a||Et)(q(gt),q(Ok,8))};
Et.oa=Ld({la:Et,aa:Et.J,da:"root"});let Ft;function Gt(){if(null==Ft&&"undefined"!==typeof window)try{window.addEventListener("test",null,Object.defineProperty({},"passive",{get:()=>Ft=!0}))}finally{Ft=Ft||!1}return Ft}function Ht(a){return Gt()?a:!!a.capture};let It,Jt;function Kt(){if(null==Jt){if("object"!==typeof document||!document||"function"!==typeof Element||!Element)return Jt=!1;if("scrollBehavior"in document.documentElement.style)Jt=!0;else{const a=Element.prototype.scrollTo;Jt=a?!/\{\s*\[native code\]\s*\}/.test(a.toString()):!1}}return Jt}
function Lt(){if("object"!==typeof document||!document)return 0;if(null==It){const b=document.createElement("div");var a=b.style;b.dir="rtl";a.width="1px";a.overflow="auto";a.visibility="hidden";a.pointerEvents="none";a.position="absolute";a=document.createElement("div");const c=a.style;c.width="2px";c.height="1px";b.appendChild(a);document.body.appendChild(b);It=0;0===b.scrollLeft&&(b.scrollLeft=1,It=0===b.scrollLeft?1:2);b.remove()}return It};let Mt;function Nt(a){if(null==Mt){const b="undefined"!==typeof document?document.head:null;Mt=!(!b||!b.createShadowRoot&&!b.attachShadow)}return Mt&&(a=a.getRootNode?a.getRootNode():null,"undefined"!==typeof ShadowRoot&&ShadowRoot&&a instanceof ShadowRoot)?a:null}function Ot(){let a="undefined"!==typeof document&&document?document.activeElement:null;for(;a&&a.shadowRoot;){const b=a.shadowRoot.activeElement;if(b===a)break;else a=b}return a}
function Pt(a){return a.composedPath?a.composedPath()[0]:a.target};function Qt(){return"undefined"!==typeof __karma__&&!!__karma__||"undefined"!==typeof jasmine&&!!jasmine||"undefined"!==typeof jest&&!!jest||"undefined"!==typeof Mocha&&!!Mocha};let Rt;try{Rt="undefined"!==typeof Intl&&Intl.v8BreakIterator}catch(a){Rt=!1}
var St=class{constructor(a){this.G=(this.isBrowser=(this.N=a)?"browser"===this.N:"object"===typeof document&&!!document)&&/(edge)/i.test(navigator.userAgent);this.C=this.isBrowser&&/(msie|trident)/i.test(navigator.userAgent);this.F=this.isBrowser&&!(!window.chrome&&!Rt)&&"undefined"!==typeof CSS&&!this.G&&!this.C;this.D=this.isBrowser&&/AppleWebKit/i.test(navigator.userAgent)&&!this.F&&!this.G&&!this.C;this.i=this.isBrowser&&/iPad|iPhone|iPod/.test(navigator.userAgent)&&!("MSStream"in window);this.K=
this.isBrowser&&/(firefox|minefield)/i.test(navigator.userAgent);this.O=this.isBrowser&&/android/i.test(navigator.userAgent)&&!this.C;this.R=this.isBrowser&&/safari/i.test(navigator.userAgent)&&this.D}};St.J=function(a){return new (a||St)(q(ji))};St.oa=Ld({la:St,aa:St.J,da:"root"});var Tt=class extends Dt{constructor(a,b,c){super(a);this.Ka=b;this.pa=c;this.F=!1;this.N=d=>{this.G=Pt(d)};this.D=d=>{const e=Pt(d),f="click"===d.type&&this.G?this.G:e;this.G=null;const g=this.C.slice();for(let k=g.length-1;-1<k;k--){const m=g[k];if(1>m.ba.kc.length||!m.fc())continue;if(m.K.contains(e)||m.K.contains(f))break;const p=m.ba;this.pa?this.pa.run(()=>p.next(d)):p.next(d)}}}add(a){super.add(a);if(!this.i){const b=this.ha.body;this.pa?Kk(this.pa,()=>this.K(b)):this.K(b);this.Ka.i&&!this.F&&
(this.O=b.style.cursor,b.style.cursor="pointer",this.F=!0);this.i=!0}}detach(){if(this.i){const a=this.ha.body;a.removeEventListener("pointerdown",this.N,!0);a.removeEventListener("click",this.D,!0);a.removeEventListener("auxclick",this.D,!0);a.removeEventListener("contextmenu",this.D,!0);this.Ka.i&&this.F&&(a.style.cursor=this.O,this.F=!1);this.i=!1}}K(a){a.addEventListener("pointerdown",this.N,!0);a.addEventListener("click",this.D,!0);a.addEventListener("auxclick",this.D,!0);a.addEventListener("contextmenu",
this.D,!0)}};Tt.J=function(a){return new (a||Tt)(q(gt),q(St),q(Ok,8))};Tt.oa=Ld({la:Tt,aa:Tt.J,da:"root"});function Ut(a){a.Di||a.i();return a.Di}
var Vt=class{constructor(a,b){this.Ka=b;this.ha=a}ua(){let a;null==(a=this.Di)||a.remove()}i(){if(this.Ka.isBrowser||Qt()){var a=this.ha.querySelectorAll('.cdk-overlay-container[platform="server"], .cdk-overlay-container[platform="test"]');for(let b=0;b<a.length;b++)a[b].remove()}a=this.ha.createElement("div");a.classList.add("cdk-overlay-container");Qt()?a.setAttribute("platform","test"):this.Ka.isBrowser||a.setAttribute("platform","server");this.ha.body.appendChild(a);this.Di=a}};
Vt.J=function(a){return new (a||Vt)(q(gt),q(St))};Vt.oa=Ld({la:Vt,aa:Vt.J,da:"root"});const Wt=Kt();
var Zt=class{constructor(a,b){this.F=a;this.C={top:"",left:""};this.i=!1;this.ha=b}attach(){}enable(){if(this.G()){const a=this.ha.documentElement;this.D=Xt(this.F);this.C.left=a.style.left||"";this.C.top=a.style.top||"";a.style.left=Os(-this.D.left);a.style.top=Os(-this.D.top);a.classList.add("cdk-global-scrollblock");this.i=!0}}disable(){if(this.i){const a=this.ha.documentElement,b=a.style,c=this.ha.body.style,d=b.i||"",e=c.i||"";this.i=!1;b.left=this.C.left;b.top=this.C.top;a.classList.remove("cdk-global-scrollblock");Wt&&
(b.i=c.i="auto");window.scroll(this.D.left,this.D.top);Wt&&(b.i=d,c.i=e)}}G(){if(this.ha.documentElement.classList.contains("cdk-global-scrollblock")||this.i)return!1;const a=this.ha.body,b=Yt(this.F);return a.scrollHeight>b.height||a.scrollWidth>b.width}};var au=class{constructor(a,b,c,d){this.F=a;this.pa=b;this.D=c;this.xa=d;this.i=null;this.C=()=>{this.disable();this.ka.fc()&&this.pa.run(()=>this.ka.detach())}}attach(a){this.ka=a}enable(){if(!this.i){var a=C($t(this.F,0),rk(b=>!b||!this.ka.K.contains(b.dc.P)));this.xa&&this.xa.threshold&&1<this.xa.threshold?(this.G=Xt(this.D).top,this.i=a.subscribe(()=>{const b=Xt(this.D).top;Math.abs(b-this.G)>this.xa.threshold?this.C():this.ka.Uc()})):this.i=a.subscribe(this.C)}}disable(){this.i&&(this.i.unsubscribe(),
this.i=null)}detach(){this.disable();this.ka=null}};var bu=class{enable(){}disable(){}attach(){}};function cu(a,b){return b.some(c=>{const d=a.top>c.bottom,e=a.right<c.left,f=a.left>c.right;return a.bottom<c.top||d||e||f})}function du(a,b){return b.some(c=>{const d=a.bottom>c.bottom,e=a.left<c.left,f=a.right>c.right;return a.top<c.top||d||e||f})};var eu=class{constructor(a,b,c,d){this.C=a;this.D=b;this.pa=c;this.xa=d;this.i=null}attach(a){this.ka=a}enable(){this.i||(this.i=$t(this.C,this.xa?this.xa.Cx:0).subscribe(()=>{this.ka.Uc();if(this.xa&&this.xa.autoClose){const a=this.ka.K.getBoundingClientRect(),{width:b,height:c}=Yt(this.D);cu(a,[{width:b,height:c,bottom:c,right:b,top:0,left:0}])&&(this.disable(),this.pa.run(()=>this.ka.detach()))}}))}disable(){this.i&&(this.i.unsubscribe(),this.i=null)}detach(){this.disable();this.ka=null}};new df("VIRTUAL_SCROLL_STRATEGY");function $t(a,b=20){return a.Ka.isBrowser?new Vi(c=>{a.C||a.K();const d=0<b?C(a.D,Jn(b)).subscribe(c):a.D.subscribe(c);a.F++;return()=>{d.unsubscribe();a.F--;a.F||a.G()}}):hj()}function fu(a,b){const c=a.i.get(b);c&&(c.unsubscribe(),a.i.delete(b))}function gu(a,b){const c=[];a.i.forEach((d,e)=>{a.N(e,b)&&c.push(e)});return c}
var hu=class{constructor(a,b,c){this.pa=a;this.Ka=b;this.D=new aj;this.C=null;this.F=0;this.i=new Map;this.ha=c}register(a){this.i.has(a)||this.i.set(a,a.F.subscribe(()=>this.D.next(a)))}ua(){this.G();this.i.forEach((a,b)=>fu(this,b));this.D.complete()}N(a,b){b=Ps(b);a=a.dc.P;do if(b==a)return!0;while(b=b.parentElement);return!1}K(){this.C=Kk(this.pa,()=>jk((this.ha.defaultView||window).document,"scroll").subscribe(()=>this.D.next()))}G(){this.C&&(this.C.unsubscribe(),this.C=null)}};
hu.J=function(a){return new (a||hu)(q(Ok),q(St),q(gt,8))};hu.oa=Ld({la:hu,aa:hu.J,da:"root"});var ju=new df("cdk-dir-doc",{da:"root",aa:iu});function iu(){return lf(gt)};const ku=/^(ar|ckb|dv|he|iw|fa|nqo|ps|sd|ug|ur|yi|.*[-_](Adlm|Arab|Hebr|Nkoo|Rohg|Thaa))(?!.*[-_](Latn|Cyrl)($|-|_))($|-|_)/i;var lu=class{constructor(a){this.value="ltr";this.vb=new Dk;if(a){var b=a.documentElement?a.documentElement.dir:null;b=(a.body?a.body.dir:null)||b||"ltr";b=(null==b?void 0:b.toLowerCase())||"";let c;this.value="auto"===b&&"undefined"!==typeof navigator&&(null==(c=navigator)?0:c.language)?ku.test(navigator.language)?"rtl":"ltr":"rtl"===b?"rtl":"ltr"}}ua(){this.vb.complete()}};
lu.J=function(a){return new (a||lu)(q(ju,8))};lu.oa=Ld({la:lu,aa:lu.J,da:"root"});var mu=class{};mu.J=function(a){return new (a||mu)};mu.Wa=Mf({type:mu});mu.Va=Md({});var nu=class{constructor(a,b,c,d){this.dc=a;this.i=b;this.C=c;this.dir=d;this.Fa=new aj;this.F=new Vi(e=>Kk(this.C,()=>C(jk(this.dc.P,"scroll"),Jo(this.Fa)).subscribe(e)))}Eb(){this.i.register(this)}ua(){fu(this.i,this);this.Fa.next();this.Fa.complete()}scrollTo(a){const b=this.dc.P,c=this.dir&&"rtl"==this.dir.value;null==a.left&&(a.left=c?a.end:a.start);null==a.right&&(a.right=c?a.start:a.end);null!=a.bottom&&(a.top=b.scrollHeight-b.clientHeight-a.bottom);c&&0!=Lt()?(null!=a.left&&(a.right=b.scrollWidth-
b.clientWidth-a.left),2==Lt()?a.left=a.right:1==Lt()&&(a.left=a.right?-a.right:a.right)):null!=a.right&&(a.left=b.scrollWidth-b.clientWidth-a.right);this.D(a)}D(a){const b=this.dc.P;Kt()?b.scrollTo(a):(null!=a.top&&(b.scrollTop=a.top),null!=a.left&&(b.scrollLeft=a.left))}};nu.J=function(a){return new (a||nu)(y(qi),y(hu),y(Ok),y(lu,8))};nu.Ea=Of({type:nu,ga:[["","cdk-scrollable",""],["","cdkScrollable",""]],ja:!0});var ou=class{};function pu(a){return a&&"function"===typeof a.connect&&!(a instanceof sj)};new df("_ViewRepeater");function qu(a,...b){b.forEach(c=>a.R(c));b=a.K();a.Gi();return b}function ru(a,b){return a.i.has(a.G(b))}
var su=class{get selected(){this.F||(this.F=Array.from(this.i.values()));return this.F}constructor(a=!1){this.N=a;this.ba=!0;this.Pk=void 0;this.i=new Set;this.C=[];this.D=[];this.Ah=new aj}select(...a){a.forEach(b=>this.T(b));a=this.K();this.Gi();return a}toggle(a){return ru(this,a)?qu(this,a):this.select(a)}clear(a=!0){this.O();const b=this.K();a&&this.Gi();return b}sort(a){this.N&&this.selected&&this.F.sort(a)}Gi(){this.F=null;if(this.D.length||this.C.length)this.Ah.next({source:this,added:this.D,
removed:this.C}),this.C=[],this.D=[]}T(a){a=this.G(a);ru(this,a)||(this.N||this.O(),ru(this,a)||this.i.add(a),this.D.push(a))}R(a){a=this.G(a);ru(this,a)&&(this.i.delete(a),this.C.push(a))}O(){0===this.i.size||this.i.forEach(a=>this.R(a))}ea(){}K(){return!(!this.C.length&&!this.D.length)}G(a,b){if(this.Pk){let c;b=null!=(c=b)?c:this.i;for(let d of b)if(this.Pk(a,d))return d}return a}};function Xt(a){if(!a.Ka.isBrowser)return{top:0,left:0};const b=a.ha;a=a.ha.defaultView||window;const c=b.documentElement,d=c.getBoundingClientRect();return{top:-d.top||b.body.scrollTop||a.scrollY||c.scrollTop||0,left:-d.left||b.body.scrollLeft||a.scrollX||c.scrollLeft||0}}function Yt(a){a.i||a.F();const b={width:a.i.width,height:a.i.height};a.Ka.isBrowser||(a.i=null);return b}
var tu=class{constructor(a,b,c){this.Ka=a;this.C=new aj;this.D=d=>{this.C.next(d)};this.ha=c;Kk(b,()=>{if(a.isBrowser){const d=this.ha.defaultView||window;d.addEventListener("resize",this.D);d.addEventListener("orientationchange",this.D)}this.vb().subscribe(()=>this.i=null)})}ua(){if(this.Ka.isBrowser){const a=this.ha.defaultView||window;a.removeEventListener("resize",this.D);a.removeEventListener("orientationchange",this.D)}this.C.complete()}vb(a=20){return 0<a?C(this.C,Jn(a)):this.C}F(){const a=
this.ha.defaultView||window;this.i=this.Ka.isBrowser?{width:a.innerWidth,height:a.innerHeight}:{width:0,height:0}}};tu.J=function(a){return new (a||tu)(q(St),q(Ok),q(gt,8))};tu.oa=Ld({la:tu,aa:tu.J,da:"root"});new df("VIRTUAL_SCROLLABLE");var uu=class{};uu.J=function(a){return new (a||uu)};uu.Wa=Mf({type:uu});uu.Va=Md({});var vu=class{};vu.J=function(a){return new (a||vu)};vu.Wa=Mf({type:vu});vu.Va=Md({imports:[mu,uu,mu,uu]});var wu=class{constructor(a,b,c,d){this.D=a;this.C=b;this.pa=c;this.F=()=>new bu;this.close=e=>new au(this.D,this.pa,this.C,e);this.block=()=>new Zt(this.C,this.ha);this.i=e=>new eu(this.D,this.C,this.pa,e);this.ha=d}};wu.J=function(a){return new (a||wu)(q(hu),q(tu),q(Ok),q(gt))};wu.oa=Ld({la:wu,aa:wu.J,da:"root"});var xu=class{constructor(a){this.tc=new bu;this.gb="";this.Sb=!1;this.bc="cdk-overlay-dark-backdrop";this.Hh=!1;if(a){const b=Object.keys(a);for(const c of b)void 0!==a[c]&&(this[c]=a[c])}}};function yu(a,...b){return b.length?b.some(c=>a[c]):a.altKey||a.shiftKey||a.ctrlKey||a.metaKey};function zu(a){const b=a.F;b&&(a.ea?a.R(b):(b.classList.remove("cdk-overlay-backdrop-showing"),Kk(a.pa,()=>{b.addEventListener("transitionend",a.Ra)}),b.style.pointerEvents="none",a.ta=Kk(a.pa,()=>setTimeout(()=>{a.R(b)},500))))}function Au(a){return(a=a.xa.direction)?"string"===typeof a?a:a.value:"ltr"}
var Bu=class{constructor(a,b,c,d,e,f,g,k,m,p=!1,t){this.Ue=a;this.i=b;this.C=c;this.xa=d;this.pa=e;this.ia=f;this.ha=g;this.fb=k;this.ma=m;this.ea=p;this.Ya=t;this.F=null;this.ra=new aj;this.O=new aj;this.G=new aj;this.va=Li.EMPTY;this.Oa=v=>this.ra.next(v);this.Ra=v=>{this.R(v.target)};this.T=new aj;this.ba=new aj;this.Ia=new aj;d.tc&&(this.Jc=d.tc,this.Jc.attach(this));this.D=d.sc;this.kb=Hs(()=>Vk(()=>{this.Ia.next()},{wa:this.Ya}))}get K(){return this.C}get cf(){return this.i}attach(a){!this.i.parentElement&&
this.Da&&this.Da.appendChild(this.i);a=this.Ue.attach(a);this.D&&this.D.attach(this);this.Nb();this.ab();this.Mb();this.Jc&&this.Jc.enable();Zk(()=>{this.fc()&&this.Uc()},{wa:this.Ya});this.Ta(!0);this.xa.Sb&&this.rb();this.xa.gb&&this.N(this.C,this.xa.gb,!0);this.O.next();this.ia.add(this);this.xa.Hh&&(this.va=this.fb.subscribe(()=>this.dispose()));this.ma.add(this);"function"===typeof(null==a?void 0:a.nb)&&a.nb(()=>{this.fc()&&Kk(this.pa,()=>Promise.resolve().then(()=>this.detach()))});return a}detach(){if(this.fc()){zu(this);
this.Ta(!1);this.D&&this.D.detach&&this.D.detach();this.Jc&&this.Jc.disable();var a=this.Ue.detach();this.G.next();this.ia.remove(this);this.Jb();this.va.unsubscribe();this.ma.remove(this);return a}}dispose(){const a=this.fc();this.D&&this.D.dispose();this.Kb();this.R(this.F);this.va.unsubscribe();this.ia.remove(this);this.Ue.dispose();this.O.complete();this.ra.complete();this.T.complete();this.ba.complete();this.ma.remove(this);let b;null==(b=this.i)||b.remove();this.Da=this.C=this.i=null;a&&this.G.next();
this.G.complete();this.kb.destroy();this.Ia.complete()}fc(){return this.Ue.fc()}bd(){return this.ra}df(){return this.T}Kl(){return this.ba}Uc(){this.D&&this.D.apply()}me(a){this.xa=Object.assign({},this.xa,a);this.ab()}og(a){this.C&&this.N(this.C,a,!0)}Jj(a){this.C&&this.N(this.C,a,!1)}Mb(){this.i.setAttribute("dir",Au(this))}ab(){if(this.C){var a=this.C.style;a.width=Os(this.xa.width);a.height=Os(this.xa.height);a.minWidth=Os(this.xa.minWidth);a.minHeight=Os(this.xa.minHeight);a.maxWidth=Os(this.xa.maxWidth);
a.maxHeight=Os(this.xa.maxHeight)}}Ta(a){this.C.style.pointerEvents=a?"":"none"}rb(){this.F=this.ha.createElement("div");this.F.classList.add("cdk-overlay-backdrop");this.ea&&this.F.classList.add("cdk-overlay-backdrop-noop-animation");this.xa.bc&&this.N(this.F,this.xa.bc,!0);this.i.parentElement.insertBefore(this.F,this.i);this.F.addEventListener("click",this.Oa);this.ea||"undefined"===typeof requestAnimationFrame?this.F.classList.add("cdk-overlay-backdrop-showing"):Kk(this.pa,()=>{requestAnimationFrame(()=>
{this.F&&this.F.classList.add("cdk-overlay-backdrop-showing")})})}Nb(){this.i.nextSibling&&this.i.parentNode.appendChild(this.i)}N(a,b,c){b=Ms(b||[]).filter(d=>!!d);b.length&&(c?a.classList.add(...b):a.classList.remove(...b))}Jb(){Kk(this.pa,()=>{const a=C(this.Ia,Jo(pk(this.O,this.G))).subscribe(()=>{this.C&&this.i&&0!==this.C.children.length||(this.C&&this.xa.gb&&this.N(this.C,this.xa.gb,!1),this.i&&this.i.parentElement&&(this.Da=this.i.parentElement,this.i.remove()),a.unsubscribe())})})}Kb(){const a=
this.Jc;a&&(a.disable(),a.detach&&a.detach())}R(a){a&&(a.removeEventListener("click",this.Oa),a.removeEventListener("transitionend",this.Ra),a.remove(),this.F===a&&(this.F=null));this.ta&&(clearTimeout(this.ta),this.ta=void 0)}};var Cu=class{constructor(a,b){this.i=a;this.C=b}};const Du=/([A-Za-z%]+)$/;function Eu(a,b){a.rb=b;return a}function Fu(a){if(!a.Se&&a.Ka.isBrowser){var b=a.F;b?(a.Ra=a.Ia(),a.D=a.C.getBoundingClientRect(),a.ta=a.uc(),a.Ei=Ut(a.Jb).getBoundingClientRect(),a.T(b,a.Cc(a.Ra,a.Ei,b))):a.apply()}}function Gu(a,b){a.Vc=b;return a}function Hu(a,b){a.ab=b;-1===b.indexOf(a.F)&&(a.F=null);return a}function Iu(a,b){a.i=b;return a}function wv(a,b=!0){a.ia=b;return a}function xv(a,b=!0){a.ea=b;return a}function yv(a,b=!0){a.Mb=b;return a}
function zv(a,b=!0){a.Ta=b;return a}function Av(a,b){a.kb=b;return a}function Bv(a,b){a.jd=b;return a}function Cv(a){return"rtl"===Au(a.ka)}
var Gv=class{get he(){return this.ab}constructor(a,b,c,d,e){this.Da=b;this.ha=c;this.Ka=d;this.Jb=e;this.O={width:0,height:0};this.N=!1;this.Mb=!0;this.ea=!1;this.ia=!0;this.Ta=!1;this.i=0;this.Vc=[];this.ab=[];this.ma=new aj;this.va=Li.EMPTY;this.kb=0;this.R=[];this.fb=this.ma;Eu(this,a)}attach(a){a.cf.classList.add("cdk-overlay-connected-position-bounding-box");this.ka=a;this.G=a.cf;this.C=a.K;this.Se=!1;this.K=!0;this.F=null;this.va.unsubscribe();this.va=this.Da.vb().subscribe(()=>{this.K=!0;this.apply()})}apply(){if(!this.Se&&
this.Ka.isBrowser)if(!this.K&&this.Ta&&this.F)Fu(this);else{this.Nb();this.Ic();this.Rd();this.ta=this.uc();this.Ra=this.Ia();this.D=this.C.getBoundingClientRect();this.Ei=Ut(this.Jb).getBoundingClientRect();var a=this.Ra,b=this.D,c=this.ta,d=this.Ei,e=[];for(let g of this.ab){let k=this.Cc(a,d,g),m=this.Oa(k,b,g),p=this.Pd(m,b,c,g);if(p.tC){this.N=!1;this.T(g,k);return}if(this.rd(p,m,c))e.push({position:g,origin:k,oD:b,Mu:this.Kb(k,g)});else if(!f||f.nD.Ey<p.Ey)var f={nD:p,eG:m,jD:k,position:g,oD:b}}if(e.length){a=
null;b=-1;for(const g of e)e=g.Mu.width*g.Mu.height*(g.position.weight||1),e>b&&(b=e,a=g);this.N=!1;this.T(a.position,a.origin)}else this.Mb&&(this.N=!0),this.T(f.position,f.jD)}}detach(){this.Nb();this.ra=this.F=null;this.va.unsubscribe()}dispose(){this.Se||(this.G&&Dv(this.G.style,{top:"",left:"",right:"",bottom:"",height:"",width:"",alignItems:"",justifyContent:""}),this.C&&this.Ic(),this.ka&&this.ka.cf.classList.remove("cdk-overlay-connected-position-bounding-box"),this.detach(),this.ma.complete(),
this.ka=this.G=null,this.Se=!0)}Cc(a,b,c){if("center"==c.bb)var d=a.left+a.width/2;else{d=Cv(this)?a.right:a.left;const e=Cv(this)?a.left:a.right;d="start"==c.bb?d:e}0>b.left&&(d-=b.left);a="center"==c.cb?a.top+a.height/2:"top"==c.cb?a.top:a.bottom;0>b.top&&(a-=b.top);return{x:d,y:a}}Oa(a,b,c){return{x:a.x+("center"==c.La?-b.width/2:"start"===c.La?Cv(this)?-b.width:0:Cv(this)?0:-b.width),y:a.y+("center"==c.Sa?-b.height/2:"top"==c.Sa?0:-b.height)}}Pd(a,b,c,d){b=Ev(b);let {x:e,y:f}=a;a=this.ba(d,"x");
d=this.ba(d,"y");a&&(e+=a);d&&(f+=d);d=-f;a=f+b.height-c.height;c=this.Wc(b.width,-e,e+b.width-c.width);d=this.Wc(b.height,d,a);a=c*d;return{Ey:a,tC:b.width*b.height===a,PB:d===b.height,OB:c==b.width}}rd(a,b,c){if(this.ia){const d=c.bottom-b.y;c=c.right-b.x;b=Fv(this.ka.xa.minHeight);const e=Fv(this.ka.xa.minWidth);c=a.OB||null!=e&&e<=c;return(a.PB||null!=b&&b<=d)&&c}return!1}Hc(a,b,c){if(this.ra&&this.Ta)return{x:a.x+this.ra.x,y:a.y+this.ra.y};b=Ev(b);const d=this.ta;var e=Math.max(a.x+b.width-d.width,
0);const f=Math.max(a.y+b.height-d.height,0),g=Math.max(d.top-c.top-a.y,0),k=Math.max(d.left-c.left-a.x,0);e=b.width<=d.width?k||-e:a.x<this.i?d.left-c.left-a.x:0;c=b.height<=d.height?g||-f:a.y<this.i?d.top-c.top-a.y:0;this.ra={x:e,y:c};return{x:a.x+e,y:a.y+c}}T(a,b){this.Ne(a);this.Vd(b,a);this.Ud(b,a);a.gb&&this.qd(a.gb);if(this.ma.kc.length){b=this.Qd();var c;if(c=a===this.F&&this.Gc)c=this.Gc,c=c===b?!0:c.sw===b.sw&&c.tw===b.tw&&c.gr===b.gr&&c.uw===b.uw;c||this.ma.next(new Cu(a,b));this.Gc=b}this.F=
a;this.K=!1}Ne(a){if(this.jd){var b=this.G.querySelectorAll(this.jd),c=a.Sa;a="center"===a.La?"center":Cv(this)?"start"===a.La?"right":"left":"start"===a.La?"left":"right";for(let d=0;d<b.length;d++)b[d].style.transformOrigin=`${a} ${c}`}}Kb(a,b){var c=this.ta;const d=Cv(this);let e;let f;if("top"===b.Sa){var g=a.y;e=c.height-g+this.i}else if("bottom"===b.Sa)f=c.height-a.y+2*this.i,e=c.height-f+this.i;else{g=Math.min(c.bottom-a.y+c.top,a.y);var k=this.O.height;e=2*g;g=a.y-g;e>k&&!this.K&&!this.ea&&
(g=a.y-k/2)}k="start"===b.La&&!d||"end"===b.La&&d;let m;if("end"===b.La&&!d||"start"===b.La&&d)m=c.width-a.x+2*this.i,b=a.x-this.i;else if(k){var p=a.x;b=c.right-a.x}else p=Math.min(c.right-a.x+c.left,a.x),c=this.O.width,b=2*p,p=a.x-p,b>c&&!this.K&&!this.ea&&(p=a.x-c/2);return{top:g,left:p,bottom:f,right:m,width:b,height:e}}Ud(a,b){a=this.Kb(a,b);this.K||this.ea||(a.height=Math.min(a.height,this.O.height),a.width=Math.min(a.width,this.O.width));const c={};if(this.Fc())c.top=c.left="0",c.bottom=c.right=
c.maxHeight=c.maxWidth="",c.width=c.height="100%";else{const d=this.ka.xa.maxHeight,e=this.ka.xa.maxWidth;c.height=Os(a.height);c.top=Os(a.top);c.bottom=Os(a.bottom);c.width=Os(a.width);c.left=Os(a.left);c.right=Os(a.right);c.alignItems="center"===b.La?"center":"end"===b.La?"flex-end":"flex-start";c.justifyContent="center"===b.Sa?"center":"bottom"===b.Sa?"flex-end":"flex-start";d&&(c.maxHeight=Os(d));e&&(c.maxWidth=Os(e))}this.O=a;Dv(this.G.style,c)}Rd(){Dv(this.G.style,{top:"0",left:"0",right:"0",
bottom:"0",height:"",width:"",alignItems:"",justifyContent:""})}Ic(){Dv(this.C.style,{top:"",left:"",bottom:"",right:"",position:"",transform:""})}Vd(a,b){const c={},d=this.Fc(),e=this.ia,f=this.ka.xa;if(d){var g=Xt(this.Da);Dv(c,this.Od(b,a,g));Dv(c,this.sd(b,a,g))}else c.position="static";a="";g=this.ba(b,"x");b=this.ba(b,"y");g&&(a+=`translateX(${g}px) `);b&&(a+=`translateY(${b}px)`);c.transform=a.trim();f.maxHeight&&(d?c.maxHeight=Os(f.maxHeight):e&&(c.maxHeight=""));f.maxWidth&&(d?c.maxWidth=
Os(f.maxWidth):e&&(c.maxWidth=""));Dv(this.C.style,c)}Od(a,b,c){let d={top:"",bottom:""};b=this.Oa(b,this.D,a);this.N&&(b=this.Hc(b,this.D,c));"bottom"===a.Sa?d.bottom=`${this.ha.documentElement.clientHeight-(b.y+this.D.height)}px`:d.top=Os(b.y);return d}sd(a,b,c){let d={left:"",right:""};b=this.Oa(b,this.D,a);this.N&&(b=this.Hc(b,this.D,c));"right"===(Cv(this)?"end"===a.La?"left":"right":"end"===a.La?"right":"left")?d.right=`${this.ha.documentElement.clientWidth-(b.x+this.D.width)}px`:d.left=Os(b.x);
return d}Qd(){const a=this.Ia(),b=this.C.getBoundingClientRect(),c=this.Vc.map(d=>d.dc.P.getBoundingClientRect());return{sw:du(a,c),tw:cu(a,c),gr:du(b,c),uw:cu(b,c)}}Wc(a,...b){return b.reduce((c,d)=>c-Math.max(d,0),a)}uc(){const a=this.ha.documentElement.clientWidth,b=this.ha.documentElement.clientHeight,c=Xt(this.Da);return{top:c.top+this.i,left:c.left+this.i,right:c.left+a-this.i,bottom:c.top+b-this.i,width:a-2*this.i,height:b-2*this.i}}Fc(){return!this.ia||this.N}ba(a,b){return"x"===b?null==a.offsetX?
this.kb:a.offsetX:null==a.offsetY?0:a.offsetY}fg(){}qd(a){this.C&&Ms(a).forEach(b=>{""!==b&&-1===this.R.indexOf(b)&&(this.R.push(b),this.C.classList.add(b))})}Nb(){this.C&&(this.R.forEach(a=>{this.C.classList.remove(a)}),this.R=[])}Ia(){const a=this.rb;if(a instanceof qi)return a.P.getBoundingClientRect();if(a instanceof Element)return a.getBoundingClientRect();const b=a.width||0,c=a.height||0;return{top:a.y,bottom:a.y+c,left:a.x,right:a.x+b,height:c,width:b}}};
function Dv(a,b){for(let c in b)b.hasOwnProperty(c)&&(a[c]=b[c])}function Fv(a){if("number"!==typeof a&&null!=a){const [b,c]=a.split(Du);return c&&"px"!==c?null:parseFloat(b)}return a||null}function Ev(a){return{top:Math.floor(a.top),right:Math.floor(a.right),bottom:Math.floor(a.bottom),left:Math.floor(a.left),width:Math.floor(a.width),height:Math.floor(a.height)}};function Hv(a){a.left("");a.Ef="center";return a}function Iv(a){a.top("");a.om="center";return a}
var Jv=class{constructor(){this.Iz="static";this.wp=this.Vp=this.Fk=this.Ef=this.om=this.gp=this.Np="";this.Se=!1}attach(a){const b=a.xa;this.ka=a;this.Vp&&!b.width&&a.me({width:this.Vp});this.wp&&!b.height&&a.me({height:this.wp});a.cf.classList.add("cdk-global-overlay-wrapper");this.Se=!1}top(a=""){this.gp="";this.Np=a;this.om="flex-start";return this}left(a=""){this.Fk=a;this.Ef="left";return this}bottom(a=""){this.Np="";this.gp=a;this.om="flex-end";return this}right(a=""){this.Fk=a;this.Ef="right";
return this}start(a=""){this.Fk=a;this.Ef="start";return this}end(a=""){this.Fk=a;this.Ef="end";return this}width(a=""){this.ka?this.ka.me({width:a}):this.Vp=a;return this}height(a=""){this.ka?this.ka.me({height:a}):this.wp=a;return this}apply(){if(this.ka&&this.ka.fc()){var a=this.ka.K.style,b=this.ka.cf.style,c=this.ka.xa,d=c.width,e=c.height,f=c.maxWidth;c=c.maxHeight;d=("100%"===d||"100vw"===d)&&(!f||"100%"===f||"100vw"===f);e=("100%"===e||"100vh"===e)&&(!c||"100%"===c||"100vh"===c);f=this.Ef;
c=this.Fk;var g="rtl"===this.ka.xa.direction,k="",m="",p="";if(d)p="flex-start";else if("center"===f)p="center",g?m=c:k=c;else if(g)if("left"===f||"end"===f)p="flex-end",k=c;else{if("right"===f||"start"===f)p="flex-start",m=c}else if("left"===f||"start"===f)p="flex-start",k=c;else if("right"===f||"end"===f)p="flex-end",m=c;a.position=this.Iz;a.marginLeft=d?"0":k;a.marginTop=e?"0":this.Np;a.marginBottom=this.gp;a.marginRight=d?"0":m;b.justifyContent=p;b.alignItems=e?"flex-start":this.om}}dispose(){if(!this.Se&&
this.ka){var a=this.ka.K.style,b=this.ka.cf,c=b.style;b.classList.remove("cdk-global-overlay-wrapper");c.justifyContent=c.alignItems=a.marginTop=a.marginBottom=a.marginLeft=a.marginRight=a.position="";this.ka=null;this.Se=!0}}};function Kv(){return new Jv}function Lv(a,b){return new Gv(b,a.C,a.ha,a.Ka,a.i)}var Mv=class{constructor(a,b,c,d){this.C=a;this.ha=b;this.Ka=c;this.i=d}};Mv.J=function(a){return new (a||Mv)(q(tu),q(gt),q(St),q(Vt))};Mv.oa=Ld({la:Mv,aa:Mv.J,da:"root"});var Nv=class{attach(a){this.C=a;return a.attach(this)}detach(){let a=this.C;null!=a&&(this.C=null,a.detach())}},Ov=class extends Nv{constructor(a,b,c,d){super();this.component=a;this.wb=b;this.wa=c;this.i=d;this.uo=void 0}},Pv=class extends Nv{constructor(a,b,c,d){super();this.cg=a;this.wb=b;this.context=c;this.wa=d}get origin(){return this.cg.dc}attach(a,b=this.context){this.context=b;return super.attach(a)}detach(){this.context=void 0;return super.detach()}};function Qv(a,b){a.mp=b}
var Rv=class{constructor(){this.Se=!1}fc(){return!!this.Xd}attach(a){if(a instanceof Ov)return this.Xd=a,this.Zd(a);if(a instanceof Pv)return this.Xd=a,this.Ze(a)}detach(){this.Xd&&(this.Xd=this.Xd.C=null);this.Wt()}dispose(){this.fc()&&this.detach();this.Wt();this.Se=!0}Wt(){this.mp&&(this.mp(),this.mp=null)}};var Sv=class extends Rv{constructor(a,b,c,d,e){super();this.C=a;this.D=b;this.i=c;this.F=d;this.ha=e}Zd(a){const b=dn(a.i||this.D,a.component);let c;a.wb?(c=op(a.wb,b,a.wb.length,a.wa||a.wb.wa,a.uo||void 0),Qv(this,()=>c.destroy())):(c=b.create(a.wa||this.F||Wh),bp(this.i,c.i),Qv(this,()=>{0<this.i.ta&&this.i.fj(c.i);c.destroy()}));this.C.appendChild(this.G(c));this.Xd=a;return c}Ze(a){let b=a.wb,c=b.vd(a.cg,a.context,{wa:a.wa});c.rootNodes.forEach(d=>this.C.appendChild(d));$m(c);Qv(this,()=>{let d=
b.indexOf(c);-1!==d&&b.remove(d)});this.Xd=a;return c}dispose(){super.dispose();this.C.remove()}G(a){return a.i.rootNodes[0]}};var Tv=class extends Rv{constructor(a,b,c){super();this.F=a;this.i=b;this.C=!1;this.Zp=new Dk;this.ha=c}get Jd(){return this.Xd}set Jd(a){if(!this.fc()||a||this.C)this.fc()&&super.detach(),a&&super.attach(a),this.Xd=a||null}Eb(){this.C=!0}ua(){super.dispose();this.D=this.Xd=null}Zd(a){a.C=this;const b=null!=a.wb?a.wb:this.i,c=dn(a.i||this.F,a.component),d=op(b,c,b.length,a.wa||b.wa,a.uo||void 0);b!==this.i&&this.G().appendChild(d.i.rootNodes[0]);Qv(this,()=>d.destroy());this.Xd=a;this.D=d;this.Zp.emit(d);
return d}Ze(a){a.C=this;const b=this.i.vd(a.cg,a.context,{wa:a.wa});Qv(this,()=>this.i.clear());this.Xd=a;this.D=b;this.Zp.emit(b);return b}G(){const a=this.i.element.P;return a.nodeType===a.ELEMENT_NODE?a:a.parentNode}};Tv.J=function(a){return new (a||Tv)(y(Xh),y(ip),y(gt))};Tv.Ea=Of({type:Tv,ga:[["","cdkPortalOutlet",""]],inputs:{Jd:[0,"cdkPortalOutlet","portal"]},outputs:{Zp:"attached"},hb:["cdkPortalOutlet"],ja:!0,features:[Ap]});var Uv=class{};Uv.J=function(a){return new (a||Uv)};Uv.Wa=Mf({type:Uv});
Uv.Va=Md({});let Vv=0;
var Wv=class{constructor(a,b,c,d,e,f,g,k,m,p,t,v){this.i=a;this.O=b;this.F=c;this.ma=d;this.G=e;this.Ya=f;this.pa=g;this.ha=k;this.ia=m;this.K=p;this.N=t;this.R=v}create(a){const b=this.T(),c=this.ba(b),d=this.ea(c);a=new xu(a);a.direction=a.direction||this.ia.value;return new Bu(d,b,c,a,this.pa,this.G,this.ha,this.K,this.N,"NoopAnimations"===this.R,this.Ya.get(ig))}position(){return this.ma}ba(a){const b=this.ha.createElement("div");b.id=`cdk-overlay-${Vv++}`;b.classList.add("cdk-overlay-pane");a.appendChild(b);
return b}T(){const a=this.ha.createElement("div");Ut(this.O).appendChild(a);return a}ea(a){this.D||(this.D=this.Ya.get(dp));return new Sv(a,this.F,this.D,this.Ya,this.ha)}};Wv.J=function(a){return new (a||Wv)(q(wu),q(Vt),q(Xh),q(Mv),q(Et),q(Vh),q(Ok),q(gt),q(lu),q(Bt),q(Tt),q(ki,8))};Wv.oa=Ld({la:Wv,aa:Wv.J,da:"root"});const Xv=[{bb:"start",cb:"bottom",La:"start",Sa:"top"},{bb:"start",cb:"top",La:"start",Sa:"bottom"},{bb:"end",cb:"top",La:"end",Sa:"bottom"},{bb:"end",cb:"bottom",La:"end",Sa:"top"}];var Yv=new df("cdk-connected-overlay-scroll-strategy",{da:"root",aa:()=>{const a=lf(Wv);return()=>a.i.i()}}),Zv=class{constructor(a){this.dc=a}};Zv.J=function(a){return new (a||Zv)(y(qi))};Zv.Ea=Of({type:Zv,ga:[["","cdk-overlay-origin",""],["","overlay-origin",""],["","cdkOverlayOrigin",""]],hb:["cdkOverlayOrigin"],ja:!0});
function $v(a){a.ka?a.ka.xa.Sb=a.Sb:aw(a);a.ka.fc()||a.ka.attach(a.ta);a.Sb?a.D=a.ka.bd().subscribe(b=>{a.bd.emit(b)}):a.D.unsubscribe();a.C.unsubscribe();0<a.Ej.kc.length&&(a.C=C(a.i.fb,Ko(()=>0<a.Ej.kc.length)).subscribe(b=>{a.pa.run(()=>a.Ej.emit(b));0===a.Ej.kc.length&&a.C.unsubscribe()}))}
function aw(a){a.he&&a.he.length||(a.he=Xv);const b=a.ka=a.K.create(a.ma());a.N=b.O.subscribe(()=>a.attach.emit());a.wm=b.G.subscribe(()=>a.detach.emit());b.df().subscribe(c=>{a.Tw.next(c);27!==c.keyCode||a.wd||yu(c)||(c.preventDefault(),a.O())});a.ka.Kl().subscribe(c=>{a.Uw.next(c)})}
var bw=class{get offsetX(){return this.ba}set offsetX(a){this.ba=a;this.i&&this.F(this.i)}get offsetY(){return this.ea}set offsetY(a){this.ea=a;this.i&&this.F(this.i)}get Hh(){return this.R}set Hh(a){this.R=a}constructor(a,b,c,d,e){this.K=a;this.G=e;this.C=this.wm=this.N=this.D=Li.EMPTY;this.R=!1;this.pa=lf(Ok);this.Dy=0;this.push=this.Zv=this.Rv=this.Cw=this.Sb=this.wd=this.open=!1;this.bd=new Dk;this.Ej=new Dk;this.attach=new Dk;this.detach=new Dk;this.Tw=new Dk;this.Uw=new Dk;this.ta=new Pv(b,
c);this.ia=d;this.tc=this.ia()}get Ub(){return this.ka}get dir(){return this.G?this.G.value:"ltr"}ua(){this.N.unsubscribe();this.wm.unsubscribe();this.D.unsubscribe();this.C.unsubscribe();this.ka&&this.ka.dispose()}rc(a){this.i&&(this.F(this.i),this.ka.me({width:this.width,minWidth:this.minWidth,height:this.height,minHeight:this.minHeight}),a.origin&&this.open&&this.i.apply());a.open&&(this.open?$v(this):this.O())}ma(){var a=this.i=this.sc||this.ra();a=new xu({direction:this.G,sc:a,tc:this.tc,Sb:this.Sb,
Hh:this.Hh});if(this.width||0===this.width)a.width=this.width;if(this.height||0===this.height)a.height=this.height;if(this.minWidth||0===this.minWidth)a.minWidth=this.minWidth;if(this.minHeight||0===this.minHeight)a.minHeight=this.minHeight;this.bc&&(a.bc=this.bc);this.gb&&(a.gb=this.gb);return a}F(a){const b=this.he.map(c=>({bb:c.bb,cb:c.cb,La:c.La,Sa:c.Sa,offsetX:c.offsetX||this.offsetX,offsetY:c.offsetY||this.offsetY,gb:c.gb||void 0}));return Bv(zv(Iu(xv(yv(wv(Hu(Eu(a,this.T()),b),this.Rv),this.push),
this.Zv),this.Dy),this.Cw),this.GE)}ra(){const a=Lv(this.K.position(),this.T());this.F(a);return a}T(){return this.origin instanceof Zv?this.origin.dc:this.origin}O(){this.ka&&this.ka.detach();this.D.unsubscribe();this.C.unsubscribe()}};bw.J=function(a){return new (a||bw)(y(Wv),y($q),y(ip),y(Yv),y(lu,8))};
bw.Ea=Of({type:bw,ga:[["","cdk-connected-overlay",""],["","connected-overlay",""],["","cdkConnectedOverlay",""]],inputs:{origin:[0,"cdkConnectedOverlayOrigin","origin"],he:[0,"cdkConnectedOverlayPositions","positions"],sc:[0,"cdkConnectedOverlayPositionStrategy","positionStrategy"],offsetX:[0,"cdkConnectedOverlayOffsetX","offsetX"],offsetY:[0,"cdkConnectedOverlayOffsetY","offsetY"],width:[0,"cdkConnectedOverlayWidth","width"],height:[0,"cdkConnectedOverlayHeight","height"],minWidth:[0,"cdkConnectedOverlayMinWidth",
"minWidth"],minHeight:[0,"cdkConnectedOverlayMinHeight","minHeight"],bc:[0,"cdkConnectedOverlayBackdropClass","backdropClass"],gb:[0,"cdkConnectedOverlayPanelClass","panelClass"],Dy:[0,"cdkConnectedOverlayViewportMargin","viewportMargin"],tc:[0,"cdkConnectedOverlayScrollStrategy","scrollStrategy"],open:[0,"cdkConnectedOverlayOpen","open"],wd:[0,"cdkConnectedOverlayDisableClose","disableClose"],GE:[0,"cdkConnectedOverlayTransformOriginOn","transformOriginSelector"],Sb:[2,"cdkConnectedOverlayHasBackdrop",
"hasBackdrop",ws],Cw:[2,"cdkConnectedOverlayLockPosition","lockPosition",ws],Rv:[2,"cdkConnectedOverlayFlexibleDimensions","flexibleDimensions",ws],Zv:[2,"cdkConnectedOverlayGrowAfterOpen","growAfterOpen",ws],push:[2,"cdkConnectedOverlayPush","push",ws],Hh:[2,"cdkConnectedOverlayDisposeOnNavigation","disposeOnNavigation",ws]},outputs:{bd:"backdropClick",Ej:"positionChange",attach:"attach",detach:"detach",Tw:"overlayKeydown",Uw:"overlayOutsideClick"},hb:["cdkConnectedOverlay"],ja:!0,features:[Hp,Cg]});
var cw={na:Yv,zc:[Wv],Ec:function(a){return()=>a.i.i()}};var dw=class{};dw.J=function(a){return new (a||dw)};dw.Wa=Mf({type:dw});dw.Va=Md({Ua:[Wv,cw],imports:[mu,Uv,vu,vu]});function ew(a,b){a.C.includes(b)||a.C.push(b)}var fw=class extends Wv{constructor(){super(...arguments);this.C=[]}create(a){return super.create(Object.assign({},a,{gb:(null==a?0:a.gb)?Ms(a.gb).concat(this.C):this.C}))}};fw.J=(()=>{let a;return function(b){return(a||(a=Lh(fw)))(b||fw)}})();fw.oa=Ld({la:fw,aa:fw.J});var gw=class{constructor(a,b){a.qc||ew(b,"gmat-mdc-autocomplete")}};gw.J=function(a){return new (a||gw)(y(Ls),y(Wv))};gw.Ea=Of({type:gw,ga:[["input","matAutocomplete",""],["textarea","matAutocomplete",""]],features:[Hr([{na:Wv,Dc:fw}])]});var hw=class{constructor(a,b){this.D=a;this.qa=b;this.ho=()=>{};this.Fr=()=>{}}setProperty(a,b){this.D.setProperty(this.qa.P,a,b)}Ij(a){this.Fr=a}Lg(a){this.ho=a}gi(a){this.setProperty("disabled",a)}};hw.J=function(a){return new (a||hw)(y(ti),y(qi))};hw.Ea=Of({type:hw});var iw=class extends hw{};iw.J=(()=>{let a;return function(b){return(a||(a=Lh(iw)))(b||iw)}})();iw.Ea=Of({type:iw,features:[Ap]});var jw=new df("");const lw={na:jw,zb:af(()=>kw),Db:!0};var kw=class extends iw{pi(a){this.setProperty("checked",a)}};kw.J=(()=>{let a;return function(b){return(a||(a=Lh(kw)))(b||kw)}})();kw.Ea=Of({type:kw,ga:[["input","type","checkbox","formControlName",""],["input","type","checkbox","formControl",""],["input","type","checkbox","ngModel",""]],Ha:function(a,b){a&1&&V("change",function(c){return b.ho(c.target.checked)})("blur",function(){return b.Fr()})},features:[Hr([lw]),Ap]});var nw={na:jw,zb:af(()=>mw),Db:!0},ow=new df(""),mw=class extends hw{constructor(a,b,c){super(a,b);this.i=c;this.C=!1;null==this.i&&(this.i=!/android (\d+)/.test((ht?window.navigator.userAgent:"").toLowerCase()))}pi(a){this.setProperty("value",null==a?"":a)}sp(a){(!this.i||this.i&&!this.C)&&this.ho(a)}Hz(){this.C=!0}Gz(a){this.C=!1;this.i&&this.ho(a)}};mw.J=function(a){return new (a||mw)(y(ti),y(qi),y(ow,8))};
mw.Ea=Of({type:mw,ga:[["input","formControlName","",3,"type","checkbox"],["textarea","formControlName",""],["input","formControl","",3,"type","checkbox"],["textarea","formControl",""],["input","ngModel","",3,"type","checkbox"],["textarea","ngModel",""],["","ngDefaultControl",""]],Ha:function(a,b){a&1&&V("input",function(c){return b.sp(c.target.value)})("blur",function(){return b.Fr()})("compositionstart",function(){return b.Hz()})("compositionend",function(c){return b.Gz(c.target.value)})},features:[Hr([nw]),
Ap]});var pw=new df(""),qw=new df("");function rw(a){a=a.value;return null==a||("string"===typeof a||Array.isArray(a))&&0===a.length?{required:!0}:null}function sw(a){return null!=a}function tw(a){return pn(a)?Qj(a):a}function uw(a){let b={};a.forEach(c=>{b=null!=c?Object.assign({},b,c):b});return 0===Object.keys(b).length?null:b}function vw(a,b){return b.map(c=>c(a))}function ww(a){return a.map(b=>b.validate?c=>b.validate(c):b)}
function xw(a){if(!a)return null;const b=a.filter(sw);return 0==b.length?null:function(c){return uw(vw(c,b))}}function yw(a){return null!=a?xw(ww(a)):null}function zw(a){if(!a)return null;const b=a.filter(sw);return 0==b.length?null:function(c){c=vw(c,b).map(tw);return C(hk(c),vj(uw))}}function Aw(a){return null!=a?zw(ww(a)):null}function Bw(a,b){return null===a?[b]:Array.isArray(a)?[...a,b]:[a,b]};var Cw=class{constructor(){this.Ve=[];this.Cf=[];this.D=[]}get value(){return this.control?this.control.value:null}get valid(){return this.control?this.control.valid:null}get Pn(){return this.control?this.control.Pn:null}get pending(){return this.control?this.control.pending:null}get disabled(){return this.control?this.control.disabled:null}get enabled(){return this.control?this.control.enabled:null}get errors(){return this.control?this.control.errors:null}get ie(){return this.control?this.control.ie:
null}get pc(){return this.control?this.control.pc:null}get Tc(){return this.control?this.control.Tc:null}get status(){return this.control?this.control.status:null}get Ks(){return this.control?this.control.Ks:null}get am(){return this.control?this.control.am:null}get ah(){return this.control?this.control.ah:null}get path(){return null}mu(a){this.Ve=a||[];this.um=yw(this.Ve)}lu(a){this.Cf=a||[];this.tm=Aw(this.Cf)}get Zg(){return this.um||null}get Ye(){return this.tm||null}F(a){this.D.push(a)}G(){this.D.forEach(a=>
a());this.D=[]}reset(a){this.control&&this.control.reset(a)}ye(a,b){return this.control?this.control.ye(a,b):!1}getError(a,b){return this.control?this.control.getError(a,b):null}};var Dw=class extends Cw{constructor(){super(...arguments);this.i=this.name=this.Pa=null}};var Ew=class extends Cw{get path(){return null}};var Fw=class{constructor(a){this.i=a}get CC(){let a,b;return!!(null==(a=this.i)?0:null==(b=a.control)?0:b.Tc)}get DC(){let a,b;return!!(null==(a=this.i)?0:null==(b=a.control)?0:b.Ks)}get AC(){let a,b;return!!(null==(a=this.i)?0:null==(b=a.control)?0:b.ie)}get Sn(){let a,b;return!!(null==(a=this.i)?0:null==(b=a.control)?0:b.pc)}get ir(){let a,b;return!!(null==(a=this.i)?0:null==(b=a.control)?0:b.valid)}get xC(){let a,b;return!!(null==(a=this.i)?0:null==(b=a.control)?0:b.Pn)}get zC(){let a,b;return!!(null==
(a=this.i)?0:null==(b=a.control)?0:b.pending)}};Object.assign({},{"[class.ng-untouched]":"isUntouched","[class.ng-touched]":"isTouched","[class.ng-pristine]":"isPristine","[class.ng-dirty]":"isDirty","[class.ng-valid]":"isValid","[class.ng-invalid]":"isInvalid","[class.ng-pending]":"isPending"},{"[class.ng-submitted]":"isSubmitted"});var Gw=class extends Fw{};Gw.J=function(a){return new (a||Gw)(y(Dw,2))};
Gw.Ea=Of({type:Gw,ga:[["","formControlName",""],["","ngModel",""],["","formControl",""]],Xa:14,Ha:function(a,b){a&2&&lq("ng-untouched",b.DC)("ng-touched",b.CC)("ng-pristine",b.AC)("ng-dirty",b.Sn)("ng-valid",b.ir)("ng-invalid",b.xC)("ng-pending",b.zC)},features:[Ap]});var Hw=new df("CallSetDisabledState",{da:"root",aa:()=>"whenDisabledForLegacyCode"});function Iw(a,b,c="whenDisabledForLegacyCode"){Jw(a,b);b.i.pi(a.value);if(a.disabled||"always"===c){let d,e;null==(e=(d=b.i).gi)||e.call(d,a.disabled)}Kw(a,b);Lw(a,b);Mw(a,b);Nw(a,b)}function Ow(a,b){const c=()=>{};b.i&&(b.i.Lg(c),b.i.Ij(c));Pw(a,b);a&&(b.G(),a.Ak(()=>{}))}function Qw(a,b){a.forEach(c=>{c.Xr&&c.Xr(b)})}function Nw(a,b){if(b.i.gi){const c=d=>{b.i.gi(d)};a.Em.push(c);b.F(()=>{a.QA(c)})}}
function Jw(a,b){var c=a.Ve;null!==b.Zg?Rw(a,Bw(c,b.Zg)):"function"===typeof c&&Rw(a,[c]);c=a.Cf;null!==b.Ye?Sw(a,Bw(c,b.Ye)):"function"===typeof c&&Sw(a,[c]);c=()=>Tw(a);Qw(b.Ve,c);Qw(b.Cf,c)}
function Pw(a,b){let c=!1;if(null!==a){if(null!==b.Zg){var d=a.Ve;if(Array.isArray(d)&&0<d.length){var e=d.filter(f=>f!==b.Zg);e.length!==d.length&&(c=!0,a.ep(e))}}null!==b.Ye&&(d=a.Cf,Array.isArray(d)&&0<d.length&&(e=d.filter(f=>f!==b.Ye),e.length!==d.length&&(c=!0,a.cp(e))))}a=()=>{};Qw(b.Ve,a);Qw(b.Cf,a);return c}function Kw(a,b){b.i.Lg(c=>{a.th=c;a.rh=!0;a.Im=!0;"change"===a.sf&&Uw(a,b)})}function Mw(a,b){b.i.Ij(()=>{a.Gp=!0;"blur"===a.sf&&a.rh&&Uw(a,b);"submit"!==a.sf&&Vw(a)})}
function Uw(a,b){a.Im&&Ww(a);a.setValue(a.th,{Lv:!1});var c=a.th;b.C=c;b.update.emit(c);a.rh=!1}function Lw(a,b){const c=(d,e)=>{b.i.pi(d);e&&(b.C=d,b.update.emit(d))};a.Lg(c);b.F(()=>{a.PA(c)})}function Xw(a,b){a.Mp();b.forEach(c=>{const d=c.control;if("submit"===d.sf&&d.rh){var e=d.th;c.C=e;c.update.emit(e);d.rh=!1}})}function Yw(a){if(!a)return null;let b=void 0,c=void 0,d=void 0;a.forEach(e=>{e.constructor===mw?b=e:Object.getPrototypeOf(e.constructor)===iw?c=e:d=e});return d?d:c?c:b?b:null};var Zw=class{},$w=class extends Zw{constructor(a,b){super();this.value=a;this.source=b}},ax=class extends Zw{constructor(a,b){super();this.ie=a;this.source=b}},bx=class extends Zw{constructor(a,b){super();this.Tc=a;this.source=b}},cx=class extends Zw{constructor(a,b){super();this.status=a;this.source=b}},dx=class extends Zw{constructor(a){super();this.source=a}},ex=class extends Zw{constructor(a){super();this.source=a}};function fx(a){return null!=a&&!Array.isArray(a)&&"object"===typeof a}
function gx(a,b){a.Qe((c,d)=>{if(void 0===b[d])throw new Yd(1002,"");})}function Rw(a,b){a.ep(b)}function Sw(a,b){a.cp(b)}function Tw(a,b={}){a.FA();a.Sp();a.enabled&&(a.Bz(),a.errors=a.DA(),a.status=a.pt(),"VALID"!==a.status&&"PENDING"!==a.status||a.CA(b.yb));let c;const d=null!=(c=b.Yf)?c:a;!1!==b.yb&&(a.Ab.next(new $w(a.value,d)),a.Ab.next(new cx(a.status,d)),a.ah.emit(a.value),a.am.emit(a.status));a.Pa&&!b.Tb&&Tw(a.Pa,Object.assign({},b,{Yf:d}))}
function Vw(a,b={}){const c=!1===a.Tc;a.Tc=!0;let d;const e=null!=(d=b.Yf)?d:a;a.Pa&&!b.Tb&&Vw(a.Pa,Object.assign({},b,{Yf:e}));c&&!1!==b.yb&&a.Ab.next(new bx(!0,e))}function Ww(a,b={}){const c=!0===a.ie;a.ie=!1;let d;const e=null!=(d=b.Yf)?d:a;a.Pa&&!b.Tb&&Ww(a.Pa,Object.assign({},b,{Yf:e}));c&&!1!==b.yb&&a.Ab.next(new ax(!1,e))}
function hx(a,b={}){const c=!0===a.Tc;a.Tc=!1;a.Gp=!1;let d;const e=null!=(d=b.Yf)?d:a;a.Qe(f=>{hx(f,{Tb:!0,yb:b.yb,Yf:e})});a.Pa&&!b.Tb&&a.Pa.Qm(b,e);c&&!1!==b.yb&&a.Ab.next(new bx(!1,e))}function ix(a,b={}){const c=!1===a.ie;a.ie=!0;a.Im=!1;let d;const e=null!=(d=b.Yf)?d:a;a.Qe(f=>{ix(f,{Tb:!0,yb:b.yb})});a.Pa&&!b.Tb&&a.Pa.Pm(b,e);c&&!1!==b.yb&&a.Ab.next(new ax(!0,e))}function jx(a,b,c={}){a.errors=b;a.uu(!1!==c.yb,a)}
var kx=class{constructor(a,b){this.Gp=this.ym=this.Im=!1;this.Mi=()=>{};this.Pa=null;this.ie=!0;this.Tc=!1;this.Ab=new aj;this.ec=Zi(this.Ab);this.Em=[];this.ep(a);this.cp(b)}get Zg(){return this.um}set Zg(a){this.Ve=this.um=a}get Ye(){return this.tm}set Ye(a){this.Cf=this.tm=a}get parent(){return this.Pa}get valid(){return"VALID"===this.status}get Pn(){return"INVALID"===this.status}get pending(){return"PENDING"==this.status}get disabled(){return"DISABLED"===this.status}get enabled(){return"DISABLED"!==
this.status}get pc(){return!this.ie}get Ks(){return!this.Tc}get sf(){return this.Rp?this.Rp:this.parent?this.parent.sf:"change"}disable(a={}){const b=this.gu(a.Tb);this.status="DISABLED";this.errors=null;this.Qe(e=>{e.disable(Object.assign({},a,{Tb:!0}))});this.Sp();let c;const d=null!=(c=a.Yf)?c:this;!1!==a.yb&&(this.Ab.next(new $w(this.value,d)),this.Ab.next(new cx(this.status,d)),this.ah.emit(this.value),this.am.emit(this.status));this.tu(Object.assign({},a,{Rx:b}),this);this.Em.forEach(e=>e(!0))}enable(a=
{}){const b=this.gu(a.Tb);this.status="VALID";this.Qe(c=>{c.enable(Object.assign({},a,{Tb:!0}))});Tw(this,{Tb:!0,yb:a.yb});this.tu(Object.assign({},a,{Rx:b}),this);this.Em.forEach(c=>c(!1))}tu(a,b){this.Pa&&!a.Tb&&(Tw(this.Pa,a),a.Rx||this.Pa.Pm({},b),this.Pa.Qm({},b))}wu(a={yb:!0}){this.Qe(b=>b.wu(a));Tw(this,{Tb:!0,yb:a.yb})}FA(){this.status=this.ap()?"DISABLED":"VALID"}DA(){return this.Zg?this.Zg(this):null}CA(a){this.Ye&&(this.status="PENDING",this.ym=!0,this.ot=tw(this.Ye(this)).subscribe(b=>
{this.ym=!1;jx(this,b,{yb:a})}))}Bz(){this.ot&&(this.ot.unsubscribe(),this.ym=!1)}get(a){if(null==a)return null;Array.isArray(a)||(a=a.split("."));return 0===a.length?null:a.reduce((b,c)=>b&&b.zt(c),this)}getError(a,b){return(b=b?this.get(b):this)&&b.errors?b.errors[a]:null}ye(a,b){return!!this.getError(a,b)}get root(){let a=this;for(;a.Pa;)a=a.Pa;return a}uu(a,b){this.status=this.pt();a&&(this.am.emit(this.status),this.Ab.next(new cx(this.status,b)));this.Pa&&this.Pa.uu(a,b)}St(){this.ah=new Dk;
this.am=new Dk}pt(){return this.ap()?"DISABLED":this.errors?"INVALID":this.ym||this.nt("PENDING")?"PENDING":this.nt("INVALID")?"INVALID":"VALID"}nt(a){return this.pm(b=>b.status===a)}mt(){return this.pm(a=>a.pc)}Az(){return this.pm(a=>a.Tc)}Pm(a,b){const c=!this.mt(),d=this.ie!==c;this.ie=c;this.Pa&&!a.Tb&&this.Pa.Pm(a,b);d&&this.Ab.next(new ax(this.ie,b))}Qm(a={},b){this.Tc=this.Az();this.Ab.next(new bx(this.Tc,b));this.Pa&&!a.Tb&&this.Pa.Qm(a,b)}Ak(a){this.Mi=a}Lm(a){fx(a)&&null!=a.sf&&(this.Rp=
a.sf)}gu(a){const b=this.Pa&&this.Pa.pc;return!a&&!!b&&!this.Pa.mt()}zt(){return null}ep(a){a=this.Ve=Array.isArray(a)?a.slice():a;this.um=Array.isArray(a)?yw(a):a||null}cp(a){a=this.Cf=Array.isArray(a)?a.slice():a;this.tm=Array.isArray(a)?Aw(a):a||null}};var lx=class extends kx{constructor(a,b){super((fx(a)?a.OE:a)||null,(fx(a)?a.YA:b)||null);this.controls={};this.St();this.Lm(a);this.HA();Tw(this,{Tb:!0,yb:!!this.Ye})}contains(a){return this.controls.hasOwnProperty(a)&&this.controls[a].enabled}setValue(a,b={}){gx(this,a);Object.keys(a).forEach(c=>{const d=this.controls;if(!Object.keys(d).length)throw new Yd(1E3,"");if(!d[c])throw new Yd(1001,"");this.controls[c].setValue(a[c],{Tb:!0,yb:b.yb})});Tw(this,b)}reset(a={},b={}){this.Qe((c,d)=>{c.reset(a?
a[d]:null,{Tb:!0,yb:b.yb})});this.Pm(b,this);this.Qm(b,this);Tw(this,b)}Mp(){let a=this.hu(!1,(b,c)=>c.Mp()?!0:b);a&&Tw(this,{Tb:!0});return a}Qe(a){Object.keys(this.controls).forEach(b=>{const c=this.controls[b];c&&a(c,b)})}HA(){this.Qe(a=>{a.Pa=this;a.Ak(this.Mi)})}Sp(){this.value=this.AA()}pm(a){for(const [b,c]of Object.entries(this.controls)){const d=c;if(this.contains(b)&&a(d))return!0}return!1}AA(){return this.hu({},(a,b,c)=>{if(b.enabled||this.disabled)a[c]=b.value;return a})}hu(a,b){let c=
a;this.Qe((d,e)=>{c=b(c,d,e)});return c}ap(){for(const a of Object.keys(this.controls))if(this.controls[a].enabled)return!1;return 0<Object.keys(this.controls).length||this.disabled}zt(a){return this.controls.hasOwnProperty(a)?this.controls[a]:null}};const nx={na:Ew,zb:af(()=>mx)};Promise.resolve();
var mx=class extends Ew{constructor(a,b,c){super();this.Xm=c;this.Uj=!1;this.Kz=new Set;this.Hl=new Dk;this.form=new lx(yw(a),Aw(b))}nd(){this.Lm()}get control(){return this.form}get path(){return[]}get controls(){return this.form.controls}setValue(a){this.control.setValue(a)}Er(a){this.Uj=!0;Xw(this.form,this.Kz);this.Hl.emit(a);let b;return"dialog"===(null==a?void 0:null==(b=a.target)?void 0:b.method)}Cr(){this.es()}es(){this.form.reset(void 0);this.Uj=!1}Lm(){this.options&&null!=this.options.sf&&
(this.form.Rp=this.options.sf)}pF(a){a.pop();return a.length?this.form.get(a):this.form}};mx.J=function(a){return new (a||mx)(y(pw,10),y(qw,10),y(Hw,8))};mx.Ea=Of({type:mx,ga:[["form",3,"ngNoForm","",3,"formGroup",""],["ng-form"],["","ngForm",""]],Ha:function(a,b){a&1&&V("submit",function(c){return b.Er(c)})("reset",function(){return b.Cr()})},inputs:{options:[0,"ngFormOptions","options"]},outputs:{Hl:"ngSubmit"},hb:["ngForm"],features:[Hr([nx]),Ap]});function ox(a){return"object"===typeof a&&null!==a&&2===Object.keys(a).length&&"value"in a&&"disabled"in a}
var px=class extends kx{constructor(a=null){super((fx()?(void 0).OE:void 0)||null,(fx()?(void 0).YA:void 0)||null);this.defaultValue=null;this.i=[];this.rh=!1;this.C(a);this.Lm(void 0);this.St();Tw(this,{Tb:!0,yb:!!this.Ye});fx()&&((void 0).cG||(void 0).TF)&&(ox(a)?this.defaultValue=a.value:this.defaultValue=a)}setValue(a,b={}){this.value=this.th=a;this.i.length&&!1!==b.Lv&&this.i.forEach(c=>c(this.value,!1!==b.IF));Tw(this,b)}reset(a=this.defaultValue,b={}){this.C(a);ix(this,b);hx(this,b);this.setValue(this.value,
b);this.rh=!1}Sp(){}pm(){return!1}ap(){return this.disabled}Lg(a){this.i.push(a)}PA(a){var b=this.i;a=b.indexOf(a);-1<a&&b.splice(a,1)}QA(a){var b=this.Em;a=b.indexOf(a);-1<a&&b.splice(a,1)}Qe(){}Mp(){return"submit"===this.sf&&(this.Im&&Ww(this),this.Gp&&Vw(this),this.rh)?(this.setValue(this.th,{Tb:!0,Lv:!1}),!0):!1}C(a){ox(a)?(this.value=this.th=a.value,a.disabled?this.disable({Tb:!0,yb:!1}):this.enable({Tb:!0,yb:!1})):this.value=this.th=a}};Promise.resolve();var qx=new df("");const sx={na:Dw,zb:af(()=>rx)};var rx=class extends Dw{set fr(a){}constructor(a,b,c,d,e){super();this.Xm=e;this.update=new Dk;this.N=!1;this.mu(a);this.lu(b);this.i=Yw(c)}rc(a){if(this.K(a)){var b=a.form.jx;b&&Ow(b,this);Iw(this.form,this,this.Xm);Tw(this.form,{yb:!1})}b=this.C;a.hasOwnProperty("model")?(a=a.model,a=a.vn?!0:!Object.is(b,a.pq)):a=!1;a&&(this.form.setValue(this.model),this.C=this.model)}ua(){this.form&&Ow(this.form,this)}get path(){return[]}get control(){return this.form}K(a){return a.hasOwnProperty("form")}};
rx.J=function(a){return new (a||rx)(y(pw,10),y(qw,10),y(jw,10),y(qx,8),y(Hw,8))};rx.Ea=Of({type:rx,ga:[["","formControl",""]],inputs:{form:[0,"formControl","form"],fr:[0,"disabled","isDisabled"],model:[0,"ngModel","model"]},outputs:{update:"ngModelChange"},hb:["ngForm"],features:[Hr([sx]),Ap,Cg]});const ux={na:Ew,zb:af(()=>tx)};
var tx=class extends Ew{constructor(a,b,c){super();this.Xm=c;this.Uj=!1;this.Mi=()=>this.vu();this.Fv=[];this.form=null;this.Hl=new Dk;this.mu(a);this.lu(b)}rc(a){a.hasOwnProperty("form")&&(this.SA(),this.vu(),this.RA(),this.Dm=this.form)}ua(){this.form&&(Pw(this.form,this),this.form.Mi===this.Mi&&this.form.Ak(()=>{}))}get control(){return this.form}get path(){return[]}Er(a){this.Uj=!0;Xw(this.form,this.Fv);this.Hl.emit(a);this.form.Ab.next(new dx(this.control));let b;return"dialog"===(null==a?void 0:
null==(b=a.target)?void 0:b.method)}Cr(){this.es()}es(){this.form.reset(void 0);this.Uj=!1;this.form.Ab.next(new ex(this.form))}vu(){this.Fv.forEach(a=>{const b=a.control,c=this.form.get(a.path);b!==c&&(Ow(b||null,a),c instanceof px&&(Iw(c,a,this.Xm),a.control=c))});this.form.wu({yb:!1})}vF(a){const b=this.form.get(a.path);Jw(b,a);Tw(b,{yb:!1})}nF(a){if(this.form){const b=this.form.get(a.path);b&&Pw(b,a)&&Tw(b,{yb:!1})}}RA(){this.form.Ak(this.Mi);this.Dm&&this.Dm.Ak(()=>{})}SA(){Jw(this.form,this);
this.Dm&&Pw(this.Dm,this)}mF(){}};tx.J=function(a){return new (a||tx)(y(pw,10),y(qw,10),y(Hw,8))};tx.Ea=Of({type:tx,ga:[["","formGroup",""]],Ha:function(a,b){a&1&&V("submit",function(c){return b.Er(c)})("reset",function(){return b.Cr()})},inputs:{form:[0,"formGroup","form"]},outputs:{Hl:"ngSubmit"},hb:["ngForm"],features:[Hr([ux]),Ap,Cg]});var vx=class{};vx.J=function(a){return new (a||vx)};vx.Wa=Mf({type:vx});vx.Va=Md({});var wx=class{};wx.J=function(a){return new (a||wx)};wx.Wa=Mf({type:wx});wx.Va=Md({imports:[vx]});function xx(a){return 0===a.buttons||0===a.detail}function yx(a){a=a.touches&&a.touches[0]||a.changedTouches&&a.changedTouches[0];return!!a&&-1===a.identifier&&(null==a.radiusX||1===a.radiusX)&&(null==a.radiusY||1===a.radiusY)};var zx=new df("cdk-input-modality-detector-options"),Ax={jC:[18,17,224,91,16]};const Bx=Ht({passive:!0,capture:!0});
var Cx=class{get N(){return this.i.value}constructor(a,b,c,d){this.Ka=a;this.C=null;this.i=new cj(null);this.D=0;this.F=e=>{let f,g;(null==(f=this.Ni)?0:null==(g=f.jC)?0:g.some(k=>k===e.keyCode))||(this.i.next("keyboard"),this.C=Pt(e))};this.Gm=e=>{650>Date.now()-this.D||(this.i.next(xx(e)?"keyboard":"mouse"),this.C=Pt(e))};this.G=e=>{yx(e)?this.i.next("keyboard"):(this.D=Date.now(),this.i.next("touch"),this.C=Pt(e))};this.Ni=Object.assign({},Ax,d);this.K=C(this.i,Co());C(this.K,$n());a.isBrowser&&
Kk(b,()=>{c.addEventListener("keydown",this.F,Bx);c.addEventListener("mousedown",this.Gm,Bx);c.addEventListener("touchstart",this.G,Bx)})}ua(){this.i.complete();this.Ka.isBrowser&&(document.removeEventListener("keydown",this.F,Bx),document.removeEventListener("mousedown",this.Gm,Bx),document.removeEventListener("touchstart",this.G,Bx))}};Cx.J=function(a){return new (a||Cx)(q(St),q(Ok),q(gt),q(zx,8))};Cx.oa=Ld({la:Cx,aa:Cx.J,da:"root"});var Dx=new df("cdk-focus-monitor-default-options");const Ex=Ht({passive:!0,capture:!0});function Fx(a,b,c=!1){b=Ps(b);if(!a.Ka.isBrowser||1!==b.nodeType)return hj();const d=Nt(b)||a.F(),e=a.i.get(b);if(e)return c&&(e.an=!0),e.Tg;c={an:c,Tg:new aj,rootNode:d};a.i.set(b,c);a.Ta(c);return c.Tg}function Gx(a,b){b=Ps(b);const c=a.i.get(b);c&&(c.Tg.complete(),a.O(b),a.i.delete(b),a.ab(c))}
function Hx(a,b,c,d){b=Ps(b);b===a.F().activeElement?a.Ia(b).forEach(([e,f])=>a.ma(e,c,f)):(a.ta(c),"function"===typeof b.focus&&b.focus(d))}
var Ix=class{constructor(a,b,c,d,e){this.pa=a;this.Ka=b;this.G=c;this.D=null;this.N=this.R=!1;this.i=new Map;this.ia=0;this.C=new Map;this.Da=()=>{this.R=!0;this.kb=window.setTimeout(()=>this.R=!1)};this.va=new aj;this.K=f=>{for(var g=Pt(f);g;g=g.parentElement)"focus"===f.type?this.Fp(f,g):this.xk(f,g)};this.ha=d;this.T=(null==e?void 0:e.BF)||0}ua(){this.i.forEach((a,b)=>Gx(this,b))}F(){return this.ha||document}Oa(a){return this.D?this.N?this.fb(a)?"touch":"program":this.D:this.R&&this.ea?this.ea:
a&&this.Ra(a)?"mouse":"program"}fb(a){return 1===this.T||!(null==a||!a.contains(this.G.C))}O(a,b){a.classList.toggle("cdk-focused",!!b);a.classList.toggle("cdk-touch-focused","touch"===b);a.classList.toggle("cdk-keyboard-focused","keyboard"===b);a.classList.toggle("cdk-mouse-focused","mouse"===b);a.classList.toggle("cdk-program-focused","program"===b)}ta(a,b=!1){Kk(this.pa,()=>{this.D=a;this.N="touch"===a&&b;0===this.T&&(clearTimeout(this.ra),this.ra=setTimeout(()=>this.D=null,this.N?650:1))})}Fp(a,
b){const c=this.i.get(b);a=Pt(a);c&&(c.an||b===a)&&this.ma(b,this.Oa(a),c)}xk(a,b){const c=this.i.get(b);!c||c.an&&a.relatedTarget instanceof Node&&b.contains(a.relatedTarget)||(this.O(b),this.ba(c,null))}ba(a,b){a.Tg.kc.length&&this.pa.run(()=>a.Tg.next(b))}Ta(a){if(this.Ka.isBrowser){var b=a.rootNode;(a=this.C.get(b)||0)||Kk(this.pa,()=>{b.addEventListener("focus",this.K,Ex);b.addEventListener("blur",this.K,Ex)});this.C.set(b,a+1);1===++this.ia&&(Kk(this.pa,()=>{(this.F().defaultView||window).addEventListener("focus",
this.Da)}),C(this.G.K,Jo(this.va)).subscribe(c=>{this.ta(c,!0)}))}}ab(a){a=a.rootNode;if(this.C.has(a)){const b=this.C.get(a);1<b?this.C.set(a,b-1):(a.removeEventListener("focus",this.K,Ex),a.removeEventListener("blur",this.K,Ex),this.C.delete(a))}--this.ia||((this.F().defaultView||window).removeEventListener("focus",this.Da),this.va.next(),clearTimeout(this.kb),clearTimeout(this.ra))}ma(a,b,c){this.O(a,b);this.ba(c,b);this.ea=b}Ia(a){const b=[];this.i.forEach((c,d)=>{(d===a||c.an&&d.contains(a))&&
b.push([d,c])});return b}Ra(a){const b=this.G.C;if("mouse"!==this.G.N||!b||b===a||"INPUT"!==a.nodeName&&"TEXTAREA"!==a.nodeName||a.disabled)return!1;if(a=a.labels)for(let c=0;c<a.length;c++)if(a[c].contains(b))return!0;return!1}};Ix.J=function(a){return new (a||Ix)(q(Ok),q(St),q(Cx),q(gt,8),q(Dx,8))};Ix.oa=Ld({la:Ix,aa:Ix.J,da:"root"});function Jx(a,b){if(!a.Ka.isBrowser)return!1;try{var c=(b.ownerDocument&&b.ownerDocument.defaultView||window).frameElement}catch(f){c=null}if(c&&(-1===Kx(c)||!a.isVisible(c)))return!1;c=b.nodeName.toLowerCase();let d=Kx(b);if(b.hasAttribute("contenteditable"))a=-1!==d;else{var e;if(!(e="iframe"===c||"object"===c)&&(e=a.Ka.D&&a.Ka.i)){e=b.nodeName.toLowerCase();let f="input"===e&&b.type;e=!("text"===f||"password"===f||"select"===e||"textarea"===e)}a=e?!1:"audio"===c?b.hasAttribute("controls")?-1!==
d:!1:"video"===c?-1===d?!1:null!==d?!0:a.Ka.K||b.hasAttribute("controls"):0<=b.tabIndex}return a}function Lx(a,b){if("input"==b.nodeName.toLowerCase()&&"hidden"==b.type)var c=!1;else c=b.nodeName.toLowerCase(),c="input"===c||"select"===c||"button"===c||"textarea"===c||"a"==b.nodeName.toLowerCase()&&b.hasAttribute("href")||b.hasAttribute("contenteditable")||Mx(b);return c&&!a.fr(b)&&a.isVisible(b)}
var Nx=class{constructor(a){this.Ka=a}fr(a){return a.hasAttribute("disabled")}isVisible(a){return!!(a.offsetWidth||a.offsetHeight||"function"===typeof a.getClientRects&&a.getClientRects().length)&&"visible"===getComputedStyle(a).visibility}};Nx.J=function(a){return new (a||Nx)(q(St))};Nx.oa=Ld({la:Nx,aa:Nx.J,da:"root"});function Mx(a){if(!a.hasAttribute("tabindex")||void 0===a.tabIndex)return!1;a=a.getAttribute("tabindex");return!(!a||isNaN(parseInt(a,10)))}
function Kx(a){if(!Mx(a))return null;a=parseInt(a.getAttribute("tabindex")||"",10);return isNaN(a)?-1:a};function Ox(a){(a=a.ia("start"))&&a.focus(void 0);return!!a}function Px(a){a.O||(Kk(a.pa,()=>{a.D||(a.D=a.ba(),a.D.addEventListener("focus",a.ra));a.C||(a.C=a.ba(),a.C.addEventListener("focus",a.ma))}),a.i.parentNode&&(a.i.parentNode.insertBefore(a.D,a.i),a.i.parentNode.insertBefore(a.C,a.i.nextSibling),a.O=!0))}
function Qx(a){return new Promise(b=>{a.ta(()=>{var c;(c=a.i.querySelector("[cdk-focus-initial], [cdkFocusInitial]"))?Lx(a.G,c)?(c.focus(void 0),c=!0):(c=a.R(c),null==c||c.focus(void 0),c=!!c):c=Ox(a);return b(c)})})}function Rx(a,b){a.D&&a.C&&(a.K(b,a.D),a.K(b,a.C))}
var Sx=class{get enabled(){return this.F}set enabled(a){this.F=a;this.D&&this.C&&(this.K(a,this.D),this.K(a,this.C))}constructor(a,b,c,d,e=!1){this.i=a;this.G=b;this.pa=c;this.ha=d;this.O=!1;this.ra=()=>{const f=this.ia("end");f&&f.focus(void 0);return!!f};this.ma=()=>Ox(this);this.F=!0;e||Px(this)}destroy(){const a=this.D,b=this.C;a&&(a.removeEventListener("focus",this.ra),a.remove());b&&(b.removeEventListener("focus",this.ma),b.remove());this.D=this.C=null;this.O=!1}ia(a){const b=this.i.querySelectorAll(`[cdk-focus-region-${a}], `+
`[cdkFocusRegion${a}], `+`[cdk-focus-${a}]`);return"start"==a?b.length?b[0]:this.R(this.i):b.length?b[b.length-1]:this.ea(this.i)}fc(){return this.O}R(a){if(Lx(this.G,a)&&Jx(this.G,a))return a;a=a.children;for(let b=0;b<a.length;b++){const c=a[b].nodeType===this.ha.ELEMENT_NODE?this.R(a[b]):null;if(c)return c}return null}ea(a){if(Lx(this.G,a)&&Jx(this.G,a))return a;a=a.children;for(let b=a.length-1;0<=b;b--){const c=a[b].nodeType===this.ha.ELEMENT_NODE?this.ea(a[b]):null;if(c)return c}return null}ba(){const a=
this.ha.createElement("div");this.K(this.F,a);a.classList.add("cdk-visually-hidden");a.classList.add("cdk-focus-trap-anchor");a.setAttribute("aria-hidden","true");return a}K(a,b){a?b.setAttribute("tabindex","0"):b.removeAttribute("tabindex")}ta(a){this.pa.isStable?a():C(this.pa.jo,co()).subscribe(a)}},Tx=class{constructor(a,b,c){this.i=a;this.pa=b;this.ha=c}create(a,b=!1){return new Sx(a,this.i,this.pa,this.ha,b)}};Tx.J=function(a){return new (a||Tx)(q(Nx),q(Ok),q(gt))};Tx.oa=Ld({la:Tx,aa:Tx.J,da:"root"});const Ux=new Set;let Vx;function Wx(a,b){if(a.Ka.D||a.Ka.F){var c=a.C;if(!Ux.has(b))try{Vx||(Vx=document.createElement("style"),c&&Vx.setAttribute("nonce",c),Vx.setAttribute("type","text/css"),document.head.appendChild(Vx)),Vx.sheet&&(Vx.sheet.insertRule(`@media ${b} {body{ }}`,0),Ux.add(b))}catch(d){console.error(d)}}return a.i(b)}var Yx=class{constructor(a,b){this.Ka=a;this.C=b;this.i=this.Ka.isBrowser&&window.matchMedia?window.matchMedia.bind(window):Xx}};
Yx.J=function(a){return new (a||Yx)(q(St),q(li,8))};Yx.oa=Ld({la:Yx,aa:Yx.J,da:"root"});function Xx(a){return{matches:"all"===a||""===a,media:a,addListener:()=>{},removeListener:()=>{}}};var $x=class{constructor(a,b){this.D=a;this.xb=b;this.C=new Map;this.i=new aj}ua(){this.i.next();this.i.complete()}observe(a){a=Zx(Ms(a)).map(b=>this.F(b).observable);a=Nj(a);a=fk(C(a,co()),C(a,Co(),Mn(0)));return C(a,vj(b=>{const c={matches:!1,Nu:{}};b.forEach(({matches:d,query:e})=>{c.matches=c.matches||d;c.Nu[e]=d});return c}))}F(a){if(this.C.has(a))return this.C.get(a);const b=Wx(this.D,a),c={observable:C(new Vi(d=>{const e=f=>this.xb.run(()=>d.next(f));b.addListener(e);return()=>{b.removeListener(e)}}),
Fo(b),vj(({matches:d})=>({query:a,matches:d})),Jo(this.i)),XF:b};this.C.set(a,c);return c}};$x.J=function(a){return new (a||$x)(q(Yx),q(Ok))};$x.oa=Ld({la:$x,aa:$x.J,da:"root"});function Zx(a){return a.map(b=>b.split(",")).reduce((b,c)=>b.concat(c)).map(b=>b.trim())};function ay(a){if(!a.Ka.isBrowser)return 0;const b=a.ha.createElement("div");b.style.backgroundColor="rgb(1,2,3)";b.style.position="absolute";a.ha.body.appendChild(b);a=(a=a.ha.defaultView||window)&&a.getComputedStyle?a.getComputedStyle(b):null;a=(a&&a.backgroundColor||"").replace(/ /g,"");b.remove();switch(a){case "rgb(0,0,0)":case "rgb(45,50,54)":case "rgb(32,32,32)":return 2;case "rgb(255,255,255)":case "rgb(255,250,239)":return 1}return 0}
var by=class{constructor(a,b){this.Ka=a;this.ha=b;this.D=lf($x).observe("(forced-colors: active)").subscribe(()=>{this.C&&(this.C=!1,this.i())})}ua(){this.D.unsubscribe()}i(){if(!this.C&&this.Ka.isBrowser&&this.ha.body){const a=this.ha.body.classList;a.remove("cdk-high-contrast-active","cdk-high-contrast-black-on-white","cdk-high-contrast-white-on-black");this.C=!0;const b=ay(this);1===b?a.add("cdk-high-contrast-active","cdk-high-contrast-black-on-white"):2===b&&a.add("cdk-high-contrast-active","cdk-high-contrast-white-on-black")}}};
by.J=function(a){return new (a||by)(q(St),q(gt))};by.oa=Ld({la:by,aa:by.J,da:"root"});var dy=new df("liveAnnouncerElement",{da:"root",aa:cy});function cy(){return null}var ey=new df("LIVE_ANNOUNCER_DEFAULT_OPTIONS");var fy=class{create(a){return"undefined"===typeof MutationObserver?null:new MutationObserver(a)}};fy.J=function(a){return new (a||fy)};fy.oa=Ld({la:fy,aa:fy.J,da:"root"});var gy=class{};gy.J=function(a){return new (a||gy)};gy.Wa=Mf({type:gy});gy.Va=Md({Ua:[fy]});let hy=0;function iy(a,b,...c){const d=a.G;let e,f;1===c.length&&"number"===typeof c[0]?f=c[0]:[e,f]=c;a.clear();clearTimeout(a.F);e||(e=d&&d.Nl?d.Nl:"polite");null==f&&d&&(f=d.duration);a.i.setAttribute("aria-live",e);a.i.id&&a.N(a.i.id);Kk(a.pa,()=>{a.C||(a.C=new Promise(g=>a.D=g));clearTimeout(a.F);a.F=setTimeout(()=>{a.i.textContent=b;"number"===typeof f&&(a.F=setTimeout(()=>a.clear(),f));let g;null==(g=a.D)||g.call(a);a.C=a.D=void 0},100);return a.C})}
var jy=class{constructor(a,b,c,d){this.pa=b;this.G=d;this.ha=c;this.i=a||this.K()}clear(){this.i&&(this.i.textContent="")}ua(){clearTimeout(this.F);let a;null==(a=this.i)||a.remove();this.i=null;let b;null==(b=this.D)||b.call(this);this.C=this.D=void 0}K(){const a=this.ha.getElementsByClassName("cdk-live-announcer-element"),b=this.ha.createElement("div");for(let c=0;c<a.length;c++)a[c].remove();b.classList.add("cdk-live-announcer-element");b.classList.add("cdk-visually-hidden");b.setAttribute("aria-atomic",
"true");b.setAttribute("aria-live","polite");b.id=`cdk-live-announcer-${hy++}`;this.ha.body.appendChild(b);return b}N(a){const b=this.ha.querySelectorAll('body > .cdk-overlay-container [aria-modal="true"]');for(let c=0;c<b.length;c++){const d=b[c],e=d.getAttribute("aria-owns");e?-1===e.indexOf(a)&&d.setAttribute("aria-owns",e+" "+a):d.setAttribute("aria-owns",a)}}};jy.J=function(a){return new (a||jy)(q(dy,8),q(Ok),q(gt),q(ey,8))};jy.oa=Ld({la:jy,aa:jy.J,da:"root"});var ky=class{constructor(a){a.i()}};ky.J=function(a){return new (a||ky)(q(by))};ky.Wa=Mf({type:ky});ky.Va=Md({imports:[gy]});function ly(a,b,c){const d=my(a,b);c=c.trim();d.some(e=>e.trim()===c)||(d.push(c),a.setAttribute(b,d.join(" ")))}function ny(a,b,c){var d=my(a,b);c=c.trim();d=d.filter(e=>e!==c);d.length?a.setAttribute(b,d.join(" ")):a.removeAttribute(b)}function my(a,b){let c,d;return null!=(d=null==(c=a.getAttribute(b))?void 0:c.match(/\S+/g))?d:[]};let oy=0;function py(a,b,c,d){if(a.K(b,c)){var e=qy(c,d);"string"!==typeof c?(ry(c,a.Wb),a.i.set(e,{El:c,referenceCount:0})):a.i.has(e)||a.N(c,d);a.D(b,e)||a.G(b,e)}}function sy(a,b,c){if(c&&a.F(b)){var d=qy(c,"tooltip");a.D(b,d)&&a.ba(b,d);"string"===typeof c&&(b=a.i.get(d))&&0===b.referenceCount&&a.R(d);var e;0===(null==(e=a.C)?void 0:e.childNodes.length)&&(a.C.remove(),a.C=null)}}
var ty=class{constructor(a,b){this.Ka=b;this.i=new Map;this.C=null;this.Wb=`${oy++}`;this.ha=a;this.Wb=lf(hi)+"-"+oy++}ua(){const a=this.ha.querySelectorAll(`[${"cdk-describedby-host"}="${this.Wb}"]`);for(let c=0;c<a.length;c++)this.T(a[c]),a[c].removeAttribute("cdk-describedby-host");let b;null==(b=this.C)||b.remove();this.C=null;this.i.clear()}N(a,b){const c=this.ha.createElement("div");ry(c,this.Wb);c.textContent=a;b&&c.setAttribute("role",b);this.O();this.C.appendChild(c);this.i.set(qy(a,b),{El:c,
referenceCount:0})}R(a){let b,c;null==(b=this.i.get(a))||null==(c=b.El)||c.remove();this.i.delete(a)}O(){if(!this.C){var a=this.ha.querySelectorAll('.cdk-describedby-message-container[platform="server"]');for(let b=0;b<a.length;b++)a[b].remove();a=this.ha.createElement("div");a.style.visibility="hidden";a.classList.add("cdk-describedby-message-container");a.classList.add("cdk-visually-hidden");this.Ka&&!this.Ka.isBrowser&&a.setAttribute("platform","server");this.ha.body.appendChild(a);this.C=a}}T(a){const b=
my(a,"aria-describedby").filter(c=>0!=c.indexOf("cdk-describedby-message"));a.setAttribute("aria-describedby",b.join(" "))}G(a,b){b=this.i.get(b);ly(a,"aria-describedby",b.El.id);a.setAttribute("cdk-describedby-host",this.Wb);b.referenceCount++}ba(a,b){b=this.i.get(b);b.referenceCount--;ny(a,"aria-describedby",b.El.id);a.removeAttribute("cdk-describedby-host")}D(a,b){a=my(a,"aria-describedby");b=(b=this.i.get(b))&&b.El.id;return!!b&&-1!=a.indexOf(b)}K(a,b){if(!this.F(a))return!1;if(b&&"object"===
typeof b)return!0;b=null==b?"":`${b}`.trim();a=a.getAttribute("aria-label");return b?!a||a.trim()!==b:!1}F(a){return a.nodeType===this.ha.ELEMENT_NODE}};ty.J=function(a){return new (a||ty)(q(gt),q(St))};ty.oa=Ld({la:ty,aa:ty.J,da:"root"});function qy(a,b){return"string"===typeof a?`${b||""}/${a}`:a}function ry(a,b){a.id||(a.id=`${"cdk-describedby-message"}-${b}-${oy++}`)};var wy=class extends Sx{get enabled(){return this.F}set enabled(a){(this.F=a)?this.N.register(this):uy(this.N,this)}constructor(a,b,c,d,e,f,g){super(a,b,c,d,g.defer);this.N=e;this.T=f;this.N.register(this)}destroy(){uy(this.N,this);super.destroy()}yt(){vy(this.T,this);Rx(this,!0)}xt(){var a=this.T;a.i&&(this.ha.removeEventListener("focus",a.i,!0),a.i=null);Rx(this,!1)}};function vy(a,b){a.i&&b.ha.removeEventListener("focus",a.i,!0);a.i=c=>xy(b,c);Kk(b.pa,()=>{b.ha.addEventListener("focus",a.i,!0)})}function xy(a,b){b=b.target;const c=a.i;let d;!b||c.contains(b)||(null==(d=b.closest)?0:d.call(b,"div.cdk-overlay-pane"))||setTimeout(()=>{a.enabled&&!c.contains(a.ha.activeElement)&&Ox(a)})}var yy=class{constructor(){this.i=null}};var zy=new df("FOCUS_TRAP_INERT_STRATEGY");function uy(a,b){b.xt();a=a.i;b=a.indexOf(b);-1!==b&&(a.splice(b,1),a.length&&a[a.length-1].yt())}var Ay=class{constructor(){this.i=[]}register(a){let b=this.i=this.i.filter(c=>c!==a);b.length&&b[b.length-1].xt();b.push(a);a.yt()}};Ay.J=function(a){return new (a||Ay)};Ay.oa=Ld({la:Ay,aa:Ay.J,da:"root"});var By=class{constructor(a,b,c,d,e){this.i=a;this.pa=b;this.C=c;this.ha=d;this.D=e||new yy}create(a,b={defer:!1}){let c;"boolean"===typeof b?c={defer:b}:c=b;return new wy(a,this.i,this.pa,this.ha,this.C,this.D,c)}};By.J=function(a){return new (a||By)(q(Nx),q(Ok),q(Ay),q(gt),q(zy,8))};By.oa=Ld({la:By,aa:By.J,da:"root"});function Cy(a,b){a.ma=b;return a}function Dy(a){a.Ia=!0;return a}function Ey(a){a.Da=!0;return a}function Fy(a,b){a.ea=b;return a}function Gy(a){a.Oa=["shiftKey"];return a}function Hy(a,b=200){a.va.unsubscribe();a.va=C(a.ia,No(c=>a.F.push(c)),Mn(b),rk(()=>0<a.F.length),vj(()=>a.F.join(""))).subscribe(c=>{const d=a.K();for(let e=1;e<d.length+1;e++){const f=(a.D+e)%d.length,g=d[f];if(!a.ma(g)&&0===g.Vv().toUpperCase().trim().indexOf(c)){a.C(f);break}}a.F=[]});return a}
function Iy(a){a.ta=!0;return a}function Jy(a){a.T={enabled:!0,delta:10};return a}function Ky(a,b){var c=a.K();b="number"===typeof b?b:c.indexOf(b);c=c[b];a.O=null==c?null:c;a.D=b}function Ly(a){0>a.D?a.G(0,1):a.Ta(1)}function My(a){0>a.D&&a.Ia?a.G(a.K().length-1,-1):a.Ta(-1)}
function Ny(a,b){var c=b.keyCode,d=["altKey","ctrlKey","metaKey","shiftKey"].every(e=>!b[e]||-1<a.Oa.indexOf(e));switch(c){case 9:a.ba.next();return;case 40:if(a.Da&&d){Ly(a);break}else return;case 38:if(a.Da&&d){My(a);break}else return;case 39:if(a.ea&&d){"rtl"===a.ea?My(a):Ly(a);break}else return;case 37:if(a.ea&&d){"rtl"===a.ea?Ly(a):My(a);break}else return;case 36:if(a.ta&&d){a.G(0,1);break}else return;case 35:if(a.ta&&d){a.G(a.K().length-1,-1);break}else return;case 33:if(a.T.enabled&&d){c=a.D-
a.T.delta;a.G(0<c?c:0,1);break}else return;case 34:if(a.T.enabled&&d){c=a.D+a.T.delta;d=a.K().length;a.G(c<d?c:d-1,-1);break}else return;default:if(d||yu(b,"shiftKey"))b.key&&1===b.key.length?a.ia.next(b.key.toLocaleUpperCase()):(65<=c&&90>=c||48<=c&&57>=c)&&a.ia.next(String.fromCharCode(c));return}a.F=[];b.preventDefault()}
var Oy=class{constructor(a,b){this.R=a;this.D=-1;this.O=null;this.Ia=!1;this.ia=new aj;this.va=Li.EMPTY;this.Da=!0;this.Oa=[];this.ta=!1;this.T={enabled:!1,delta:10};this.ma=c=>c.disabled;this.F=[];this.ba=new aj;this.vb=new aj;a instanceof Zq?this.fb=a.i.subscribe(c=>this.Ra(c.toArray())):vn(a)&&(this.ab=Gs(()=>this.Ra(a()),{wa:b}))}C(a){const b=this.O;Ky(this,a);this.O!==b&&this.vb.next(this.D)}get N(){return this.D}get i(){return this.O}destroy(){this.va.unsubscribe();let a;null==(a=this.fb)||
a.unsubscribe();let b;null==(b=this.ab)||b.destroy();this.ia.complete();this.ba.complete();this.vb.complete();this.F=[]}Ta(a){this.Ia?this.rb(a):this.kb(a)}rb(a){const b=this.K();for(let c=1;c<=b.length;c++){const d=(this.D+a*c+b.length)%b.length;if(!this.ma(b[d])){this.C(d);break}}}kb(a){this.G(this.D+a,a)}G(a,b){const c=this.K();if(c[a]){for(;this.ma(c[a]);)if(a+=b,!c[a])return;this.C(a)}}K(){return vn(this.R)?this.R():this.R instanceof Zq?this.R.toArray():this.R}Ra(a){this.O&&(a=a.indexOf(this.O),
-1<a&&a!==this.D&&(this.D=a))}};var Py=class extends Oy{C(a){if(this.i){var b=this.i;b.C&&(b.C=!1,Zm(b.Aa))}super.C(a);this.i&&(a=this.i,a.C||(a.C=!0,Zm(a.Aa)))}};var Qy=class extends Oy{constructor(){super(...arguments);this.ra="program"}C(a){super.C(a);this.i&&this.i.focus(this.ra)}};function Ry(a,b){return{type:7,name:a,xB:b,options:{}}}function Sy(a,b=null){return{type:4,styles:b,dg:a}}function Ty(a){return{type:6,styles:a,offset:null}}function Uy(a,b){return{type:0,name:a,styles:b,options:void 0}}function Vy(a,b){return{type:1,LB:a,animation:b,options:null}};function Wy(a){a.F||(a.F=!0,a.i.forEach(b=>b()),a.i=[])}function Xy(a){a.C.forEach(b=>b());a.C=[]}function Yy(a){queueMicrotask(()=>Wy(a))}
var Zy=class{constructor(a=0,b=0){this.i=[];this.C=[];this.G=[];this.N=[];this.O=[];this.F=this.Fa=this.K=!1;this.D=null;this.totalTime=a+b}onStart(a){this.O.push(a);this.C.push(a)}Id(a){this.N.push(a);this.i.push(a)}nb(a){this.G.push(a)}Pf(){return this.K}init(){}play(){this.Pf()||(Xy(this),Yy(this));this.K=!0}pause(){}ke(){}finish(){Wy(this)}destroy(){this.Fa||(this.Fa=!0,this.Pf()||Xy(this),this.finish(),this.G.forEach(a=>a()),this.G=[])}reset(){this.F=this.K=!1;this.C=this.O;this.i=this.N}setPosition(){}oi(a){a=
"start"==a?this.C:this.i;a.forEach(b=>b());a.length=0}};function $y(a){a.G||(a.G=!0,a.C.forEach(b=>b()),a.C=[])}function az(a){a.Fa||(a.Fa=!0,$y(a),a.i.forEach(b=>b.destroy()),a.K.forEach(b=>b()),a.K=[])}function bz(a){a.Pf()||(a.N=!0,a.F.forEach(b=>b()),a.F=[])}
var cz=class{constructor(a){this.C=[];this.F=[];this.Fa=this.N=this.G=!1;this.K=[];this.D=null;this.totalTime=0;this.i=a;let b=0,c=0,d=0;const e=this.i.length;0==e?queueMicrotask(()=>$y(this)):this.i.forEach(f=>{f.Id(()=>{++b==e&&$y(this)});f.nb(()=>{++c==e&&az(this)});f.onStart(()=>{++d==e&&bz(this)})});this.totalTime=this.i.reduce((f,g)=>Math.max(f,g.totalTime),0)}init(){this.i.forEach(a=>a.init())}onStart(a){this.F.push(a)}Id(a){this.C.push(a)}nb(a){this.K.push(a)}Pf(){return this.N}play(){this.D||
this.init();bz(this);this.i.forEach(a=>a.play())}pause(){this.i.forEach(a=>a.pause())}ke(){this.i.forEach(a=>a.ke())}finish(){$y(this);this.i.forEach(a=>a.finish())}destroy(){az(this)}reset(){this.i.forEach(a=>a.reset());this.N=this.G=this.Fa=!1}setPosition(a){const b=a*this.totalTime;this.i.forEach(c=>{c.setPosition(c.totalTime?Math.min(1,b/c.totalTime):1)})}Jk(){this.i.forEach(a=>{a.Jk&&a.Jk()})}oi(a){a="start"==a?this.F:this.C;a.forEach(b=>b());a.length=0}};var dz=Ry("panelAnimation",[Uy("void, hidden",Ty({opacity:0,transform:"scaleY(0.8)"})),Vy(":enter, hidden => visible",[function(a,b=null){return{type:3,steps:a,options:b}}([Sy("0.03s linear",Ty({opacity:1})),Sy("0.12s cubic-bezier(0, 0, 0.2, 1)",Ty({transform:"scaleY(1)"}))])]),Vy(":leave, visible => hidden",[Sy("0.075s linear",Ty({opacity:0}))])]);var ez=new df("mat-sanity-checks",{da:"root",aa:function(){return!0}}),fz=class{constructor(a,b,c){this.i=b;this.ha=c;this.C=!1;a.i();this.C||(this.C=!0)}D(a){return Qt()?!1:"boolean"===typeof this.i?this.i:!!this.i[a]}};fz.J=function(a){return new (a||fz)(q(by),q(ez,8),q(gt))};fz.Wa=Mf({type:fz});fz.Va=Md({imports:[mu,mu]});var gz=class{constructor(a,b,c,d,e){this.C=a;this.Hd=b;this.F=c;this.D=d;this.i=e;this.we=!1}};new df("MAT_DATE_LOCALE",{da:"root",aa:hz});function hz(){return lf(ls)};new df("mat-date-formats");var iz=class{};iz.J=function(a){return new (a||iz)};iz.oa=Ld({la:iz,aa:iz.J,da:"root"});var jz=class{};jz.J=function(a){return new (a||jz)};
jz.Ca=Gf({type:jz,ga:[["div","mat-internal-form-field",""]],Ja:[1,"mdc-form-field","mat-internal-form-field"],Xa:2,Ha:function(a,b){a&2&&lq("mdc-form-field--align-end","before"===b.Lh)},inputs:{Lh:"labelPosition"},ja:!0,features:[Jr],attrs:["mat-internal-form-field",""],Yb:["*"],ya:1,za:0,sa:function(a){a&1&&(Vq(),Wq(0))},styles:[".mdc-form-field{display:inline-flex;align-items:center;vertical-align:middle}.mdc-form-field[hidden]{display:none}.mdc-form-field>label{margin-left:0;margin-right:auto;padding-left:4px;padding-right:0;order:0;cursor:inherit}[dir=rtl] .mdc-form-field>label,.mdc-form-field>label[dir=rtl]{margin-left:auto;margin-right:0}[dir=rtl] .mdc-form-field>label,.mdc-form-field>label[dir=rtl]{padding-left:0;padding-right:4px}.mdc-form-field--nowrap>label{text-overflow:ellipsis;overflow:hidden;white-space:nowrap}.mdc-form-field--align-end>label{margin-left:auto;margin-right:0;padding-left:0;padding-right:4px;order:-1}[dir=rtl] .mdc-form-field--align-end>label,.mdc-form-field--align-end>label[dir=rtl]{margin-left:0;margin-right:auto}[dir=rtl] .mdc-form-field--align-end>label,.mdc-form-field--align-end>label[dir=rtl]{padding-left:4px;padding-right:0}.mdc-form-field--space-between{justify-content:space-between}.mdc-form-field--space-between>label{margin:0}[dir=rtl] .mdc-form-field--space-between>label,.mdc-form-field--space-between>label[dir=rtl]{margin:0}.mdc-form-field{font-family:var(--mdc-form-field-label-text-font);line-height:var(--mdc-form-field-label-text-line-height);font-size:var(--mdc-form-field-label-text-size);font-weight:var(--mdc-form-field-label-text-weight);letter-spacing:var(--mdc-form-field-label-text-tracking);color:var(--mdc-form-field-label-text-color)}.mat-internal-form-field{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased}\n"],ob:2,
Qa:0});var kz=new df("MAT_OPTION_PARENT_COMPONENT");const lz=["*",[["mat-option"],["ng-container"]]];let mz=0;var nz=new df("MatOptgroup"),oz=class{constructor(a){this.disabled=!1;this.Te=`mat-optgroup-label-${mz++}`;let b;this.zm=null!=(b=null==a?void 0:a.oC)?b:!1}};oz.J=function(a){return new (a||oz)(y(kz,8))};
oz.Ca=Gf({type:oz,ga:[["mat-optgroup"]],Ja:[1,"mat-mdc-optgroup"],Xa:3,Ha:function(a,b){a&2&&Ip("role",b.zm?null:"group")("aria-disabled",b.zm?null:b.disabled.toString())("aria-labelledby",b.zm?null:b.Te)},inputs:{label:"label",disabled:[2,"disabled","disabled",ws]},hb:["matOptgroup"],ja:!0,features:[Hr([{na:nz,zb:oz}]),Hp,Jr],Yb:["*","mat-option, ng-container"],ya:5,za:4,Ba:[["role","presentation",1,"mat-mdc-optgroup-label",3,"id"],[1,"mdc-list-item__primary-text"]],sa:function(a,b){a&1&&(Vq(lz),
R(0,"span",0)(1,"span",1),Z(2),Wq(3),S()(),Wq(4,1));a&2&&(lq("mdc-list-item--disabled",b.disabled),H("id",b.Te),D(2),yr("",b.label," "))},styles:[".mat-mdc-optgroup{color:var(--mat-optgroup-label-text-color);font-family:var(--mat-optgroup-label-text-font);line-height:var(--mat-optgroup-label-text-line-height);font-size:var(--mat-optgroup-label-text-size);letter-spacing:var(--mat-optgroup-label-text-tracking);font-weight:var(--mat-optgroup-label-text-weight)}.mat-mdc-optgroup-label{display:flex;position:relative;align-items:center;justify-content:flex-start;overflow:hidden;padding:0;padding-left:16px;padding-right:16px;min-height:48px}.mat-mdc-optgroup-label:focus{outline:none}[dir=rtl] .mat-mdc-optgroup-label,.mat-mdc-optgroup-label[dir=rtl]{padding-left:16px;padding-right:16px}.mat-mdc-optgroup-label.mdc-list-item--disabled{opacity:.38}.mat-mdc-optgroup-label .mdc-list-item__primary-text{font-size:inherit;font-weight:inherit;letter-spacing:inherit;line-height:inherit;font-family:inherit;text-decoration:inherit;text-transform:inherit;white-space:normal}\n"],
ob:2,Qa:0});const pz=Ht({passive:!0,capture:!0});function qz(a,b,c,d){var e=rz;const f=e.Ab.get(b);f?(a=f.get(c))?a.add(d):f.set(c,new Set([d])):(e.Ab.set(b,new Map([[c,new Set([d])]])),Kk(a,()=>{document.addEventListener(b,e.i,pz)}))}var sz=class{constructor(){this.Ab=new Map;this.i=a=>{const b=Pt(a);if(b){let c;null==(c=this.Ab.get(a.type))||c.forEach((d,e)=>{(e===b||e.contains(b))&&d.forEach(f=>f.handleEvent(a))})}}}};var tz=class{constructor(a,b,c,d=!1){this.i=a;this.element=b;this.config=c;this.C=d;this.state=3}};var uz={Mv:225,tn:150};const vz=Ht({passive:!0,capture:!0}),wz=["mousedown","touchstart"],xz=["mouseup","mouseleave","touchend","touchcancel"];function yz(a,b){if(2!==b.state&&3!==b.state){var c=b.element,d=Object.assign({},uz,b.config.animation);c.style.transitionDuration=`${d.tn}ms`;c.style.opacity="0";b.state=2;!b.C&&d.tn||a.np(b)}}
function zz(a,b,c,d={}){var e=a.Ei=a.Ei||a.Di.getBoundingClientRect();const f=Object.assign({},uz,d.animation);d.Wi&&(b=e.left+e.width/2,c=e.top+e.height/2);var g=d.radius||Az(b,c,e);b-=e.left;const k=c-e.top;c=f.Mv;const m=document.createElement("div");m.classList.add("mat-ripple-element");m.style.left=`${b-g}px`;m.style.top=`${k-g}px`;m.style.height=`${2*g}px`;m.style.width=`${2*g}px`;null!=d.color&&(m.style.backgroundColor=d.color);m.style.transitionDuration=`${c}ms`;a.Di.appendChild(m);g=window.getComputedStyle(m);
b=g.transitionDuration;e="none"===g.transitionProperty||"0s"===b||"0s, 0s"===b||0===e.width&&0===e.height;const p=new tz(a,m,d,e);m.style.transform="scale3d(1, 1, 1)";p.state=0;d.Nr||(a.Cp=p);let t=null;e||!c&&!f.tn||Kk(a.pa,()=>{const v=()=>a.np(p),B=()=>a.wt(p);m.addEventListener("transitionend",v);m.addEventListener("transitioncancel",B);t={iD:v,hD:B}});a.kk.set(p,t);!e&&c||a.np(p)}function Bz(a,b){const c=Ps(b);a.Ka.isBrowser&&c&&c!==a.Pi&&(a.iu(),a.Pi=c,wz.forEach(d=>{qz(a.pa,d,c,a)}))}
var Cz=class{constructor(a,b,c,d){this.Om=a;this.pa=b;this.Ka=d;this.uk=!1;this.kk=new Map;this.Jm=!1;d.isBrowser&&(this.Di=Ps(c))}Eq(){this.Ct().forEach(a=>{a.config.Nr||yz(a.i,a)})}handleEvent(a){"mousedown"===a.type?this.Gm(a):"touchstart"===a.type?this.rA(a):this.qA();this.Jm||(Kk(this.pa,()=>{xz.forEach(b=>{this.Pi.addEventListener(b,this,vz)})}),this.Jm=!0)}np(a){0===a.state?this.IA(a):2===a.state&&this.wt(a)}IA(a){const b=a===this.Cp,c=a.config.Nr;a.state=1;c||b&&this.uk||yz(a.i,a)}wt(a){let b;
const c=null!=(b=this.kk.get(a))?b:null;this.kk.delete(a);this.kk.size||(this.Ei=null);a===this.Cp&&(this.Cp=null);a.state=3;null!==c&&(a.element.removeEventListener("transitionend",c.iD),a.element.removeEventListener("transitioncancel",c.hD));a.element.remove()}Gm(a){const b=xx(a),c=this.au&&Date.now()<this.au+800;this.Om.xx||b||c||(this.uk=!0,zz(this,a.clientX,a.clientY,this.Om.wx))}rA(a){if(!this.Om.xx&&!yx(a)&&(this.au=Date.now(),this.uk=!0,a=a.changedTouches))for(let b=0;b<a.length;b++)zz(this,
a[b].clientX,a[b].clientY,this.Om.wx)}qA(){this.uk&&(this.uk=!1,this.Ct().forEach(a=>{const b=1===a.state||a.config.ly&&0===a.state;!a.config.Nr&&b&&yz(a.i,a)}))}Ct(){return Array.from(this.kk.keys())}iu(){const a=this.Pi;a&&(wz.forEach(b=>{var c=rz;const d=c.Ab.get(b);if(d){var e=d.get(a);e&&(e.delete(this),0===e.size&&d.delete(a),0===d.size&&(c.Ab.delete(b),document.removeEventListener(b,c.i,pz)))}}),this.Jm&&(xz.forEach(b=>a.removeEventListener(b,this,vz)),this.Jm=!1))}},rz=new sz;
function Az(a,b,c){a=Math.max(Math.abs(a-c.left),Math.abs(a-c.right));b=Math.max(Math.abs(b-c.top),Math.abs(b-c.bottom));return Math.sqrt(a*a+b*b)};var Dz=new df("mat-ripple-global-options"),Ez=class{get disabled(){return this.Hb}set disabled(a){a&&this.Eq();this.Hb=a;this.F()}get Ke(){return this.G||this.qa.P}set Ke(a){this.G=a;this.F()}constructor(a,b,c,d,e){this.qa=a;this.Yc=e;this.radius=0;this.i=this.Hb=!1;this.C=d||{};this.D=new Cz(this,b,a,c)}Eb(){this.i=!0;this.F()}ua(){this.D.iu()}Eq(){this.D.Eq()}get wx(){return{Wi:this.Wi,radius:this.radius,color:this.color,animation:Object.assign({},this.C.animation,"NoopAnimations"===this.Yc?{Mv:0,
tn:0}:{},this.animation),ly:this.C.ly}}get xx(){return this.disabled||!!this.C.disabled}F(){!this.disabled&&this.i&&Bz(this.D,this.Ke)}};Ez.J=function(a){return new (a||Ez)(y(qi),y(Ok),y(St),y(Dz,8),y(ki,8))};
Ez.Ea=Of({type:Ez,ga:[["","mat-ripple",""],["","matRipple",""]],Ja:[1,"mat-ripple"],Xa:2,Ha:function(a,b){a&2&&lq("mat-ripple-unbounded",b.KE)},inputs:{color:[0,"matRippleColor","color"],KE:[0,"matRippleUnbounded","unbounded"],Wi:[0,"matRippleCentered","centered"],radius:[0,"matRippleRadius","radius"],animation:[0,"matRippleAnimation","animation"],disabled:[0,"matRippleDisabled","disabled"],Ke:[0,"matRippleTrigger","trigger"]},hb:["matRipple"],ja:!0});var Fz=class{constructor(a){this.Yc=a;this.state="unchecked";this.disabled=!1;this.Dd="full"}};Fz.J=function(a){return new (a||Fz)(y(ki,8))};
Fz.Ca=Gf({type:Fz,ga:[["mat-pseudo-checkbox"]],Ja:[1,"mat-pseudo-checkbox"],Xa:12,Ha:function(a,b){a&2&&lq("mat-pseudo-checkbox-indeterminate","indeterminate"===b.state)("mat-pseudo-checkbox-checked","checked"===b.state)("mat-pseudo-checkbox-disabled",b.disabled)("mat-pseudo-checkbox-minimal","minimal"===b.Dd)("mat-pseudo-checkbox-full","full"===b.Dd)("_mat-animation-noopable","NoopAnimations"===b.Yc)},inputs:{state:"state",disabled:"disabled",Dd:"appearance"},ja:!0,features:[Jr],ya:0,za:0,sa:function(){},
styles:['.mat-pseudo-checkbox{border-radius:2px;cursor:pointer;display:inline-block;vertical-align:middle;box-sizing:border-box;position:relative;flex-shrink:0;transition:border-color 90ms cubic-bezier(0, 0, 0.2, 0.1),background-color 90ms cubic-bezier(0, 0, 0.2, 0.1)}.mat-pseudo-checkbox::after{position:absolute;opacity:0;content:"";border-bottom:2px solid currentColor;transition:opacity 90ms cubic-bezier(0, 0, 0.2, 0.1)}.mat-pseudo-checkbox._mat-animation-noopable{transition:none !important;animation:none !important}.mat-pseudo-checkbox._mat-animation-noopable::after{transition:none}.mat-pseudo-checkbox-disabled{cursor:default}.mat-pseudo-checkbox-indeterminate::after{left:1px;opacity:1;border-radius:2px}.mat-pseudo-checkbox-checked::after{left:1px;border-left:2px solid currentColor;transform:rotate(-45deg);opacity:1;box-sizing:content-box}.mat-pseudo-checkbox-minimal.mat-pseudo-checkbox-checked::after,.mat-pseudo-checkbox-minimal.mat-pseudo-checkbox-indeterminate::after{color:var(--mat-minimal-pseudo-checkbox-selected-checkmark-color)}.mat-pseudo-checkbox-minimal.mat-pseudo-checkbox-checked.mat-pseudo-checkbox-disabled::after,.mat-pseudo-checkbox-minimal.mat-pseudo-checkbox-indeterminate.mat-pseudo-checkbox-disabled::after{color:var(--mat-minimal-pseudo-checkbox-disabled-selected-checkmark-color)}.mat-pseudo-checkbox-full{border-color:var(--mat-full-pseudo-checkbox-unselected-icon-color);border-width:2px;border-style:solid}.mat-pseudo-checkbox-full.mat-pseudo-checkbox-disabled{border-color:var(--mat-full-pseudo-checkbox-disabled-unselected-icon-color)}.mat-pseudo-checkbox-full.mat-pseudo-checkbox-checked,.mat-pseudo-checkbox-full.mat-pseudo-checkbox-indeterminate{background-color:var(--mat-full-pseudo-checkbox-selected-icon-color);border-color:rgba(0,0,0,0)}.mat-pseudo-checkbox-full.mat-pseudo-checkbox-checked::after,.mat-pseudo-checkbox-full.mat-pseudo-checkbox-indeterminate::after{color:var(--mat-full-pseudo-checkbox-selected-checkmark-color)}.mat-pseudo-checkbox-full.mat-pseudo-checkbox-checked.mat-pseudo-checkbox-disabled,.mat-pseudo-checkbox-full.mat-pseudo-checkbox-indeterminate.mat-pseudo-checkbox-disabled{background-color:var(--mat-full-pseudo-checkbox-disabled-selected-icon-color)}.mat-pseudo-checkbox-full.mat-pseudo-checkbox-checked.mat-pseudo-checkbox-disabled::after,.mat-pseudo-checkbox-full.mat-pseudo-checkbox-indeterminate.mat-pseudo-checkbox-disabled::after{color:var(--mat-full-pseudo-checkbox-disabled-selected-checkmark-color)}.mat-pseudo-checkbox{width:18px;height:18px}.mat-pseudo-checkbox-minimal.mat-pseudo-checkbox-checked::after{width:14px;height:6px;transform-origin:center;top:-4.2426406871px;left:0;bottom:0;right:0;margin:auto}.mat-pseudo-checkbox-minimal.mat-pseudo-checkbox-indeterminate::after{top:8px;width:16px}.mat-pseudo-checkbox-full.mat-pseudo-checkbox-checked::after{width:10px;height:4px;transform-origin:center;top:-2.8284271247px;left:0;bottom:0;right:0;margin:auto}.mat-pseudo-checkbox-full.mat-pseudo-checkbox-indeterminate::after{top:6px;width:12px}\n'],
ob:2,Qa:0});const Gz=["text"],Hz=[[["mat-icon"]],"*"];function Iz(a){a&1&&Kq(0,"mat-pseudo-checkbox",1);a&2&&(a=Y(),H("disabled",a.disabled)("state",a.selected?"checked":"unchecked"))}function Jz(a){a&1&&Kq(0,"mat-pseudo-checkbox",3);a&2&&(a=Y(),H("disabled",a.disabled))}function Kz(a){a&1&&(R(0,"span",4),Z(1),S());a&2&&(a=Y(),D(),yr("(",a.group.label,")"))}let Lz=0;var Mz=class{constructor(a,b=!1){this.source=a;this.i=b}};function Nz(a,b=!0){a.i&&(a.i=!1,Zm(a.Aa),b&&a.G())}
var Oz=class{get multiple(){return this.Pa&&this.Pa.multiple}get selected(){return this.i}get disabled(){return this.group&&this.group.disabled||this.Hb}set disabled(a){this.Hb=a}get Lc(){return!(!this.Pa||!this.Pa.Lc)}get ze(){return!(!this.Pa||!this.Pa.ze)}constructor(a,b,c,d){this.N=a;this.Aa=b;this.Pa=c;this.group=d;this.Hb=this.C=this.i=!1;this.K="";this.id=`mat-option-${Lz++}`;this.io=new Dk;this.F=new aj}get active(){return this.C}get D(){let a;return((null==(a=this.MA)?void 0:a.P.textContent)||
"").trim()}select(a=!0){this.i||(this.i=!0,Zm(this.Aa),a&&this.G())}focus(a,b){const c=this.pe();"function"===typeof c.focus&&c.focus(b)}Vv(){return this.D}Re(a){13!==a.keyCode&&32!==a.keyCode||yu(a)||(this.uh(),a.preventDefault())}uh(){this.disabled||(this.i=this.multiple?!this.i:!0,Zm(this.Aa),this.G(!0))}Gt(){return this.disabled?"-1":"0"}pe(){return this.N.P}Lw(){if(this.i){const a=this.D;a!==this.K&&(this.K&&this.F.next(),this.K=a)}}ua(){this.F.complete()}G(a=!1){this.io.emit(new Mz(this,a))}};
Oz.J=function(a){return new (a||Oz)(y(qi),y(Pr),y(kz,8),y(nz,8))};
Oz.Ca=Gf({type:Oz,ga:[["mat-option"]],eb:function(a,b){a&1&&rr(Gz,7);if(a&2){let c;sr(c=tr())&&(b.MA=c.first)}},Ja:["role","option",1,"mat-mdc-option","mdc-list-item"],Xa:11,Ha:function(a,b){a&1&&V("click",function(){return b.uh()})("keydown",function(c){return b.Re(c)});a&2&&(Oq("id",b.id),Ip("aria-selected",b.selected)("aria-disabled",b.disabled.toString()),lq("mdc-list-item--selected",b.selected)("mat-mdc-option-multiple",b.multiple)("mat-mdc-option-active",b.active)("mdc-list-item--disabled",
b.disabled))},inputs:{value:"value",id:"id",disabled:[2,"disabled","disabled",ws]},outputs:{io:"onSelectionChange"},hb:["matOption"],ja:!0,features:[Hp,Jr],Yb:["mat-icon","*"],ya:8,za:5,Ba:[["text",""],["aria-hidden","true",1,"mat-mdc-option-pseudo-checkbox",3,"disabled","state"],[1,"mdc-list-item__primary-text"],["state","checked","aria-hidden","true","appearance","minimal",1,"mat-mdc-option-pseudo-checkbox",3,"disabled"],[1,"cdk-visually-hidden"],["aria-hidden","true","mat-ripple","",1,"mat-mdc-option-ripple",
"mat-mdc-focus-indicator",3,"matRippleTrigger","matRippleDisabled"]],sa:function(a,b){a&1&&(Vq(Hz),yp(0,Iz,1,2,"mat-pseudo-checkbox",1),Wq(1),R(2,"span",2,0),Wq(4,1),S(),yp(5,Jz,1,1,"mat-pseudo-checkbox",3)(6,Kz,2,1,"span",4),Kq(7,"div",5));a&2&&(Cq(b.multiple?0:-1),D(5),Cq(b.multiple||!b.selected||b.ze?-1:5),D(),Cq(b.group&&b.group.zm?6:-1),D(),H("matRippleTrigger",b.pe())("matRippleDisabled",b.disabled||b.Lc))},Ga:[Fz,Ez],styles:['.mat-mdc-option{display:flex;position:relative;align-items:center;justify-content:flex-start;overflow:hidden;padding:0;padding-left:16px;padding-right:16px;-webkit-user-select:none;user-select:none;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;cursor:pointer;-webkit-tap-highlight-color:rgba(0,0,0,0);color:var(--mat-option-label-text-color);font-family:var(--mat-option-label-text-font);line-height:var(--mat-option-label-text-line-height);font-size:var(--mat-option-label-text-size);letter-spacing:var(--mat-option-label-text-tracking);font-weight:var(--mat-option-label-text-weight);min-height:48px}.mat-mdc-option:focus{outline:none}[dir=rtl] .mat-mdc-option,.mat-mdc-option[dir=rtl]{padding-left:16px;padding-right:16px}.mat-mdc-option:hover:not(.mdc-list-item--disabled){background-color:var(--mat-option-hover-state-layer-color)}.mat-mdc-option:focus.mdc-list-item,.mat-mdc-option.mat-mdc-option-active.mdc-list-item{background-color:var(--mat-option-focus-state-layer-color)}.mat-mdc-option.mdc-list-item--selected:not(.mdc-list-item--disabled) .mdc-list-item__primary-text{color:var(--mat-option-selected-state-label-text-color)}.mat-mdc-option.mdc-list-item--selected:not(.mdc-list-item--disabled):not(.mat-mdc-option-multiple){background-color:var(--mat-option-selected-state-layer-color)}.mat-mdc-option.mdc-list-item{align-items:center;background:rgba(0,0,0,0)}.mat-mdc-option.mdc-list-item--disabled{cursor:default;pointer-events:none}.mat-mdc-option.mdc-list-item--disabled .mat-mdc-option-pseudo-checkbox,.mat-mdc-option.mdc-list-item--disabled .mdc-list-item__primary-text,.mat-mdc-option.mdc-list-item--disabled>mat-icon{opacity:.38}.mat-mdc-optgroup .mat-mdc-option:not(.mat-mdc-option-multiple){padding-left:32px}[dir=rtl] .mat-mdc-optgroup .mat-mdc-option:not(.mat-mdc-option-multiple){padding-left:16px;padding-right:32px}.mat-mdc-option .mat-icon,.mat-mdc-option .mat-pseudo-checkbox-full{margin-right:16px;flex-shrink:0}[dir=rtl] .mat-mdc-option .mat-icon,[dir=rtl] .mat-mdc-option .mat-pseudo-checkbox-full{margin-right:0;margin-left:16px}.mat-mdc-option .mat-pseudo-checkbox-minimal{margin-left:16px;flex-shrink:0}[dir=rtl] .mat-mdc-option .mat-pseudo-checkbox-minimal{margin-right:16px;margin-left:0}.mat-mdc-option .mat-mdc-option-ripple{top:0;left:0;right:0;bottom:0;position:absolute;pointer-events:none}.mat-mdc-option .mdc-list-item__primary-text{white-space:normal;font-size:inherit;font-weight:inherit;letter-spacing:inherit;line-height:inherit;font-family:inherit;text-decoration:inherit;text-transform:inherit;margin-right:auto}[dir=rtl] .mat-mdc-option .mdc-list-item__primary-text{margin-right:0;margin-left:auto}.cdk-high-contrast-active .mat-mdc-option.mdc-list-item--selected:not(.mat-mdc-option-multiple)::after{content:"";position:absolute;top:50%;right:16px;transform:translateY(-50%);width:10px;height:0;border-bottom:solid 10px;border-radius:10px}[dir=rtl] .cdk-high-contrast-active .mat-mdc-option.mdc-list-item--selected:not(.mat-mdc-option-multiple)::after{right:auto;left:16px}.mat-mdc-option-multiple{--mdc-list-list-item-selected-container-color:var(--mdc-list-list-item-container-color, transparent)}.mat-mdc-option-active .mat-mdc-focus-indicator::before{content:""}\n'],
ob:2,Qa:0});function Pz(a,b,c){if(c.length){b=b.toArray();c=c.toArray();let d=0;for(let e=0;e<a+1;e++)b[e].group&&b[e].group===c[d]&&d++;return d}return 0}function Qz(a,b,c,d){return a<c?a:a+b>c+d?Math.max(0,a-d+b):c};var Rz=class{};Rz.J=function(a){return new (a||Rz)};Rz.Wa=Mf({type:Rz});Rz.Va=Md({imports:[fz,fz]});var Sz=class{};Sz.J=function(a){return new (a||Sz)};Sz.Wa=Mf({type:Sz});Sz.Va=Md({imports:[fz]});var Tz=class{};Tz.J=function(a){return new (a||Tz)};Tz.Wa=Mf({type:Tz});Tz.Va=Md({imports:[Rz,fz,Sz,Oz]});const Uz={capture:!0},Vz=["focus","mousedown","mouseenter","touchstart"];function Wz(a,b){const c=a.i.get(b);c&&(c.ua(),a.i.delete(b))}function Xz(a,b,c){let d,e;b.setAttribute("mat-ripple-loader-uninitialized",null!=(e=null==(d=a.C)?void 0:d.namespace)?e:"");!c.className&&b.hasAttribute("mat-ripple-loader-class-name")||b.setAttribute("mat-ripple-loader-class-name",c.className||"");c.Wi&&b.setAttribute("mat-ripple-loader-centered","");c.disabled&&b.setAttribute("mat-ripple-loader-disabled","")}
function Yz(a,b,c){b.removeAttribute("mat-ripple-loader-uninitialized");a.i.set(b,c)}
var Zz=class{constructor(){this.ha=lf(gt,{optional:!0});this.Yc=lf(ki,{optional:!0});this.C=lf(Dz,{optional:!0});this.Ka=lf(St);this.pa=lf(Ok);this.i=new Map;this.F=a=>{a=Pt(a);if(a instanceof HTMLElement){let b,c;(a=a.closest(`[${"mat-ripple-loader-uninitialized"}="${null!=(c=null==(b=this.C)?void 0:b.namespace)?c:""}"]`))&&this.D(a)}};Kk(this.pa,()=>{for(const a of Vz){let b;null==(b=this.ha)||b.addEventListener(a,this.F,Uz)}})}ua(){const a=this.i.keys();for(const b of a)Wz(this,b);for(const b of Vz){let c;
null==(c=this.ha)||c.removeEventListener(b,this.F,Uz)}}D(a){if(this.ha){var b=this.i.get(a);if(b)return b;var c;null==(c=a.querySelector(".mat-ripple"))||c.remove();b=this.ha.createElement("span");b.classList.add("mat-ripple",a.getAttribute("mat-ripple-loader-class-name"));a.append(b);b=new Ez(new qi(b),this.pa,this.Ka,this.C?this.C:void 0,this.Yc?this.Yc:void 0);b.i=!0;b.Ke=a;b.Wi=a.hasAttribute("mat-ripple-loader-centered");b.disabled=a.hasAttribute("mat-ripple-loader-disabled");Yz(this,a,b);return b}}};
Zz.J=function(a){return new (a||Zz)};Zz.oa=Ld({la:Zz,aa:Zz.J,da:"root"});const $z=["panel"];function aA(a,b){if(a&1){const c=Tg();R(0,"div",1,0);V("@panelAnimation.done",function(d){u(c);const e=Y();return x(e.hg.next(d))});Wq(2);S()}a&2&&(a=b.id,b=Y(),oq(rq,b.Oe),lq("mat-mdc-autocomplete-visible",b.Yl)("mat-mdc-autocomplete-hidden",!b.Yl)("mat-primary","primary"===b.mh)("mat-accent","accent"===b.mh)("mat-warn","warn"===b.mh),H("id",b.id)("@panelAnimation",b.rw?"visible":"hidden"),Ip("aria-label",b.ariaLabel||null)("aria-labelledby",b.qp(a)))}let bA=0;
var cA=class{constructor(a,b){this.source=a;this.Pw=b}},eA=new df("mat-autocomplete-default-options",{da:"root",aa:dA});function dA(){return{Rm:!1,Tm:!1,ze:!1,Kj:!1}}
var fA=class{get rw(){return this.C&&this.Yl}ea(a){this.mh=a;Zm(this.Aa)}set classList(a){this.Oe=a;this.qa.P.className=""}get ze(){return this.D}set ze(a){this.D=a;if(this.options)for(const b of this.options)Zm(b.Aa)}constructor(a,b,c,d){this.Aa=a;this.qa=b;this.O=c;this.F=Li.EMPTY;this.hg=new Dk;this.C=this.Yl=!1;this.wq=null;this.Rw=new Dk;this.gf=new Dk;this.closed=new Dk;this.Qw=new Dk;this.id=`mat-autocomplete-${bA++}`;this.oC=(null==d?void 0:d.R)||!1;this.Rm=!!c.Rm;this.Tm=!!c.Tm;this.Kj=!!c.Kj;
let e;this.D=null!=(e=this.O.ze)?e:!1}yj(){this.i=Cy(Dy(new Py(this.options)),this.R);this.F=this.i.vb.subscribe(a=>{this.rw&&this.Qw.emit({source:this,Pw:this.options.toArray()[a]||null})});this.N()}ua(){let a;null==(a=this.i)||a.destroy();this.F.unsubscribe();this.hg.complete()}K(a){this.Wf&&(this.Wf.P.scrollTop=a)}ba(){return this.Wf?this.Wf.P.scrollTop:0}N(){this.Yl=!!this.options.length;Zm(this.Aa)}T(a){this.Rw.emit(new cA(this,a))}qp(a){return this.ariaLabel?null:this.ad?(a?a+" ":"")+this.ad:
a}R(){return!1}};fA.J=function(a){return new (a||fA)(y(Pr),y(qi),y(eA),y(St))};
fA.Ca=Gf({type:fA,ga:[["mat-autocomplete"]],cc:function(a,b,c){a&1&&(qr(c,Oz,5),qr(c,nz,5));if(a&2){let d;sr(d=tr())&&(b.options=d);sr(d=tr())&&(b.Hr=d)}},eb:function(a,b){a&1&&(rr($q,7),rr($z,5));if(a&2){let c;sr(c=tr())&&(b.sa=c.first);sr(c=tr())&&(b.Wf=c.first)}},Ja:[1,"mat-mdc-autocomplete"],inputs:{ariaLabel:[0,"aria-label","ariaLabel"],ad:[0,"aria-labelledby","ariaLabelledby"],wq:"displayWith",Rm:[2,"autoActiveFirstOption","autoActiveFirstOption",ws],Tm:[2,"autoSelectActiveOption","autoSelectActiveOption",
ws],Kj:[2,"requireSelection","requireSelection",ws],Gg:"panelWidth",Lc:[2,"disableRipple","disableRipple",ws],classList:[0,"class","classList"],ze:[2,"hideSingleSelectionIndicator","hideSingleSelectionIndicator",ws]},outputs:{Rw:"optionSelected",gf:"opened",closed:"closed",Qw:"optionActivated"},hb:["matAutocomplete"],ja:!0,features:[Hr([{na:kz,zb:fA}]),Hp,Jr],Yb:["*"],ya:1,za:0,Ba:[["panel",""],["role","listbox",1,"mat-mdc-autocomplete-panel","mdc-menu-surface","mdc-menu-surface--open",3,"id"]],sa:function(a){a&
1&&(Vq(),yp(0,aA,3,16,"ng-template"))},styles:["div.mat-mdc-autocomplete-panel{width:100%;max-height:256px;visibility:hidden;transform-origin:center top;overflow:auto;padding:8px 0;box-sizing:border-box;position:static;border-radius:var(--mat-autocomplete-container-shape);box-shadow:var(--mat-autocomplete-container-elevation-shadow);background-color:var(--mat-autocomplete-background-color)}.cdk-high-contrast-active div.mat-mdc-autocomplete-panel{outline:solid 1px}.cdk-overlay-pane:not(.mat-mdc-autocomplete-panel-above) div.mat-mdc-autocomplete-panel{border-top-left-radius:0;border-top-right-radius:0}.mat-mdc-autocomplete-panel-above div.mat-mdc-autocomplete-panel{border-bottom-left-radius:0;border-bottom-right-radius:0;transform-origin:center bottom}div.mat-mdc-autocomplete-panel.mat-mdc-autocomplete-visible{visibility:visible}div.mat-mdc-autocomplete-panel.mat-mdc-autocomplete-hidden{visibility:hidden;pointer-events:none}mat-autocomplete{display:none}\n"],
ob:2,data:{animation:[dz]},Qa:0});var gA=new df("MatError");let hA=0;var iA=class{constructor(){this.align="start";this.id=`mat-mdc-hint-${hA++}`}};iA.J=function(a){return new (a||iA)};iA.Ea=Of({type:iA,ga:[["mat-hint"]],Ja:[1,"mat-mdc-form-field-hint","mat-mdc-form-field-bottom-align"],Xa:4,Ha:function(a,b){a&2&&(Oq("id",b.id),Ip("align",null),lq("mat-mdc-form-field-hint-end","end"===b.align))},inputs:{align:"align",id:"id"},ja:!0});var jA=class{};jA.J=function(a){return new (a||jA)};jA.Ea=Of({type:jA,ga:[["mat-label"]],ja:!0});var kA=new df("MatPrefix");var lA=new df("MatSuffix");var mA=Ry("transitionMessages",[Uy("enter",Ty({opacity:1,transform:"translateY(0%)"})),Vy("void => enter",[Ty({opacity:0,transform:"translateY(-5px)"}),Sy("300ms cubic-bezier(0.55, 0, 0.55, 0.2)")])]);var nA=class{};nA.J=function(a){return new (a||nA)};nA.Ea=Of({type:nA});class oA{constructor(a){this.F=a;this.Fa=new aj;this.C=new aj;this.i=new Map;"undefined"!==typeof ResizeObserver&&(this.D=new ResizeObserver(b=>this.C.next(b)))}observe(a){this.i.has(a)||this.i.set(a,C(new Vi(b=>{const c=this.C.subscribe(b);let d;null==(d=this.D)||d.observe(a,{box:this.F});return()=>{let e;null==(e=this.D)||e.unobserve(a);c.unsubscribe();this.i.delete(a)}}),rk(b=>b.some(c=>c.target===a)),Ao(),Jo(this.Fa)));return this.i.get(a)}destroy(){this.Fa.next();this.Fa.complete();this.C.complete();
this.i.clear()}}var pA=class{constructor(){this.i=new Map;this.pa=lf(Ok)}ua(){for(const [,a]of this.i)a.destroy();this.i.clear()}observe(a,b){b=(null==b?void 0:b.box)||"content-box";this.i.has(b)||this.i.set(b,new oA(b));return this.i.get(b).observe(a)}};pA.J=function(a){return new (a||pA)};pA.oa=Ld({la:pA,aa:pA.J,da:"root"});var qA=new df("FloatingLabelParent"),rA=class{get Gq(){return this.D}set Gq(a){this.D=a;this.qr&&this.F()}get qr(){return this.C}set qr(a){(this.C=a)?this.K():this.i.unsubscribe()}constructor(a){this.qa=a;this.C=this.D=!1;this.G=lf(pA);this.pa=lf(Ok);this.Pa=lf(qA);this.i=new Li}ua(){this.i.unsubscribe()}get element(){return this.qa.P}F(){setTimeout(()=>this.Pa.Yz())}K(){this.i.unsubscribe();Kk(this.pa,()=>{this.i=this.G.observe(this.qa.P,{box:"border-box"}).subscribe(()=>this.F())})}};
rA.J=function(a){return new (a||rA)(y(qi))};rA.Ea=Of({type:rA,ga:[["label","matFormFieldFloatingLabel",""]],Ja:[1,"mdc-floating-label","mat-mdc-floating-label"],Xa:2,Ha:function(a,b){a&2&&lq("mdc-floating-label--float-above",b.Gq)},inputs:{Gq:"floating",qr:"monitorResize"},ja:!0});var sA=class{constructor(a,b){this.qa=a;this.i=c=>{const d=this.qa.P.classList,e=d.contains("mdc-line-ripple--deactivating");"opacity"===c.propertyName&&e&&d.remove("mdc-line-ripple--active","mdc-line-ripple--deactivating")};Kk(b,()=>{a.P.addEventListener("transitionend",this.i)})}hn(){this.qa.P.classList.add("mdc-line-ripple--deactivating")}ua(){this.qa.P.removeEventListener("transitionend",this.i)}};sA.J=function(a){return new (a||sA)(y(qi),y(Ok))};
sA.Ea=Of({type:sA,ga:[["div","matFormFieldLineRipple",""]],Ja:[1,"mdc-line-ripple"],ja:!0});const tA=["notch"];
var uA=class{constructor(a,b){this.qa=a;this.pa=b;this.open=!1}nd(){const a=this.qa.P.querySelector(".mdc-floating-label");a?(this.qa.P.classList.add("mdc-notched-outline--upgraded"),"function"===typeof requestAnimationFrame&&(a.style.transitionDuration="0s",Kk(this.pa,()=>{requestAnimationFrame(()=>a.style.transitionDuration="")}))):this.qa.P.classList.add("mdc-notched-outline--no-label")}i(a){this.jA.P.style.width=this.open&&a?`calc(${a}px * var(--mat-mdc-form-field-floating-label-scale, 0.75) + ${9}px)`:""}};
uA.J=function(a){return new (a||uA)(y(qi),y(Ok))};
uA.Ca=Gf({type:uA,ga:[["div","matFormFieldNotchedOutline",""]],eb:function(a,b){a&1&&rr(tA,5);if(a&2){let c;sr(c=tr())&&(b.jA=c.first)}},Ja:[1,"mdc-notched-outline"],Xa:2,Ha:function(a,b){a&2&&lq("mdc-notched-outline--notched",b.open)},inputs:{open:[0,"matFormFieldNotchedOutlineOpen","open"]},ja:!0,features:[Jr],attrs:["matFormFieldNotchedOutline",""],Yb:["*"],ya:5,za:0,Ba:[["notch",""],[1,"mdc-notched-outline__leading"],[1,"mdc-notched-outline__notch"],[1,"mdc-notched-outline__trailing"]],sa:function(a){a&
1&&(Vq(),Kq(0,"div",1),R(1,"div",2,0),Wq(3),S(),Kq(4,"div",3))},ob:2,Qa:0});const vA=["textField"],wA=["iconPrefixContainer"],xA=["textPrefixContainer"],yA=["*",[["mat-label"]],[["","matPrefix",""],["","matIconPrefix",""]],[["","matTextPrefix",""]],[["","matTextSuffix",""]],[["","matSuffix",""],["","matIconSuffix",""]],[["mat-error"],["","matError",""]],[["mat-hint",3,"align","end"]],[["mat-hint","align","end"]]];function zA(a){a&1&&Kq(0,"span",19)}
function AA(a){a&1&&(R(0,"label",18),Wq(1,1),yp(2,zA,1,0,"span",19),S());a&2&&(a=Y(2),H("floating",a.Bk())("monitorResize",a.yf())("id",a.Te),Ip("for",a.Gb.yB?null:a.Gb.id),D(2),Cq(!a.Jn&&a.Gb.required?2:-1))}function BA(a){a&1&&yp(0,AA,3,5,"label",18);a&2&&(a=Y(),Cq(a.ph()?0:-1))}function CA(a){a&1&&Kq(0,"div",5)}function DA(){}function EA(a){a&1&&yp(0,DA,0,0,"ng-template",11);a&2&&(Y(2),a=wr(1),H("ngTemplateOutlet",a))}
function FA(a){a&1&&(R(0,"div",7),yp(1,EA,1,1,null,11),S());a&2&&(a=Y(),H("matFormFieldNotchedOutlineOpen",a.Bk()),D(),Cq(a.At()?-1:1))}function GA(a){a&1&&(R(0,"div",8,2),Wq(2,2),S())}function HA(a){a&1&&(R(0,"div",9,3),Wq(2,3),S())}function IA(){}function JA(a){a&1&&yp(0,IA,0,0,"ng-template",11);a&2&&(Y(),a=wr(1),H("ngTemplateOutlet",a))}function KA(a){a&1&&(R(0,"div",12),Wq(1,4),S())}function LA(a){a&1&&(R(0,"div",13),Wq(1,5),S())}function MA(a){a&1&&Kq(0,"div",14)}
function NA(a){a&1&&(R(0,"div",16),Wq(1,6),S());a&2&&(a=Y(),H("@transitionMessages",a.Kp))}function OA(a){a&1&&(R(0,"mat-hint",20),Z(1),S());a&2&&(a=Y(2),H("id",a.Qt),D(),xr(a.Ln))}function PA(a){a&1&&(R(0,"div",17),yp(1,OA,2,2,"mat-hint",20),Wq(2,7),Kq(3,"div",21),Wq(4,8),S());a&2&&(a=Y(),H("@transitionMessages",a.Kp),D(),Cq(a.Ln?1:-1))}var QA=new df("MatFormField"),RA=new df("MAT_FORM_FIELD_DEFAULT_OPTIONS");let SA=0;function TA(a){return a.ru||a.qa}
var VA=class{get Jn(){return this.K}set Jn(a){this.K=Ns(a)}get wg(){let a;return this.R||(null==(a=this.F)?void 0:a.wg)||"auto"}set wg(a){a!==this.R&&(this.R=a,Zm(this.Aa))}get Dd(){return this.C}set Dd(a){const b=this.C;let c;this.C=a||(null==(c=this.F)?void 0:c.Dd)||"fill";"outline"===this.C&&this.C!==b&&(this.i=!0)}get cm(){let a;return this.ea||(null==(a=this.F)?void 0:a.cm)||"fixed"}set cm(a){let b;this.ea=a||(null==(b=this.F)?void 0:b.cm)||"fixed"}get Ln(){return this.N}set Ln(a){this.N=a;this.ba()}get Gb(){return this.ra||
this.Qz}set Gb(a){this.ra=a}constructor(a,b,c,d,e,f,g){this.qa=a;this.Aa=b;this.O=d;this.Ka=e;this.F=f;this.Yc=g;this.K=!1;this.color="primary";this.C="fill";this.ea=null;this.N="";this.Ot=this.vp=this.Nt=this.tp=!1;this.Te=`mat-mdc-form-field-label-${SA++}`;this.Qt=`mat-mdc-hint-${SA++}`;this.Kp="";this.Fa=new aj;this.D=null;this.i=!1;this.Ya=lf(Vh);f&&(f.Dd&&(this.Dd=f.Dd),this.K=!(null==f||!f.Jn),f.color&&(this.color=f.color))}nd(){this.ia();this.Kp="enter";$m(this.Aa)}yj(){this.ta();this.Ia();
this.Da();this.va()}Kw(){}ua(){this.Fa.next();this.Fa.complete()}ma(){this.ph()&&(this.wg="always")}ta(){const a=this.Gb;a.jv&&this.qa.P.classList.add(`mat-mdc-form-field-type-${a.jv}`);a.Rc.subscribe(()=>{this.ia();this.G();Zm(this.Aa)});a.Hd&&a.Hd.ah&&C(a.Hd.ah,Jo(this.Fa)).subscribe(()=>Zm(this.Aa))}T(){this.tp=!!this.yk.find(a=>!a.i);this.Nt=!!this.yk.find(a=>a.i);this.vp=!!this.Lp.find(a=>!a.i);this.Ot=!!this.Lp.find(a=>a.i)}Da(){this.T();pk(this.yk.i,this.Lp.i).subscribe(()=>{this.T();Zm(this.Aa)})}Ia(){this.rk.i.subscribe(()=>
{this.ba();Zm(this.Aa)});this.nk.i.subscribe(()=>{this.G();Zm(this.Aa)});this.G()}ab(){}ia(){if(this.Gb.focused&&!this.D){this.D=!0;var a;null!=(a=this.bu)&&(a=a.qa.P.classList,a.remove("mdc-line-ripple--deactivating"),a.add("mdc-line-ripple--active"))}else this.Gb.focused||!this.D&&null!==this.D||(this.D=!1,null==(a=this.bu)||a.hn());let b;null==(b=this.ru)||b.P.classList.toggle("mdc-text-field--focused",this.Gb.focused)}va(){this.yk.i.subscribe(()=>this.i=!0);Vk(()=>{this.i&&(this.i=!1,this.Ta())},
{wa:this.Ya});C(this.O.vb,Jo(this.Fa)).subscribe(()=>this.i=!0)}nu(){return"always"===this.wg}yf(){return"outline"===this.Dd}At(){return!this.Ka.isBrowser&&this.yk.length&&!this.Bk()}ph(){return!!this.gA||!!this.hA}Bk(){return this.Gb.UD||this.nu()}vh(a){const b=this.Gb?this.Gb.Hd:null;return b&&b[a]}Ft(){return this.nk&&0<this.nk.length&&this.Gb.we?"error":"hint"}Yz(){this.Ra()}Ra(){if(this.yf()&&this.xm&&this.Bk()){var a;if(null!=(a=this.cu)){var b=a.i;var c=this.xm.qa.P;if(null!==c.offsetParent)c=
c.scrollWidth;else{c=c.cloneNode(!0);c.style.setProperty("position","absolute");c.style.setProperty("transform","translate(-9999px, -9999px)");document.documentElement.appendChild(c);var d=c.scrollWidth;c.remove();c=d}b.call(a,c)}}else null==(a=this.cu)||a.i(0)}ba(){this.G()}fb(){}G(){if(this.Gb){let a=[];this.Gb.Ms&&"string"===typeof this.Gb.Ms&&a.push(...this.Gb.Ms.split(" "));if("hint"===this.Ft()){const b=this.rk?this.rk.find(d=>"start"===d.align):null,c=this.rk?this.rk.find(d=>"end"===d.align):
null;b?a.push(b.id):this.N&&a.push(this.Qt);c&&a.push(c.id)}else this.nk&&a.push(...this.nk.map(b=>b.id));UA(this.Gb,a)}}Ta(){if(this.yf()&&this.xm){var a=this.xm.element;if(this.Rt||this.su)if(this.Oa()){var b,c=null==(b=this.Rt)?void 0:b.P,d;b=null==(d=this.su)?void 0:d.P;var e;c=null!=(e=null==c?void 0:c.getBoundingClientRect().width)?e:0;var f;e=null!=(f=null==b?void 0:b.getBoundingClientRect().width)?f:0;a.style.transform=`var(
        --mat-mdc-form-field-label-transform,
        ${"translateY(-50%)"} translateX(${`calc(${"rtl"===this.O.value?"-1":"1"} * (${`${c+e}px`} + ${"var(--mat-mdc-form-field-label-offset-x, 0px)"}))`})
    )`}else this.i=!0;else a.style.transform=""}}Oa(){const a=this.qa.P;if(a.getRootNode){const b=a.getRootNode();return b&&b!==a}return document.documentElement.contains(a)}};VA.J=function(a){return new (a||VA)(y(qi),y(Pr),y(Ok),y(lu),y(St),y(RA,8),y(ki,8),y(gt))};
VA.Ca=Gf({type:VA,ga:[["mat-form-field"]],cc:function(a,b,c){a&1&&(qr(c,jA,5),qr(c,jA,7),qr(c,nA,5),qr(c,kA,5),qr(c,lA,5),qr(c,gA,5),qr(c,iA,5));if(a&2){let d;sr(d=tr())&&(b.gA=d.first);sr(d=tr())&&(b.hA=d.first);sr(d=tr())&&(b.Qz=d.first);sr(d=tr())&&(b.yk=d);sr(d=tr())&&(b.Lp=d);sr(d=tr())&&(b.nk=d);sr(d=tr())&&(b.rk=d)}},eb:function(a,b){a&1&&(rr(vA,5),rr(wA,5),rr(xA,5),rr(rA,5),rr(uA,5),rr(sA,5));if(a&2){let c;sr(c=tr())&&(b.ru=c.first);sr(c=tr())&&(b.Rt=c.first);sr(c=tr())&&(b.su=c.first);sr(c=
tr())&&(b.xm=c.first);sr(c=tr())&&(b.cu=c.first);sr(c=tr())&&(b.bu=c.first)}},Ja:[1,"mat-mdc-form-field"],Xa:42,Ha:function(a,b){a&2&&lq("mat-mdc-form-field-label-always-float",b.nu())("mat-mdc-form-field-has-icon-prefix",b.tp)("mat-mdc-form-field-has-icon-suffix",b.vp)("mat-form-field-invalid",b.Gb.we)("mat-form-field-disabled",b.Gb.disabled)("mat-form-field-autofilled",b.Gb.yF)("mat-form-field-no-animations","NoopAnimations"===b.Yc)("mat-form-field-appearance-fill","fill"==b.Dd)("mat-form-field-appearance-outline",
"outline"==b.Dd)("mat-form-field-hide-placeholder",b.ph()&&!b.Bk())("mat-focused",b.Gb.focused)("mat-primary","accent"!==b.color&&"warn"!==b.color)("mat-accent","accent"===b.color)("mat-warn","warn"===b.color)("ng-untouched",b.vh("untouched"))("ng-touched",b.vh("touched"))("ng-pristine",b.vh("pristine"))("ng-dirty",b.vh("dirty"))("ng-valid",b.vh("valid"))("ng-invalid",b.vh("invalid"))("ng-pending",b.vh("pending"))},inputs:{Jn:"hideRequiredMarker",color:"color",wg:"floatLabel",Dd:"appearance",cm:"subscriptSizing",
Ln:"hintLabel"},hb:["matFormField"],ja:!0,features:[Hr([{na:QA,zb:VA},{na:qA,zb:VA}]),Jr],Yb:"*;mat-label;[matPrefix], [matIconPrefix];[matTextPrefix];[matTextSuffix];[matSuffix], [matIconSuffix];mat-error, [matError];mat-hint:not([align='end']);mat-hint[align='end']".split(";"),ya:18,za:21,Ba:[["labelTemplate",""],["textField",""],["iconPrefixContainer",""],["textPrefixContainer",""],[1,"mat-mdc-text-field-wrapper","mdc-text-field",3,"click"],[1,"mat-mdc-form-field-focus-overlay"],[1,"mat-mdc-form-field-flex"],
["matFormFieldNotchedOutline","",3,"matFormFieldNotchedOutlineOpen"],[1,"mat-mdc-form-field-icon-prefix"],[1,"mat-mdc-form-field-text-prefix"],[1,"mat-mdc-form-field-infix"],[3,"ngTemplateOutlet"],[1,"mat-mdc-form-field-text-suffix"],[1,"mat-mdc-form-field-icon-suffix"],["matFormFieldLineRipple",""],[1,"mat-mdc-form-field-subscript-wrapper","mat-mdc-form-field-bottom-align"],[1,"mat-mdc-form-field-error-wrapper"],[1,"mat-mdc-form-field-hint-wrapper"],["matFormFieldFloatingLabel","",3,"floating","monitorResize",
"id"],["aria-hidden","true",1,"mat-mdc-form-field-required-marker","mdc-floating-label--required"],[3,"id"],[1,"mat-mdc-form-field-hint-spacer"]],sa:function(a,b){if(a&1){const c=Tg();Vq(yA);yp(0,BA,1,1,"ng-template",null,0,Nr);R(2,"div",4,1);V("click",function(){u(c);var d=b.Gb;d.focus();d.open();return x()});yp(4,CA,1,0,"div",5);R(5,"div",6);yp(6,FA,2,2,"div",7)(7,GA,3,0,"div",8)(8,HA,3,0,"div",9);R(9,"div",10);yp(10,JA,1,1,null,11);Wq(11);S();yp(12,KA,2,0,"div",12)(13,LA,2,0,"div",13);S();yp(14,
MA,1,0,"div",14);S();R(15,"div",15);yp(16,NA,2,1,"div",16)(17,PA,5,2,"div",17);S()}if(a&2){let c;D(2);lq("mdc-text-field--filled",!b.yf())("mdc-text-field--outlined",b.yf())("mdc-text-field--no-label",!b.ph())("mdc-text-field--disabled",b.Gb.disabled)("mdc-text-field--invalid",b.Gb.we);D(2);Cq(b.yf()||b.Gb.disabled?-1:4);D(2);Cq(b.yf()?6:-1);D();Cq(b.tp?7:-1);D();Cq(b.Nt?8:-1);D(2);Cq(!b.yf()||b.At()?10:-1);D(2);Cq(b.Ot?12:-1);D();Cq(b.vp?13:-1);D();Cq(b.yf()?-1:14);D();lq("mat-mdc-form-field-subscript-dynamic-size",
"dynamic"===b.cm);D();Cq("error"===(c=b.Ft())?16:"hint"===c?17:-1)}},Ga:[rA,uA,dt,sA,iA],styles:['.mdc-text-field{border-top-left-radius:4px;border-top-left-radius:var(--mdc-shape-small, 4px);border-top-right-radius:4px;border-top-right-radius:var(--mdc-shape-small, 4px);border-bottom-right-radius:0;border-bottom-left-radius:0;display:inline-flex;align-items:baseline;padding:0 16px;position:relative;box-sizing:border-box;overflow:hidden;will-change:opacity,transform,color}.mdc-text-field .mdc-floating-label{top:50%;transform:translateY(-50%);pointer-events:none}.mdc-text-field__input{height:28px;width:100%;min-width:0;border:none;border-radius:0;background:none;appearance:none;padding:0}.mdc-text-field__input::-ms-clear{display:none}.mdc-text-field__input::-webkit-calendar-picker-indicator{display:none}.mdc-text-field__input:focus{outline:none}.mdc-text-field__input:invalid{box-shadow:none}@media all{.mdc-text-field__input::placeholder{opacity:0}}@media all{.mdc-text-field__input:-ms-input-placeholder{opacity:0}}@media all{.mdc-text-field--no-label .mdc-text-field__input::placeholder,.mdc-text-field--focused .mdc-text-field__input::placeholder{opacity:1}}@media all{.mdc-text-field--no-label .mdc-text-field__input:-ms-input-placeholder,.mdc-text-field--focused .mdc-text-field__input:-ms-input-placeholder{opacity:1}}.mdc-text-field__affix{height:28px;opacity:0;white-space:nowrap}.mdc-text-field--label-floating .mdc-text-field__affix,.mdc-text-field--no-label .mdc-text-field__affix{opacity:1}@supports(-webkit-hyphens: none){.mdc-text-field--outlined .mdc-text-field__affix{align-items:center;align-self:center;display:inline-flex;height:100%}}.mdc-text-field__affix--prefix{padding-left:0;padding-right:2px}[dir=rtl] .mdc-text-field__affix--prefix,.mdc-text-field__affix--prefix[dir=rtl]{padding-left:2px;padding-right:0}.mdc-text-field--end-aligned .mdc-text-field__affix--prefix{padding-left:0;padding-right:12px}[dir=rtl] .mdc-text-field--end-aligned .mdc-text-field__affix--prefix,.mdc-text-field--end-aligned .mdc-text-field__affix--prefix[dir=rtl]{padding-left:12px;padding-right:0}.mdc-text-field__affix--suffix{padding-left:12px;padding-right:0}[dir=rtl] .mdc-text-field__affix--suffix,.mdc-text-field__affix--suffix[dir=rtl]{padding-left:0;padding-right:12px}.mdc-text-field--end-aligned .mdc-text-field__affix--suffix{padding-left:2px;padding-right:0}[dir=rtl] .mdc-text-field--end-aligned .mdc-text-field__affix--suffix,.mdc-text-field--end-aligned .mdc-text-field__affix--suffix[dir=rtl]{padding-left:0;padding-right:2px}.mdc-text-field--filled{height:56px}.mdc-text-field--filled::before{display:inline-block;width:0;height:40px;content:"";vertical-align:0}.mdc-text-field--filled .mdc-floating-label{left:16px;right:initial}[dir=rtl] .mdc-text-field--filled .mdc-floating-label,.mdc-text-field--filled .mdc-floating-label[dir=rtl]{left:initial;right:16px}.mdc-text-field--filled .mdc-floating-label--float-above{transform:translateY(-106%) scale(0.75)}.mdc-text-field--filled.mdc-text-field--no-label .mdc-text-field__input{height:100%}.mdc-text-field--filled.mdc-text-field--no-label .mdc-floating-label{display:none}.mdc-text-field--filled.mdc-text-field--no-label::before{display:none}@supports(-webkit-hyphens: none){.mdc-text-field--filled.mdc-text-field--no-label .mdc-text-field__affix{align-items:center;align-self:center;display:inline-flex;height:100%}}.mdc-text-field--outlined{height:56px;overflow:visible}.mdc-text-field--outlined .mdc-floating-label--float-above{transform:translateY(-37.25px) scale(1)}.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{transform:translateY(-34.75px) scale(0.75)}.mdc-text-field--outlined .mdc-floating-label--float-above{font-size:.75rem}.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:1rem}.mdc-text-field--outlined .mdc-text-field__input{height:100%}.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading{border-top-left-radius:4px;border-top-left-radius:var(--mdc-shape-small, 4px);border-top-right-radius:0;border-bottom-right-radius:0;border-bottom-left-radius:4px;border-bottom-left-radius:var(--mdc-shape-small, 4px)}[dir=rtl] .mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading[dir=rtl]{border-top-left-radius:0;border-top-right-radius:4px;border-top-right-radius:var(--mdc-shape-small, 4px);border-bottom-right-radius:4px;border-bottom-right-radius:var(--mdc-shape-small, 4px);border-bottom-left-radius:0}@supports(top: max(0%)){.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading{width:max(12px,var(--mdc-shape-small, 4px))}}@supports(top: max(0%)){.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__notch{max-width:calc(100% - max(12px,var(--mdc-shape-small, 4px))*2)}}.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__trailing{border-top-left-radius:0;border-top-right-radius:4px;border-top-right-radius:var(--mdc-shape-small, 4px);border-bottom-right-radius:4px;border-bottom-right-radius:var(--mdc-shape-small, 4px);border-bottom-left-radius:0}[dir=rtl] .mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__trailing,.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__trailing[dir=rtl]{border-top-left-radius:4px;border-top-left-radius:var(--mdc-shape-small, 4px);border-top-right-radius:0;border-bottom-right-radius:0;border-bottom-left-radius:4px;border-bottom-left-radius:var(--mdc-shape-small, 4px)}@supports(top: max(0%)){.mdc-text-field--outlined{padding-left:max(16px,calc(var(--mdc-shape-small, 4px) + 4px))}}@supports(top: max(0%)){.mdc-text-field--outlined{padding-right:max(16px,var(--mdc-shape-small, 4px))}}@supports(top: max(0%)){.mdc-text-field--outlined+.mdc-text-field-helper-line{padding-left:max(16px,calc(var(--mdc-shape-small, 4px) + 4px))}}@supports(top: max(0%)){.mdc-text-field--outlined+.mdc-text-field-helper-line{padding-right:max(16px,var(--mdc-shape-small, 4px))}}.mdc-text-field--outlined.mdc-text-field--with-leading-icon{padding-left:0}@supports(top: max(0%)){.mdc-text-field--outlined.mdc-text-field--with-leading-icon{padding-right:max(16px,var(--mdc-shape-small, 4px))}}[dir=rtl] .mdc-text-field--outlined.mdc-text-field--with-leading-icon,.mdc-text-field--outlined.mdc-text-field--with-leading-icon[dir=rtl]{padding-right:0}@supports(top: max(0%)){[dir=rtl] .mdc-text-field--outlined.mdc-text-field--with-leading-icon,.mdc-text-field--outlined.mdc-text-field--with-leading-icon[dir=rtl]{padding-left:max(16px,var(--mdc-shape-small, 4px))}}.mdc-text-field--outlined.mdc-text-field--with-trailing-icon{padding-right:0}@supports(top: max(0%)){.mdc-text-field--outlined.mdc-text-field--with-trailing-icon{padding-left:max(16px,calc(var(--mdc-shape-small, 4px) + 4px))}}[dir=rtl] .mdc-text-field--outlined.mdc-text-field--with-trailing-icon,.mdc-text-field--outlined.mdc-text-field--with-trailing-icon[dir=rtl]{padding-left:0}@supports(top: max(0%)){[dir=rtl] .mdc-text-field--outlined.mdc-text-field--with-trailing-icon,.mdc-text-field--outlined.mdc-text-field--with-trailing-icon[dir=rtl]{padding-right:max(16px,calc(var(--mdc-shape-small, 4px) + 4px))}}.mdc-text-field--outlined.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon{padding-left:0;padding-right:0}.mdc-text-field--outlined .mdc-notched-outline--notched .mdc-notched-outline__notch{padding-top:1px}.mdc-text-field--outlined .mdc-floating-label{left:4px;right:initial}[dir=rtl] .mdc-text-field--outlined .mdc-floating-label,.mdc-text-field--outlined .mdc-floating-label[dir=rtl]{left:initial;right:4px}.mdc-text-field--outlined .mdc-text-field__input{display:flex;border:none !important;background-color:rgba(0,0,0,0)}.mdc-text-field--outlined .mdc-notched-outline{z-index:1}.mdc-text-field--textarea{flex-direction:column;align-items:center;width:auto;height:auto;padding:0}.mdc-text-field--textarea .mdc-floating-label{top:19px}.mdc-text-field--textarea .mdc-floating-label:not(.mdc-floating-label--float-above){transform:none}.mdc-text-field--textarea .mdc-text-field__input{flex-grow:1;height:auto;min-height:1.5rem;overflow-x:hidden;overflow-y:auto;box-sizing:border-box;resize:none;padding:0 16px}.mdc-text-field--textarea.mdc-text-field--filled::before{display:none}.mdc-text-field--textarea.mdc-text-field--filled .mdc-floating-label--float-above{transform:translateY(-10.25px) scale(0.75)}.mdc-text-field--textarea.mdc-text-field--filled .mdc-text-field__input{margin-top:23px;margin-bottom:9px}.mdc-text-field--textarea.mdc-text-field--filled.mdc-text-field--no-label .mdc-text-field__input{margin-top:16px;margin-bottom:16px}.mdc-text-field--textarea.mdc-text-field--outlined .mdc-notched-outline--notched .mdc-notched-outline__notch{padding-top:0}.mdc-text-field--textarea.mdc-text-field--outlined .mdc-floating-label--float-above{transform:translateY(-27.25px) scale(1)}.mdc-text-field--textarea.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--textarea.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{transform:translateY(-24.75px) scale(0.75)}.mdc-text-field--textarea.mdc-text-field--outlined .mdc-floating-label--float-above{font-size:.75rem}.mdc-text-field--textarea.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--textarea.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:1rem}.mdc-text-field--textarea.mdc-text-field--outlined .mdc-text-field__input{margin-top:16px;margin-bottom:16px}.mdc-text-field--textarea.mdc-text-field--outlined .mdc-floating-label{top:18px}.mdc-text-field--textarea.mdc-text-field--with-internal-counter .mdc-text-field__input{margin-bottom:2px}.mdc-text-field--textarea.mdc-text-field--with-internal-counter .mdc-text-field-character-counter{align-self:flex-end;padding:0 16px}.mdc-text-field--textarea.mdc-text-field--with-internal-counter .mdc-text-field-character-counter::after{display:inline-block;width:0;height:16px;content:"";vertical-align:-16px}.mdc-text-field--textarea.mdc-text-field--with-internal-counter .mdc-text-field-character-counter::before{display:none}.mdc-text-field__resizer{align-self:stretch;display:inline-flex;flex-direction:column;flex-grow:1;max-height:100%;max-width:100%;min-height:56px;min-width:fit-content;min-width:-moz-available;min-width:-webkit-fill-available;overflow:hidden;resize:both}.mdc-text-field--filled .mdc-text-field__resizer{transform:translateY(-1px)}.mdc-text-field--filled .mdc-text-field__resizer .mdc-text-field__input,.mdc-text-field--filled .mdc-text-field__resizer .mdc-text-field-character-counter{transform:translateY(1px)}.mdc-text-field--outlined .mdc-text-field__resizer{transform:translateX(-1px) translateY(-1px)}[dir=rtl] .mdc-text-field--outlined .mdc-text-field__resizer,.mdc-text-field--outlined .mdc-text-field__resizer[dir=rtl]{transform:translateX(1px) translateY(-1px)}.mdc-text-field--outlined .mdc-text-field__resizer .mdc-text-field__input,.mdc-text-field--outlined .mdc-text-field__resizer .mdc-text-field-character-counter{transform:translateX(1px) translateY(1px)}[dir=rtl] .mdc-text-field--outlined .mdc-text-field__resizer .mdc-text-field__input,[dir=rtl] .mdc-text-field--outlined .mdc-text-field__resizer .mdc-text-field-character-counter,.mdc-text-field--outlined .mdc-text-field__resizer .mdc-text-field__input[dir=rtl],.mdc-text-field--outlined .mdc-text-field__resizer .mdc-text-field-character-counter[dir=rtl]{transform:translateX(-1px) translateY(1px)}.mdc-text-field--with-leading-icon{padding-left:0;padding-right:16px}[dir=rtl] .mdc-text-field--with-leading-icon,.mdc-text-field--with-leading-icon[dir=rtl]{padding-left:16px;padding-right:0}.mdc-text-field--with-leading-icon.mdc-text-field--filled .mdc-floating-label{max-width:calc(100% - 48px);left:48px;right:initial}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--filled .mdc-floating-label,.mdc-text-field--with-leading-icon.mdc-text-field--filled .mdc-floating-label[dir=rtl]{left:initial;right:48px}.mdc-text-field--with-leading-icon.mdc-text-field--filled .mdc-floating-label--float-above{max-width:calc(100%/0.75 - 64px/0.75)}.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label{left:36px;right:initial}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label[dir=rtl]{left:initial;right:36px}.mdc-text-field--with-leading-icon.mdc-text-field--outlined :not(.mdc-notched-outline--notched) .mdc-notched-outline__notch{max-width:calc(100% - 60px)}.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--float-above{transform:translateY(-37.25px) translateX(-32px) scale(1)}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--float-above[dir=rtl]{transform:translateY(-37.25px) translateX(32px) scale(1)}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{transform:translateY(-34.75px) translateX(-32px) scale(0.75)}[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,[dir=rtl] .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above[dir=rtl],.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above[dir=rtl]{transform:translateY(-34.75px) translateX(32px) scale(0.75)}.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--float-above{font-size:.75rem}.mdc-text-field--with-leading-icon.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:1rem}.mdc-text-field--with-trailing-icon{padding-left:16px;padding-right:0}[dir=rtl] .mdc-text-field--with-trailing-icon,.mdc-text-field--with-trailing-icon[dir=rtl]{padding-left:0;padding-right:16px}.mdc-text-field--with-trailing-icon.mdc-text-field--filled .mdc-floating-label{max-width:calc(100% - 64px)}.mdc-text-field--with-trailing-icon.mdc-text-field--filled .mdc-floating-label--float-above{max-width:calc(100%/0.75 - 64px/0.75)}.mdc-text-field--with-trailing-icon.mdc-text-field--outlined :not(.mdc-notched-outline--notched) .mdc-notched-outline__notch{max-width:calc(100% - 60px)}.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon{padding-left:0;padding-right:0}.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--filled .mdc-floating-label{max-width:calc(100% - 96px)}.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon.mdc-text-field--filled .mdc-floating-label--float-above{max-width:calc(100%/0.75 - 96px/0.75)}.mdc-text-field-helper-line{display:flex;justify-content:space-between;box-sizing:border-box}.mdc-text-field+.mdc-text-field-helper-line{padding-right:16px;padding-left:16px}.mdc-form-field>.mdc-text-field+label{align-self:flex-start}.mdc-text-field--focused .mdc-notched-outline__leading,.mdc-text-field--focused .mdc-notched-outline__notch,.mdc-text-field--focused .mdc-notched-outline__trailing{border-width:2px}.mdc-text-field--focused+.mdc-text-field-helper-line .mdc-text-field-helper-text:not(.mdc-text-field-helper-text--validation-msg){opacity:1}.mdc-text-field--focused.mdc-text-field--outlined .mdc-notched-outline--notched .mdc-notched-outline__notch{padding-top:2px}.mdc-text-field--focused.mdc-text-field--outlined.mdc-text-field--textarea .mdc-notched-outline--notched .mdc-notched-outline__notch{padding-top:0}.mdc-text-field--invalid+.mdc-text-field-helper-line .mdc-text-field-helper-text--validation-msg{opacity:1}.mdc-text-field--disabled{pointer-events:none}@media screen and (forced-colors: active){.mdc-text-field--disabled .mdc-text-field__input{background-color:Window}.mdc-text-field--disabled .mdc-floating-label{z-index:1}}.mdc-text-field--disabled .mdc-floating-label{cursor:default}.mdc-text-field--disabled.mdc-text-field--filled .mdc-text-field__ripple{display:none}.mdc-text-field--disabled .mdc-text-field__input{pointer-events:auto}.mdc-text-field--end-aligned .mdc-text-field__input{text-align:right}[dir=rtl] .mdc-text-field--end-aligned .mdc-text-field__input,.mdc-text-field--end-aligned .mdc-text-field__input[dir=rtl]{text-align:left}[dir=rtl] .mdc-text-field--ltr-text .mdc-text-field__input,[dir=rtl] .mdc-text-field--ltr-text .mdc-text-field__affix,.mdc-text-field--ltr-text[dir=rtl] .mdc-text-field__input,.mdc-text-field--ltr-text[dir=rtl] .mdc-text-field__affix{direction:ltr}[dir=rtl] .mdc-text-field--ltr-text .mdc-text-field__affix--prefix,.mdc-text-field--ltr-text[dir=rtl] .mdc-text-field__affix--prefix{padding-left:0;padding-right:2px}[dir=rtl] .mdc-text-field--ltr-text .mdc-text-field__affix--suffix,.mdc-text-field--ltr-text[dir=rtl] .mdc-text-field__affix--suffix{padding-left:12px;padding-right:0}[dir=rtl] .mdc-text-field--ltr-text .mdc-text-field__icon--leading,.mdc-text-field--ltr-text[dir=rtl] .mdc-text-field__icon--leading{order:1}[dir=rtl] .mdc-text-field--ltr-text .mdc-text-field__affix--suffix,.mdc-text-field--ltr-text[dir=rtl] .mdc-text-field__affix--suffix{order:2}[dir=rtl] .mdc-text-field--ltr-text .mdc-text-field__input,.mdc-text-field--ltr-text[dir=rtl] .mdc-text-field__input{order:3}[dir=rtl] .mdc-text-field--ltr-text .mdc-text-field__affix--prefix,.mdc-text-field--ltr-text[dir=rtl] .mdc-text-field__affix--prefix{order:4}[dir=rtl] .mdc-text-field--ltr-text .mdc-text-field__icon--trailing,.mdc-text-field--ltr-text[dir=rtl] .mdc-text-field__icon--trailing{order:5}[dir=rtl] .mdc-text-field--ltr-text.mdc-text-field--end-aligned .mdc-text-field__input,.mdc-text-field--ltr-text.mdc-text-field--end-aligned[dir=rtl] .mdc-text-field__input{text-align:right}[dir=rtl] .mdc-text-field--ltr-text.mdc-text-field--end-aligned .mdc-text-field__affix--prefix,.mdc-text-field--ltr-text.mdc-text-field--end-aligned[dir=rtl] .mdc-text-field__affix--prefix{padding-right:12px}[dir=rtl] .mdc-text-field--ltr-text.mdc-text-field--end-aligned .mdc-text-field__affix--suffix,.mdc-text-field--ltr-text.mdc-text-field--end-aligned[dir=rtl] .mdc-text-field__affix--suffix{padding-left:2px}.mdc-floating-label{position:absolute;left:0;-webkit-transform-origin:left top;transform-origin:left top;line-height:1.15rem;text-align:left;text-overflow:ellipsis;white-space:nowrap;cursor:text;overflow:hidden;will-change:transform}[dir=rtl] .mdc-floating-label,.mdc-floating-label[dir=rtl]{right:0;left:auto;-webkit-transform-origin:right top;transform-origin:right top;text-align:right}.mdc-floating-label--float-above{cursor:auto}.mdc-floating-label--required:not(.mdc-floating-label--hide-required-marker)::after{margin-left:1px;margin-right:0px;content:"*"}[dir=rtl] .mdc-floating-label--required:not(.mdc-floating-label--hide-required-marker)::after,.mdc-floating-label--required:not(.mdc-floating-label--hide-required-marker)[dir=rtl]::after{margin-left:0;margin-right:1px}.mdc-notched-outline{display:flex;position:absolute;top:0;right:0;left:0;box-sizing:border-box;width:100%;max-width:100%;height:100%;text-align:left;pointer-events:none}[dir=rtl] .mdc-notched-outline,.mdc-notched-outline[dir=rtl]{text-align:right}.mdc-notched-outline__leading,.mdc-notched-outline__notch,.mdc-notched-outline__trailing{box-sizing:border-box;height:100%;pointer-events:none}.mdc-notched-outline__trailing{flex-grow:1}.mdc-notched-outline__notch{flex:0 0 auto;width:auto}.mdc-notched-outline .mdc-floating-label{display:inline-block;position:relative;max-width:100%}.mdc-notched-outline .mdc-floating-label--float-above{text-overflow:clip}.mdc-notched-outline--upgraded .mdc-floating-label--float-above{max-width:133.3333333333%}.mdc-notched-outline--notched .mdc-notched-outline__notch{padding-left:0;padding-right:8px;border-top:none}[dir=rtl] .mdc-notched-outline--notched .mdc-notched-outline__notch,.mdc-notched-outline--notched .mdc-notched-outline__notch[dir=rtl]{padding-left:8px;padding-right:0}.mdc-notched-outline--no-label .mdc-notched-outline__notch{display:none}.mdc-line-ripple::before,.mdc-line-ripple::after{position:absolute;bottom:0;left:0;width:100%;border-bottom-style:solid;content:""}.mdc-line-ripple::before{z-index:1}.mdc-line-ripple::after{transform:scaleX(0);opacity:0;z-index:2}.mdc-line-ripple--active::after{transform:scaleX(1);opacity:1}.mdc-line-ripple--deactivating::after{opacity:0}.mdc-floating-label--float-above{transform:translateY(-106%) scale(0.75)}.mdc-notched-outline__leading,.mdc-notched-outline__notch,.mdc-notched-outline__trailing{border-top:1px solid;border-bottom:1px solid}.mdc-notched-outline__leading{border-left:1px solid;border-right:none;width:12px}[dir=rtl] .mdc-notched-outline__leading,.mdc-notched-outline__leading[dir=rtl]{border-left:none;border-right:1px solid}.mdc-notched-outline__trailing{border-left:none;border-right:1px solid}[dir=rtl] .mdc-notched-outline__trailing,.mdc-notched-outline__trailing[dir=rtl]{border-left:1px solid;border-right:none}.mdc-notched-outline__notch{max-width:calc(100% - 12px*2)}.mdc-line-ripple::before{border-bottom-width:1px}.mdc-line-ripple::after{border-bottom-width:2px}.mdc-text-field--filled{border-top-left-radius:var(--mdc-filled-text-field-container-shape);border-top-right-radius:var(--mdc-filled-text-field-container-shape);border-bottom-right-radius:0;border-bottom-left-radius:0}.mdc-text-field--filled:not(.mdc-text-field--disabled) .mdc-text-field__input{caret-color:var(--mdc-filled-text-field-caret-color)}.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-text-field__input{caret-color:var(--mdc-filled-text-field-error-caret-color)}.mdc-text-field--filled:not(.mdc-text-field--disabled) .mdc-text-field__input{color:var(--mdc-filled-text-field-input-text-color)}.mdc-text-field--filled.mdc-text-field--disabled .mdc-text-field__input{color:var(--mdc-filled-text-field-disabled-input-text-color)}.mdc-text-field--filled:not(.mdc-text-field--disabled) .mdc-floating-label,.mdc-text-field--filled:not(.mdc-text-field--disabled) .mdc-floating-label--float-above{color:var(--mdc-filled-text-field-label-text-color)}.mdc-text-field--filled:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-floating-label,.mdc-text-field--filled:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-floating-label--float-above{color:var(--mdc-filled-text-field-focus-label-text-color)}.mdc-text-field--filled:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-floating-label,.mdc-text-field--filled:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-floating-label--float-above{color:var(--mdc-filled-text-field-hover-label-text-color)}.mdc-text-field--filled.mdc-text-field--disabled .mdc-floating-label,.mdc-text-field--filled.mdc-text-field--disabled .mdc-floating-label--float-above{color:var(--mdc-filled-text-field-disabled-label-text-color)}.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-floating-label,.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-floating-label--float-above{color:var(--mdc-filled-text-field-error-label-text-color)}.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-floating-label,.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-floating-label--float-above{color:var(--mdc-filled-text-field-error-focus-label-text-color)}.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-floating-label,.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-floating-label--float-above{color:var(--mdc-filled-text-field-error-hover-label-text-color)}.mdc-text-field--filled .mdc-floating-label{font-family:var(--mdc-filled-text-field-label-text-font);font-size:var(--mdc-filled-text-field-label-text-size);font-weight:var(--mdc-filled-text-field-label-text-weight);letter-spacing:var(--mdc-filled-text-field-label-text-tracking)}@media all{.mdc-text-field--filled:not(.mdc-text-field--disabled) .mdc-text-field__input::placeholder{color:var(--mdc-filled-text-field-input-text-placeholder-color)}}@media all{.mdc-text-field--filled:not(.mdc-text-field--disabled) .mdc-text-field__input:-ms-input-placeholder{color:var(--mdc-filled-text-field-input-text-placeholder-color)}}.mdc-text-field--filled:not(.mdc-text-field--disabled){background-color:var(--mdc-filled-text-field-container-color)}.mdc-text-field--filled.mdc-text-field--disabled{background-color:var(--mdc-filled-text-field-disabled-container-color)}.mdc-text-field--filled:not(.mdc-text-field--disabled) .mdc-line-ripple::before{border-bottom-color:var(--mdc-filled-text-field-active-indicator-color)}.mdc-text-field--filled:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-line-ripple::before{border-bottom-color:var(--mdc-filled-text-field-hover-active-indicator-color)}.mdc-text-field--filled:not(.mdc-text-field--disabled) .mdc-line-ripple::after{border-bottom-color:var(--mdc-filled-text-field-focus-active-indicator-color)}.mdc-text-field--filled.mdc-text-field--disabled .mdc-line-ripple::before{border-bottom-color:var(--mdc-filled-text-field-disabled-active-indicator-color)}.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-line-ripple::before{border-bottom-color:var(--mdc-filled-text-field-error-active-indicator-color)}.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-line-ripple::before{border-bottom-color:var(--mdc-filled-text-field-error-hover-active-indicator-color)}.mdc-text-field--filled.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-line-ripple::after{border-bottom-color:var(--mdc-filled-text-field-error-focus-active-indicator-color)}.mdc-text-field--filled .mdc-line-ripple::before{border-bottom-width:var(--mdc-filled-text-field-active-indicator-height)}.mdc-text-field--filled .mdc-line-ripple::after{border-bottom-width:var(--mdc-filled-text-field-focus-active-indicator-height)}.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-text-field__input{caret-color:var(--mdc-outlined-text-field-caret-color)}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-text-field__input{caret-color:var(--mdc-outlined-text-field-error-caret-color)}.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-text-field__input{color:var(--mdc-outlined-text-field-input-text-color)}.mdc-text-field--outlined.mdc-text-field--disabled .mdc-text-field__input{color:var(--mdc-outlined-text-field-disabled-input-text-color)}.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-floating-label,.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-floating-label--float-above{color:var(--mdc-outlined-text-field-label-text-color)}.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-floating-label,.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-floating-label--float-above{color:var(--mdc-outlined-text-field-focus-label-text-color)}.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-floating-label,.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-floating-label--float-above{color:var(--mdc-outlined-text-field-hover-label-text-color)}.mdc-text-field--outlined.mdc-text-field--disabled .mdc-floating-label,.mdc-text-field--outlined.mdc-text-field--disabled .mdc-floating-label--float-above{color:var(--mdc-outlined-text-field-disabled-label-text-color)}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-floating-label,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-floating-label--float-above{color:var(--mdc-outlined-text-field-error-label-text-color)}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-floating-label,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-floating-label--float-above{color:var(--mdc-outlined-text-field-error-focus-label-text-color)}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-floating-label,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-floating-label--float-above{color:var(--mdc-outlined-text-field-error-hover-label-text-color)}.mdc-text-field--outlined .mdc-floating-label{font-family:var(--mdc-outlined-text-field-label-text-font);font-size:var(--mdc-outlined-text-field-label-text-size);font-weight:var(--mdc-outlined-text-field-label-text-weight);letter-spacing:var(--mdc-outlined-text-field-label-text-tracking)}@media all{.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-text-field__input::placeholder{color:var(--mdc-outlined-text-field-input-text-placeholder-color)}}@media all{.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-text-field__input:-ms-input-placeholder{color:var(--mdc-outlined-text-field-input-text-placeholder-color)}}.mdc-text-field--outlined.mdc-text-field--textarea.mdc-text-field--outlined .mdc-floating-label--float-above{font-size:calc(.75*var(--mdc-outlined-text-field-label-text-size))}.mdc-text-field--outlined.mdc-text-field--textarea.mdc-text-field--outlined.mdc-notched-outline--upgraded .mdc-floating-label--float-above,.mdc-text-field--outlined.mdc-text-field--textarea.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:var(--mdc-outlined-text-field-label-text-size)}.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading{border-top-left-radius:var(--mdc-outlined-text-field-container-shape);border-top-right-radius:0;border-bottom-right-radius:0;border-bottom-left-radius:var(--mdc-outlined-text-field-container-shape)}[dir=rtl] .mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading[dir=rtl]{border-top-left-radius:0;border-top-right-radius:var(--mdc-outlined-text-field-container-shape);border-bottom-right-radius:var(--mdc-outlined-text-field-container-shape);border-bottom-left-radius:0}@supports(top: max(0%)){.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__leading{width:max(12px,var(--mdc-outlined-text-field-container-shape))}}@supports(top: max(0%)){.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__notch{max-width:calc(100% - max(12px,var(--mdc-outlined-text-field-container-shape))*2)}}.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__trailing{border-top-left-radius:0;border-top-right-radius:var(--mdc-outlined-text-field-container-shape);border-bottom-right-radius:var(--mdc-outlined-text-field-container-shape);border-bottom-left-radius:0}[dir=rtl] .mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__trailing,.mdc-text-field--outlined .mdc-notched-outline .mdc-notched-outline__trailing[dir=rtl]{border-top-left-radius:var(--mdc-outlined-text-field-container-shape);border-top-right-radius:0;border-bottom-right-radius:0;border-bottom-left-radius:var(--mdc-outlined-text-field-container-shape)}@supports(top: max(0%)){.mdc-text-field--outlined{padding-left:max(16px,calc(var(--mdc-outlined-text-field-container-shape) + 4px))}}@supports(top: max(0%)){.mdc-text-field--outlined{padding-right:max(16px,var(--mdc-outlined-text-field-container-shape))}}@supports(top: max(0%)){.mdc-text-field--outlined+.mdc-text-field-helper-line{padding-left:max(16px,calc(var(--mdc-outlined-text-field-container-shape) + 4px))}}@supports(top: max(0%)){.mdc-text-field--outlined+.mdc-text-field-helper-line{padding-right:max(16px,var(--mdc-outlined-text-field-container-shape))}}.mdc-text-field--outlined.mdc-text-field--with-leading-icon{padding-left:0}@supports(top: max(0%)){.mdc-text-field--outlined.mdc-text-field--with-leading-icon{padding-right:max(16px,var(--mdc-outlined-text-field-container-shape))}}[dir=rtl] .mdc-text-field--outlined.mdc-text-field--with-leading-icon,.mdc-text-field--outlined.mdc-text-field--with-leading-icon[dir=rtl]{padding-right:0}@supports(top: max(0%)){[dir=rtl] .mdc-text-field--outlined.mdc-text-field--with-leading-icon,.mdc-text-field--outlined.mdc-text-field--with-leading-icon[dir=rtl]{padding-left:max(16px,var(--mdc-outlined-text-field-container-shape))}}.mdc-text-field--outlined.mdc-text-field--with-trailing-icon{padding-right:0}@supports(top: max(0%)){.mdc-text-field--outlined.mdc-text-field--with-trailing-icon{padding-left:max(16px,calc(var(--mdc-outlined-text-field-container-shape) + 4px))}}[dir=rtl] .mdc-text-field--outlined.mdc-text-field--with-trailing-icon,.mdc-text-field--outlined.mdc-text-field--with-trailing-icon[dir=rtl]{padding-left:0}@supports(top: max(0%)){[dir=rtl] .mdc-text-field--outlined.mdc-text-field--with-trailing-icon,.mdc-text-field--outlined.mdc-text-field--with-trailing-icon[dir=rtl]{padding-right:max(16px,calc(var(--mdc-outlined-text-field-container-shape) + 4px))}}.mdc-text-field--outlined.mdc-text-field--with-leading-icon.mdc-text-field--with-trailing-icon{padding-left:0;padding-right:0}.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-notched-outline__leading,.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-notched-outline__notch,.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-notched-outline__trailing{border-color:var(--mdc-outlined-text-field-outline-color)}.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--outlined:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-notched-outline .mdc-notched-outline__trailing{border-color:var(--mdc-outlined-text-field-hover-outline-color)}.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__leading,.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__notch,.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__trailing{border-color:var(--mdc-outlined-text-field-focus-outline-color)}.mdc-text-field--outlined.mdc-text-field--disabled .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--disabled .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--disabled .mdc-notched-outline__trailing{border-color:var(--mdc-outlined-text-field-disabled-outline-color)}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled) .mdc-notched-outline__trailing{border-color:var(--mdc-outlined-text-field-error-outline-color)}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled):not(.mdc-text-field--focused):hover .mdc-notched-outline .mdc-notched-outline__trailing{border-color:var(--mdc-outlined-text-field-error-hover-outline-color)}.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__leading,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__notch,.mdc-text-field--outlined.mdc-text-field--invalid:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline__trailing{border-color:var(--mdc-outlined-text-field-error-focus-outline-color)}.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--outlined:not(.mdc-text-field--disabled) .mdc-notched-outline .mdc-notched-outline__trailing{border-width:var(--mdc-outlined-text-field-outline-width)}.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline .mdc-notched-outline__leading,.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline .mdc-notched-outline__notch,.mdc-text-field--outlined:not(.mdc-text-field--disabled).mdc-text-field--focused .mdc-notched-outline .mdc-notched-outline__trailing{border-width:var(--mdc-outlined-text-field-focus-outline-width)}.mat-mdc-form-field-textarea-control{vertical-align:middle;resize:vertical;box-sizing:border-box;height:auto;margin:0;padding:0;border:none;overflow:auto}.mat-mdc-form-field-input-control.mat-mdc-form-field-input-control{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font:inherit;letter-spacing:inherit;text-decoration:inherit;text-transform:inherit;border:none}.mat-mdc-form-field .mat-mdc-floating-label.mdc-floating-label{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;line-height:normal;pointer-events:all}.mat-mdc-form-field:not(.mat-form-field-disabled) .mat-mdc-floating-label.mdc-floating-label{cursor:inherit}.mdc-text-field--no-label:not(.mdc-text-field--textarea) .mat-mdc-form-field-input-control.mdc-text-field__input,.mat-mdc-text-field-wrapper .mat-mdc-form-field-input-control{height:auto}.mat-mdc-text-field-wrapper .mat-mdc-form-field-input-control.mdc-text-field__input[type=color]{height:23px}.mat-mdc-text-field-wrapper{height:auto;flex:auto}.mat-mdc-form-field-has-icon-prefix .mat-mdc-text-field-wrapper{padding-left:0;--mat-mdc-form-field-label-offset-x: -16px}.mat-mdc-form-field-has-icon-suffix .mat-mdc-text-field-wrapper{padding-right:0}[dir=rtl] .mat-mdc-text-field-wrapper{padding-left:16px;padding-right:16px}[dir=rtl] .mat-mdc-form-field-has-icon-suffix .mat-mdc-text-field-wrapper{padding-left:0}[dir=rtl] .mat-mdc-form-field-has-icon-prefix .mat-mdc-text-field-wrapper{padding-right:0}.mat-form-field-disabled .mdc-text-field__input::placeholder{color:var(--mat-form-field-disabled-input-text-placeholder-color)}.mat-form-field-disabled .mdc-text-field__input::-moz-placeholder{color:var(--mat-form-field-disabled-input-text-placeholder-color)}.mat-form-field-disabled .mdc-text-field__input::-webkit-input-placeholder{color:var(--mat-form-field-disabled-input-text-placeholder-color)}.mat-form-field-disabled .mdc-text-field__input:-ms-input-placeholder{color:var(--mat-form-field-disabled-input-text-placeholder-color)}.mat-mdc-form-field-label-always-float .mdc-text-field__input::placeholder{transition-delay:40ms;transition-duration:110ms;opacity:1}.mat-mdc-text-field-wrapper .mat-mdc-form-field-infix .mat-mdc-floating-label{left:auto;right:auto}.mat-mdc-text-field-wrapper.mdc-text-field--outlined .mdc-text-field__input{display:inline-block}.mat-mdc-form-field .mat-mdc-text-field-wrapper.mdc-text-field .mdc-notched-outline__notch{padding-top:0}.mat-mdc-text-field-wrapper::before{content:none}.mat-mdc-form-field.mat-mdc-form-field.mat-mdc-form-field.mat-mdc-form-field.mat-mdc-form-field.mat-mdc-form-field .mdc-notched-outline__notch{border-left:1px solid rgba(0,0,0,0)}[dir=rtl] .mat-mdc-form-field.mat-mdc-form-field.mat-mdc-form-field.mat-mdc-form-field.mat-mdc-form-field.mat-mdc-form-field .mdc-notched-outline__notch{border-left:none;border-right:1px solid rgba(0,0,0,0)}.mat-mdc-form-field-infix{min-height:var(--mat-form-field-container-height);padding-top:var(--mat-form-field-filled-with-label-container-padding-top);padding-bottom:var(--mat-form-field-filled-with-label-container-padding-bottom)}.mdc-text-field--outlined .mat-mdc-form-field-infix,.mdc-text-field--no-label .mat-mdc-form-field-infix{padding-top:var(--mat-form-field-container-vertical-padding);padding-bottom:var(--mat-form-field-container-vertical-padding)}.mat-mdc-text-field-wrapper .mat-mdc-form-field-flex .mat-mdc-floating-label{top:calc(var(--mat-form-field-container-height)/2)}.mdc-text-field--filled .mat-mdc-floating-label{display:var(--mat-form-field-filled-label-display, block)}.mat-mdc-text-field-wrapper.mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{--mat-mdc-form-field-label-transform: translateY(calc(calc(6.75px + var(--mat-form-field-container-height) / 2) * -1)) scale(var(--mat-mdc-form-field-floating-label-scale, 0.75));transform:var(--mat-mdc-form-field-label-transform)}.mat-mdc-form-field-subscript-wrapper{box-sizing:border-box;width:100%;position:relative}.mat-mdc-form-field-hint-wrapper,.mat-mdc-form-field-error-wrapper{position:absolute;top:0;left:0;right:0;padding:0 16px}.mat-mdc-form-field-subscript-dynamic-size .mat-mdc-form-field-hint-wrapper,.mat-mdc-form-field-subscript-dynamic-size .mat-mdc-form-field-error-wrapper{position:static}.mat-mdc-form-field-bottom-align::before{content:"";display:inline-block;height:16px}.mat-mdc-form-field-bottom-align.mat-mdc-form-field-subscript-dynamic-size::before{content:unset}.mat-mdc-form-field-hint-end{order:1}.mat-mdc-form-field-hint-wrapper{display:flex}.mat-mdc-form-field-hint-spacer{flex:1 0 1em}.mat-mdc-form-field-error{display:block;color:var(--mat-form-field-error-text-color)}.mat-mdc-form-field-subscript-wrapper,.mat-mdc-form-field-bottom-align::before{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-family:var(--mat-form-field-subscript-text-font);line-height:var(--mat-form-field-subscript-text-line-height);font-size:var(--mat-form-field-subscript-text-size);letter-spacing:var(--mat-form-field-subscript-text-tracking);font-weight:var(--mat-form-field-subscript-text-weight)}.mat-mdc-form-field-focus-overlay{top:0;left:0;right:0;bottom:0;position:absolute;opacity:0;pointer-events:none;background-color:var(--mat-form-field-state-layer-color)}.mat-mdc-text-field-wrapper:hover .mat-mdc-form-field-focus-overlay{opacity:var(--mat-form-field-hover-state-layer-opacity)}.mat-mdc-form-field.mat-focused .mat-mdc-form-field-focus-overlay{opacity:var(--mat-form-field-focus-state-layer-opacity)}select.mat-mdc-form-field-input-control{-moz-appearance:none;-webkit-appearance:none;background-color:rgba(0,0,0,0);display:inline-flex;box-sizing:border-box}select.mat-mdc-form-field-input-control:not(:disabled){cursor:pointer}select.mat-mdc-form-field-input-control:not(.mat-mdc-native-select-inline) option{color:var(--mat-form-field-select-option-text-color)}select.mat-mdc-form-field-input-control:not(.mat-mdc-native-select-inline) option:disabled{color:var(--mat-form-field-select-disabled-option-text-color)}.mat-mdc-form-field-type-mat-native-select .mat-mdc-form-field-infix::after{content:"";width:0;height:0;border-left:5px solid rgba(0,0,0,0);border-right:5px solid rgba(0,0,0,0);border-top:5px solid;position:absolute;right:0;top:50%;margin-top:-2.5px;pointer-events:none;color:var(--mat-form-field-enabled-select-arrow-color)}[dir=rtl] .mat-mdc-form-field-type-mat-native-select .mat-mdc-form-field-infix::after{right:auto;left:0}.mat-mdc-form-field-type-mat-native-select.mat-focused .mat-mdc-form-field-infix::after{color:var(--mat-form-field-focus-select-arrow-color)}.mat-mdc-form-field-type-mat-native-select.mat-form-field-disabled .mat-mdc-form-field-infix::after{color:var(--mat-form-field-disabled-select-arrow-color)}.mat-mdc-form-field-type-mat-native-select .mat-mdc-form-field-input-control{padding-right:15px}[dir=rtl] .mat-mdc-form-field-type-mat-native-select .mat-mdc-form-field-input-control{padding-right:0;padding-left:15px}.cdk-high-contrast-active .mat-form-field-appearance-fill .mat-mdc-text-field-wrapper{outline:solid 1px}.cdk-high-contrast-active .mat-form-field-appearance-fill.mat-form-field-disabled .mat-mdc-text-field-wrapper{outline-color:GrayText}.cdk-high-contrast-active .mat-form-field-appearance-fill.mat-focused .mat-mdc-text-field-wrapper{outline:dashed 3px}.cdk-high-contrast-active .mat-mdc-form-field.mat-focused .mdc-notched-outline{border:dashed 3px}.mat-mdc-form-field-input-control[type=date],.mat-mdc-form-field-input-control[type=datetime],.mat-mdc-form-field-input-control[type=datetime-local],.mat-mdc-form-field-input-control[type=month],.mat-mdc-form-field-input-control[type=week],.mat-mdc-form-field-input-control[type=time]{line-height:1}.mat-mdc-form-field-input-control::-webkit-datetime-edit{line-height:1;padding:0;margin-bottom:-2px}.mat-mdc-form-field{--mat-mdc-form-field-floating-label-scale: 0.75;display:inline-flex;flex-direction:column;min-width:0;text-align:left;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;font-family:var(--mat-form-field-container-text-font);line-height:var(--mat-form-field-container-text-line-height);font-size:var(--mat-form-field-container-text-size);letter-spacing:var(--mat-form-field-container-text-tracking);font-weight:var(--mat-form-field-container-text-weight)}[dir=rtl] .mat-mdc-form-field{text-align:right}.mat-mdc-form-field .mdc-text-field--outlined .mdc-floating-label--float-above{font-size:calc(var(--mat-form-field-outlined-label-text-populated-size)*var(--mat-mdc-form-field-floating-label-scale))}.mat-mdc-form-field .mdc-text-field--outlined .mdc-notched-outline--upgraded .mdc-floating-label--float-above{font-size:var(--mat-form-field-outlined-label-text-populated-size)}.mat-mdc-form-field-flex{display:inline-flex;align-items:baseline;box-sizing:border-box;width:100%}.mat-mdc-text-field-wrapper{width:100%;z-index:0}.mat-mdc-form-field-icon-prefix,.mat-mdc-form-field-icon-suffix{align-self:center;line-height:0;pointer-events:auto;position:relative;z-index:1}.mat-mdc-form-field-icon-prefix>.mat-icon,.mat-mdc-form-field-icon-suffix>.mat-icon{padding:0 12px;box-sizing:content-box}.mat-mdc-form-field-icon-prefix{color:var(--mat-form-field-leading-icon-color)}.mat-form-field-disabled .mat-mdc-form-field-icon-prefix{color:var(--mat-form-field-disabled-leading-icon-color)}.mat-mdc-form-field-icon-suffix{color:var(--mat-form-field-trailing-icon-color)}.mat-form-field-disabled .mat-mdc-form-field-icon-suffix{color:var(--mat-form-field-disabled-trailing-icon-color)}.mat-form-field-invalid .mat-mdc-form-field-icon-suffix{color:var(--mat-form-field-error-trailing-icon-color)}.mat-form-field-invalid:not(.mat-focused):not(.mat-form-field-disabled) .mat-mdc-text-field-wrapper:hover .mat-mdc-form-field-icon-suffix{color:var(--mat-form-field-error-hover-trailing-icon-color)}.mat-form-field-invalid.mat-focused .mat-mdc-text-field-wrapper .mat-mdc-form-field-icon-suffix{color:var(--mat-form-field-error-focus-trailing-icon-color)}.mat-mdc-form-field-icon-prefix,[dir=rtl] .mat-mdc-form-field-icon-suffix{padding:0 4px 0 0}.mat-mdc-form-field-icon-suffix,[dir=rtl] .mat-mdc-form-field-icon-prefix{padding:0 0 0 4px}.mat-mdc-form-field-subscript-wrapper .mat-icon,.mat-mdc-form-field label .mat-icon{width:1em;height:1em;font-size:inherit}.mat-mdc-form-field-infix{flex:auto;min-width:0;width:180px;position:relative;box-sizing:border-box}.mat-mdc-form-field .mdc-notched-outline__notch{margin-left:-1px;-webkit-clip-path:inset(-9em -999em -9em 1px);clip-path:inset(-9em -999em -9em 1px)}[dir=rtl] .mat-mdc-form-field .mdc-notched-outline__notch{margin-left:0;margin-right:-1px;-webkit-clip-path:inset(-9em 1px -9em -999em);clip-path:inset(-9em 1px -9em -999em)}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field__input{transition:opacity 150ms 0ms cubic-bezier(0.4, 0, 0.2, 1)}@media all{.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field__input::placeholder{transition:opacity 67ms 0ms cubic-bezier(0.4, 0, 0.2, 1)}}@media all{.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field__input:-ms-input-placeholder{transition:opacity 67ms 0ms cubic-bezier(0.4, 0, 0.2, 1)}}@media all{.mdc-text-field--no-label .mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field__input::placeholder,.mdc-text-field--focused .mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field__input::placeholder{transition-delay:40ms;transition-duration:110ms}}@media all{.mdc-text-field--no-label .mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field__input:-ms-input-placeholder,.mdc-text-field--focused .mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field__input:-ms-input-placeholder{transition-delay:40ms;transition-duration:110ms}}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field__affix{transition:opacity 150ms 0ms cubic-bezier(0.4, 0, 0.2, 1)}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field--filled.mdc-ripple-upgraded--background-focused .mdc-text-field__ripple::before,.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field--filled:not(.mdc-ripple-upgraded):focus .mdc-text-field__ripple::before{transition-duration:75ms}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field--outlined .mdc-floating-label--shake{animation:mdc-floating-label-shake-float-above-text-field-outlined 250ms 1}@keyframes mdc-floating-label-shake-float-above-text-field-outlined{0%{transform:translateX(calc(0% - 0%)) translateY(calc(0% - 34.75px)) scale(0.75)}33%{animation-timing-function:cubic-bezier(0.5, 0, 0.701732, 0.495819);transform:translateX(calc(4% - 0%)) translateY(calc(0% - 34.75px)) scale(0.75)}66%{animation-timing-function:cubic-bezier(0.302435, 0.381352, 0.55, 0.956352);transform:translateX(calc(-4% - 0%)) translateY(calc(0% - 34.75px)) scale(0.75)}100%{transform:translateX(calc(0% - 0%)) translateY(calc(0% - 34.75px)) scale(0.75)}}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field--textarea{transition:none}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field--textarea.mdc-text-field--filled .mdc-floating-label--shake{animation:mdc-floating-label-shake-float-above-textarea-filled 250ms 1}@keyframes mdc-floating-label-shake-float-above-textarea-filled{0%{transform:translateX(calc(0% - 0%)) translateY(calc(0% - 10.25px)) scale(0.75)}33%{animation-timing-function:cubic-bezier(0.5, 0, 0.701732, 0.495819);transform:translateX(calc(4% - 0%)) translateY(calc(0% - 10.25px)) scale(0.75)}66%{animation-timing-function:cubic-bezier(0.302435, 0.381352, 0.55, 0.956352);transform:translateX(calc(-4% - 0%)) translateY(calc(0% - 10.25px)) scale(0.75)}100%{transform:translateX(calc(0% - 0%)) translateY(calc(0% - 10.25px)) scale(0.75)}}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field--textarea.mdc-text-field--outlined .mdc-floating-label--shake{animation:mdc-floating-label-shake-float-above-textarea-outlined 250ms 1}@keyframes mdc-floating-label-shake-float-above-textarea-outlined{0%{transform:translateX(calc(0% - 0%)) translateY(calc(0% - 24.75px)) scale(0.75)}33%{animation-timing-function:cubic-bezier(0.5, 0, 0.701732, 0.495819);transform:translateX(calc(4% - 0%)) translateY(calc(0% - 24.75px)) scale(0.75)}66%{animation-timing-function:cubic-bezier(0.302435, 0.381352, 0.55, 0.956352);transform:translateX(calc(-4% - 0%)) translateY(calc(0% - 24.75px)) scale(0.75)}100%{transform:translateX(calc(0% - 0%)) translateY(calc(0% - 24.75px)) scale(0.75)}}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--shake{animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon 250ms 1}@keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon{0%{transform:translateX(calc(0% - 32px)) translateY(calc(0% - 34.75px)) scale(0.75)}33%{animation-timing-function:cubic-bezier(0.5, 0, 0.701732, 0.495819);transform:translateX(calc(4% - 32px)) translateY(calc(0% - 34.75px)) scale(0.75)}66%{animation-timing-function:cubic-bezier(0.302435, 0.381352, 0.55, 0.956352);transform:translateX(calc(-4% - 32px)) translateY(calc(0% - 34.75px)) scale(0.75)}100%{transform:translateX(calc(0% - 32px)) translateY(calc(0% - 34.75px)) scale(0.75)}}[dir=rtl] .mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field--with-leading-icon.mdc-text-field--outlined .mdc-floating-label--shake,.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-text-field--with-leading-icon.mdc-text-field--outlined[dir=rtl] .mdc-floating-label--shake{animation:mdc-floating-label-shake-float-above-text-field-outlined-leading-icon 250ms 1}@keyframes mdc-floating-label-shake-float-above-text-field-outlined-leading-icon-rtl{0%{transform:translateX(calc(0% - -32px)) translateY(calc(0% - 34.75px)) scale(0.75)}33%{animation-timing-function:cubic-bezier(0.5, 0, 0.701732, 0.495819);transform:translateX(calc(4% - -32px)) translateY(calc(0% - 34.75px)) scale(0.75)}66%{animation-timing-function:cubic-bezier(0.302435, 0.381352, 0.55, 0.956352);transform:translateX(calc(-4% - -32px)) translateY(calc(0% - 34.75px)) scale(0.75)}100%{transform:translateX(calc(0% - -32px)) translateY(calc(0% - 34.75px)) scale(0.75)}}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-floating-label{transition:transform 150ms cubic-bezier(0.4, 0, 0.2, 1),color 150ms cubic-bezier(0.4, 0, 0.2, 1)}.mdc-floating-label--shake{animation:mdc-floating-label-shake-float-above-standard 250ms 1}@keyframes mdc-floating-label-shake-float-above-standard{0%{transform:translateX(calc(0% - 0%)) translateY(calc(0% - 106%)) scale(0.75)}33%{animation-timing-function:cubic-bezier(0.5, 0, 0.701732, 0.495819);transform:translateX(calc(4% - 0%)) translateY(calc(0% - 106%)) scale(0.75)}66%{animation-timing-function:cubic-bezier(0.302435, 0.381352, 0.55, 0.956352);transform:translateX(calc(-4% - 0%)) translateY(calc(0% - 106%)) scale(0.75)}100%{transform:translateX(calc(0% - 0%)) translateY(calc(0% - 106%)) scale(0.75)}}.mat-mdc-form-field:not(.mat-form-field-no-animations) .mdc-line-ripple::after{transition:transform 180ms cubic-bezier(0.4, 0, 0.2, 1),opacity 180ms cubic-bezier(0.4, 0, 0.2, 1)}.mdc-notched-outline .mdc-floating-label{max-width:calc(100% + 1px)}.mdc-notched-outline--upgraded .mdc-floating-label--float-above{max-width:calc(133.3333333333% + 1px)}\n'],
ob:2,data:{animation:[mA]},Qa:0});var WA=class{};WA.J=function(a){return new (a||WA)};WA.Wa=Mf({type:WA});WA.Va=Md({imports:[fz,et,gy,fz]});var YA={na:jw,zb:af(()=>XA),Db:!0},ZA=new df("mat-autocomplete-scroll-strategy",{da:"root",aa:()=>{const a=lf(Wv);return()=>a.i.i()}}),$A={na:ZA,zc:[Wv],Ec:function(a){return()=>a.i.i()}};function aB(a){let b;return(null==(b=a.ha)?void 0:b.defaultView)||window}
function bB(a){a.sd();a.F&&(a.pb&&a.xb.run(()=>{a.autocomplete.closed.emit()}),a.autocomplete.G===a&&(a.autocomplete.C=!1,a.autocomplete.G=null),a.F=!1,a.G=null,a.ka&&a.ka.fc()&&(a.ka.detach(),a.Cc.unsubscribe()),a.Ta(),a.fb||$m(a.Aa),a.D&&ny(a.D,"aria-owns",a.autocomplete.id))}function cB(a){const b=a.i.P;return!b.readOnly&&!b.disabled&&!a.Ti}
function dB(a,b){let c=a.ka;if(c)Eu(a.O,a.ra()),c.me({width:a.ta()});else{let e;a.Hc=new Pv(a.autocomplete.sa,a.Ic,{id:null==(e=a.C)?void 0:e.ph()?e.Te:null});c=a.ab.create(eB(a));a.ka=c;a.Mb=a.Vc.vb().subscribe(()=>{a.pb&&c&&c.me({width:a.ta()})})}c&&!c.fc()&&(c.attach(a.Hc),a.Ud=b,a.N=null,a.Cc=a.Qd());b=a.pb;a.autocomplete.C=a.F=!0;a.autocomplete.G=a;let d;a.autocomplete.ea(null==(d=a.C)?void 0:d.color);a.Ta();fB(a);a.pb&&b!==a.pb&&a.kb()}
function gB(a,b=!1){a.C&&"auto"===a.C.wg&&(b?a.C.ma():a.C.wg="always",a.Da=!0)}function eB(a){let b,c;const d=yv(wv(Lv(a.ab.position(),a.ra()),!1),!1);a.Jb(d);a.O=d;return new xu({sc:d,tc:a.Jc(),width:a.ta(),direction:null!=(c=a.Gc)?c:void 0,gb:null==(b=a.Fc)?void 0:b.Wh})}function fB(a){const b=a.i.P.closest('body > .cdk-overlay-container [aria-modal="true"]');if(b){var c=a.autocomplete.id;a.D&&ny(a.D,"aria-owns",c);ly(b,"aria-owns",c);a.D=b}}
var XA=class{constructor(a,b,c,d,e,f,g,k,m,p,t){this.i=a;this.ab=b;this.Ic=c;this.xb=d;this.Aa=e;this.Gc=g;this.C=k;this.ha=m;this.Vc=p;this.Fc=t;this.Da=this.fb=!1;this.Mb=Li.EMPTY;this.ia=!0;this.ma=new aj;this.Nb=()=>{this.ia=this.ha.activeElement!==this.i.P||this.pb};this.K=()=>{};this.Yd=()=>{};this.position="auto";this.Lu="off";this.ea=new aj;this.Ya=lf(Vh);this.Ne="mat-mdc-autocomplete-panel-above";this.F=!1;this.uc=gk(()=>{const v=this.autocomplete?this.autocomplete.options:null;return v?
C(v.i,Fo(v),Go(()=>pk(...v.map(B=>B.io)))):C(this.ea,Go(()=>this.uc))});this.rd=v=>{if(27===v.keyCode&&!yu(v)||38===v.keyCode&&yu(v,"altKey")){if(this.G){let B;this.Kb(null!=(B=this.Rd)?B:"");this.G=null}this.ma.next();this.Ra();v.stopPropagation();v.preventDefault()}};this.D=null;this.Jc=f}nd(){this.ea.next();this.ea.complete();const a=aB(this);"undefined"!==typeof a&&Kk(this.xb,()=>a.addEventListener("blur",this.Nb))}rc(a){a.position&&this.O&&(this.Jb(this.O),this.pb&&this.ka.Uc())}ua(){const a=
aB(this);"undefined"!==typeof a&&a.removeEventListener("blur",this.Nb);this.Mb.unsubscribe();this.fb=!0;this.Wc();this.ma.complete();this.D&&(ny(this.D,"aria-owns",this.autocomplete.id),this.D=null)}get pb(){return this.F&&this.autocomplete.Yl}Uc(){this.F&&this.ka.Uc()}get Vd(){return C(pk(this.uc,C(this.autocomplete.i.ba,rk(()=>this.F)),this.ma,this.qd(),this.ka?C(this.ka.G,rk(()=>this.F)):hj()),vj(a=>a instanceof Mz?a:null))}get xh(){return this.autocomplete&&this.autocomplete.i?this.autocomplete.i.i:
null}qd(){return C(pk(jk(this.ha,"click"),jk(this.ha,"auxclick"),jk(this.ha,"touchend")),rk(a=>{a=Pt(a);const b=this.C?TA(this.C).P:null,c=this.en?this.en.dc.P:null;return this.F&&a!==this.i.P&&this.ha.activeElement!==this.i.P&&(!b||!b.contains(a))&&(!c||!c.contains(a))&&!!this.ka&&!this.ka.K.contains(a)}))}pi(a){Promise.resolve(null).then(()=>this.R(a))}Lg(a){this.K=a}Ij(a){this.Yd=a}gi(a){this.i.P.disabled=a}Re(a){const b=a.keyCode,c=yu(a);27!==b||c||a.preventDefault();this.N=this.i.P.value;if(this.xh&&
13===b&&this.pb&&!c)this.xh.uh(),this.Ra(),a.preventDefault();else if(this.autocomplete){const d=this.autocomplete.i.i,e=38===b||40===b;9===b||e&&!c&&this.pb?Ny(this.autocomplete.i,a):e&&cB(this)&&this.Ia(this.N);if(e||this.autocomplete.i.i!==d)this.Od(this.autocomplete.i.N||0),this.autocomplete.Tm&&this.xh&&(this.G||(this.Rd=this.N),this.G=this.xh,this.R(this.xh.value))}}sp(a){var b=a.target;let c=b.value;"number"===b.type&&(c=""==c?null:parseFloat(c));if(this.ba!==c){this.ba=c;this.G=null;this.autocomplete&&
this.autocomplete.Kj||this.K(c);if(!c)this.T(null,!1);else if(this.pb&&!this.autocomplete.Kj){var d;if(b=null==(d=this.autocomplete.options)?void 0:d.find(e=>e.selected))d=this.rb(b.value),c!==d&&Nz(b,!1)}if(cB(this)&&this.ha.activeElement===a.target){let e;a=null!=(e=this.N)?e:this.i.P.value;this.N=null;this.Ia(a)}}}Xz(){this.ia?cB(this)&&(this.ba=this.i.P.value,dB(this,this.ba),gB(this,!0)):this.ia=!0}pk(){cB(this)&&!this.pb&&this.Ia()}sd(){this.Da&&(this.C&&(this.C.wg="auto"),this.Da=!1)}Qd(){const a=
new Vi(c=>{Zk(()=>{c.next()},{wa:this.Ya})}),b=C(this.autocomplete.options.i,No(()=>Fu(this.O)),Vn());return C(pk(a,b),Go(()=>this.xb.run(()=>{const c=this.pb;this.Ra();this.Ta();$m(this.Aa);this.pb&&this.ka.Uc();c!==this.pb&&(this.pb?this.kb():this.autocomplete.closed.emit());return this.Vd})),co()).subscribe(c=>this.Pd(c))}kb(){this.autocomplete.gf.emit()}Wc(){this.ka&&(bB(this),this.ka.dispose(),this.ka=null)}rb(a){const b=this.autocomplete;return b&&b.wq?b.wq(a):a}R(a){const b=this.rb(a);null==
a&&this.T(null,!1);this.Kb(null!=b?b:"")}Kb(a){this.C?this.C.Gb.value=a:this.i.P.value=a;this.ba=a}Pd(a){const b=this.autocomplete;(a=a?a.source:this.G)?(this.T(a),this.R(a.value),this.K(a.value),b.T(a),this.i.P.focus()):b.Kj&&this.i.P.value!==this.Ud&&(this.T(null),this.R(null),b.hg?C(b.hg,co()).subscribe(()=>this.K(null)):this.K(null));bB(this)}T(a,b){let c,d;null==(c=this.autocomplete)||null==(d=c.options)||d.forEach(e=>{e!==a&&e.selected&&Nz(e,b)})}Ia(a=this.i.P.value){dB(this,a);gB(this);this.D&&
ly(this.D,"aria-owns",this.autocomplete.id)}Ta(){this.autocomplete.N();if(this.pb){var a=this.ka;this.va||(this.va=a.df().subscribe(this.rd));this.Oa||(this.Oa=a.Kl().subscribe())}else{null==(a=this.va)||a.unsubscribe();let b;null==(b=this.Oa)||b.unsubscribe();this.va=this.Oa=null}}Jb(a){var b=[{bb:"start",cb:"bottom",La:"start",Sa:"top"},{bb:"end",cb:"bottom",La:"end",Sa:"top"}];const c=[{bb:"start",cb:"top",La:"start",Sa:"bottom",gb:"mat-mdc-autocomplete-panel-above"},{bb:"end",cb:"top",La:"end",
Sa:"bottom",gb:"mat-mdc-autocomplete-panel-above"}];b="above"===this.position?c:"below"===this.position?b:[...b,...c];Hu(a,b)}ra(){return this.en?this.en.dc:this.C?TA(this.C):this.i}ta(){return this.autocomplete.Gg||this.jd()}jd(){return this.ra().P.getBoundingClientRect().width}Ra(){const a=this.autocomplete;if(a.Rm){let b=-1;for(let c=0;c<a.options.length;c++)if(!a.options.get(c).disabled){b=c;break}a.i.C(b)}else a.i.C(-1)}Od(a){const b=this.autocomplete,c=Pz(a,b.options,b.Hr);0===a&&1===c?b.K(0):
b.Wf&&(a=b.options.toArray()[a])&&(a=a.pe(),b.K(Qz(a.offsetTop,a.offsetHeight,b.ba(),b.Wf.P.offsetHeight)))}};XA.J=function(a){return new (a||XA)(y(qi),y(Wv),y(ip),y(Ok),y(Pr),y(ZA),y(lu,8),y(QA,9),y(gt,8),y(tu),y(eA,8))};
XA.Ea=Of({type:XA,ga:[["input","matAutocomplete",""],["textarea","matAutocomplete",""]],Ja:[1,"mat-mdc-autocomplete-trigger"],Xa:7,Ha:function(a,b){a&1&&V("focusin",function(){return b.Xz()})("blur",function(){return b.Yd()})("input",function(c){return b.sp(c)})("keydown",function(c){return b.Re(c)})("click",function(){return b.pk()});a&2&&Ip("autocomplete",b.Lu)("role",b.Ti?null:"combobox")("aria-autocomplete",b.Ti?null:"list")("aria-activedescendant",b.pb&&b.xh?b.xh.id:null)("aria-expanded",b.Ti?
null:b.pb.toString())("aria-controls",b.Ti||!b.pb?null:null==b.autocomplete?null:b.autocomplete.id)("aria-haspopup",b.Ti?null:"listbox")},inputs:{autocomplete:[0,"matAutocomplete","autocomplete"],position:[0,"matAutocompletePosition","position"],en:[0,"matAutocompleteConnectedTo","connectedTo"],Lu:[0,"autocomplete","autocompleteAttribute"],Ti:[2,"matAutocompleteDisabled","autocompleteDisabled",ws]},hb:["matAutocompleteTrigger"],ja:!0,features:[Hr([YA]),Hp,Cg]});var hB=class{};hB.J=function(a){return new (a||hB)};hB.Wa=Mf({type:hB});hB.Va=Md({Ua:[$A],imports:[dw,Tz,fz,et,uu,Tz,fz]});var iB=class{};iB.J=function(a){return new (a||iB)};iB.Wa=Mf({type:iB});iB.Va=Md({imports:[hB]});var jB=new df("GMAT_BUTTON_OPTIONS",{da:"root",aa:()=>({qc:!1})});var kB=new df("MAT_BUTTON_CONFIG");
const lB=[{yh:"mat-button",Qh:["mdc-button","mat-mdc-button"]},{yh:"mat-flat-button",Qh:["mdc-button","mdc-button--unelevated","mat-mdc-unelevated-button"]},{yh:"mat-raised-button",Qh:["mdc-button","mdc-button--raised","mat-mdc-raised-button"]},{yh:"mat-stroked-button",Qh:["mdc-button","mdc-button--outlined","mat-mdc-outlined-button"]},{yh:"mat-fab",Qh:["mdc-fab","mat-mdc-fab"]},{yh:"mat-mini-fab",Qh:["mdc-fab","mdc-fab--mini","mat-mdc-mini-fab"]},{yh:"mat-icon-button",Qh:["mdc-icon-button","mat-mdc-icon-button"]}];
var mB=class{get vx(){var a;if(null==(a=this.i))a=void 0;else{var b=this.qa.P;a=a.i.get(b)||a.D(b)}return a}set vx(a){let b;null==(b=this.i)||Yz(b,this.qa.P,a)}get Lc(){return this.D}set Lc(a){this.D=a;this.F()}get disabled(){return this.Hb}set disabled(a){this.Hb=a;this.F()}constructor(a,b,c,d){this.qa=a;this.Ka=b;this.pa=c;this.Yc=d;this.C=lf(Ix);this.i=lf(Zz);this.Hb=this.D=this.Yt=!1;const e=lf(kB,{optional:!0}),f=a.P,g=f.classList;let k;this.gj=null!=(k=null==e?void 0:e.gj)?k:!1;let m;null==
(m=this.i)||Xz(m,f,{className:"mat-mdc-button-ripple"});for(const {yh:p,Qh:t}of lB)f.hasAttribute(p)&&g.add(...t)}nd(){Fx(this.C,this.qa,!0)}ua(){Gx(this.C,this.qa);let a;null==(a=this.i)||Wz(a,this.qa.P)}focus(a="program",b){a?Hx(this.C,this.qa.P,a,b):this.qa.P.focus(b)}Dt(){return null!=this.ariaDisabled?this.ariaDisabled:this.disabled&&this.gj?!0:null}Et(){return this.gj||!this.disabled?null:!0}F(){var a;if(null!=(a=this.i)){var b=this.qa.P,c=this.Lc||this.disabled;(a=a.i.get(b))?a.disabled=c:
c?b.setAttribute("mat-ripple-loader-disabled",""):b.removeAttribute("mat-ripple-loader-disabled")}}};mB.J=function(){throw Error("invalid");};mB.Ea=Of({type:mB,inputs:{color:"color",Lc:[2,"disableRipple","disableRipple",ws],disabled:[2,"disabled","disabled",ws],ariaDisabled:[2,"aria-disabled","ariaDisabled",ws],gj:[2,"disabledInteractive","disabledInteractive",ws]},features:[Hp]});const nB=[[["",8,"material-icons",3,"iconPositionEnd",""],["mat-icon",3,"iconPositionEnd",""],["","matButtonIcon","",3,"iconPositionEnd",""]],"*",[["","iconPositionEnd","",8,"material-icons"],["mat-icon","iconPositionEnd",""],["","matButtonIcon","","iconPositionEnd",""]]];var oB=class extends mB{};oB.J=function(a){return new (a||oB)(y(qi),y(St),y(Ok),y(ki,8))};
oB.Ca=Gf({type:oB,ga:[["button","mat-button",""],["button","mat-raised-button",""],["button","mat-flat-button",""],["button","mat-stroked-button",""]],Xa:14,Ha:function(a,b){a&2&&(Ip("disabled",b.Et())("aria-disabled",b.Dt()),oq(rq,b.color?"mat-"+b.color:""),lq("mat-mdc-button-disabled",b.disabled)("mat-mdc-button-disabled-interactive",b.gj)("_mat-animation-noopable","NoopAnimations"===b.Yc)("mat-unthemed",!b.color)("mat-mdc-button-base",!0))},hb:["matButton"],ja:!0,features:[Ap,Jr],attrs:["mat-button",
""],Yb:[".material-icons:not([iconPositionEnd]), mat-icon:not([iconPositionEnd]), [matButtonIcon]:not([iconPositionEnd])","*",".material-icons[iconPositionEnd], mat-icon[iconPositionEnd], [matButtonIcon][iconPositionEnd]"],ya:7,za:4,Ba:[[1,"mat-mdc-button-persistent-ripple"],[1,"mdc-button__label"],[1,"mat-mdc-focus-indicator"],[1,"mat-mdc-button-touch-target"]],sa:function(a,b){a&1&&(Vq(nB),Kq(0,"span",0),Wq(1),R(2,"span",1),Wq(3,1),S(),Wq(4,2),Kq(5,"span",2)(6,"span",3));a&2&&lq("mdc-button__ripple",
!b.Yt)("mdc-fab__ripple",b.Yt)},styles:['.mdc-button{position:relative;display:inline-flex;align-items:center;justify-content:center;box-sizing:border-box;min-width:64px;border:none;outline:none;line-height:inherit;user-select:none;-webkit-appearance:none;overflow:visible;vertical-align:middle;background:rgba(0,0,0,0)}.mdc-button .mdc-elevation-overlay{width:100%;height:100%;top:0;left:0}.mdc-button::-moz-focus-inner{padding:0;border:0}.mdc-button:active{outline:none}.mdc-button:hover{cursor:pointer}.mdc-button:disabled{cursor:default;pointer-events:none}.mdc-button[hidden]{display:none}.mdc-button .mdc-button__icon{margin-left:0;margin-right:8px;display:inline-block;position:relative;vertical-align:top}[dir=rtl] .mdc-button .mdc-button__icon,.mdc-button .mdc-button__icon[dir=rtl]{margin-left:8px;margin-right:0}.mdc-button .mdc-button__progress-indicator{font-size:0;position:absolute;transform:translate(-50%, -50%);top:50%;left:50%;line-height:initial}.mdc-button .mdc-button__label{position:relative}.mdc-button .mdc-button__focus-ring{pointer-events:none;border:2px solid rgba(0,0,0,0);border-radius:6px;box-sizing:content-box;position:absolute;top:50%;left:50%;transform:translate(-50%, -50%);height:calc(100% + 4px);width:calc(100% + 4px);display:none}@media screen and (forced-colors: active){.mdc-button .mdc-button__focus-ring{border-color:CanvasText}}.mdc-button .mdc-button__focus-ring::after{content:"";border:2px solid rgba(0,0,0,0);border-radius:8px;display:block;position:absolute;top:50%;left:50%;transform:translate(-50%, -50%);height:calc(100% + 4px);width:calc(100% + 4px)}@media screen and (forced-colors: active){.mdc-button .mdc-button__focus-ring::after{border-color:CanvasText}}@media screen and (forced-colors: active){.mdc-button.mdc-ripple-upgraded--background-focused .mdc-button__focus-ring,.mdc-button:not(.mdc-ripple-upgraded):focus .mdc-button__focus-ring{display:block}}.mdc-button .mdc-button__touch{position:absolute;top:50%;height:48px;left:0;right:0;transform:translateY(-50%)}.mdc-button__label+.mdc-button__icon{margin-left:8px;margin-right:0}[dir=rtl] .mdc-button__label+.mdc-button__icon,.mdc-button__label+.mdc-button__icon[dir=rtl]{margin-left:0;margin-right:8px}svg.mdc-button__icon{fill:currentColor}.mdc-button--touch{margin-top:6px;margin-bottom:6px}.mdc-button{padding:0 8px 0 8px}.mdc-button--unelevated{transition:box-shadow 280ms cubic-bezier(0.4, 0, 0.2, 1);padding:0 16px 0 16px}.mdc-button--unelevated.mdc-button--icon-trailing{padding:0 12px 0 16px}.mdc-button--unelevated.mdc-button--icon-leading{padding:0 16px 0 12px}.mdc-button--raised{transition:box-shadow 280ms cubic-bezier(0.4, 0, 0.2, 1);padding:0 16px 0 16px}.mdc-button--raised.mdc-button--icon-trailing{padding:0 12px 0 16px}.mdc-button--raised.mdc-button--icon-leading{padding:0 16px 0 12px}.mdc-button--outlined{border-style:solid;transition:border 280ms cubic-bezier(0.4, 0, 0.2, 1)}.mdc-button--outlined .mdc-button__ripple{border-style:solid;border-color:rgba(0,0,0,0)}.mat-mdc-button{font-family:var(--mdc-text-button-label-text-font);font-size:var(--mdc-text-button-label-text-size);letter-spacing:var(--mdc-text-button-label-text-tracking);font-weight:var(--mdc-text-button-label-text-weight);text-transform:var(--mdc-text-button-label-text-transform);height:var(--mdc-text-button-container-height);border-radius:var(--mdc-text-button-container-shape);padding:0 var(--mat-text-button-horizontal-padding, 8px)}.mat-mdc-button:not(:disabled){color:var(--mdc-text-button-label-text-color)}.mat-mdc-button:disabled{color:var(--mdc-text-button-disabled-label-text-color)}.mat-mdc-button .mdc-button__ripple{border-radius:var(--mdc-text-button-container-shape)}.mat-mdc-button:has(.material-icons,mat-icon,[matButtonIcon]){padding:0 var(--mat-text-button-with-icon-horizontal-padding, 8px)}.mat-mdc-button>.mat-icon{margin-right:var(--mat-text-button-icon-spacing, 8px);margin-left:var(--mat-text-button-icon-offset, 0)}[dir=rtl] .mat-mdc-button>.mat-icon{margin-right:var(--mat-text-button-icon-offset, 0);margin-left:var(--mat-text-button-icon-spacing, 8px)}.mat-mdc-button .mdc-button__label+.mat-icon{margin-right:var(--mat-text-button-icon-offset, 0);margin-left:var(--mat-text-button-icon-spacing, 8px)}[dir=rtl] .mat-mdc-button .mdc-button__label+.mat-icon{margin-right:var(--mat-text-button-icon-spacing, 8px);margin-left:var(--mat-text-button-icon-offset, 0)}.mat-mdc-button .mat-ripple-element{background-color:var(--mat-text-button-ripple-color)}.mat-mdc-button .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-text-button-state-layer-color)}.mat-mdc-button.mat-mdc-button-disabled .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-text-button-disabled-state-layer-color)}.mat-mdc-button:hover .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-text-button-hover-state-layer-opacity)}.mat-mdc-button.cdk-program-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-button.cdk-keyboard-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-button.mat-mdc-button-disabled-interactive:focus .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-text-button-focus-state-layer-opacity)}.mat-mdc-button:active .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-text-button-pressed-state-layer-opacity)}.mat-mdc-button .mat-mdc-button-touch-target{position:absolute;top:50%;height:48px;left:0;right:0;transform:translateY(-50%);display:var(--mat-text-button-touch-target-display)}.mat-mdc-button[disabled],.mat-mdc-button.mat-mdc-button-disabled{cursor:default;pointer-events:none;color:var(--mdc-text-button-disabled-label-text-color)}.mat-mdc-button.mat-mdc-button-disabled-interactive{pointer-events:auto}.mat-mdc-unelevated-button{font-family:var(--mdc-filled-button-label-text-font);font-size:var(--mdc-filled-button-label-text-size);letter-spacing:var(--mdc-filled-button-label-text-tracking);font-weight:var(--mdc-filled-button-label-text-weight);text-transform:var(--mdc-filled-button-label-text-transform);height:var(--mdc-filled-button-container-height);border-radius:var(--mdc-filled-button-container-shape);padding:0 var(--mat-filled-button-horizontal-padding, 16px)}.mat-mdc-unelevated-button:not(:disabled){background-color:var(--mdc-filled-button-container-color)}.mat-mdc-unelevated-button:disabled{background-color:var(--mdc-filled-button-disabled-container-color)}.mat-mdc-unelevated-button:not(:disabled){color:var(--mdc-filled-button-label-text-color)}.mat-mdc-unelevated-button:disabled{color:var(--mdc-filled-button-disabled-label-text-color)}.mat-mdc-unelevated-button .mdc-button__ripple{border-radius:var(--mdc-filled-button-container-shape)}.mat-mdc-unelevated-button>.mat-icon{margin-right:var(--mat-filled-button-icon-spacing, 8px);margin-left:var(--mat-filled-button-icon-offset, -4px)}[dir=rtl] .mat-mdc-unelevated-button>.mat-icon{margin-right:var(--mat-filled-button-icon-offset, -4px);margin-left:var(--mat-filled-button-icon-spacing, 8px)}.mat-mdc-unelevated-button .mdc-button__label+.mat-icon{margin-right:var(--mat-filled-button-icon-offset, -4px);margin-left:var(--mat-filled-button-icon-spacing, 8px)}[dir=rtl] .mat-mdc-unelevated-button .mdc-button__label+.mat-icon{margin-right:var(--mat-filled-button-icon-spacing, 8px);margin-left:var(--mat-filled-button-icon-offset, -4px)}.mat-mdc-unelevated-button .mat-ripple-element{background-color:var(--mat-filled-button-ripple-color)}.mat-mdc-unelevated-button .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-filled-button-state-layer-color)}.mat-mdc-unelevated-button.mat-mdc-button-disabled .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-filled-button-disabled-state-layer-color)}.mat-mdc-unelevated-button:hover .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-filled-button-hover-state-layer-opacity)}.mat-mdc-unelevated-button.cdk-program-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-unelevated-button.cdk-keyboard-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-unelevated-button.mat-mdc-button-disabled-interactive:focus .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-filled-button-focus-state-layer-opacity)}.mat-mdc-unelevated-button:active .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-filled-button-pressed-state-layer-opacity)}.mat-mdc-unelevated-button .mat-mdc-button-touch-target{position:absolute;top:50%;height:48px;left:0;right:0;transform:translateY(-50%);display:var(--mat-filled-button-touch-target-display)}.mat-mdc-unelevated-button[disabled],.mat-mdc-unelevated-button.mat-mdc-button-disabled{cursor:default;pointer-events:none;color:var(--mdc-filled-button-disabled-label-text-color);background-color:var(--mdc-filled-button-disabled-container-color)}.mat-mdc-unelevated-button.mat-mdc-button-disabled-interactive{pointer-events:auto}.mat-mdc-raised-button{font-family:var(--mdc-protected-button-label-text-font);font-size:var(--mdc-protected-button-label-text-size);letter-spacing:var(--mdc-protected-button-label-text-tracking);font-weight:var(--mdc-protected-button-label-text-weight);text-transform:var(--mdc-protected-button-label-text-transform);height:var(--mdc-protected-button-container-height);border-radius:var(--mdc-protected-button-container-shape);padding:0 var(--mat-protected-button-horizontal-padding, 16px);box-shadow:var(--mdc-protected-button-container-elevation-shadow)}.mat-mdc-raised-button:not(:disabled){background-color:var(--mdc-protected-button-container-color)}.mat-mdc-raised-button:disabled{background-color:var(--mdc-protected-button-disabled-container-color)}.mat-mdc-raised-button:not(:disabled){color:var(--mdc-protected-button-label-text-color)}.mat-mdc-raised-button:disabled{color:var(--mdc-protected-button-disabled-label-text-color)}.mat-mdc-raised-button .mdc-button__ripple{border-radius:var(--mdc-protected-button-container-shape)}.mat-mdc-raised-button>.mat-icon{margin-right:var(--mat-protected-button-icon-spacing, 8px);margin-left:var(--mat-protected-button-icon-offset, -4px)}[dir=rtl] .mat-mdc-raised-button>.mat-icon{margin-right:var(--mat-protected-button-icon-offset, -4px);margin-left:var(--mat-protected-button-icon-spacing, 8px)}.mat-mdc-raised-button .mdc-button__label+.mat-icon{margin-right:var(--mat-protected-button-icon-offset, -4px);margin-left:var(--mat-protected-button-icon-spacing, 8px)}[dir=rtl] .mat-mdc-raised-button .mdc-button__label+.mat-icon{margin-right:var(--mat-protected-button-icon-spacing, 8px);margin-left:var(--mat-protected-button-icon-offset, -4px)}.mat-mdc-raised-button .mat-ripple-element{background-color:var(--mat-protected-button-ripple-color)}.mat-mdc-raised-button .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-protected-button-state-layer-color)}.mat-mdc-raised-button.mat-mdc-button-disabled .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-protected-button-disabled-state-layer-color)}.mat-mdc-raised-button:hover .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-protected-button-hover-state-layer-opacity)}.mat-mdc-raised-button.cdk-program-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-raised-button.cdk-keyboard-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-raised-button.mat-mdc-button-disabled-interactive:focus .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-protected-button-focus-state-layer-opacity)}.mat-mdc-raised-button:active .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-protected-button-pressed-state-layer-opacity)}.mat-mdc-raised-button .mat-mdc-button-touch-target{position:absolute;top:50%;height:48px;left:0;right:0;transform:translateY(-50%);display:var(--mat-protected-button-touch-target-display)}.mat-mdc-raised-button:hover{box-shadow:var(--mdc-protected-button-hover-container-elevation-shadow)}.mat-mdc-raised-button:focus{box-shadow:var(--mdc-protected-button-focus-container-elevation-shadow)}.mat-mdc-raised-button:active,.mat-mdc-raised-button:focus:active{box-shadow:var(--mdc-protected-button-pressed-container-elevation-shadow)}.mat-mdc-raised-button[disabled],.mat-mdc-raised-button.mat-mdc-button-disabled{cursor:default;pointer-events:none;color:var(--mdc-protected-button-disabled-label-text-color);background-color:var(--mdc-protected-button-disabled-container-color)}.mat-mdc-raised-button[disabled].mat-mdc-button-disabled,.mat-mdc-raised-button.mat-mdc-button-disabled.mat-mdc-button-disabled{box-shadow:var(--mdc-protected-button-disabled-container-elevation-shadow)}.mat-mdc-raised-button.mat-mdc-button-disabled-interactive{pointer-events:auto}.mat-mdc-outlined-button{font-family:var(--mdc-outlined-button-label-text-font);font-size:var(--mdc-outlined-button-label-text-size);letter-spacing:var(--mdc-outlined-button-label-text-tracking);font-weight:var(--mdc-outlined-button-label-text-weight);text-transform:var(--mdc-outlined-button-label-text-transform);height:var(--mdc-outlined-button-container-height);border-radius:var(--mdc-outlined-button-container-shape);padding:0 15px 0 15px;border-width:var(--mdc-outlined-button-outline-width);padding:0 var(--mat-outlined-button-horizontal-padding, 15px)}.mat-mdc-outlined-button:not(:disabled){color:var(--mdc-outlined-button-label-text-color)}.mat-mdc-outlined-button:disabled{color:var(--mdc-outlined-button-disabled-label-text-color)}.mat-mdc-outlined-button .mdc-button__ripple{border-radius:var(--mdc-outlined-button-container-shape)}.mat-mdc-outlined-button:not(:disabled){border-color:var(--mdc-outlined-button-outline-color)}.mat-mdc-outlined-button:disabled{border-color:var(--mdc-outlined-button-disabled-outline-color)}.mat-mdc-outlined-button.mdc-button--icon-trailing{padding:0 11px 0 15px}.mat-mdc-outlined-button.mdc-button--icon-leading{padding:0 15px 0 11px}.mat-mdc-outlined-button .mdc-button__ripple{top:-1px;left:-1px;bottom:-1px;right:-1px;border-width:var(--mdc-outlined-button-outline-width)}.mat-mdc-outlined-button .mdc-button__touch{left:calc(-1 * var(--mdc-outlined-button-outline-width));width:calc(100% + 2 * var(--mdc-outlined-button-outline-width))}.mat-mdc-outlined-button>.mat-icon{margin-right:var(--mat-outlined-button-icon-spacing, 8px);margin-left:var(--mat-outlined-button-icon-offset, -4px)}[dir=rtl] .mat-mdc-outlined-button>.mat-icon{margin-right:var(--mat-outlined-button-icon-offset, -4px);margin-left:var(--mat-outlined-button-icon-spacing, 8px)}.mat-mdc-outlined-button .mdc-button__label+.mat-icon{margin-right:var(--mat-outlined-button-icon-offset, -4px);margin-left:var(--mat-outlined-button-icon-spacing, 8px)}[dir=rtl] .mat-mdc-outlined-button .mdc-button__label+.mat-icon{margin-right:var(--mat-outlined-button-icon-spacing, 8px);margin-left:var(--mat-outlined-button-icon-offset, -4px)}.mat-mdc-outlined-button .mat-ripple-element{background-color:var(--mat-outlined-button-ripple-color)}.mat-mdc-outlined-button .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-outlined-button-state-layer-color)}.mat-mdc-outlined-button.mat-mdc-button-disabled .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-outlined-button-disabled-state-layer-color)}.mat-mdc-outlined-button:hover .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-outlined-button-hover-state-layer-opacity)}.mat-mdc-outlined-button.cdk-program-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-outlined-button.cdk-keyboard-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-outlined-button.mat-mdc-button-disabled-interactive:focus .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-outlined-button-focus-state-layer-opacity)}.mat-mdc-outlined-button:active .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-outlined-button-pressed-state-layer-opacity)}.mat-mdc-outlined-button .mat-mdc-button-touch-target{position:absolute;top:50%;height:48px;left:0;right:0;transform:translateY(-50%);display:var(--mat-outlined-button-touch-target-display)}.mat-mdc-outlined-button[disabled],.mat-mdc-outlined-button.mat-mdc-button-disabled{cursor:default;pointer-events:none;color:var(--mdc-outlined-button-disabled-label-text-color);border-color:var(--mdc-outlined-button-disabled-outline-color)}.mat-mdc-outlined-button.mat-mdc-button-disabled-interactive{pointer-events:auto}.mat-mdc-button-base{text-decoration:none}.mat-mdc-button,.mat-mdc-unelevated-button,.mat-mdc-raised-button,.mat-mdc-outlined-button{-webkit-tap-highlight-color:rgba(0,0,0,0)}.mat-mdc-button .mat-mdc-button-ripple,.mat-mdc-button .mat-mdc-button-persistent-ripple,.mat-mdc-button .mat-mdc-button-persistent-ripple::before,.mat-mdc-unelevated-button .mat-mdc-button-ripple,.mat-mdc-unelevated-button .mat-mdc-button-persistent-ripple,.mat-mdc-unelevated-button .mat-mdc-button-persistent-ripple::before,.mat-mdc-raised-button .mat-mdc-button-ripple,.mat-mdc-raised-button .mat-mdc-button-persistent-ripple,.mat-mdc-raised-button .mat-mdc-button-persistent-ripple::before,.mat-mdc-outlined-button .mat-mdc-button-ripple,.mat-mdc-outlined-button .mat-mdc-button-persistent-ripple,.mat-mdc-outlined-button .mat-mdc-button-persistent-ripple::before{top:0;left:0;right:0;bottom:0;position:absolute;pointer-events:none;border-radius:inherit}.mat-mdc-button .mat-mdc-button-ripple,.mat-mdc-unelevated-button .mat-mdc-button-ripple,.mat-mdc-raised-button .mat-mdc-button-ripple,.mat-mdc-outlined-button .mat-mdc-button-ripple{overflow:hidden}.mat-mdc-button .mat-mdc-button-persistent-ripple::before,.mat-mdc-unelevated-button .mat-mdc-button-persistent-ripple::before,.mat-mdc-raised-button .mat-mdc-button-persistent-ripple::before,.mat-mdc-outlined-button .mat-mdc-button-persistent-ripple::before{content:"";opacity:0}.mat-mdc-button .mdc-button__label,.mat-mdc-unelevated-button .mdc-button__label,.mat-mdc-raised-button .mdc-button__label,.mat-mdc-outlined-button .mdc-button__label{z-index:1}.mat-mdc-button .mat-mdc-focus-indicator,.mat-mdc-unelevated-button .mat-mdc-focus-indicator,.mat-mdc-raised-button .mat-mdc-focus-indicator,.mat-mdc-outlined-button .mat-mdc-focus-indicator{top:0;left:0;right:0;bottom:0;position:absolute}.mat-mdc-button:focus .mat-mdc-focus-indicator::before,.mat-mdc-unelevated-button:focus .mat-mdc-focus-indicator::before,.mat-mdc-raised-button:focus .mat-mdc-focus-indicator::before,.mat-mdc-outlined-button:focus .mat-mdc-focus-indicator::before{content:""}.mat-mdc-button._mat-animation-noopable,.mat-mdc-unelevated-button._mat-animation-noopable,.mat-mdc-raised-button._mat-animation-noopable,.mat-mdc-outlined-button._mat-animation-noopable{transition:none !important;animation:none !important}.mat-mdc-button>.mat-icon,.mat-mdc-unelevated-button>.mat-icon,.mat-mdc-raised-button>.mat-icon,.mat-mdc-outlined-button>.mat-icon{display:inline-block;position:relative;vertical-align:top;font-size:1.125rem;height:1.125rem;width:1.125rem}.mat-mdc-outlined-button .mat-mdc-button-ripple,.mat-mdc-outlined-button .mdc-button__ripple{top:-1px;left:-1px;bottom:-1px;right:-1px;border-width:-1px}.mat-mdc-unelevated-button .mat-mdc-focus-indicator::before,.mat-mdc-raised-button .mat-mdc-focus-indicator::before{margin:calc(calc(var(--mat-mdc-focus-indicator-border-width, 3px) + 2px)*-1)}.mat-mdc-outlined-button .mat-mdc-focus-indicator::before{margin:calc(calc(var(--mat-mdc-focus-indicator-border-width, 3px) + 3px)*-1)}\n',
".cdk-high-contrast-active .mat-mdc-button:not(.mdc-button--outlined),.cdk-high-contrast-active .mat-mdc-unelevated-button:not(.mdc-button--outlined),.cdk-high-contrast-active .mat-mdc-raised-button:not(.mdc-button--outlined),.cdk-high-contrast-active .mat-mdc-outlined-button:not(.mdc-button--outlined),.cdk-high-contrast-active .mat-mdc-icon-button{outline:solid 1px}\n"],ob:2,Qa:0});var qB=new df("mat-mdc-fab-default-options",{da:"root",aa:pB});function pB(){return{color:"accent"}};var rB=class extends mB{constructor(a,b,c,d){super(a,b,c,d);Xz(this.i,this.qa.P,{Wi:!0})}};rB.J=function(a){return new (a||rB)(y(qi),y(St),y(Ok),y(ki,8))};
rB.Ca=Gf({type:rB,ga:[["button","mat-icon-button",""]],Xa:14,Ha:function(a,b){a&2&&(Ip("disabled",b.Et())("aria-disabled",b.Dt()),oq(rq,b.color?"mat-"+b.color:""),lq("mat-mdc-button-disabled",b.disabled)("mat-mdc-button-disabled-interactive",b.gj)("_mat-animation-noopable","NoopAnimations"===b.Yc)("mat-unthemed",!b.color)("mat-mdc-button-base",!0))},hb:["matButton"],ja:!0,features:[Ap,Jr],attrs:["mat-icon-button",""],Yb:["*"],ya:4,za:0,Ba:[[1,"mat-mdc-button-persistent-ripple","mdc-icon-button__ripple"],
[1,"mat-mdc-focus-indicator"],[1,"mat-mdc-button-touch-target"]],sa:function(a){a&1&&(Vq(),Kq(0,"span",0),Wq(1),Kq(2,"span",1)(3,"span",2))},styles:['.mdc-icon-button{display:inline-block;position:relative;box-sizing:border-box;border:none;outline:none;background-color:rgba(0,0,0,0);fill:currentColor;color:inherit;text-decoration:none;cursor:pointer;user-select:none;z-index:0;overflow:visible}.mdc-icon-button .mdc-icon-button__touch{position:absolute;top:50%;height:48px;left:50%;width:48px;transform:translate(-50%, -50%)}@media screen and (forced-colors: active){.mdc-icon-button.mdc-ripple-upgraded--background-focused .mdc-icon-button__focus-ring,.mdc-icon-button:not(.mdc-ripple-upgraded):focus .mdc-icon-button__focus-ring{display:block}}.mdc-icon-button:disabled{cursor:default;pointer-events:none}.mdc-icon-button[hidden]{display:none}.mdc-icon-button--display-flex{align-items:center;display:inline-flex;justify-content:center}.mdc-icon-button__focus-ring{pointer-events:none;border:2px solid rgba(0,0,0,0);border-radius:6px;box-sizing:content-box;position:absolute;top:50%;left:50%;transform:translate(-50%, -50%);height:100%;width:100%;display:none}@media screen and (forced-colors: active){.mdc-icon-button__focus-ring{border-color:CanvasText}}.mdc-icon-button__focus-ring::after{content:"";border:2px solid rgba(0,0,0,0);border-radius:8px;display:block;position:absolute;top:50%;left:50%;transform:translate(-50%, -50%);height:calc(100% + 4px);width:calc(100% + 4px)}@media screen and (forced-colors: active){.mdc-icon-button__focus-ring::after{border-color:CanvasText}}.mdc-icon-button__icon{display:inline-block}.mdc-icon-button__icon.mdc-icon-button__icon--on{display:none}.mdc-icon-button--on .mdc-icon-button__icon{display:none}.mdc-icon-button--on .mdc-icon-button__icon.mdc-icon-button__icon--on{display:inline-block}.mdc-icon-button__link{height:100%;left:0;outline:none;position:absolute;top:0;width:100%}.mat-mdc-icon-button{color:var(--mdc-icon-button-icon-color)}.mat-mdc-icon-button .mdc-button__icon{font-size:var(--mdc-icon-button-icon-size)}.mat-mdc-icon-button svg,.mat-mdc-icon-button img{width:var(--mdc-icon-button-icon-size);height:var(--mdc-icon-button-icon-size)}.mat-mdc-icon-button:disabled{color:var(--mdc-icon-button-disabled-icon-color)}.mat-mdc-icon-button{border-radius:50%;flex-shrink:0;text-align:center;width:var(--mdc-icon-button-state-layer-size, 48px);height:var(--mdc-icon-button-state-layer-size, 48px);padding:calc(calc(var(--mdc-icon-button-state-layer-size, 48px) - var(--mdc-icon-button-icon-size, 24px)) / 2);font-size:var(--mdc-icon-button-icon-size);-webkit-tap-highlight-color:rgba(0,0,0,0)}.mat-mdc-icon-button svg{vertical-align:baseline}.mat-mdc-icon-button[disabled],.mat-mdc-icon-button.mat-mdc-button-disabled{cursor:default;pointer-events:none;color:var(--mdc-icon-button-disabled-icon-color)}.mat-mdc-icon-button.mat-mdc-button-disabled-interactive{pointer-events:auto}.mat-mdc-icon-button .mat-mdc-button-ripple,.mat-mdc-icon-button .mat-mdc-button-persistent-ripple,.mat-mdc-icon-button .mat-mdc-button-persistent-ripple::before{top:0;left:0;right:0;bottom:0;position:absolute;pointer-events:none;border-radius:inherit}.mat-mdc-icon-button .mat-mdc-button-ripple{overflow:hidden}.mat-mdc-icon-button .mat-mdc-button-persistent-ripple::before{content:"";opacity:0}.mat-mdc-icon-button .mdc-button__label{z-index:1}.mat-mdc-icon-button .mat-mdc-focus-indicator{top:0;left:0;right:0;bottom:0;position:absolute}.mat-mdc-icon-button:focus .mat-mdc-focus-indicator::before{content:""}.mat-mdc-icon-button .mat-ripple-element{background-color:var(--mat-icon-button-ripple-color)}.mat-mdc-icon-button .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-icon-button-state-layer-color)}.mat-mdc-icon-button.mat-mdc-button-disabled .mat-mdc-button-persistent-ripple::before{background-color:var(--mat-icon-button-disabled-state-layer-color)}.mat-mdc-icon-button:hover .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-icon-button-hover-state-layer-opacity)}.mat-mdc-icon-button.cdk-program-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-icon-button.cdk-keyboard-focused .mat-mdc-button-persistent-ripple::before,.mat-mdc-icon-button.mat-mdc-button-disabled-interactive:focus .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-icon-button-focus-state-layer-opacity)}.mat-mdc-icon-button:active .mat-mdc-button-persistent-ripple::before{opacity:var(--mat-icon-button-pressed-state-layer-opacity)}.mat-mdc-icon-button .mat-mdc-button-touch-target{position:absolute;top:50%;height:48px;left:50%;width:48px;transform:translate(-50%, -50%);display:var(--mat-icon-button-touch-target-display)}.mat-mdc-icon-button._mat-animation-noopable{transition:none !important;animation:none !important}.mat-mdc-icon-button .mat-mdc-button-persistent-ripple{border-radius:50%}.mat-mdc-icon-button.mat-unthemed:not(.mdc-ripple-upgraded):focus::before,.mat-mdc-icon-button.mat-primary:not(.mdc-ripple-upgraded):focus::before,.mat-mdc-icon-button.mat-accent:not(.mdc-ripple-upgraded):focus::before,.mat-mdc-icon-button.mat-warn:not(.mdc-ripple-upgraded):focus::before{background:rgba(0,0,0,0);opacity:1}\n',
".cdk-high-contrast-active .mat-mdc-button:not(.mdc-button--outlined),.cdk-high-contrast-active .mat-mdc-unelevated-button:not(.mdc-button--outlined),.cdk-high-contrast-active .mat-mdc-raised-button:not(.mdc-button--outlined),.cdk-high-contrast-active .mat-mdc-outlined-button:not(.mdc-button--outlined),.cdk-high-contrast-active .mat-mdc-icon-button{outline:solid 1px}\n"],ob:2,Qa:0});var sB=class{};sB.J=function(a){return new (a||sB)};sB.Wa=Mf({type:sB});sB.Va=Md({imports:[fz,Rz,fz]});var tB=class{constructor(a,b){this.dc=a;this.options=b}Eb(){this.dc.P.querySelector(".mat-icon, .material-icons")&&this.dc.P.classList.add("gmat-mdc-button-with-prefix")}};tB.J=function(a){return new (a||tB)(y(qi),y(jB))};
tB.Ea=Of({type:tB,ga:[["button","mat-button",""],["a","mat-button",""],["button","mat-raised-button",""],["a","mat-raised-button",""],["button","mat-flat-button",""],["a","mat-flat-button",""],["button","mat-stroked-button",""],["a","mat-stroked-button",""],["button","mat-icon-button",""],["a","mat-icon-button",""],[""]],Xa:2,Ha:function(a,b){a&2&&lq("gmat-mdc-button",!b.options.qc)}});var uB=class{};uB.J=function(a){return new (a||uB)};uB.Wa=Mf({type:uB});uB.Va=Md({Ua:[{na:qB,mb:{color:"primary"}}],imports:[sB]});var vB=new df("GMAT_CHECKBOX_OPTIONS",{da:"root",aa:()=>({qc:!1})});var wB=class{constructor(a){this.options=a}};wB.J=function(a){return new (a||wB)(y(vB))};wB.Ea=Of({type:wB,ga:[["mat-checkbox"]],Xa:2,Ha:function(a,b){a&2&&lq("gmat-mdc-checkbox",!b.options.qc)}});var yB=new df("mat-checkbox-default-options",{da:"root",aa:xB});function xB(){return{color:"accent",gB:"check-indeterminate"}};const zB=["input"],AB=["label"];var CB={na:jw,zb:af(()=>BB),Db:!0},DB=class{};let EB=0;const FB=xB();
var BB=class{focus(){this.ig.P.focus()}kp(a){const b=new DB;b.source=this;b.checked=a;return b}Sz(){let a;return null==(a=this.ig)?void 0:a.P}get Yq(){return`${this.id||this.Dk}-input`}constructor(a,b,c,d,e,f){this.qa=a;this.Aa=b;this.pa=c;this.Yc=e;this.Ni=f;this.wf={wy:"mdc-checkbox--anim-unchecked-checked",xy:"mdc-checkbox--anim-unchecked-indeterminate",bB:"mdc-checkbox--anim-checked-unchecked",Uu:"mdc-checkbox--anim-checked-indeterminate",mC:"mdc-checkbox--anim-indeterminate-checked",nC:"mdc-checkbox--anim-indeterminate-unchecked"};
this.ariaLabel="";this.ad=null;this.Lh="after";this.name=null;this.vb=new Dk;this.Vq=new Dk;this.Yd=()=>{};this.Fi="";this.tt=0;this.jp=()=>{};this.xu=()=>{};this.zf=this.Hb=this.xf=!1;this.Ni=this.Ni||FB;this.color=this.Ni.color||FB.color;this.tabIndex=parseInt(d)||0;this.id=this.Dk=`mat-mdc-checkbox-${++EB}`}rc(a){a.required&&this.xu()}nd(){this.qu(this.zf)}get checked(){return this.xf}set checked(a){a!=this.checked&&(this.xf=a,Zm(this.Aa))}get disabled(){return this.Hb}set disabled(a){a!==this.disabled&&
(this.Hb=a,Zm(this.Aa))}get indeterminate(){return this.zf}set indeterminate(a){const b=a!=this.zf;this.zf=a;b&&(this.zf?this.Pp(3):this.Pp(this.checked?1:2),this.Vq.emit(this.zf));this.qu(this.zf)}rF(){return this.Lc||this.disabled}tF(){$m(this.Aa)}pi(a){this.checked=!!a}Lg(a){this.jp=a}Ij(a){this.Yd=a}gi(a){this.disabled=a}validate(a){return this.required&&!0!==a.value?{required:!0}:null}Xr(a){this.xu=a}Pp(a){let b=this.tt,c=this.Sz();if(b!==a&&c&&(this.Fi&&c.classList.remove(this.Fi),this.Fi=this.Rz(b,
a),this.tt=a,0<this.Fi.length)){c.classList.add(this.Fi);const d=this.Fi;Kk(this.pa,()=>{setTimeout(()=>{c.classList.remove(d)},1E3)})}}Gi(){this.jp(this.checked);this.vb.emit(this.kp(this.checked));this.ig&&(this.ig.P.checked=this.checked)}toggle(){this.checked=!this.checked;this.jp(this.checked)}Jt(){let a;const b=null==(a=this.Ni)?void 0:a.gB;this.disabled||"noop"===b?this.disabled||"noop"!==b||(this.ig.P.checked=this.checked,this.ig.P.indeterminate=this.indeterminate):(this.indeterminate&&"check"!==
b&&Promise.resolve().then(()=>{this.zf=!1;this.Vq.emit(this.zf)}),this.xf=!this.xf,this.Pp(this.xf?1:2),this.Gi())}pA(a){a.stopPropagation()}xk(){Promise.resolve().then(()=>{this.Yd();Zm(this.Aa)})}Rz(a,b){if("NoopAnimations"===this.Yc)return"";switch(a){case 0:if(1===b)return this.wf.wy;if(3==b)return this.xf?this.wf.Uu:this.wf.xy;break;case 2:return 1===b?this.wf.wy:this.wf.xy;case 1:return 2===b?this.wf.bB:this.wf.Uu;case 3:return 1===b?this.wf.mC:this.wf.nC}return""}qu(a){const b=this.ig;b&&(b.P.indeterminate=
a)}oA(){this.Jt()}sA(){this.Jt();this.disabled||this.ig.P.focus()}zA(a){a.target&&this.iA.P.contains(a.target)&&a.stopPropagation()}};BB.J=function(a){return new (a||BB)(y(qi),y(Pr),y(Ok),xh("tabindex"),y(ki,8),y(yB,8))};
BB.Ca=Gf({type:BB,ga:[["mat-checkbox"]],eb:function(a,b){a&1&&(rr(zB,5),rr(AB,5),rr(Ez,5));if(a&2){let c;sr(c=tr())&&(b.ig=c.first);sr(c=tr())&&(b.iA=c.first);sr(c=tr())&&(b.vx=c.first)}},Ja:[1,"mat-mdc-checkbox"],Xa:14,Ha:function(a,b){a&2&&(Oq("id",b.id),Ip("tabindex",null)("aria-label",null)("aria-labelledby",null),oq(rq,b.color?"mat-"+b.color:"mat-accent"),lq("_mat-animation-noopable","NoopAnimations"===b.Yc)("mdc-checkbox--disabled",b.disabled)("mat-mdc-checkbox-disabled",b.disabled)("mat-mdc-checkbox-checked",
b.checked))},inputs:{ariaLabel:[0,"aria-label","ariaLabel"],ad:[0,"aria-labelledby","ariaLabelledby"],Hk:[0,"aria-describedby","ariaDescribedby"],id:"id",required:[2,"required","required",ws],Lh:"labelPosition",name:"name",value:"value",Lc:[2,"disableRipple","disableRipple",ws],tabIndex:[2,"tabIndex","tabIndex",a=>null==a?void 0:xs(a)],color:"color",checked:[2,"checked","checked",ws],disabled:[2,"disabled","disabled",ws],indeterminate:[2,"indeterminate","indeterminate",ws]},outputs:{vb:"change",Vq:"indeterminateChange"},
hb:["matCheckbox"],ja:!0,features:[Hr([CB,{na:pw,zb:BB,Db:!0}]),Hp,Cg,Jr],Yb:["*"],ya:15,za:19,Ba:[["checkbox",""],["input",""],["label",""],["mat-internal-form-field","",3,"click","labelPosition"],[1,"mdc-checkbox"],[1,"mat-mdc-checkbox-touch-target",3,"click"],["type","checkbox",1,"mdc-checkbox__native-control",3,"blur","click","change","checked","indeterminate","disabled","id","required","tabIndex"],[1,"mdc-checkbox__ripple"],[1,"mdc-checkbox__background"],["focusable","false","viewBox","0 0 24 24",
"aria-hidden","true",1,"mdc-checkbox__checkmark"],["fill","none","d","M1.73,12.91 8.1,19.28 22.79,4.59",1,"mdc-checkbox__checkmark-path"],[1,"mdc-checkbox__mixedmark"],["mat-ripple","",1,"mat-mdc-checkbox-ripple","mat-mdc-focus-indicator",3,"matRippleTrigger","matRippleDisabled","matRippleCentered"],[1,"mdc-label",3,"for"]],sa:function(a,b){if(a&1){const c=Tg();Vq();R(0,"div",3);V("click",function(d){u(c);return x(b.zA(d))});R(1,"div",4,0)(3,"div",5);V("click",function(){u(c);return x(b.sA())});S();
R(4,"input",6,1);V("blur",function(){u(c);return x(b.xk())})("click",function(){u(c);return x(b.oA())})("change",function(d){u(c);return x(b.pA(d))});S();Kq(6,"div",7);R(7,"div",8);eh();R(8,"svg",9);Kq(9,"path",10);S();Qg.Vk=null;Kq(10,"div",11);S();Kq(11,"div",12);S();R(12,"label",13,2);Wq(14);S()()}a&2&&(a=wr(2),H("labelPosition",b.Lh),D(4),lq("mdc-checkbox--selected",b.checked),H("checked",b.checked)("indeterminate",b.indeterminate)("disabled",b.disabled)("id",b.Yq)("required",b.required)("tabIndex",
b.disabled?-1:b.tabIndex),Ip("aria-label",b.ariaLabel||null)("aria-labelledby",b.ad)("aria-describedby",b.Hk)("aria-checked",b.indeterminate?"mixed":null)("name",b.name)("value",b.value),D(7),H("matRippleTrigger",a)("matRippleDisabled",b.Lc||b.disabled)("matRippleCentered",!0),D(),H("for",b.Yq))},Ga:[Ez,jz],styles:['@keyframes mdc-checkbox-unchecked-checked-checkmark-path{0%,50%{stroke-dashoffset:29.7833385}50%{animation-timing-function:cubic-bezier(0, 0, 0.2, 1)}100%{stroke-dashoffset:0}}@keyframes mdc-checkbox-unchecked-indeterminate-mixedmark{0%,68.2%{transform:scaleX(0)}68.2%{animation-timing-function:cubic-bezier(0, 0, 0, 1)}100%{transform:scaleX(1)}}@keyframes mdc-checkbox-checked-unchecked-checkmark-path{from{animation-timing-function:cubic-bezier(0.4, 0, 1, 1);opacity:1;stroke-dashoffset:0}to{opacity:0;stroke-dashoffset:-29.7833385}}@keyframes mdc-checkbox-checked-indeterminate-checkmark{from{animation-timing-function:cubic-bezier(0, 0, 0.2, 1);transform:rotate(0deg);opacity:1}to{transform:rotate(45deg);opacity:0}}@keyframes mdc-checkbox-indeterminate-checked-checkmark{from{animation-timing-function:cubic-bezier(0.14, 0, 0, 1);transform:rotate(45deg);opacity:0}to{transform:rotate(360deg);opacity:1}}@keyframes mdc-checkbox-checked-indeterminate-mixedmark{from{animation-timing-function:mdc-animation-deceleration-curve-timing-function;transform:rotate(-45deg);opacity:0}to{transform:rotate(0deg);opacity:1}}@keyframes mdc-checkbox-indeterminate-checked-mixedmark{from{animation-timing-function:cubic-bezier(0.14, 0, 0, 1);transform:rotate(0deg);opacity:1}to{transform:rotate(315deg);opacity:0}}@keyframes mdc-checkbox-indeterminate-unchecked-mixedmark{0%{animation-timing-function:linear;transform:scaleX(1);opacity:1}32.8%,100%{transform:scaleX(0);opacity:0}}.mdc-checkbox{display:inline-block;position:relative;flex:0 0 18px;box-sizing:content-box;width:18px;height:18px;line-height:0;white-space:nowrap;cursor:pointer;vertical-align:bottom}.mdc-checkbox[hidden]{display:none}.mdc-checkbox.mdc-ripple-upgraded--background-focused .mdc-checkbox__focus-ring,.mdc-checkbox:not(.mdc-ripple-upgraded):focus .mdc-checkbox__focus-ring{pointer-events:none;border:2px solid rgba(0,0,0,0);border-radius:6px;box-sizing:content-box;position:absolute;top:50%;left:50%;transform:translate(-50%, -50%);height:100%;width:100%}@media screen and (forced-colors: active){.mdc-checkbox.mdc-ripple-upgraded--background-focused .mdc-checkbox__focus-ring,.mdc-checkbox:not(.mdc-ripple-upgraded):focus .mdc-checkbox__focus-ring{border-color:CanvasText}}.mdc-checkbox.mdc-ripple-upgraded--background-focused .mdc-checkbox__focus-ring::after,.mdc-checkbox:not(.mdc-ripple-upgraded):focus .mdc-checkbox__focus-ring::after{content:"";border:2px solid rgba(0,0,0,0);border-radius:8px;display:block;position:absolute;top:50%;left:50%;transform:translate(-50%, -50%);height:calc(100% + 4px);width:calc(100% + 4px)}@media screen and (forced-colors: active){.mdc-checkbox.mdc-ripple-upgraded--background-focused .mdc-checkbox__focus-ring::after,.mdc-checkbox:not(.mdc-ripple-upgraded):focus .mdc-checkbox__focus-ring::after{border-color:CanvasText}}@media all and (-ms-high-contrast: none){.mdc-checkbox .mdc-checkbox__focus-ring{display:none}}@media screen and (forced-colors: active),(-ms-high-contrast: active){.mdc-checkbox__mixedmark{margin:0 1px}}.mdc-checkbox--disabled{cursor:default;pointer-events:none}.mdc-checkbox__background{display:inline-flex;position:absolute;align-items:center;justify-content:center;box-sizing:border-box;width:18px;height:18px;border:2px solid currentColor;border-radius:2px;background-color:rgba(0,0,0,0);pointer-events:none;will-change:background-color,border-color;transition:background-color 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1),border-color 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-checkbox__checkmark{position:absolute;top:0;right:0;bottom:0;left:0;width:100%;opacity:0;transition:opacity 180ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-checkbox--upgraded .mdc-checkbox__checkmark{opacity:1}.mdc-checkbox__checkmark-path{transition:stroke-dashoffset 180ms 0ms cubic-bezier(0.4, 0, 0.6, 1);stroke:currentColor;stroke-width:3.12px;stroke-dashoffset:29.7833385;stroke-dasharray:29.7833385}.mdc-checkbox__mixedmark{width:100%;height:0;transform:scaleX(0) rotate(0deg);border-width:1px;border-style:solid;opacity:0;transition:opacity 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1),transform 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-checkbox--anim-unchecked-checked .mdc-checkbox__background,.mdc-checkbox--anim-unchecked-indeterminate .mdc-checkbox__background,.mdc-checkbox--anim-checked-unchecked .mdc-checkbox__background,.mdc-checkbox--anim-indeterminate-unchecked .mdc-checkbox__background{animation-duration:180ms;animation-timing-function:linear}.mdc-checkbox--anim-unchecked-checked .mdc-checkbox__checkmark-path{animation:mdc-checkbox-unchecked-checked-checkmark-path 180ms linear 0s;transition:none}.mdc-checkbox--anim-unchecked-indeterminate .mdc-checkbox__mixedmark{animation:mdc-checkbox-unchecked-indeterminate-mixedmark 90ms linear 0s;transition:none}.mdc-checkbox--anim-checked-unchecked .mdc-checkbox__checkmark-path{animation:mdc-checkbox-checked-unchecked-checkmark-path 90ms linear 0s;transition:none}.mdc-checkbox--anim-checked-indeterminate .mdc-checkbox__checkmark{animation:mdc-checkbox-checked-indeterminate-checkmark 90ms linear 0s;transition:none}.mdc-checkbox--anim-checked-indeterminate .mdc-checkbox__mixedmark{animation:mdc-checkbox-checked-indeterminate-mixedmark 90ms linear 0s;transition:none}.mdc-checkbox--anim-indeterminate-checked .mdc-checkbox__checkmark{animation:mdc-checkbox-indeterminate-checked-checkmark 500ms linear 0s;transition:none}.mdc-checkbox--anim-indeterminate-checked .mdc-checkbox__mixedmark{animation:mdc-checkbox-indeterminate-checked-mixedmark 500ms linear 0s;transition:none}.mdc-checkbox--anim-indeterminate-unchecked .mdc-checkbox__mixedmark{animation:mdc-checkbox-indeterminate-unchecked-mixedmark 300ms linear 0s;transition:none}.mdc-checkbox__native-control:checked~.mdc-checkbox__background,.mdc-checkbox__native-control:indeterminate~.mdc-checkbox__background,.mdc-checkbox__native-control[data-indeterminate=true]~.mdc-checkbox__background{transition:border-color 90ms 0ms cubic-bezier(0, 0, 0.2, 1),background-color 90ms 0ms cubic-bezier(0, 0, 0.2, 1)}.mdc-checkbox__native-control:checked~.mdc-checkbox__background .mdc-checkbox__checkmark-path,.mdc-checkbox__native-control:indeterminate~.mdc-checkbox__background .mdc-checkbox__checkmark-path,.mdc-checkbox__native-control[data-indeterminate=true]~.mdc-checkbox__background .mdc-checkbox__checkmark-path{stroke-dashoffset:0}.mdc-checkbox__native-control{position:absolute;margin:0;padding:0;opacity:0;cursor:inherit}.mdc-checkbox__native-control:disabled{cursor:default;pointer-events:none}.mdc-checkbox--touch{margin:calc((var(--mdc-checkbox-state-layer-size) - var(--mdc-checkbox-state-layer-size)) / 2)}.mdc-checkbox--touch .mdc-checkbox__native-control{top:calc((var(--mdc-checkbox-state-layer-size) - var(--mdc-checkbox-state-layer-size)) / 2);right:calc((var(--mdc-checkbox-state-layer-size) - var(--mdc-checkbox-state-layer-size)) / 2);left:calc((var(--mdc-checkbox-state-layer-size) - var(--mdc-checkbox-state-layer-size)) / 2);width:var(--mdc-checkbox-state-layer-size);height:var(--mdc-checkbox-state-layer-size)}.mdc-checkbox__native-control:checked~.mdc-checkbox__background .mdc-checkbox__checkmark{transition:opacity 180ms 0ms cubic-bezier(0, 0, 0.2, 1),transform 180ms 0ms cubic-bezier(0, 0, 0.2, 1);opacity:1}.mdc-checkbox__native-control:checked~.mdc-checkbox__background .mdc-checkbox__mixedmark{transform:scaleX(1) rotate(-45deg)}.mdc-checkbox__native-control:indeterminate~.mdc-checkbox__background .mdc-checkbox__checkmark,.mdc-checkbox__native-control[data-indeterminate=true]~.mdc-checkbox__background .mdc-checkbox__checkmark{transform:rotate(45deg);opacity:0;transition:opacity 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1),transform 90ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-checkbox__native-control:indeterminate~.mdc-checkbox__background .mdc-checkbox__mixedmark,.mdc-checkbox__native-control[data-indeterminate=true]~.mdc-checkbox__background .mdc-checkbox__mixedmark{transform:scaleX(1) rotate(0deg);opacity:1}.mdc-checkbox.mdc-checkbox--upgraded .mdc-checkbox__background,.mdc-checkbox.mdc-checkbox--upgraded .mdc-checkbox__checkmark,.mdc-checkbox.mdc-checkbox--upgraded .mdc-checkbox__checkmark-path,.mdc-checkbox.mdc-checkbox--upgraded .mdc-checkbox__mixedmark{transition:none}.mdc-checkbox{padding:calc((var(--mdc-checkbox-state-layer-size) - 18px) / 2);margin:calc((var(--mdc-checkbox-state-layer-size) - var(--mdc-checkbox-state-layer-size)) / 2)}.mdc-checkbox .mdc-checkbox__native-control[disabled]:not(:checked):not(:indeterminate):not([data-indeterminate=true])~.mdc-checkbox__background{border-color:var(--mdc-checkbox-disabled-unselected-icon-color);background-color:transparent}.mdc-checkbox .mdc-checkbox__native-control[disabled]:checked~.mdc-checkbox__background,.mdc-checkbox .mdc-checkbox__native-control[disabled]:indeterminate~.mdc-checkbox__background,.mdc-checkbox .mdc-checkbox__native-control[data-indeterminate=true][disabled]~.mdc-checkbox__background{border-color:transparent;background-color:var(--mdc-checkbox-disabled-selected-icon-color)}.mdc-checkbox .mdc-checkbox__native-control:enabled~.mdc-checkbox__background .mdc-checkbox__checkmark{color:var(--mdc-checkbox-selected-checkmark-color)}.mdc-checkbox .mdc-checkbox__native-control:enabled~.mdc-checkbox__background .mdc-checkbox__mixedmark{border-color:var(--mdc-checkbox-selected-checkmark-color)}.mdc-checkbox .mdc-checkbox__native-control:disabled~.mdc-checkbox__background .mdc-checkbox__checkmark{color:var(--mdc-checkbox-disabled-selected-checkmark-color)}.mdc-checkbox .mdc-checkbox__native-control:disabled~.mdc-checkbox__background .mdc-checkbox__mixedmark{border-color:var(--mdc-checkbox-disabled-selected-checkmark-color)}.mdc-checkbox .mdc-checkbox__native-control:enabled:not(:checked):not(:indeterminate):not([data-indeterminate=true])~.mdc-checkbox__background{border-color:var(--mdc-checkbox-unselected-icon-color);background-color:transparent}.mdc-checkbox .mdc-checkbox__native-control:enabled:checked~.mdc-checkbox__background,.mdc-checkbox .mdc-checkbox__native-control:enabled:indeterminate~.mdc-checkbox__background,.mdc-checkbox .mdc-checkbox__native-control[data-indeterminate=true]:enabled~.mdc-checkbox__background{border-color:var(--mdc-checkbox-selected-icon-color);background-color:var(--mdc-checkbox-selected-icon-color)}@keyframes mdc-checkbox-fade-in-background-8A000000FFF4433600000000FFF44336{0%{border-color:var(--mdc-checkbox-unselected-icon-color);background-color:transparent}50%{border-color:var(--mdc-checkbox-selected-icon-color);background-color:var(--mdc-checkbox-selected-icon-color)}}@keyframes mdc-checkbox-fade-out-background-8A000000FFF4433600000000FFF44336{0%,80%{border-color:var(--mdc-checkbox-selected-icon-color);background-color:var(--mdc-checkbox-selected-icon-color)}100%{border-color:var(--mdc-checkbox-unselected-icon-color);background-color:transparent}}.mdc-checkbox.mdc-checkbox--anim-unchecked-checked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox.mdc-checkbox--anim-unchecked-indeterminate .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-in-background-8A000000FFF4433600000000FFF44336}.mdc-checkbox.mdc-checkbox--anim-checked-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox.mdc-checkbox--anim-indeterminate-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-out-background-8A000000FFF4433600000000FFF44336}.mdc-checkbox:hover .mdc-checkbox__native-control:enabled:not(:checked):not(:indeterminate):not([data-indeterminate=true])~.mdc-checkbox__background{border-color:var(--mdc-checkbox-unselected-hover-icon-color);background-color:transparent}.mdc-checkbox:hover .mdc-checkbox__native-control:enabled:checked~.mdc-checkbox__background,.mdc-checkbox:hover .mdc-checkbox__native-control:enabled:indeterminate~.mdc-checkbox__background,.mdc-checkbox:hover .mdc-checkbox__native-control[data-indeterminate=true]:enabled~.mdc-checkbox__background{border-color:var(--mdc-checkbox-selected-hover-icon-color);background-color:var(--mdc-checkbox-selected-hover-icon-color)}@keyframes mdc-checkbox-fade-in-background-FF212121FFF4433600000000FFF44336{0%{border-color:var(--mdc-checkbox-unselected-hover-icon-color);background-color:transparent}50%{border-color:var(--mdc-checkbox-selected-hover-icon-color);background-color:var(--mdc-checkbox-selected-hover-icon-color)}}@keyframes mdc-checkbox-fade-out-background-FF212121FFF4433600000000FFF44336{0%,80%{border-color:var(--mdc-checkbox-selected-hover-icon-color);background-color:var(--mdc-checkbox-selected-hover-icon-color)}100%{border-color:var(--mdc-checkbox-unselected-hover-icon-color);background-color:transparent}}.mdc-checkbox:hover.mdc-checkbox--anim-unchecked-checked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox:hover.mdc-checkbox--anim-unchecked-indeterminate .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-in-background-FF212121FFF4433600000000FFF44336}.mdc-checkbox:hover.mdc-checkbox--anim-checked-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox:hover.mdc-checkbox--anim-indeterminate-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-out-background-FF212121FFF4433600000000FFF44336}.mdc-checkbox:not(:disabled):active .mdc-checkbox__native-control:enabled:not(:checked):not(:indeterminate):not([data-indeterminate=true])~.mdc-checkbox__background{border-color:var(--mdc-checkbox-unselected-pressed-icon-color);background-color:transparent}.mdc-checkbox:not(:disabled):active .mdc-checkbox__native-control:enabled:checked~.mdc-checkbox__background,.mdc-checkbox:not(:disabled):active .mdc-checkbox__native-control:enabled:indeterminate~.mdc-checkbox__background,.mdc-checkbox:not(:disabled):active .mdc-checkbox__native-control[data-indeterminate=true]:enabled~.mdc-checkbox__background{border-color:var(--mdc-checkbox-selected-pressed-icon-color);background-color:var(--mdc-checkbox-selected-pressed-icon-color)}@keyframes mdc-checkbox-fade-in-background-8A000000FFF4433600000000FFF44336{0%{border-color:var(--mdc-checkbox-unselected-pressed-icon-color);background-color:transparent}50%{border-color:var(--mdc-checkbox-selected-pressed-icon-color);background-color:var(--mdc-checkbox-selected-pressed-icon-color)}}@keyframes mdc-checkbox-fade-out-background-8A000000FFF4433600000000FFF44336{0%,80%{border-color:var(--mdc-checkbox-selected-pressed-icon-color);background-color:var(--mdc-checkbox-selected-pressed-icon-color)}100%{border-color:var(--mdc-checkbox-unselected-pressed-icon-color);background-color:transparent}}.mdc-checkbox:not(:disabled):active.mdc-checkbox--anim-unchecked-checked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox:not(:disabled):active.mdc-checkbox--anim-unchecked-indeterminate .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-in-background-8A000000FFF4433600000000FFF44336}.mdc-checkbox:not(:disabled):active.mdc-checkbox--anim-checked-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background,.mdc-checkbox:not(:disabled):active.mdc-checkbox--anim-indeterminate-unchecked .mdc-checkbox__native-control:enabled~.mdc-checkbox__background{animation-name:mdc-checkbox-fade-out-background-8A000000FFF4433600000000FFF44336}.mdc-checkbox .mdc-checkbox__background{top:calc((var(--mdc-checkbox-state-layer-size) - 18px) / 2);left:calc((var(--mdc-checkbox-state-layer-size) - 18px) / 2)}.mdc-checkbox .mdc-checkbox__native-control{top:calc((var(--mdc-checkbox-state-layer-size) - var(--mdc-checkbox-state-layer-size)) / 2);right:calc((var(--mdc-checkbox-state-layer-size) - var(--mdc-checkbox-state-layer-size)) / 2);left:calc((var(--mdc-checkbox-state-layer-size) - var(--mdc-checkbox-state-layer-size)) / 2);width:var(--mdc-checkbox-state-layer-size);height:var(--mdc-checkbox-state-layer-size)}.mdc-checkbox .mdc-checkbox__native-control:enabled:focus:focus:not(:checked):not(:indeterminate)~.mdc-checkbox__background{border-color:var(--mdc-checkbox-unselected-focus-icon-color)}.mdc-checkbox .mdc-checkbox__native-control:enabled:focus:checked~.mdc-checkbox__background,.mdc-checkbox .mdc-checkbox__native-control:enabled:focus:indeterminate~.mdc-checkbox__background{border-color:var(--mdc-checkbox-selected-focus-icon-color);background-color:var(--mdc-checkbox-selected-focus-icon-color)}.mdc-checkbox:hover .mdc-checkbox__ripple{opacity:var(--mdc-checkbox-unselected-hover-state-layer-opacity);background-color:var(--mdc-checkbox-unselected-hover-state-layer-color)}.mdc-checkbox:hover .mat-mdc-checkbox-ripple .mat-ripple-element{background-color:var(--mdc-checkbox-unselected-hover-state-layer-color)}.mdc-checkbox .mdc-checkbox__native-control:focus~.mdc-checkbox__ripple{opacity:var(--mdc-checkbox-unselected-focus-state-layer-opacity);background-color:var(--mdc-checkbox-unselected-focus-state-layer-color)}.mdc-checkbox .mdc-checkbox__native-control:focus~.mat-mdc-checkbox-ripple .mat-ripple-element{background-color:var(--mdc-checkbox-unselected-focus-state-layer-color)}.mdc-checkbox:active .mdc-checkbox__native-control~.mdc-checkbox__ripple{opacity:var(--mdc-checkbox-unselected-pressed-state-layer-opacity);background-color:var(--mdc-checkbox-unselected-pressed-state-layer-color)}.mdc-checkbox:active .mdc-checkbox__native-control~.mat-mdc-checkbox-ripple .mat-ripple-element{background-color:var(--mdc-checkbox-unselected-pressed-state-layer-color)}.mdc-checkbox:hover .mdc-checkbox__native-control:checked~.mdc-checkbox__ripple{opacity:var(--mdc-checkbox-selected-hover-state-layer-opacity);background-color:var(--mdc-checkbox-selected-hover-state-layer-color)}.mdc-checkbox:hover .mdc-checkbox__native-control:checked~.mat-mdc-checkbox-ripple .mat-ripple-element{background-color:var(--mdc-checkbox-selected-hover-state-layer-color)}.mdc-checkbox .mdc-checkbox__native-control:focus:checked~.mdc-checkbox__ripple{opacity:var(--mdc-checkbox-selected-focus-state-layer-opacity);background-color:var(--mdc-checkbox-selected-focus-state-layer-color)}.mdc-checkbox .mdc-checkbox__native-control:focus:checked~.mat-mdc-checkbox-ripple .mat-ripple-element{background-color:var(--mdc-checkbox-selected-focus-state-layer-color)}.mdc-checkbox:active .mdc-checkbox__native-control:checked~.mdc-checkbox__ripple{opacity:var(--mdc-checkbox-selected-pressed-state-layer-opacity);background-color:var(--mdc-checkbox-selected-pressed-state-layer-color)}.mdc-checkbox:active .mdc-checkbox__native-control:checked~.mat-mdc-checkbox-ripple .mat-ripple-element{background-color:var(--mdc-checkbox-selected-pressed-state-layer-color)}.mat-mdc-checkbox{display:inline-block;position:relative;-webkit-tap-highlight-color:rgba(0,0,0,0)}.mat-mdc-checkbox .mdc-checkbox__background{-webkit-print-color-adjust:exact;color-adjust:exact}.mat-mdc-checkbox._mat-animation-noopable *,.mat-mdc-checkbox._mat-animation-noopable *::before{transition:none !important;animation:none !important}.mat-mdc-checkbox label{cursor:pointer}.mat-mdc-checkbox.mat-mdc-checkbox-disabled label{cursor:default;color:var(--mat-checkbox-disabled-label-color)}.mat-mdc-checkbox label:empty{display:none}.cdk-high-contrast-active .mat-mdc-checkbox.mat-mdc-checkbox-disabled{opacity:.5}.cdk-high-contrast-active .mat-mdc-checkbox .mdc-checkbox__checkmark{--mdc-checkbox-selected-checkmark-color: CanvasText;--mdc-checkbox-disabled-selected-checkmark-color: CanvasText}.mat-mdc-checkbox .mdc-checkbox__ripple{opacity:0}.mat-mdc-checkbox-ripple,.mdc-checkbox__ripple{top:0;left:0;right:0;bottom:0;position:absolute;border-radius:50%;pointer-events:none}.mat-mdc-checkbox-ripple:not(:empty),.mdc-checkbox__ripple:not(:empty){transform:translateZ(0)}.mat-mdc-checkbox-ripple .mat-ripple-element{opacity:.1}.mat-mdc-checkbox-touch-target{position:absolute;top:50%;height:48px;left:50%;width:48px;transform:translate(-50%, -50%);display:var(--mat-checkbox-touch-target-display)}.mat-mdc-checkbox-ripple::before{border-radius:50%}.mdc-checkbox__native-control:focus~.mat-mdc-focus-indicator::before{content:""}\n'],
ob:2,Qa:0});var GB=class{};GB.J=function(a){return new (a||GB)};GB.Wa=Mf({type:GB});GB.Va=Md({imports:[BB,fz,fz]});var HB=class{};HB.J=function(a){return new (a||HB)};HB.Wa=Mf({type:HB});HB.Va=Md({Ua:[{na:yB,mb:{color:"primary"}}],imports:[GB]});var IB=new df("GMAT_DIALOG_OPTIONS",{da:"root",aa:()=>({qc:!1})});var JB=class{constructor(){this.role="dialog";this.gb="";this.Sb=!0;this.bc="";this.wd=!1;this.height=this.width="";this.ariaLabel=this.Yp=this.Xp=this.data=null;this.ariaModal=!0;this.Sm="first-tabbable";this.Zu=this.Av=this.Ng=!0}};var KB=class{constructor(){this.role="dialog";this.gb="";this.Sb=!0;this.bc="";this.wd=!1;this.height=this.width="";this.ariaLabel=this.Yp=this.Xp=this.data=null;this.ariaModal=!0;this.Sm="first-tabbable";this.av=this.Yu=this.Zu=this.Ng=!0}};function LB(){}function MB(a){const b=a.qa.P;switch(a.xa.Sm){case !1:case "dialog":a.ba()||b.focus();break;case !0:case "first-tabbable":let c;null==(c=a.N)||Qx(c).then(d=>{d||a.Oa()});break;case "first-heading":a.ma('h1, h2, h3, h4, h5, h6, [role="heading"]');break;default:a.ma(a.xa.Sm)}}
var NB=class extends Rv{constructor(a,b,c,d,e,f,g,k){super();this.qa=a;this.Da=b;this.xa=d;this.fb=e;this.pa=f;this.ka=g;this.O=k;this.Ka=lf(St);this.Bi=this.ea=this.N=null;this.Ai=[];this.Aa=lf(Pr);this.ha=c;this.xa.Yp&&this.Ai.push(this.xa.Yp)}Ia(a){this.Ai.push(a);Zm(this.Aa)}Jb(a){a=this.Ai.indexOf(a);-1<a&&(this.Ai.splice(a,1),Zm(this.Aa))}F(){this.ab();this.Ta();this.R()}R(){MB(this)}ua(){this.Kb()}Zd(a){a=this.Ue.Zd(a);this.F();return a}Ze(a){a=this.Ue.Ze(a);this.F();return a}rb(){this.ba()||
MB(this)}Ra(a,b){Lx(this.fb,a)||(a.tabIndex=-1,Kk(this.pa,()=>{const c=()=>{a.removeEventListener("blur",c);a.removeEventListener("mousedown",c);a.removeAttribute("tabindex")};a.addEventListener("blur",c);a.addEventListener("mousedown",c)}));a.focus(b)}ma(a,b){(a=this.qa.P.querySelector(a))&&this.Ra(a,b)}Kb(){var a=this.xa.Ng;let b=null;"string"===typeof a?b=this.ha.querySelector(a):"boolean"===typeof a?b=a?this.ea:null:a&&(b=a);if(this.xa.Ng&&b&&"function"===typeof b.focus){a=Ot();const c=this.qa.P;
if(!a||a===this.ha.body||a===c||c.contains(a))this.O?(Hx(this.O,b,this.Bi),this.Bi=null):b.focus()}this.N&&this.N.destroy()}Oa(){this.qa.P.focus&&this.qa.P.focus()}ba(){const a=this.qa.P,b=Ot();return a===b||a.contains(b)}ab(){this.Ka.isBrowser&&(this.N=this.Da.create(this.qa.P),this.ha&&(this.ea=Ot()))}Ta(){this.ka.bd().subscribe(()=>{this.xa.wd&&this.rb()})}};NB.J=function(a){return new (a||NB)(y(qi),y(Tx),y(gt,8),y(KB),y(Nx),y(Ok),y(Bu),y(Ix))};
NB.Ca=Gf({type:NB,ga:[["cdk-dialog-container"]],eb:function(a,b){a&1&&rr(Tv,7);if(a&2){let c;sr(c=tr())&&(b.Ue=c.first)}},Ja:["tabindex","-1",1,"cdk-dialog-container"],Xa:6,Ha:function(a,b){a&2&&Ip("id",b.xa.id||null)("role",b.xa.role)("aria-modal",b.xa.ariaModal)("aria-labelledby",b.xa.ariaLabel?null:b.Ai[0])("aria-label",b.xa.ariaLabel)("aria-describedby",b.xa.Xp||null)},ja:!0,features:[Ap,Jr],ya:1,za:0,Ba:[["cdkPortalOutlet",""]],sa:function(a){a&1&&yp(0,LB,0,0,"ng-template",0)},Ga:[Tv],styles:[".cdk-dialog-container{display:block;width:100%;height:100%;min-height:inherit;max-height:inherit}\n"],
ob:2});var OB=new df("DialogScrollStrategy",{da:"root",aa:()=>{const a=lf(Wv);return()=>a.i.block()}}),PB=new df("DialogData"),QB=new df("DefaultDialogConfig");var RB=class{constructor(a,b){this.Ub=a;this.config=b;this.closed=new aj;this.wd=b.wd;this.bd=a.bd();this.df=a.df();this.Kl=a.Kl();this.id=b.id;this.df.subscribe(c=>{27!==c.keyCode||this.wd||yu(c)||(c.preventDefault(),this.close(void 0,{Hq:"keyboard"}))});this.bd.subscribe(()=>{this.wd||this.close(void 0,{Hq:"mouse"})});this.wm=a.G.subscribe(()=>{!1!==b.av&&this.close()})}close(a,b){if(this.rg){const c=this.closed;this.rg.Bi=(null==b?void 0:b.Hq)||"program";this.wm.unsubscribe();this.Ub.dispose();
c.next(a);c.complete();this.dn=this.rg=null}}Uc(){this.Ub.Uc()}me(a="",b=""){this.Ub.me({width:a,height:b})}og(a){this.Ub.og(a)}Jj(a){this.Ub.Jj(a)}};let SB=0;function TB(a,b){a.i.find(c=>c.id===b)}function UB(a,b){a=new xu({sc:b.sc||Iv(Hv(Kv(a.N.position()))),tc:b.tc||a.Jc(),gb:b.gb,Sb:b.Sb,direction:b.direction,minWidth:b.minWidth,minHeight:b.minHeight,maxWidth:b.maxWidth,maxHeight:b.maxHeight,width:b.width,height:b.height,Hh:b.Zu});b.bc&&(a.bc=b.bc);return a}
function VB(a,b,c,d){var e;const f=a.wa||(null==(e=a.wb)?void 0:e.wa);e=[{na:PB,mb:a.data},{na:RB,mb:b}];a.Ua&&("function"===typeof a.Ua?e.push(...a.Ua(b,a,c)):e.push(...a.Ua));!a.direction||f&&f.get(lu,null,{optional:!0})||e.push({na:lu,mb:{value:a.direction,vb:hj()}});return Uh({parent:f||d,Ua:e})}function WB(a){const b=a.C;return b?WB(b):a.G}
var YB=class{get i(){return this.C?this.C.i:this.D}get pg(){return this.C?this.C.pg:this.K}constructor(a,b,c,d,e,f){this.N=a;this.Ya=b;this.R=c;this.C=d;this.T=e;this.D=[];this.G=new aj;this.K=new aj;this.F=new Map;this.Jc=f}open(a,b){b=Object.assign({},this.R||new KB,b);b.id=b.id||`cdk-dialog-${SB++}`;b.id&&TB(this,b.id);var c=UB(this,b);c=this.N.create(c);const d=new RB(c,b);c=this.ba(c,d,b);d.rg=c;this.ea(a,d,c,b);this.i.length||this.ia();this.i.push(d);d.closed.subscribe(()=>this.O(d,!0));this.pg.next(d);
return d}ua(){XB(this.D,a=>{!1===a.config.Yu&&this.O(a,!1)});XB(this.D,a=>a.close());this.G.complete();this.K.complete();this.D=[]}ba(a,b,c){var d;const e=c.wa||(null==(d=c.wb)?void 0:d.wa);b=[{na:KB,mb:c},{na:RB,mb:b},{na:Bu,mb:a}];c.Za?"function"===typeof c.Za?d=c.Za:(d=c.Za.type,b.push(...c.Za.Ua(c))):d=NB;c=new Ov(d,c.wb,Uh({parent:e||this.Ya,Ua:b}),c.i);return a.attach(c).instance}ea(a,b,c,d){if(a instanceof $q){var e=VB(d,b,c);b={ca:d.data,Yk:b};d.Ho&&(b=Object.assign({},b,"function"===typeof d.Ho?
d.Ho():d.Ho));c.Ze(new Pv(a,null,b,e))}else e=VB(d,b,c,this.Ya),a=c.Zd(new Ov(a,d.wb,e,d.i)),b.fv=a,b.dn=a.instance}O(a,b){a=this.i.indexOf(a);-1<a&&(this.i.splice(a,1),this.i.length||(this.F.forEach((c,d)=>{c?d.setAttribute("aria-hidden",c):d.removeAttribute("aria-hidden")}),this.F.clear(),b&&WB(this).next()))}ia(){const a=Ut(this.T);if(a.parentElement){const b=a.parentElement.children;for(let c=b.length-1;-1<c;c--){const d=b[c];d===a||"SCRIPT"===d.nodeName||"STYLE"===d.nodeName||d.hasAttribute("aria-live")||
(this.F.set(d,d.getAttribute("aria-hidden")),d.setAttribute("aria-hidden","true"))}}}};YB.J=function(a){return new (a||YB)(q(Wv),q(Vh),q(QB,8),q(YB,12),q(Vt),q(OB))};YB.oa=Ld({la:YB,aa:YB.J,da:"root"});function XB(a,b){let c=a.length;for(;c--;)b(a[c])};var ZB=class{};ZB.J=function(a){return new (a||ZB)};ZB.Wa=Mf({type:ZB});ZB.Va=Md({Ua:[YB],imports:[dw,Uv,ky,Uv]});function $B(){}
var bC=class extends NB{constructor(a,b,c,d,e,f,g,k,m){super(a,b,c,d,e,f,g,m);this.Yc=k;this.i=new Dk;this.lk="NoopAnimations"!==this.Yc;this.Yo=0;this.C=this.qa.P;let p;this.G=this.lk?null!=(p=aC(this.xa.JF))?p:150:0;let t;this.K=this.lk?null!=(t=aC(this.xa.MF))?t:75:0;this.D=null;this.ia=()=>{this.T();this.kb(this.G)};this.Hi=()=>{this.T();this.i.emit({state:"closed",totalTime:this.K})}}F(){super.F();this.Nb()}Nb(){this.i.emit({state:"opening",totalTime:this.G});this.lk?(this.C.style.setProperty("--mat-dialog-transition-duration",`${this.G}ms`),
this.ra(()=>this.C.classList.add("mdc-dialog--opening","mdc-dialog--open")),this.va(this.G,this.ia)):(this.C.classList.add("mdc-dialog--open"),Promise.resolve().then(()=>this.ia()))}Mb(){this.i.emit({state:"closing",totalTime:this.K});this.C.classList.remove("mdc-dialog--open");this.lk?(this.C.style.setProperty("--mat-dialog-transition-duration",`${this.K}ms`),this.ra(()=>this.C.classList.add("mdc-dialog--closing")),this.va(this.K,this.Hi)):Promise.resolve().then(()=>this.Hi())}ta(a){this.Yo+=a;Zm(this.Aa)}T(){this.C.classList.remove("mdc-dialog--opening",
"mdc-dialog--closing")}va(a,b){null!==this.D&&clearTimeout(this.D);this.D=setTimeout(b,a)}ra(a){Kk(this.pa,()=>{"function"===typeof requestAnimationFrame?requestAnimationFrame(a):a()})}R(){this.xa.Av||MB(this)}kb(a){this.xa.Av&&MB(this);this.i.next({state:"opened",totalTime:a})}ua(){super.ua();null!==this.D&&clearTimeout(this.D)}Zd(a){a=super.Zd(a);a.location.P.classList.add("mat-mdc-dialog-component-host");return a}};
bC.J=function(a){return new (a||bC)(y(qi),y(Tx),y(gt,8),y(JB),y(Nx),y(Ok),y(Bu),y(ki,8),y(Ix))};
bC.Ca=Gf({type:bC,ga:[["mat-dialog-container"]],Ja:["tabindex","-1",1,"mat-mdc-dialog-container","mdc-dialog"],Xa:10,Ha:function(a,b){a&2&&(Oq("id",b.xa.id),Ip("aria-modal",b.xa.ariaModal)("role",b.xa.role)("aria-labelledby",b.xa.ariaLabel?null:b.Ai[0])("aria-label",b.xa.ariaLabel)("aria-describedby",b.xa.Xp||null),lq("_mat-animation-noopable",!b.lk)("mat-mdc-dialog-container-with-actions",0<b.Yo))},ja:!0,features:[Ap,Jr],ya:3,za:0,Ba:[[1,"mdc-dialog__container"],[1,"mat-mdc-dialog-surface","mdc-dialog__surface"],
["cdkPortalOutlet",""]],sa:function(a){a&1&&(R(0,"div",0)(1,"div",1),yp(2,$B,0,0,"ng-template",2),S()())},Ga:[Tv],styles:['.mdc-dialog,.mdc-dialog__scrim{position:fixed;top:0;left:0;align-items:center;justify-content:center;box-sizing:border-box;width:100%;height:100%}.mdc-dialog{display:none;z-index:var(--mdc-dialog-z-index, 7)}.mdc-dialog .mdc-dialog__content{padding:20px 24px 20px 24px}.mdc-dialog .mdc-dialog__surface{min-width:280px}@media(max-width: 592px){.mdc-dialog .mdc-dialog__surface{max-width:calc(100vw - 32px)}}@media(min-width: 592px){.mdc-dialog .mdc-dialog__surface{max-width:560px}}.mdc-dialog .mdc-dialog__surface{max-height:calc(100% - 32px)}.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface{max-width:none}@media(max-width: 960px){.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface{max-height:560px;width:560px}.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface .mdc-dialog__close{right:-12px}}@media(max-width: 720px)and (max-width: 672px){.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface{width:calc(100vw - 112px)}}@media(max-width: 720px)and (min-width: 672px){.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface{width:560px}}@media(max-width: 720px)and (max-height: 720px){.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface{max-height:calc(100vh - 160px)}}@media(max-width: 720px)and (min-height: 720px){.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface{max-height:560px}}@media(max-width: 720px){.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface .mdc-dialog__close{right:-12px}}@media(max-width: 720px)and (max-height: 400px),(max-width: 600px),(min-width: 720px)and (max-height: 400px){.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface{height:100%;max-height:100vh;max-width:100vw;width:100vw;border-radius:0}.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface .mdc-dialog__close{order:-1;left:-12px}.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface .mdc-dialog__header{padding:0 16px 9px;justify-content:flex-start}.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface .mdc-dialog__title{margin-left:calc(16px - 2 * 12px)}}@media(min-width: 960px){.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface{width:calc(100vw - 400px)}.mdc-dialog.mdc-dialog--fullscreen .mdc-dialog__surface .mdc-dialog__close{right:-12px}}.mdc-dialog.mdc-dialog__scrim--hidden .mdc-dialog__scrim{opacity:0}.mdc-dialog__scrim{opacity:0;z-index:-1}.mdc-dialog__container{display:flex;flex-direction:row;align-items:center;justify-content:space-around;box-sizing:border-box;height:100%;opacity:0;pointer-events:none}.mdc-dialog__surface{position:relative;display:flex;flex-direction:column;flex-grow:0;flex-shrink:0;box-sizing:border-box;max-width:100%;max-height:100%;pointer-events:auto;overflow-y:auto;outline:0;transform:scale(0.8)}.mdc-dialog__surface .mdc-elevation-overlay{width:100%;height:100%;top:0;left:0}[dir=rtl] .mdc-dialog__surface,.mdc-dialog__surface[dir=rtl]{text-align:right}@media screen and (forced-colors: active),(-ms-high-contrast: active){.mdc-dialog__surface{outline:2px solid windowText}}.mdc-dialog__surface::before{position:absolute;box-sizing:border-box;width:100%;height:100%;top:0;left:0;border:2px solid rgba(0,0,0,0);border-radius:inherit;content:"";pointer-events:none}@media screen and (forced-colors: active){.mdc-dialog__surface::before{border-color:CanvasText}}@media screen and (-ms-high-contrast: active),screen and (-ms-high-contrast: none){.mdc-dialog__surface::before{content:none}}.mdc-dialog__title{display:block;margin-top:0;position:relative;flex-shrink:0;box-sizing:border-box;margin:0 0 1px;padding:0 24px 9px}.mdc-dialog__title::before{display:inline-block;width:0;height:40px;content:"";vertical-align:0}[dir=rtl] .mdc-dialog__title,.mdc-dialog__title[dir=rtl]{text-align:right}.mdc-dialog--scrollable .mdc-dialog__title{margin-bottom:1px;padding-bottom:15px}.mdc-dialog--fullscreen .mdc-dialog__header{align-items:baseline;border-bottom:1px solid rgba(0,0,0,0);display:inline-flex;justify-content:space-between;padding:0 24px 9px;z-index:1}@media screen and (forced-colors: active){.mdc-dialog--fullscreen .mdc-dialog__header{border-bottom-color:CanvasText}}.mdc-dialog--fullscreen .mdc-dialog__header .mdc-dialog__close{right:-12px}.mdc-dialog--fullscreen .mdc-dialog__title{margin-bottom:0;padding:0;border-bottom:0}.mdc-dialog--fullscreen.mdc-dialog--scrollable .mdc-dialog__title{border-bottom:0;margin-bottom:0}.mdc-dialog--fullscreen .mdc-dialog__close{top:5px}.mdc-dialog--fullscreen.mdc-dialog--scrollable .mdc-dialog__actions{border-top:1px solid rgba(0,0,0,0)}@media screen and (forced-colors: active){.mdc-dialog--fullscreen.mdc-dialog--scrollable .mdc-dialog__actions{border-top-color:CanvasText}}.mdc-dialog--fullscreen--titleless .mdc-dialog__close{margin-top:4px}.mdc-dialog--fullscreen--titleless.mdc-dialog--scrollable .mdc-dialog__close{margin-top:0}.mdc-dialog__content{flex-grow:1;box-sizing:border-box;margin:0;overflow:auto}.mdc-dialog__content>:first-child{margin-top:0}.mdc-dialog__content>:last-child{margin-bottom:0}.mdc-dialog__title+.mdc-dialog__content,.mdc-dialog__header+.mdc-dialog__content{padding-top:0}.mdc-dialog--scrollable .mdc-dialog__title+.mdc-dialog__content{padding-top:8px;padding-bottom:8px}.mdc-dialog__content .mdc-deprecated-list:first-child:last-child{padding:6px 0 0}.mdc-dialog--scrollable .mdc-dialog__content .mdc-deprecated-list:first-child:last-child{padding:0}.mdc-dialog__actions{display:flex;position:relative;flex-shrink:0;flex-wrap:wrap;align-items:center;justify-content:flex-end;box-sizing:border-box;min-height:52px;margin:0;padding:8px;border-top:1px solid rgba(0,0,0,0)}@media screen and (forced-colors: active){.mdc-dialog__actions{border-top-color:CanvasText}}.mdc-dialog--stacked .mdc-dialog__actions{flex-direction:column;align-items:flex-end}.mdc-dialog__button{margin-left:8px;margin-right:0;max-width:100%;text-align:right}[dir=rtl] .mdc-dialog__button,.mdc-dialog__button[dir=rtl]{margin-left:0;margin-right:8px}.mdc-dialog__button:first-child{margin-left:0;margin-right:0}[dir=rtl] .mdc-dialog__button:first-child,.mdc-dialog__button:first-child[dir=rtl]{margin-left:0;margin-right:0}[dir=rtl] .mdc-dialog__button,.mdc-dialog__button[dir=rtl]{text-align:left}.mdc-dialog--stacked .mdc-dialog__button:not(:first-child){margin-top:12px}.mdc-dialog--open,.mdc-dialog--opening,.mdc-dialog--closing{display:flex}.mdc-dialog--opening .mdc-dialog__scrim{transition:opacity 150ms linear}.mdc-dialog--opening .mdc-dialog__container{transition:opacity 75ms linear,transform 150ms 0ms cubic-bezier(0, 0, 0.2, 1)}.mdc-dialog--closing .mdc-dialog__scrim,.mdc-dialog--closing .mdc-dialog__container{transition:opacity 75ms linear}.mdc-dialog--closing .mdc-dialog__container{transform:none}.mdc-dialog--closing .mdc-dialog__surface{transform:none}.mdc-dialog--chaining .mdc-dialog__scrim{transition:none;opacity:1}.mdc-dialog--open .mdc-dialog__scrim{opacity:1}.mdc-dialog--open .mdc-dialog__container{opacity:1}.mdc-dialog--open .mdc-dialog__surface{transform:none}.mdc-dialog--open.mdc-dialog__surface-scrim--shown .mdc-dialog__surface-scrim{opacity:1}.mdc-dialog--open.mdc-dialog__surface-scrim--hiding .mdc-dialog__surface-scrim{transition:opacity 75ms linear}.mdc-dialog--open.mdc-dialog__surface-scrim--showing .mdc-dialog__surface-scrim{transition:opacity 150ms linear}.mdc-dialog__surface-scrim{display:none;opacity:0;position:absolute;width:100%;height:100%;z-index:1}.mdc-dialog__surface-scrim--shown .mdc-dialog__surface-scrim,.mdc-dialog__surface-scrim--showing .mdc-dialog__surface-scrim,.mdc-dialog__surface-scrim--hiding .mdc-dialog__surface-scrim{display:block}.mdc-dialog-scroll-lock{overflow:hidden}.mdc-dialog--no-content-padding .mdc-dialog__content{padding:0}.mdc-dialog--sheet .mdc-dialog__container .mdc-dialog__close{right:12px;top:9px;position:absolute;z-index:1}.mdc-dialog__scrim--removed{pointer-events:none}.mdc-dialog__scrim--removed .mdc-dialog__scrim,.mdc-dialog__scrim--removed .mdc-dialog__surface-scrim{display:none}.mat-mdc-dialog-content{max-height:65vh}.mat-mdc-dialog-container{position:static;display:block}.mat-mdc-dialog-container,.mat-mdc-dialog-container .mdc-dialog__container,.mat-mdc-dialog-container .mdc-dialog__surface{max-height:inherit;min-height:inherit;min-width:inherit;max-width:inherit}.mat-mdc-dialog-container .mdc-dialog__surface{width:100%;height:100%}.mat-mdc-dialog-component-host{display:contents}.mat-mdc-dialog-container{--mdc-dialog-container-elevation: var(--mdc-dialog-container-elevation-shadow);outline:0}.mat-mdc-dialog-container .mdc-dialog__surface{background-color:var(--mdc-dialog-container-color, white)}.mat-mdc-dialog-container .mdc-dialog__surface{box-shadow:var(--mdc-dialog-container-elevation, 0px 11px 15px -7px rgba(0, 0, 0, 0.2), 0px 24px 38px 3px rgba(0, 0, 0, 0.14), 0px 9px 46px 8px rgba(0, 0, 0, 0.12))}.mat-mdc-dialog-container .mdc-dialog__surface{border-radius:var(--mdc-dialog-container-shape, 4px)}.mat-mdc-dialog-container .mdc-dialog__title{font-family:var(--mdc-dialog-subhead-font, Roboto, sans-serif);line-height:var(--mdc-dialog-subhead-line-height, 1.5rem);font-size:var(--mdc-dialog-subhead-size, 1rem);font-weight:var(--mdc-dialog-subhead-weight, 400);letter-spacing:var(--mdc-dialog-subhead-tracking, 0.03125em)}.mat-mdc-dialog-container .mdc-dialog__title{color:var(--mdc-dialog-subhead-color, rgba(0, 0, 0, 0.87))}.mat-mdc-dialog-container .mdc-dialog__content{font-family:var(--mdc-dialog-supporting-text-font, Roboto, sans-serif);line-height:var(--mdc-dialog-supporting-text-line-height, 1.5rem);font-size:var(--mdc-dialog-supporting-text-size, 1rem);font-weight:var(--mdc-dialog-supporting-text-weight, 400);letter-spacing:var(--mdc-dialog-supporting-text-tracking, 0.03125em)}.mat-mdc-dialog-container .mdc-dialog__content{color:var(--mdc-dialog-supporting-text-color, rgba(0, 0, 0, 0.6))}.mat-mdc-dialog-container .mdc-dialog__container{transition:opacity linear var(--mat-dialog-transition-duration, 0ms)}.mat-mdc-dialog-container .mdc-dialog__surface{transition:transform var(--mat-dialog-transition-duration, 0ms) 0ms cubic-bezier(0, 0, 0.2, 1)}.mat-mdc-dialog-container._mat-animation-noopable .mdc-dialog__container,.mat-mdc-dialog-container._mat-animation-noopable .mdc-dialog__surface{transition:none}.cdk-overlay-pane.mat-mdc-dialog-panel{max-width:var(--mat-dialog-container-max-width, 80vw);min-width:var(--mat-dialog-container-min-width, 0)}@media(max-width: 599px){.cdk-overlay-pane.mat-mdc-dialog-panel{max-width:var(--mat-dialog-container-small-max-width, 80vw)}}.mat-mdc-dialog-title{padding:var(--mat-dialog-headline-padding, 0 24px 9px)}.mat-mdc-dialog-content{display:block}.mat-mdc-dialog-container .mat-mdc-dialog-content{padding:var(--mat-dialog-content-padding, 20px 24px)}.mat-mdc-dialog-container-with-actions .mat-mdc-dialog-content{padding:var(--mat-dialog-with-actions-content-padding, 20px 24px)}.mat-mdc-dialog-container .mat-mdc-dialog-title+.mat-mdc-dialog-content{padding-top:0}.mat-mdc-dialog-actions{padding:var(--mat-dialog-actions-padding, 8px);justify-content:var(--mat-dialog-actions-alignment, start)}.mat-mdc-dialog-actions.mat-mdc-dialog-actions-align-start,.mat-mdc-dialog-actions[align=start]{justify-content:start}.mat-mdc-dialog-actions.mat-mdc-dialog-actions-align-center,.mat-mdc-dialog-actions[align=center]{justify-content:center}.mat-mdc-dialog-actions.mat-mdc-dialog-actions-align-end,.mat-mdc-dialog-actions[align=end]{justify-content:flex-end}.mat-mdc-dialog-actions .mat-button-base+.mat-button-base,.mat-mdc-dialog-actions .mat-mdc-button-base+.mat-mdc-button-base{margin-left:8px}[dir=rtl] .mat-mdc-dialog-actions .mat-button-base+.mat-button-base,[dir=rtl] .mat-mdc-dialog-actions .mat-mdc-button-base+.mat-mdc-button-base{margin-left:0;margin-right:8px}\n'],
ob:2});function aC(a){return null==a?null:"number"===typeof a?a:a.endsWith("ms")?Qs(a.substring(0,a.length-2)):a.endsWith("s")?1E3*Qs(a.substring(0,a.length-1)):"0"===a?0:null};var cC=class{constructor(a,b,c){this.We=a;this.nh=c;this.lh=new aj;this.qm=new aj;this.nc=0;this.wd=b.wd;this.id=a.id;a.og("mat-mdc-dialog-panel");C(c.i,rk(d=>"opened"===d.state),co()).subscribe(()=>{this.lh.next();this.lh.complete()});C(c.i,rk(d=>"closed"===d.state),co()).subscribe(()=>{clearTimeout(this.Ez);this.Hi()});a.Ub.G.subscribe(()=>{this.qm.next(this.ju);this.qm.complete();this.Hi()});pk(this.bd(),C(this.df(),rk(d=>27===d.keyCode&&!this.wd&&!yu(d)))).subscribe(d=>{this.wd||(d.preventDefault(),
this.Bi="keydown"===d.type?"keyboard":"mouse",this.close(void 0))})}close(a){this.ju=a;C(this.nh.i,rk(b=>"closing"===b.state),co()).subscribe(b=>{this.qm.next(a);this.qm.complete();zu(this.We.Ub);this.Ez=setTimeout(()=>this.Hi(),b.totalTime+100)});this.nc=1;this.nh.Mb()}pg(){return this.lh}bd(){return this.We.bd}df(){return this.We.df}Uc(a){let b=this.We.config.sc;a&&(a.left||a.right)?a.left?b.left(a.left):b.right(a.right):Hv(b);a&&(a.top||a.bottom)?a.top?b.top(a.top):b.bottom(a.bottom):Iv(b);this.We.Uc()}me(a=
"",b=""){this.We.me(a,b)}og(a){this.We.og(a)}Jj(a){this.We.Jj(a)}getState(){return this.nc}Hi(){this.nc=2;this.We.close(this.ju,{Hq:this.Bi});this.dn=null}};var dC=new df("MatMdcDialogData"),eC=new df("mat-mdc-dialog-default-options"),fC=new df("mat-mdc-dialog-scroll-strategy",{da:"root",aa:()=>{const a=lf(Wv);return()=>a.i.block()}});let gC=0;function hC(a){const b=a.C;return b?hC(b):a.D}
var iC=class{get i(){return this.C?this.C.i:this.G}get pg(){return this.C?this.C.pg:this.F}constructor(a,b,c,d,e,f){this.T=a;this.O=d;this.Jc=e;this.C=f;this.G=[];this.D=new aj;this.F=new aj;this.ia=JB;this.R=b.get(YB);this.N=cC;this.K=bC;this.ea=dC}open(a,b){let c;b=Object.assign({},this.O||new JB,b);b.id=b.id||`mat-mdc-dialog-${gC++}`;b.tc=b.tc||this.Jc();a=this.R.open(a,Object.assign({},b,{sc:Iv(Hv(Kv(this.T.position()))),wd:!0,Yu:!1,av:!1,Za:{type:this.K,Ua:()=>[{na:this.ia,mb:b},{na:KB,mb:b}]},
Ho:()=>({Yk:c}),Ua:(d,e,f)=>{c=new this.N(d,b,f);let g;c.Uc(null==(g=b)?void 0:g.position);return[{na:this.K,mb:f},{na:this.ea,mb:e.data},{na:this.N,mb:c}]}}));c.fv=a.fv;c.dn=a.dn;this.i.push(c);this.pg.next(c);c.We.closed.subscribe(()=>{const d=this.i.indexOf(c);-1<d&&(this.i.splice(d,1),this.i.length||hC(this).next())});return c}ua(){this.ba(this.G);this.D.complete();this.F.complete()}ba(a){let b=a.length;for(;b--;)a[b].close()}};
iC.J=function(a){return new (a||iC)(q(Wv),q(Vh),q(Bt,8),q(eC,8),q(fC),q(iC,12),q(Vt),q(ki,8))};iC.oa=Ld({la:iC,aa:iC.J,da:"root"});let jC=0;var lC=class{constructor(a,b,c){this.Yk=a;this.qa=b;this.i=c;this.type="button"}Eb(){this.Yk||(this.Yk=kC(this.qa,this.i.i))}rc(a){if(a=a._matDialogClose||a._matDialogCloseResult)this.Cv=a.pq}nA(a){var b=this.Yk,c=this.Cv;b.Bi=0===a.screenX&&0===a.screenY?"keyboard":"mouse";b.close(c)}};lC.J=function(a){return new (a||lC)(y(cC,8),y(qi),y(iC))};
lC.Ea=Of({type:lC,ga:[["","mat-dialog-close",""],["","matDialogClose",""]],Xa:2,Ha:function(a,b){a&1&&V("click",function(c){return b.nA(c)});a&2&&Ip("aria-label",b.ariaLabel||null)("type",b.type)},inputs:{ariaLabel:[0,"aria-label","ariaLabel"],type:"type",Cv:[0,"mat-dialog-close","dialogResult"],sF:[0,"matDialogClose","_matDialogClose"]},hb:["matDialogClose"],ja:!0,features:[Cg]});
var mC=class{constructor(a,b,c){this.i=a;this.qa=b;this.F=c}Eb(){this.i||(this.i=kC(this.qa,this.F.i));this.i&&Promise.resolve().then(()=>{this.C()})}ua(){let a;(null==(a=this.i)?0:a.nh)&&Promise.resolve().then(()=>{this.D()})}};mC.J=function(a){return new (a||mC)(y(cC,8),y(qi),y(iC))};mC.Ea=Of({type:mC,ja:!0});
var nC=class extends mC{constructor(){super(...arguments);this.id=`mat-mdc-dialog-title-${jC++}`}C(){let a,b;null==(a=this.i.nh)||null==(b=a.Ia)||b.call(a,this.id)}D(){let a,b,c;null==(a=this.i)||null==(b=a.nh)||null==(c=b.Jb)||c.call(b,this.id)}};nC.J=(()=>{let a;return function(b){return(a||(a=Lh(nC)))(b||nC)}})();
nC.Ea=Of({type:nC,ga:[["","mat-dialog-title",""],["","matDialogTitle",""]],Ja:[1,"mat-mdc-dialog-title","mdc-dialog__title"],Xa:1,Ha:function(a,b){a&2&&Oq("id",b.id)},inputs:{id:"id"},hb:["matDialogTitle"],ja:!0,features:[Ap]});var oC=class{};oC.J=function(a){return new (a||oC)};
oC.Ea=Of({type:oC,ga:[["","mat-dialog-content",""],["mat-dialog-content"],["","matDialogContent",""]],Ja:[1,"mat-mdc-dialog-content","mdc-dialog__content"],ja:!0,features:[function(a){const b=c=>{const d=(Array.isArray(a)?a:a()).map(e=>"function"===typeof e?{rq:bf(e),inputs:Ef,outputs:Ef}:{rq:bf(e.rq),inputs:Gp(e.inputs),outputs:Gp(e.outputs)});null===c.ol?(c.nj=Fp,c.ol=d):c.ol.unshift(...d)};b.Mw=!0;return b}([nu])]});
var pC=class extends mC{C(){let a,b;null==(a=this.i.nh)||null==(b=a.ta)||b.call(a,1)}D(){let a,b;null==(a=this.i.nh)||null==(b=a.ta)||b.call(a,-1)}};pC.J=(()=>{let a;return function(b){return(a||(a=Lh(pC)))(b||pC)}})();
pC.Ea=Of({type:pC,ga:[["","mat-dialog-actions",""],["mat-dialog-actions"],["","matDialogActions",""]],Ja:[1,"mat-mdc-dialog-actions","mdc-dialog__actions"],Xa:6,Ha:function(a,b){a&2&&lq("mat-mdc-dialog-actions-align-start","start"===b.align)("mat-mdc-dialog-actions-align-center","center"===b.align)("mat-mdc-dialog-actions-align-end","end"===b.align)},inputs:{align:"align"},ja:!0,features:[Ap]});
function kC(a,b){let c=a.P.parentElement;for(;c&&!c.classList.contains("mat-mdc-dialog-container");)c=c.parentElement;return c?b.find(d=>d.id===c.id):null};var qC=class{};qC.J=function(a){return new (a||qC)};qC.Wa=Mf({type:qC});qC.Va=Md({Ua:[iC],imports:[ZB,dw,Uv,fz,fz]});var rC=class extends iC{constructor(a,b,c,d,e,f,g,k){k.qc||ew(a,"gmat-mdc-dialog");super(a,b,c,d,e,f,g)}};rC.J=function(a){return new (a||rC)(q(Wv),q(Vh),q(Bt,8),q(eC,8),q(fC),q(iC,12),q(Vt),q(IB))};rC.oa=Ld({la:rC,aa:rC.J});var sC=class{};sC.J=function(a){return new (a||sC)};sC.Wa=Mf({type:sC});sC.Va=Md({Ua:[{na:iC,Dc:rC},{na:Wv,Dc:fw}],imports:[qC]});new df("GMAT_FORM_FIELD_OPTIONS",{da:"root",aa:()=>({qc:!1})});var tC=class{};tC.J=function(a){return new (a||tC)};tC.Wa=Mf({type:tC});tC.Va=Md({imports:[WA]});var uC=new df("GMAT_MENU_OPTIONS",{da:"root",aa:()=>({qc:!1})});var vC=class{constructor(a,b){this.options=a;a.qc||ew(b,"gmat-mdc-menu")}};vC.J=function(a){return new (a||vC)(y(uC),y(Wv))};vC.Ea=Of({type:vC,ga:[["","mat-menu-trigger-for",""],["","matMenuTriggerFor",""]],features:[Hr([{na:Wv,Dc:fw}])]});var wC=Ry("transformMenu",[Uy("void",Ty({opacity:0,transform:"scale(0.8)"})),Vy("void => enter",Sy("120ms cubic-bezier(0, 0, 0.2, 1)",Ty({opacity:1,transform:"scale(1)"}))),Vy("* => void",Sy("100ms 25ms linear",Ty({opacity:0})))]),xC=Ry("fadeInItems",[Uy("showing",Ty({opacity:1})),Vy("void => *",[Ty({opacity:0}),Sy("400ms 100ms cubic-bezier(0.55, 0, 0.55, 0.2)")])]);var yC=new df("MatMenuContent");var zC=new df("MAT_MENU_PANEL");const AC=[[["mat-icon"],["","matMenuItemIcon",""]],"*"];function BC(a){a&1&&(eh(),R(0,"svg",2),Kq(1,"polygon",3),S())}
var CC=class{constructor(a,b,c,d,e){this.qa=a;this.ha=b;this.i=c;this.C=d;this.Aa=e;this.role="menuitem";this.Lc=this.disabled=!1;this.D=new aj;this.Pe=new aj;this.Qp=this.Pt=!1;let f;null==d||null==(f=d.UA)||f.call(d,this)}focus(a,b){this.i&&a?Hx(this.i,this.pe(),a,b):this.pe().focus(b);this.Pe.next(this)}nd(){this.i&&Fx(this.i,this.qa,!1)}ua(){this.i&&Gx(this.i,this.qa);this.C&&this.C.removeItem&&this.C.removeItem(this);this.D.complete();this.Pe.complete()}Gt(){return this.disabled?"-1":"0"}pe(){return this.qa.P}Cz(a){this.disabled&&
(a.preventDefault(),a.stopPropagation())}Zz(){this.D.next(this)}Vv(){const a=this.qa.P.cloneNode(!0),b=a.querySelectorAll("mat-icon, .material-icons");for(let d=0;d<b.length;d++)b[d].remove();let c;return(null==(c=a.textContent)?void 0:c.trim())||""}F(a){this.Pt=a;let b;null==(b=this.Aa)||Zm(b)}G(a){this.Qp=a;let b;null==(b=this.Aa)||Zm(b)}cA(){return this.ha&&this.ha.activeElement===this.pe()}};CC.J=function(a){return new (a||CC)(y(qi),y(gt),y(Ix),y(zC,8),y(Pr))};
CC.Ca=Gf({type:CC,ga:[["","mat-menu-item",""]],Ja:[1,"mat-mdc-menu-item","mat-mdc-focus-indicator"],Xa:8,Ha:function(a,b){a&1&&V("click",function(c){return b.Cz(c)})("mouseenter",function(){return b.Zz()});a&2&&(Ip("role",b.role)("tabindex",b.Gt())("aria-disabled",b.disabled)("disabled",b.disabled||null),lq("mat-mdc-menu-item-highlighted",b.Pt)("mat-mdc-menu-item-submenu-trigger",b.Qp))},inputs:{role:"role",disabled:[2,"disabled","disabled",ws],Lc:[2,"disableRipple","disableRipple",ws]},hb:["matMenuItem"],
ja:!0,features:[Hp,Jr],attrs:["mat-menu-item",""],Yb:["mat-icon, [matMenuItemIcon]","*"],ya:5,za:3,Ba:[[1,"mat-mdc-menu-item-text"],["matRipple","",1,"mat-mdc-menu-ripple",3,"matRippleDisabled","matRippleTrigger"],["viewBox","0 0 5 10","focusable","false","aria-hidden","true",1,"mat-mdc-menu-submenu-icon"],["points","0,0 5,5 0,10"]],sa:function(a,b){a&1&&(Vq(AC),Wq(0),R(1,"span",0),Wq(2,1),S(),Kq(3,"div",1),yp(4,BC,2,0,":svg:svg",2));a&2&&(D(3),H("matRippleDisabled",b.Lc||b.disabled)("matRippleTrigger",
b.pe()),D(),Cq(b.Qp?4:-1))},Ga:[Ez],ob:2,Qa:0});function DC(a){if(a&1){const b=Tg();R(0,"div",0);V("keydown",function(c){u(b);const d=Y();return x(d.Re(c))})("click",function(){u(b);const c=Y();return x(c.closed.emit("click"))})("@transformMenu.start",function(c){u(b);const d=Y();return x(d.lA(c))})("@transformMenu.done",function(c){u(b);const d=Y();return x(d.kA(c))});R(1,"div",1);Wq(2);S()()}a&2&&(a=Y(),oq(rq,a.Oe),H("id",a.Ww)("@transformMenu",a.Hm),Ip("aria-label",a.ariaLabel||null)("aria-labelledby",a.ad||null)("aria-describedby",a.Hk||null))}
let EC=0;var GC=new df("mat-menu-default-options",{da:"root",aa:FC});function FC(){return{mo:!1,ri:"after",Yj:"below",bc:"cdk-overlay-transparent-backdrop"}}function HC(a){return C(a.i.i,Fo(a.i),Go(b=>pk(...b.map(c=>c.D))))}function IC(a,b="program"){let c;null==(c=a.F)||c.destroy();a.F=Zk(()=>{let d=null;a.i.length&&(d=a.i.first.pe().closest('[role="menu"]'));if(!d||!d.contains(document.activeElement)){const e=a.C;e.ra=b;e.G(0,1);!e.i&&d&&d.focus()}},{wa:a.Ya})}
var JC=class{get ri(){return this.Ef}set ri(a){this.Ef=a;this.Qj()}get Yj(){return this.K}set Yj(a){this.K=a;this.Qj()}set gb(a){const b=this.N,c=Object.assign({},this.Oe);b&&b.length&&b.split(" ").forEach(d=>{c[d]=!1});(this.N=a)&&a.length&&(a.split(" ").forEach(d=>{c[d]=!0}),this.qa.P.className="");this.Oe=c}get classList(){return this.gb}set classList(a){this.gb=a}constructor(a,b,c,d){this.qa=a;this.Aa=d;this.ea="mat-elevation-z";this.ba=8;this.i=new Zq;this.Oe={};this.Hm="void";this.hg=new aj;
this.close=this.closed=new Dk;this.Ww=`mat-menu-panel-${EC++}`;this.Ya=lf(Vh);this.Wh=c.Wh||"";this.Ef=c.ri;this.K=c.Yj;this.bc=c.bc;this.mo=c.mo;this.Sb=c.Sb}Eb(){this.Qj()}yj(){this.T();this.C=Iy(Hy(Dy(new Qy(this.i))));this.C.ba.subscribe(()=>this.closed.emit("tab"));C(this.i.i,Fo(this.i),Go(a=>pk(...a.map(b=>b.Pe)))).subscribe(a=>Ky(this.C,a));this.i.i.subscribe(a=>{const b=this.C;var c;"enter"===this.Hm&&(null==(c=b.i)?0:c.cA())&&(a=a.toArray(),c=Math.max(0,Math.min(a.length-1,b.N||0)),a[c]&&
!a[c].disabled?b.C(c):Ly(b))})}ua(){let a;null==(a=this.C)||a.destroy();this.i.destroy();this.closed.complete();let b;null==(b=this.F)||b.destroy()}UA(){}removeItem(){}Re(a){const b=a.keyCode,c=this.C;switch(b){case 27:yu(a)||(a.preventDefault(),this.closed.emit("keydown"));break;case 37:this.no&&"ltr"===this.direction&&this.closed.emit("keydown");break;case 39:this.no&&"rtl"===this.direction&&this.closed.emit("keydown");break;default:if(38===b||40===b)c.ra="keyboard";Ny(c,a);return}a.stopPropagation()}Hx(a){a=
`${"mat-elevation-z"}${Math.min(8+a,24)}`;var b=Object.keys(this.Oe).find(c=>c.startsWith("mat-elevation-z"));b&&b!==this.D||(b=Object.assign({},this.Oe),this.D&&(b[this.D]=!1),b[a]=!0,this.D=a,this.Oe=b)}Qj(a=this.ri,b=this.Yj){this.Oe=Object.assign({},this.Oe,{["mat-menu-before"]:"before"===a,["mat-menu-after"]:"after"===a,["mat-menu-above"]:"above"===b,["mat-menu-below"]:"below"===b});let c;null==(c=this.Aa)||Zm(c)}R(){this.Hm="enter"}O(){this.Hm="void"}kA(a){this.hg.next(a);this.G=!1}lA(a){this.G=
!0;"enter"===a.le&&0===this.C.N&&(a.element.scrollTop=0)}T(){C(this.kt.i,Fo(this.kt)).subscribe(a=>{this.i.reset(a.filter(b=>b.C===this));Yq(this.i)})}};JC.J=function(a){return new (a||JC)(y(qi),y(Ok),y(GC),y(Pr))};
JC.Ca=Gf({type:JC,ga:[["mat-menu"]],cc:function(a,b,c){a&1&&(qr(c,yC,5),qr(c,CC,5),qr(c,CC,4));if(a&2){let d;sr(d=tr())&&(b.tj=d.first);sr(d=tr())&&(b.kt=d);sr(d=tr())&&(b.items=d)}},eb:function(a,b){a&1&&rr($q,5);if(a&2){let c;sr(c=tr())&&(b.cg=c.first)}},Xa:3,Ha:function(a){a&2&&Ip("aria-label",null)("aria-labelledby",null)("aria-describedby",null)},inputs:{bc:"backdropClass",ariaLabel:[0,"aria-label","ariaLabel"],ad:[0,"aria-labelledby","ariaLabelledby"],Hk:[0,"aria-describedby","ariaDescribedby"],
ri:"xPosition",Yj:"yPosition",mo:[2,"overlapTrigger","overlapTrigger",ws],Sb:[2,"hasBackdrop","hasBackdrop",a=>null==a?null:ws(a)],gb:[0,"class","panelClass"],classList:"classList"},outputs:{closed:"closed",close:"close"},hb:["matMenu"],ja:!0,features:[Hr([{na:zC,zb:JC}]),Hp,Jr],Yb:["*"],ya:1,za:0,Ba:[["tabindex","-1","role","menu",1,"mat-mdc-menu-panel","mat-mdc-elevation-specific",3,"keydown","click","id"],[1,"mat-mdc-menu-content"]],sa:function(a){a&1&&(Vq(),yp(0,DC,3,7,"ng-template"))},styles:['mat-menu{display:none}.mat-mdc-menu-content{margin:0;padding:8px 0;list-style-type:none}.mat-mdc-menu-content:focus{outline:none}.mat-mdc-menu-content,.mat-mdc-menu-content .mat-mdc-menu-item .mat-mdc-menu-item-text{-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;flex:1;white-space:normal;font-family:var(--mat-menu-item-label-text-font);line-height:var(--mat-menu-item-label-text-line-height);font-size:var(--mat-menu-item-label-text-size);letter-spacing:var(--mat-menu-item-label-text-tracking);font-weight:var(--mat-menu-item-label-text-weight)}.mat-mdc-menu-panel{min-width:112px;max-width:280px;overflow:auto;-webkit-overflow-scrolling:touch;box-sizing:border-box;outline:0;border-radius:var(--mat-menu-container-shape);background-color:var(--mat-menu-container-color);will-change:transform,opacity}.mat-mdc-menu-panel.ng-animating{pointer-events:none}.cdk-high-contrast-active .mat-mdc-menu-panel{outline:solid 1px}.mat-divider{color:var(--mat-menu-divider-color);margin-bottom:var(--mat-menu-divider-bottom-spacing);margin-top:var(--mat-menu-divider-top-spacing)}.mat-mdc-menu-item{display:flex;position:relative;align-items:center;justify-content:flex-start;overflow:hidden;padding:0;padding-left:var(--mat-menu-item-leading-spacing);padding-right:var(--mat-menu-item-trailing-spacing);-webkit-user-select:none;user-select:none;cursor:pointer;outline:none;border:none;-webkit-tap-highlight-color:rgba(0,0,0,0);cursor:pointer;width:100%;text-align:left;box-sizing:border-box;color:inherit;font-size:inherit;background:none;text-decoration:none;margin:0;align-items:center;min-height:48px}.mat-mdc-menu-item:focus{outline:none}[dir=rtl] .mat-mdc-menu-item,.mat-mdc-menu-item[dir=rtl]{padding-left:var(--mat-menu-item-trailing-spacing);padding-right:var(--mat-menu-item-leading-spacing)}.mat-mdc-menu-item:has(.material-icons,mat-icon,[matButtonIcon]){padding-left:var(--mat-menu-item-with-icon-leading-spacing);padding-right:var(--mat-menu-item-with-icon-trailing-spacing)}[dir=rtl] .mat-mdc-menu-item:has(.material-icons,mat-icon,[matButtonIcon]),.mat-mdc-menu-item:has(.material-icons,mat-icon,[matButtonIcon])[dir=rtl]{padding-left:var(--mat-menu-item-with-icon-trailing-spacing);padding-right:var(--mat-menu-item-with-icon-leading-spacing)}.mat-mdc-menu-item::-moz-focus-inner{border:0}.mat-mdc-menu-item,.mat-mdc-menu-item:visited,.mat-mdc-menu-item:link{color:var(--mat-menu-item-label-text-color)}.mat-mdc-menu-item .mat-icon-no-color,.mat-mdc-menu-item .mat-mdc-menu-submenu-icon{color:var(--mat-menu-item-icon-color)}.mat-mdc-menu-item[disabled]{cursor:default;opacity:.38}.mat-mdc-menu-item[disabled]::after{display:block;position:absolute;content:"";top:0;left:0;bottom:0;right:0}.mat-mdc-menu-item .mat-icon{flex-shrink:0;margin-right:var(--mat-menu-item-spacing);height:var(--mat-menu-item-icon-size);width:var(--mat-menu-item-icon-size)}[dir=rtl] .mat-mdc-menu-item{text-align:right}[dir=rtl] .mat-mdc-menu-item .mat-icon{margin-right:0;margin-left:var(--mat-menu-item-spacing)}.mat-mdc-menu-item:not([disabled]):hover{background-color:var(--mat-menu-item-hover-state-layer-color)}.mat-mdc-menu-item:not([disabled]).cdk-program-focused,.mat-mdc-menu-item:not([disabled]).cdk-keyboard-focused,.mat-mdc-menu-item:not([disabled]).mat-mdc-menu-item-highlighted{background-color:var(--mat-menu-item-focus-state-layer-color)}.cdk-high-contrast-active .mat-mdc-menu-item{margin-top:1px}.mat-mdc-menu-submenu-icon{width:var(--mat-menu-item-icon-size);height:10px;fill:currentColor;padding-left:var(--mat-menu-item-spacing)}[dir=rtl] .mat-mdc-menu-submenu-icon{padding-right:var(--mat-menu-item-spacing);padding-left:0}[dir=rtl] .mat-mdc-menu-submenu-icon polygon{transform:scaleX(-1)}.cdk-high-contrast-active .mat-mdc-menu-submenu-icon{fill:CanvasText}.mat-mdc-menu-item .mat-mdc-menu-ripple{top:0;left:0;right:0;bottom:0;position:absolute;pointer-events:none}\n'],
ob:2,data:{animation:[wC,xC]},Qa:0});var KC=new df("mat-menu-scroll-strategy",{da:"root",aa:()=>{const a=lf(Wv);return()=>a.i.i()}}),LC={na:KC,zc:[Wv],Ec:function(a){return()=>a.i.i()}};const MC=Ht({passive:!0});function NC(a){return!!(a.F&&a.i&&a.Fd)}function OC(a){let b;null==(b=a.Fd)||b.close.emit()}
function PC(a){const b=a.Fd;if(!a.D&&b){var c=QC(a,b),d=c.xa,e=d.sc;a.fb(b,e);d.Sb=null==b.Sb?!NC(a):b.Sb;c.attach(a.Ia(b));b.tj&&b.tj.attach(a.MC);a.N=a.Ta().subscribe(()=>OC(a));a.Ra(b);b instanceof JC&&(b.R(),C(b.i.i,Jo(b.close)).subscribe(()=>{Fu(zv(e,!1));zv(e,!0)}))}}
function QC(a,b){if(!a.ka){var c=new xu({sc:Bv(xv(zv(Lv(a.ia.position(),a.G))),".mat-menu-panel, .mat-mdc-menu-panel"),bc:b.bc||"cdk-overlay-transparent-backdrop",gb:b.Wh,tc:a.Jc(),direction:a.O});a.kb(b,c.sc);a.ka=a.ia.create(c);a.ka.df().subscribe()}return a.ka}
var RC=class{get vt(){return this.Fd}set vt(a){this.Fd=a}get Fd(){return this.ta}set Fd(a){if(a!==this.ta){this.ta=a;this.T.unsubscribe();a&&(this.T=a.close.subscribe(c=>{this.Da(c);"click"!==c&&"tab"!==c||!this.i||this.i.closed.emit(c)}));var b;null==(b=this.F)||b.G(NC(this))}}constructor(a,b,c,d,e,f,g,k,m){this.ia=a;this.G=b;this.va=c;this.F=f;this.O=g;this.ea=k;this.pa=m;this.ka=null;this.D=!1;this.T=this.ra=this.N=Li.EMPTY;this.Aa=lf(Pr);this.ma=p=>{yx(p)||(this.C="touch")};this.C=void 0;this.Ng=
!0;this.gD=this.pr=new Dk;this.fD=this.mr=new Dk;this.Jc=d;this.i=e instanceof JC?e:void 0;b.P.addEventListener("touchstart",this.ma,MC)}yj(){this.Oa()}ua(){this.ka&&(this.ka.dispose(),this.ka=null);this.G.P.removeEventListener("touchstart",this.ma,MC);this.T.unsubscribe();this.N.unsubscribe();this.ra.unsubscribe()}get nr(){return this.D}get dir(){return this.O&&"rtl"===this.O.value?"rtl":"ltr"}focus(a,b){this.ea&&a?Hx(this.ea,this.G,a,b):this.G.P.focus(b)}Uc(){let a;null==(a=this.ka)||a.Uc()}Da(a){if(this.ka&&
this.nr){var b=this.Fd;this.N.unsubscribe();this.ka.detach();!this.Ng||"keydown"!==a&&this.C&&NC(this)||this.focus(this.C);this.C=void 0;if(b instanceof JC)b.O(),b.tj?C(b.hg,rk(c=>"void"===c.le),co(),Jo(b.tj.i)).subscribe({next:()=>b.tj.detach(),complete:()=>this.K(!1)}):this.K(!1);else{this.K(!1);let c;null==b||null==(c=b.tj)||c.detach()}}}Ra(a){a.no=NC(this)?this.i:void 0;a.direction=this.dir;this.ab(a);IC(a,this.C||"program");this.K(!0)}ab(a){if(a.Hx){let b=0,c=a.no;for(;c;)b++,c=c.no;a.Hx(b)}}K(a){a!==
this.D&&((this.D=a)?this.pr.emit():this.mr.emit(),NC(this)&&this.F.F(a),Zm(this.Aa))}kb(a,b){a.Qj&&b.fb.subscribe(c=>{const d="start"===c.i.La?"after":"before",e="top"===c.i.Sa?"below":"above";this.pa?this.pa.run(()=>a.Qj(d,e)):a.Qj(d,e)})}fb(a,b){let [c,d]="before"===a.ri?["end","start"]:["start","end"],e=c,f=d,[g,k]="above"===a.Yj?["bottom","top"]:["top","bottom"],[m,p]=[g,k],t=m,v=p,[B,G]=[e,f],K=B,N=G,aa=0;NC(this)?(N=e="before"===a.ri?"start":"end",f=K="end"===e?"start":"end",this.i&&(null==
this.ba&&(this.ba=(a=this.i.items.first)?a.pe().offsetTop:0),aa="bottom"===g?this.ba:-this.ba)):a.mo||(t="top"===g?"bottom":"top",v="top"===k?"bottom":"top");Hu(b,[{bb:e,cb:t,La:K,Sa:g,offsetY:aa},{bb:f,cb:t,La:N,Sa:g,offsetY:aa},{bb:e,cb:v,La:K,Sa:k,offsetY:-aa},{bb:f,cb:v,La:N,Sa:k,offsetY:-aa}])}Ta(){const a=this.ka.bd(),b=this.ka.G,c=this.i?this.i.closed:hj(),d=this.i?C(HC(this.i),rk(e=>e!==this.F),rk(()=>this.D)):hj();return pk(a,c,d,b)}bA(a){xx(a)||(this.C=0===a.button?"mouse":void 0,NC(this)&&
a.preventDefault())}Re(a){a=a.keyCode;if(13===a||32===a)this.C="keyboard";NC(this)&&(39===a&&"ltr"===this.dir||37===a&&"rtl"===this.dir)&&(this.C="keyboard",PC(this))}pk(a){NC(this)?(a.stopPropagation(),PC(this)):this.D?OC(this):PC(this)}Oa(){NC(this)&&this.i&&(this.ra=C(HC(this.i),rk(a=>a===this.F&&!a.disabled),Vn(Bk)).subscribe(()=>{this.C="mouse";this.Fd instanceof JC&&this.Fd.G?C(this.Fd.hg,co(),Vn(Bk),Jo(HC(this.i))).subscribe(()=>PC(this)):PC(this)}))}Ia(a){this.R&&this.R.cg===a.cg||(this.R=
new Pv(a.cg,this.va));return this.R}};RC.J=function(a){return new (a||RC)(y(Wv),y(qi),y(ip),y(KC),y(zC,8),y(CC,10),y(lu,8),y(Ix),y(Ok))};
RC.Ea=Of({type:RC,ga:[["","mat-menu-trigger-for",""],["","matMenuTriggerFor",""]],Ja:[1,"mat-mdc-menu-trigger"],Xa:3,Ha:function(a,b){a&1&&V("click",function(c){return b.pk(c)})("mousedown",function(c){return b.bA(c)})("keydown",function(c){return b.Re(c)});a&2&&Ip("aria-haspopup",b.Fd?"menu":null)("aria-expanded",b.nr)("aria-controls",b.nr?b.Fd.Ww:null)},inputs:{vt:[0,"mat-menu-trigger-for","_deprecatedMatMenuTriggerFor"],Fd:[0,"matMenuTriggerFor","menu"],MC:[0,"matMenuTriggerData","menuData"],Ng:[0,
"matMenuTriggerRestoreFocus","restoreFocus"]},outputs:{pr:"menuOpened",gD:"onMenuOpen",mr:"menuClosed",fD:"onMenuClose"},hb:["matMenuTrigger"],ja:!0});var SC=class{};SC.J=function(a){return new (a||SC)};SC.Wa=Mf({type:SC});SC.Va=Md({Ua:[LC],imports:[et,Rz,fz,dw,uu,fz]});var TC=class{};TC.J=function(a){return new (a||TC)};TC.Wa=Mf({type:TC});TC.Va=Md({Ua:[{na:Wv,Dc:fw}],imports:[SC]});var UC={AED:[2,"dh","\u062f.\u0625."],ALL:[0,"Lek","Lek"],AUD:[2,"$","AU$"],BDT:[2,"\u09f3","Tk"],BGN:[2,"lev","lev"],BRL:[2,"R$","R$"],CAD:[2,"$","C$"],CDF:[2,"FrCD","CDF"],CHF:[2,"CHF","CHF"],CLP:[0,"$","CL$"],CNY:[2,"\u00a5","RMB\u00a5"],COP:[32,"$","COL$"],CRC:[0,"\u20a1","CR\u20a1"],CZK:[50,"K\u010d","K\u010d"],DKK:[50,"kr.","kr."],DOP:[2,"RD$","RD$"],EGP:[2,"\u00a3","LE"],ETB:[2,"Birr","Birr"],EUR:[2,"\u20ac","\u20ac"],GBP:[2,"\u00a3","GB\u00a3"],HKD:[2,"$","HK$"],HRK:[2,"kn","kn"],HUF:[34,
"Ft","Ft"],IDR:[0,"Rp","Rp"],ILS:[34,"\u20aa","IL\u20aa"],INR:[2,"\u20b9","Rs"],IRR:[0,"Rial","IRR"],ISK:[0,"kr","kr"],JMD:[2,"$","JA$"],JPY:[0,"\u00a5","JP\u00a5"],KRW:[0,"\u20a9","KR\u20a9"],LKR:[2,"Rs","SLRs"],LTL:[2,"Lt","Lt"],MNT:[0,"\u20ae","MN\u20ae"],MVR:[2,"Rf","MVR"],MXN:[2,"$","Mex$"],MYR:[2,"RM","RM"],NOK:[50,"kr","NOkr"],PAB:[2,"B/.","B/."],PEN:[2,"S/.","S/."],PHP:[2,"\u20b1","PHP"],PKR:[0,"Rs","PKRs."],PLN:[50,"z\u0142","z\u0142"],RON:[2,"RON","RON"],RSD:[0,"din","RSD"],RUB:[50,"\u20bd",
"RUB"],SAR:[2,"SAR","SAR"],SEK:[50,"kr","kr"],SGD:[2,"$","S$"],THB:[2,"\u0e3f","THB"],TRY:[2,"\u20ba","TRY"],TWD:[2,"$","NT$"],TZS:[0,"TSh","TSh"],UAH:[2,"\u0433\u0440\u043d.","UAH"],USD:[2,"$","US$"],UYU:[2,"$","$U"],VND:[48,"\u20ab","VN\u20ab"],YER:[0,"Rial","Rial"],ZAR:[2,"R","ZAR"]};var VC={Vs:".",Oo:",",bt:"%",Xo:"0",pz:"+",Zs:"-",Xs:"E",ct:"\u2030",Qo:"\u221e",kz:"NaN",YE:"#,##0.###",hF:"#E0",oz:"#,##0%",XE:"\u00a4#,##0.00",Ws:"USD"},WC=VC;WC=VC;function XC(){this.T=40;this.C=1;this.D=3;this.ea=this.F=0;this.ra=!1;this.ba=this.O="";this.G=WC.Zs;this.R="";this.i=1;this.N=!1;this.K=[];this.ia=this.ma=!1;var a=WC.oz;const b=[0];this.O=YC(this,a,b);var c=b[0];let d=-1,e=0;var f=0,g=0;let k=-1;const m=a.length;for(let p=!0;b[0]<m&&p;b[0]++)switch(a.charAt(b[0])){case "#":0<f?g++:e++;0<=k&&0>d&&k++;break;case "0":if(0<g)throw Error('Unexpected "0" in pattern "'+a+'"');f++;0<=k&&0>d&&k++;break;case ",":0<k&&this.K.push(k);k=0;break;case ".":if(0<=
d)throw Error('Multiple decimal separators in pattern "'+a+'"');d=e+f+g;break;case "E":if(this.ia)throw Error('Multiple exponential symbols in pattern "'+a+'"');this.ia=!0;this.ea=0;b[0]+1<m&&"+"==a.charAt(b[0]+1)&&(b[0]++,this.ra=!0);for(;b[0]+1<m&&"0"==a.charAt(b[0]+1);)b[0]++,this.ea++;if(1>e+f||1>this.ea)throw Error('Malformed exponential pattern "'+a+'"');p=!1;break;default:b[0]--,p=!1}0==f&&0<e&&0<=d&&(f=d,0==f&&f++,g=e-f,e=f-1,f=1);if(0>d&&0<g||0<=d&&(d<e||d>e+f)||0==k)throw Error('Malformed pattern "'+
a+'"');g=e+f+g;this.D=0<=d?g-d:0;0<=d&&(this.F=e+f-d,0>this.F&&(this.F=0));this.C=(0<=d?d:g)-e;this.ia&&(this.T=e+this.C,0==this.D&&0==this.C&&(this.C=1));this.K.push(Math.max(0,k));this.ma=0==d||d==g;c=b[0]-c;this.ba=YC(this,a,b);b[0]<a.length&&";"==a.charAt(b[0])?(b[0]++,1!=this.i&&(this.N=!0),this.G=YC(this,a,b),b[0]+=c,this.R=YC(this,a,b)):(this.G+=this.O,this.R+=this.ba)}
XC.prototype.parse=function(a,b){b=b||[0];a=a.replace(/ |\u202f/g,"\u00a0");let c=a.indexOf(this.O,b[0])==b[0],d=a.indexOf(this.G,b[0])==b[0];c&&d&&(this.O.length>this.G.length?d=!1:this.O.length<this.G.length&&(c=!1));c?b[0]+=this.O.length:d&&(b[0]+=this.G.length);if(a.indexOf(WC.Qo,b[0])==b[0]){b[0]+=WC.Qo.length;var e=Infinity}else{e=a;let f=!1,g=!1,k=!1,m=-1,p=1;const t=WC.Vs;let v=WC.Oo;const B=WC.Xs;v=v.replace(/\u202f/g,"\u00a0");let G="";for(;b[0]<e.length;b[0]++){const K=e.charAt(b[0]),N=
ZC(K);if(0<=N&&9>=N)G+=N,k=!0;else if(K==t.charAt(0)){if(f||g)break;G+=".";f=!0}else if(K==v.charAt(0)&&("\u00a0"!=v.charAt(0)||b[0]+1<e.length&&0<=ZC(e.charAt(b[0]+1)))){if(f||g)break}else if(K==B.charAt(0)){if(g)break;G+="E";g=!0;m=b[0]}else if("+"==K||"-"==K){if(k&&m!=b[0]-1)break;G+=K}else if(1==this.i&&K==WC.bt.charAt(0)){if(1!=p)break;p=100;if(k){b[0]++;break}}else if(1==this.i&&K==WC.ct.charAt(0)){if(1!=p)break;p=1E3;if(k){b[0]++;break}}else break}1!=this.i&&(p=this.i);e=parseFloat(G)/p}if(c){if(a.indexOf(this.ba,
b[0])!=b[0])return NaN;b[0]+=this.ba.length}else if(d){if(a.indexOf(this.R,b[0])!=b[0])return NaN;b[0]+=this.R.length}return d?-e:e};
XC.prototype.format=function(a){if(this.F>this.D)throw Error("Min value must be less than max value");if(isNaN(a))return WC.kz;const b=[];var c=$C;a=aD(a,-c.DB);const d=0>a||0==a&&0>1/a;d?c.Iw?b.push(c.Iw):(b.push(c.prefix),b.push(this.G)):(b.push(c.prefix),b.push(this.O));if(isFinite(a))if(a*=d?-1:1,a*=this.i,this.ia){var e=a;if(0==e)bD(this,e,this.C,b),cD(this,0,b);else{var f=Math.floor(Math.log(e)/Math.log(10)+2E-15);e=aD(e,-f);var g=this.C;1<this.T&&this.T>this.C?(g=f%this.T,0>g&&(g=this.T+g),
e=aD(e,g),f-=g,g=1):1>this.C?(f++,e=aD(e,-1)):(f-=this.C-1,e=aD(e,this.C-1));bD(this,e,g,b);cD(this,f,b)}}else bD(this,a,this.C,b);else b.push(WC.Qo);d?c.Jw?b.push(c.Jw):(isFinite(a)&&b.push(c.iy),b.push(this.R)):(isFinite(a)&&b.push(c.iy),b.push(this.ba));return b.join("")};
function bD(a,b,c,d){if(a.F>a.D)throw Error("Min value must be less than max value");d||(d=[]);var e=aD(b,a.D);e=Math.round(e);isFinite(e)?(b=Math.floor(aD(e,-a.D)),e=Math.floor(e-aD(b,a.D))):e=0;var f=b,g=e,k=0<a.F||0<g||!1;e=a.F;k&&(e=a.F);var m="";for(b=f;1E20<b;)m="0"+m,b=Math.round(aD(b,-1));m=b+m;var p=WC.Vs;b=WC.Xo.codePointAt(0);var t=m.length,v=0;if(0<f||0<c){for(f=t;f<c;f++)d.push(String.fromCodePoint(b));if(2<=a.K.length)for(c=1;c<a.K.length;c++)v+=a.K[c];c=t-v;if(0<c){f=a.K;v=t=0;var B=
WC.Oo,G=m.length;for(let N=0;N<G;N++)if(d.push(String.fromCodePoint(b+Number(m.charAt(N)))),1<G-N){var K=f[v];if(N<c){let aa=c-N;(1===K||0<K&&1===aa%K)&&d.push(B)}else v<f.length&&(N===c?v+=1:K===N-c-t+1&&(d.push(B),t+=K,v+=1))}}else{c=m;m=a.K;f=WC.Oo;K=c.length;B=[];for(t=m.length-1;0<=t&&0<K;t--){v=m[t];for(G=0;G<v&&0<=K-G-1;G++)B.push(String.fromCodePoint(b+Number(c.charAt(K-G-1))));K-=v;0<K&&B.push(f)}d.push.apply(d,B.reverse())}}else k||d.push(String.fromCodePoint(b));(a.ma||k)&&d.push(p);k=
String(g);g=k.split("e+");if(2==g.length){if(k=parseFloat(g[0])){p=k;if(isFinite(p)){for(c=0;1<=(p/=10);)c++;p=c}else p=0<p?p:0;p=-p-1;k=-1>p?k&&isFinite(k)?aD(Math.round(aD(k,-1)),1):k:k&&isFinite(k)?aD(Math.round(aD(k,p)),-p):k}k=String(k);k=k.replace(".","");k+=wd("0",parseInt(g[1],10)-k.length+1)}a.D+1>k.length&&(k="1"+wd("0",a.D-k.length)+k);for(a=k.length;"0"==k.charAt(a-1)&&a>e+1;)a--;for(e=1;e<a;e++)d.push(String.fromCodePoint(b+Number(k.charAt(e))))}
function cD(a,b,c){c.push(WC.Xs);0>b?(b=-b,c.push(WC.Zs)):a.ra&&c.push(WC.pz);b=""+b;var d=WC.Xo;for(let e=b.length;e<a.ea;e++)c.push(d);a=d.codePointAt(0)-dD;for(d=0;d<b.length;d++)c.push(String.fromCodePoint(a+b.codePointAt(d)))}function ZC(a){a=a.codePointAt(0);if(48<=a&&58>a)return a-48;const b=WC.Xo.codePointAt(0);return b<=a&&a<b+10?a-b:-1}var dD="0".codePointAt(0);
function YC(a,b,c){let d="",e=!1;const f=b.length;for(;c[0]<f;c[0]++){var g=b.charAt(c[0]);if("'"==g)c[0]+1<f&&"'"==b.charAt(c[0]+1)?(c[0]++,d+="'"):e=!e;else if(e)d+=g;else switch(g){case "#":case "0":case ",":case ".":case ";":return d;case "\u00a4":c[0]+1<f&&"\u00a4"==b.charAt(c[0]+1)?(c[0]++,d+=WC.Ws):(g=WC.Ws,d+=g in UC?UC[g][1]:g);break;case "%":if(!a.N&&1!=a.i)throw Error("Too many percent/permill");if(a.N&&100!=a.i)throw Error("Inconsistent use of percent/permill characters");a.i=100;a.N=
!1;d+=WC.bt;break;case "\u2030":if(!a.N&&1!=a.i)throw Error("Too many percent/permill");if(a.N&&1E3!=a.i)throw Error("Inconsistent use of percent/permill characters");a.i=1E3;a.N=!1;d+=WC.ct;break;default:d+=g}}return d}var $C={DB:0,Iw:"",Jw:"",prefix:"",iy:""};function aD(a,b){if(!a||!isFinite(a)||0==b)return a;a=String(a).split("e");return parseFloat(a[0]+"e"+(parseInt(a[1]||0,10)+b))};var eD=new XC;function fD(a){const b={attributeFilter:["aria-label","aria-valuenow"]};return new Vi(c=>{(new MutationObserver(d=>{const e=d[0].target;var f;d=null!=(f=e.getAttribute("aria-label"))?f:"";let g;f=null!=(g=e.getAttribute("aria-valuenow"))?g:"indeterminate";c.next([d,f])})).observe(a,b)})};var gD=new df("GMAT_PROGRESS_SPINNER_OPTIONS",{da:"root",aa:()=>({qc:!1})});const hD=["determinateSpinner"];function iD(a){a&1&&(eh(),R(0,"svg",11),Kq(1,"circle",12),S());a&2&&(a=Y(),Ip("viewBox",a.zu()),D(),jq("stroke-dasharray",a.Mm(),"px")("stroke-dashoffset",a.Mm()/2,"px")("stroke-width",a.qt(),"%"),Ip("r",a.sm()))}var kD=new df("mat-progress-spinner-default-options",{da:"root",aa:jD});function jD(){return{diameter:100}}
var lD=class{get color(){return this.mh||this.i}set color(a){this.mh=a}constructor(a,b,c){this.qa=a;this.i="primary";this.kd=0;this.C=100;this.Dp="NoopAnimations"===b&&!!c&&!c.qF;this.mode="mat-spinner"===a.P.nodeName.toLowerCase()?"indeterminate":"determinate";c&&(c.color&&(this.color=this.i=c.color),c.diameter&&(this.diameter=c.diameter),c.strokeWidth&&(this.strokeWidth=c.strokeWidth))}get value(){return"determinate"===this.mode?this.kd:0}set value(a){this.kd=Math.max(0,Math.min(100,a||0))}get diameter(){return this.C}set diameter(a){this.C=
a||0}get strokeWidth(){let a;return null!=(a=this.D)?a:this.diameter/10}set strokeWidth(a){this.D=a||0}sm(){return(this.diameter-10)/2}zu(){const a=2*this.sm()+this.strokeWidth;return`0 0 ${a} ${a}`}Mm(){return 2*Math.PI*this.sm()}JA(){return"determinate"===this.mode?this.Mm()*(100-this.kd)/100:null}qt(){return this.strokeWidth/this.diameter*100}};lD.J=function(a){return new (a||lD)(y(qi),y(ki,8),y(kD))};
lD.Ca=Gf({type:lD,ga:[["mat-progress-spinner"],["mat-spinner"]],eb:function(a,b){a&1&&rr(hD,5);if(a&2){let c;sr(c=tr())&&(b.oF=c.first)}},Ja:["role","progressbar","tabindex","-1",1,"mat-mdc-progress-spinner","mdc-circular-progress"],Xa:18,Ha:function(a,b){a&2&&(Ip("aria-valuemin",0)("aria-valuemax",100)("aria-valuenow","determinate"===b.mode?b.value:null)("mode",b.mode),oq(rq,"mat-"+b.color),jq("width",b.diameter,"px")("height",b.diameter,"px")("--mdc-circular-progress-size",b.diameter+"px")("--mdc-circular-progress-active-indicator-width",
b.diameter+"px"),lq("_mat-animation-noopable",b.Dp)("mdc-circular-progress--indeterminate","indeterminate"===b.mode))},inputs:{color:"color",mode:"mode",value:[2,"value","value",xs],diameter:[2,"diameter","diameter",xs],strokeWidth:[2,"strokeWidth","strokeWidth",xs]},hb:["matProgressSpinner"],ja:!0,features:[Hp,Jr],ya:14,za:11,Ba:[["circle",""],["determinateSpinner",""],["aria-hidden","true",1,"mdc-circular-progress__determinate-container"],["xmlns","http://www.w3.org/2000/svg","focusable","false",
1,"mdc-circular-progress__determinate-circle-graphic"],["cx","50%","cy","50%",1,"mdc-circular-progress__determinate-circle"],["aria-hidden","true",1,"mdc-circular-progress__indeterminate-container"],[1,"mdc-circular-progress__spinner-layer"],[1,"mdc-circular-progress__circle-clipper","mdc-circular-progress__circle-left"],[3,"ngTemplateOutlet"],[1,"mdc-circular-progress__gap-patch"],[1,"mdc-circular-progress__circle-clipper","mdc-circular-progress__circle-right"],["xmlns","http://www.w3.org/2000/svg",
"focusable","false",1,"mdc-circular-progress__indeterminate-circle-graphic"],["cx","50%","cy","50%"]],sa:function(a,b){a&1&&(yp(0,iD,2,8,"ng-template",null,0,Nr),R(2,"div",2,1),eh(),R(4,"svg",3),Kq(5,"circle",4),S()(),Qg.Vk=null,R(6,"div",5)(7,"div",6)(8,"div",7),Nq(9,8),S(),R(10,"div",9),Nq(11,8),S(),R(12,"div",10),Nq(13,8),S()()());a&2&&(a=wr(1),D(4),Ip("viewBox",b.zu()),D(),jq("stroke-dasharray",b.Mm(),"px")("stroke-dashoffset",b.JA(),"px")("stroke-width",b.qt(),"%"),Ip("r",b.sm()),D(4),H("ngTemplateOutlet",
a),D(2),H("ngTemplateOutlet",a),D(2),H("ngTemplateOutlet",a))},Ga:[dt],styles:["@keyframes mdc-circular-progress-container-rotate{to{transform:rotate(360deg)}}@keyframes mdc-circular-progress-spinner-layer-rotate{12.5%{transform:rotate(135deg)}25%{transform:rotate(270deg)}37.5%{transform:rotate(405deg)}50%{transform:rotate(540deg)}62.5%{transform:rotate(675deg)}75%{transform:rotate(810deg)}87.5%{transform:rotate(945deg)}100%{transform:rotate(1080deg)}}@keyframes mdc-circular-progress-color-1-fade-in-out{from{opacity:.99}25%{opacity:.99}26%{opacity:0}89%{opacity:0}90%{opacity:.99}to{opacity:.99}}@keyframes mdc-circular-progress-color-2-fade-in-out{from{opacity:0}15%{opacity:0}25%{opacity:.99}50%{opacity:.99}51%{opacity:0}to{opacity:0}}@keyframes mdc-circular-progress-color-3-fade-in-out{from{opacity:0}40%{opacity:0}50%{opacity:.99}75%{opacity:.99}76%{opacity:0}to{opacity:0}}@keyframes mdc-circular-progress-color-4-fade-in-out{from{opacity:0}65%{opacity:0}75%{opacity:.99}90%{opacity:.99}to{opacity:0}}@keyframes mdc-circular-progress-left-spin{from{transform:rotate(265deg)}50%{transform:rotate(130deg)}to{transform:rotate(265deg)}}@keyframes mdc-circular-progress-right-spin{from{transform:rotate(-265deg)}50%{transform:rotate(-130deg)}to{transform:rotate(-265deg)}}.mdc-circular-progress{display:inline-flex;position:relative;direction:ltr;line-height:0;transition:opacity 250ms 0ms cubic-bezier(0.4, 0, 0.6, 1)}.mdc-circular-progress__determinate-container,.mdc-circular-progress__indeterminate-circle-graphic,.mdc-circular-progress__indeterminate-container,.mdc-circular-progress__spinner-layer{position:absolute;width:100%;height:100%}.mdc-circular-progress__determinate-container{transform:rotate(-90deg)}.mdc-circular-progress__indeterminate-container{font-size:0;letter-spacing:0;white-space:nowrap;opacity:0}.mdc-circular-progress__determinate-circle-graphic,.mdc-circular-progress__indeterminate-circle-graphic{fill:rgba(0,0,0,0)}.mdc-circular-progress__determinate-circle{transition:stroke-dashoffset 500ms 0ms cubic-bezier(0, 0, 0.2, 1)}.mdc-circular-progress__gap-patch{position:absolute;top:0;left:47.5%;box-sizing:border-box;width:5%;height:100%;overflow:hidden}.mdc-circular-progress__gap-patch .mdc-circular-progress__indeterminate-circle-graphic{left:-900%;width:2000%;transform:rotate(180deg)}.mdc-circular-progress__circle-clipper{display:inline-flex;position:relative;width:50%;height:100%;overflow:hidden}.mdc-circular-progress__circle-clipper .mdc-circular-progress__indeterminate-circle-graphic{width:200%}.mdc-circular-progress__circle-right .mdc-circular-progress__indeterminate-circle-graphic{left:-100%}.mdc-circular-progress--indeterminate .mdc-circular-progress__determinate-container{opacity:0}.mdc-circular-progress--indeterminate .mdc-circular-progress__indeterminate-container{opacity:1}.mdc-circular-progress--indeterminate .mdc-circular-progress__indeterminate-container{animation:mdc-circular-progress-container-rotate 1568.2352941176ms linear infinite}.mdc-circular-progress--indeterminate .mdc-circular-progress__spinner-layer{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__color-1{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both,mdc-circular-progress-color-1-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__color-2{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both,mdc-circular-progress-color-2-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__color-3{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both,mdc-circular-progress-color-3-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__color-4{animation:mdc-circular-progress-spinner-layer-rotate 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both,mdc-circular-progress-color-4-fade-in-out 5332ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__circle-left .mdc-circular-progress__indeterminate-circle-graphic{animation:mdc-circular-progress-left-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--indeterminate .mdc-circular-progress__circle-right .mdc-circular-progress__indeterminate-circle-graphic{animation:mdc-circular-progress-right-spin 1333ms cubic-bezier(0.4, 0, 0.2, 1) infinite both}.mdc-circular-progress--closed{opacity:0}.mat-mdc-progress-spinner .mdc-circular-progress__determinate-circle,.mat-mdc-progress-spinner .mdc-circular-progress__indeterminate-circle-graphic{stroke:var(--mdc-circular-progress-active-indicator-color)}@media screen and (forced-colors: active),(-ms-high-contrast: active){.mat-mdc-progress-spinner .mdc-circular-progress__determinate-circle,.mat-mdc-progress-spinner .mdc-circular-progress__indeterminate-circle-graphic{stroke:CanvasText}}.mat-mdc-progress-spinner circle{stroke-width:var(--mdc-circular-progress-active-indicator-width)}@media screen and (forced-colors: active),(-ms-high-contrast: active){.mat-mdc-progress-spinner .mdc-circular-progress--four-color .mdc-circular-progress__color-1 .mdc-circular-progress__indeterminate-circle-graphic{stroke:CanvasText}}@media screen and (forced-colors: active),(-ms-high-contrast: active){.mat-mdc-progress-spinner .mdc-circular-progress--four-color .mdc-circular-progress__color-2 .mdc-circular-progress__indeterminate-circle-graphic{stroke:CanvasText}}@media screen and (forced-colors: active),(-ms-high-contrast: active){.mat-mdc-progress-spinner .mdc-circular-progress--four-color .mdc-circular-progress__color-3 .mdc-circular-progress__indeterminate-circle-graphic{stroke:CanvasText}}@media screen and (forced-colors: active),(-ms-high-contrast: active){.mat-mdc-progress-spinner .mdc-circular-progress--four-color .mdc-circular-progress__color-4 .mdc-circular-progress__indeterminate-circle-graphic{stroke:CanvasText}}.mat-mdc-progress-spinner .mdc-circular-progress{width:var(--mdc-circular-progress-size) !important;height:var(--mdc-circular-progress-size) !important}.mat-mdc-progress-spinner{display:block;overflow:hidden;line-height:0}.mat-mdc-progress-spinner._mat-animation-noopable,.mat-mdc-progress-spinner._mat-animation-noopable .mdc-circular-progress__determinate-circle{transition:none}.mat-mdc-progress-spinner._mat-animation-noopable .mdc-circular-progress__indeterminate-circle-graphic,.mat-mdc-progress-spinner._mat-animation-noopable .mdc-circular-progress__spinner-layer,.mat-mdc-progress-spinner._mat-animation-noopable .mdc-circular-progress__indeterminate-container{animation:none}.mat-mdc-progress-spinner._mat-animation-noopable .mdc-circular-progress__indeterminate-container circle{stroke-dasharray:0 !important}.cdk-high-contrast-active .mat-mdc-progress-spinner .mdc-circular-progress__indeterminate-circle-graphic,.cdk-high-contrast-active .mat-mdc-progress-spinner .mdc-circular-progress__determinate-circle{stroke:currentColor;stroke:CanvasText}\n"],
ob:2,Qa:0});var mD=class{};mD.J=function(a){return new (a||mD)};mD.Wa=Mf({type:mD});mD.Va=Md({imports:[et,fz]});function nD(a,b,c){b="indeterminate"===c?b:b+" "+eD.format(Number(c)/100);a.C.textContent=b}
var oD=class{constructor(a,b){this.options=a;this.D=b;this.i=new aj;this.C=document.createElement("label");this.C.classList.add("cdk-visually-hidden");this.C.classList.add("gmat-mdc-progress-spinner-accessible-label");C(fD(b.qa.P),Jo(this.i)).subscribe(c=>{nD(this,c[0],c[1])})}Eb(){this.D.qa.P.insertAdjacentElement("afterend",this.C);const a=this.D.qa.P.getAttribute("aria-label");nD(this,null!=a?a:"","indeterminate"===this.D.mode?"indeterminate":this.D.value.toString())}ua(){this.C.remove();this.i.next();
this.i.complete()}};oD.J=function(a){return new (a||oD)(y(gD),y(lD,10))};oD.Ea=Of({type:oD,ga:[["mat-progress-spinner"],["mat-spinner"]],Ja:["aria-hidden","true"],Xa:3,Ha:function(a,b){a&2&&(Ip("tabindex",null),lq("gmat-mdc-progress-spinner",!b.options.qc))}});var pD=class{};pD.J=function(a){return new (a||pD)};pD.Wa=Mf({type:pD});pD.Va=Md({imports:[mD]});var qD=new df("GMAT_SELECT_OPTIONS",{da:"root",aa:()=>({qc:!1})});var rD=Ry("transformPanel",[Uy("void",Ty({opacity:0,transform:"scale(1, 0.8)"})),Vy("void => showing",Sy("120ms cubic-bezier(0, 0, 0.2, 1)",Ty({opacity:1,transform:"scale(1, 1)"}))),Vy("* => void",Sy("100ms linear",Ty({opacity:0})))]);const sD=["trigger"],tD=["panel"],uD=[[["mat-select-trigger"]],"*"];function vD(a){a&1&&(R(0,"span",4),Z(1),S());a&2&&(a=Y(),D(),xr(a.placeholder))}function wD(a){a&1&&Wq(0)}function xD(a){a&1&&(R(0,"span",11),Z(1),S());a&2&&(a=Y(2),D(),xr(a.IE))}function yD(a){a&1&&(R(0,"span",5),yp(1,wD,1,0)(2,xD,2,1,"span",11),S());a&2&&(a=Y(),D(),Cq(a.sB?1:2))}
function zD(a){if(a&1){const b=Tg();R(0,"div",12,1);V("@transformPanel.done",function(c){u(b);const d=Y();return x(d.fu.next(c.le))})("keydown",function(c){u(b);const d=Y();return x(d.Re(c))});Wq(2,1);S()}a&2&&(a=Y(),tq(a.Vz()),H("ngClass",a.gb)("@transformPanel","showing"),Ip("id",a.id+"-panel")("aria-multiselectable",a.multiple)("aria-label",a.ariaLabel||null)("aria-labelledby",a.qp()))}let AD=0;
var BD=new df("mat-select-scroll-strategy",{da:"root",aa:()=>{const a=lf(Wv);return()=>a.i.i()}}),CD=new df("MAT_SELECT_CONFIG"),DD={na:BD,zc:[Wv],Ec:function(a){return()=>a.i.i()}},ED=new df("MatSelectTrigger"),FD=class{constructor(a,b){this.source=a;this.value=b}};function UA(a,b){b.length?a.qa.P.setAttribute("aria-describedby",b.join(" ")):a.qa.P.removeAttribute("aria-describedby")}function GD(a){return a.ia?"rtl"===a.ia.value:!1}
var HD=class{Oa(a){var b=this.options.toArray()[a];if(b){const c=this.Wf.P,d=Pz(a,this.options,this.Hr);b=b.pe();c.scrollTop=0===a&&1===d?0:Qz(b.offsetTop,b.offsetHeight,c.scrollTop,c.offsetHeight)}}jd(){this.Oa(this.i.N||0)}uc(a){return new FD(this,a)}get focused(){return this.Pe||this.D}get ze(){return this.ma}set ze(a){this.ma=a;if(this.options)for(const b of this.options)Zm(b.Aa)}get placeholder(){return this.Jb}set placeholder(a){this.Jb=a;this.Rc.next()}get required(){var a;let b;null==(a=this.qd)&&
(null==(a=this.Hd)?a=void 0:null==(a=a.control)?a=void 0:(a=a.Ve,a=Array.isArray(a)?a.includes(rw):a===rw));return null!=(b=a)?b:!1}set required(a){this.qd=a;this.Rc.next()}get multiple(){return this.F}set multiple(a){this.F=a}get Pk(){return this.T}set Pk(a){this.T=a;this.C&&this.va()}get value(){return this.kd}set value(a){this.ra(a)&&this.ea(a)}get Nv(){return this.R.lr}set Nv(a){this.R.lr=a}get id(){return this.Wb}set id(a){this.Wb=a||this.sd;this.Rc.next()}get we(){return this.R.we}set we(a){this.R.we=
a}constructor(a,b,c,d,e,f,g,k,m,p,t,v,B,G){this.Nb=a;this.Aa=b;this.qa=e;this.ia=f;this.O=m;this.Hd=p;this.rb=B;this.K=G;this.yA=[{bb:"start",cb:"bottom",La:"start",Sa:"top"},{bb:"end",cb:"bottom",La:"end",Sa:"top"},{bb:"start",cb:"top",La:"start",Sa:"bottom",gb:"mat-mdc-select-panel-above"},{bb:"end",cb:"top",La:"end",Sa:"bottom",gb:"mat-mdc-select-panel-above"}];this.D=!1;this.T=(O,U)=>O===U;this.sd=`mat-select-${AD++}`;this.fb=null;this.G=new aj;this.Rc=new aj;this.yB=!0;this.ea=()=>{};this.Yd=
()=>{};this.yu=`mat-select-value-${AD++}`;this.fu=new aj;let K;this.wA=(null==(K=this.K)?void 0:K.Wh)||"";this.Pe=!1;this.jv="mat-select";this.Lc=this.disabled=!1;this.tabIndex=0;let N,aa;this.ma=null!=(aa=null==(N=this.K)?void 0:N.ze)?aa:!1;this.F=!1;let ca,ia;this.Iv=null!=(ia=null==(ca=this.K)?void 0:ca.Iv)?ia:!1;this.ariaLabel="";this.Gg=this.K&&"undefined"!==typeof this.K.Gg?this.K.Gg:"auto";this.ba=new aj;this.kb=gk(()=>{const O=this.options;return O?C(O.i,Fo(O),Go(()=>pk(...O.map(U=>U.io)))):
C(this.ba,Go(()=>this.kb))});this.lo=new Dk;this.tA=C(this.lo,rk(O=>O),vj(()=>{}));this.Fz=C(this.lo,rk(O=>!O),vj(()=>{}));this.Gx=new Dk;this.Ay=new Dk;this.N=null;this.Mb=O=>this.pb?!1:O.disabled;this.Hd&&(this.Hd.i=this);null!=(null==G?void 0:G.im)&&(this.im=G.im);this.R=new gz(d,p,k,g,this.Rc);this.Kb=v;this.Jc=this.Kb();this.tabIndex=parseInt(t)||0;this.id=this.id}Eb(){this.C=new su(this.multiple);this.Rc.next();C(this.fu,$n(),Jo(this.G)).subscribe(()=>this.Wc(this.pb));C(this.Nb.vb(),Jo(this.G)).subscribe(()=>
{this.pb&&(this.eu=this.ta(this.Hp),$m(this.Aa))})}yj(){this.ba.next();this.ba.complete();this.Ic();C(this.C.Ah,Jo(this.G)).subscribe(a=>{a.added.forEach(b=>b.select());a.removed.forEach(b=>Nz(b))});C(this.options.i,Fo(null),Jo(this.G)).subscribe(()=>{this.rd();this.va()})}zj(){var a=this.Cc(),b=this.Hd;if(a!==this.fb){var c=this.qa.P;(this.fb=a)?c.setAttribute("aria-labelledby",a):c.removeAttribute("aria-labelledby")}if(b){this.Da!==b.control&&(void 0!==this.Da&&null!==b.disabled&&b.disabled!==this.disabled&&
(this.disabled=b.disabled),this.Da=b.control);a=this.R;b=a.we;c=a.F||a.D;const d=a.Hd?a.Hd.control:null;let e;c=null!=(e=null==(a.lr||a.C)?void 0:!!(d&&d.Pn&&(d.Tc||c&&c.Uj)))?e:!1;c!==b&&(a.we=c,a.i.next())}}rc(a){(a.disabled||a.userAriaDescribedBy)&&this.Rc.next();a.typeaheadDebounceInterval&&this.i&&Hy(this.i,this.im)}ua(){let a;null==(a=this.i)||a.destroy();this.G.next();this.G.complete();this.Rc.complete();this.N&&(ny(this.N,"aria-owns",`${this.id}-panel`),this.N=null)}toggle(){this.pb?this.close():
this.open()}open(){var a;if(!this.D&&!this.disabled&&0<(null==(a=this.options)?void 0:a.length)){this.O&&(this.Hp=TA(this.O));this.eu=this.ta(this.Hp);const b=this.qa.P.closest('body > .cdk-overlay-container [aria-modal="true"]');b&&(a=`${this.id}-panel`,this.N&&ny(this.N,"aria-owns",a),ly(b,"aria-owns",a),this.N=b);this.D=!0;Fy(this.i,null);this.Hc();Zm(this.Aa);this.Rc.next()}}close(){this.D&&(this.D=!1,Fy(this.i,GD(this)?"rtl":"ltr"),Zm(this.Aa),this.Yd(),this.Rc.next())}pi(a){this.ra(a)}Lg(a){this.ea=
a}Ij(a){this.Yd=a}gi(a){this.disabled=a;Zm(this.Aa);this.Rc.next()}get pb(){return this.D}get selected(){let a,b;return this.multiple?(null==(a=this.C)?void 0:a.selected)||[]:null==(b=this.C)?void 0:b.selected[0]}get IE(){if(this.empty)return"";if(this.F){const a=this.C.selected.map(b=>b.D);GD(this)&&a.reverse();return a.join(", ")}return this.C.selected[0].D}Re(a){this.disabled||(this.pb?this.Gc(a):this.Fc(a))}Fc(a){var b=a.keyCode;const c=40===b||38===b||37===b||39===b,d=this.i;!(0<d.F.length||
13!==b&&32!==b||yu(a))||(this.multiple||a.altKey)&&c?(a.preventDefault(),this.open()):this.multiple||(b=this.selected,Ny(d,a),(a=this.selected)&&b!==a&&iy(this.rb,a.D,1E4))}Gc(a){const b=this.i;var c=a.keyCode;const d=40===c||38===c,e=0<b.F.length;if(d&&a.altKey)a.preventDefault(),this.close();else if(e||13!==c&&32!==c||!b.i||yu(a))if(!e&&this.F&&65===c&&a.ctrlKey){a.preventDefault();const f=this.options.some(g=>!g.disabled&&!g.selected);this.options.forEach(g=>{g.disabled||(f?g.select():Nz(g))})}else c=
b.N,Ny(b,a),this.F&&d&&a.shiftKey&&b.i&&b.N!==c&&b.i.uh();else a.preventDefault(),b.i.uh()}Fp(){this.disabled||(this.Pe=!0,this.Rc.next())}xk(){this.Pe=!1;let a;null!=(a=this.i)&&(a.F=[]);this.disabled||this.pb||(this.Yd(),Zm(this.Aa),this.Rc.next())}mA(){C(this.vA.Ej,co()).subscribe(()=>{$m(this.Aa);this.jd()})}Vz(){return this.O?`mat-${this.O.color}`:""}get empty(){return!this.C||0===this.C.i.size}va(){Promise.resolve().then(()=>{this.Hd&&(this.kd=this.Hd.value);this.Ta(this.kd);this.Rc.next()})}Ta(a){this.options.forEach(b=>
{b.C&&(b.C=!1,Zm(b.Aa))});this.C.clear();this.multiple&&a?(a.forEach(b=>this.Ra(b)),this.ab()):(a=this.Ra(a))?Ky(this.i,a):this.pb||Ky(this.i,-1);Zm(this.Aa)}Ra(a){const b=this.options.find(c=>{if(ru(this.C,c))return!1;try{return null!=c.value&&this.T(c.value,a)}catch(d){return!1}});b&&this.C.select(b);return b}ra(a){return a!==this.kd||this.F&&Array.isArray(a)?(this.options&&this.Ta(a),this.kd=a,!0):!1}ta(a){return"auto"===this.Gg?(a instanceof Zv?a.dc:a||this.qa).P.getBoundingClientRect().width:
null===this.Gg?"":this.Gg}Ic(){this.i=Cy(Gy(Jy(Iy(Fy(Ey(Hy(new Py(this.options),this.im)),GD(this)?"rtl":"ltr")))),this.Mb);this.i.ba.subscribe(()=>{this.pb&&(!this.multiple&&this.i.i&&this.i.i.uh(),this.focus(),this.close())});this.i.vb.subscribe(()=>{this.D&&this.Wf?this.Oa(this.i.N||0):this.D||this.multiple||!this.i.i||this.i.i.uh()})}rd(){const a=pk(this.options.i,this.G);C(this.kb,Jo(a)).subscribe(b=>{this.Vc(b.source,b.i);b.i&&!this.multiple&&this.D&&(this.close(),this.focus())});C(pk(...this.options.map(b=>
b.F)),Jo(a)).subscribe(()=>{$m(this.Aa);this.Rc.next()})}Vc(a,b){const c=ru(this.C,a);null!=a.value||this.F?(c!==a.selected&&(a.selected?this.C.select(a):qu(this.C,a)),b&&this.i.C(a),this.multiple&&(this.ab(),b&&this.focus())):(Nz(a),this.C.clear(),null!=this.value&&this.Ia(a.value));c!==ru(this.C,a)&&this.Ia();this.Rc.next()}ab(){if(this.multiple){const a=this.options.toArray();this.C.sort((b,c)=>this.Xx?this.Xx(b,c,a):a.indexOf(b)-a.indexOf(c));this.Rc.next()}}Ia(a){let b;this.multiple?b=this.selected.map(c=>
c.value):b=this.selected?this.selected.value:a;this.kd=b;this.Ay.emit(b);this.ea(b);this.Gx.emit(this.uc(b));Zm(this.Aa)}Hc(){if(this.i)if(this.empty){let a=-1;for(let b=0;b<this.options.length;b++)if(!this.options.get(b).disabled){a=b;break}this.i.C(a)}else this.i.C(this.C.selected[0])}focus(a){this.qa.P.focus(a)}qp(){if(this.ariaLabel)return null;let a;const b=null==(a=this.O)?void 0:a.ph()?a.Te:null;return this.ad?(b?b+" ":"")+this.ad:b}Tz(){return this.pb&&this.i&&this.i.i?this.i.i.id:null}Cc(){if(this.ariaLabel)return null;
var a;const b=null==(a=this.O)?void 0:a.ph()?a.Te:null;a=(b?b+" ":"")+this.yu;this.ad&&(a+=" "+this.ad);return a}Wc(a){this.lo.emit(a)}get UD(){return this.pb||!this.empty||this.focused&&!!this.placeholder}};HD.J=function(a){return new (a||HD)(y(tu),y(Pr),y(Ok),y(iz),y(qi),y(lu,8),y(mx,8),y(tx,8),y(QA,8),y(Dw,10),xh("tabindex"),y(BD),y(jy),y(CD,8))};
HD.Ca=Gf({type:HD,ga:[["mat-select"]],cc:function(a,b,c){a&1&&(qr(c,ED,5),qr(c,Oz,5),qr(c,nz,5));if(a&2){let d;sr(d=tr())&&(b.sB=d.first);sr(d=tr())&&(b.options=d);sr(d=tr())&&(b.Hr=d)}},eb:function(a,b){a&1&&(rr(sD,5),rr(tD,5),rr(bw,5));if(a&2){let c;sr(c=tr())&&(b.Ke=c.first);sr(c=tr())&&(b.Wf=c.first);sr(c=tr())&&(b.vA=c.first)}},Ja:["role","combobox","aria-autocomplete","none","aria-haspopup","listbox",1,"mat-mdc-select"],Xa:19,Ha:function(a,b){a&1&&V("keydown",function(c){return b.Re(c)})("focus",
function(){return b.Fp()})("blur",function(){return b.xk()});a&2&&(Ip("id",b.id)("tabindex",b.disabled?-1:b.tabIndex)("aria-controls",b.pb?b.id+"-panel":null)("aria-expanded",b.pb)("aria-label",b.ariaLabel||null)("aria-required",b.required.toString())("aria-disabled",b.disabled.toString())("aria-invalid",b.we)("aria-activedescendant",b.Tz()),lq("mat-mdc-select-disabled",b.disabled)("mat-mdc-select-invalid",b.we)("mat-mdc-select-required",b.required)("mat-mdc-select-empty",b.empty)("mat-mdc-select-multiple",
b.multiple))},inputs:{Ms:[0,"aria-describedby","userAriaDescribedBy"],gb:"panelClass",disabled:[2,"disabled","disabled",ws],Lc:[2,"disableRipple","disableRipple",ws],tabIndex:[2,"tabIndex","tabIndex",a=>null==a?0:xs(a)],ze:[2,"hideSingleSelectionIndicator","hideSingleSelectionIndicator",ws],placeholder:"placeholder",required:[2,"required","required",ws],multiple:[2,"multiple","multiple",ws],Iv:[2,"disableOptionCentering","disableOptionCentering",ws],Pk:"compareWith",value:"value",ariaLabel:[0,"aria-label",
"ariaLabel"],ad:[0,"aria-labelledby","ariaLabelledby"],Nv:"errorStateMatcher",im:[2,"typeaheadDebounceInterval","typeaheadDebounceInterval",xs],Xx:"sortComparator",id:"id",Gg:"panelWidth"},outputs:{lo:"openedChange",tA:"opened",Fz:"closed",Gx:"selectionChange",Ay:"valueChange"},hb:["matSelect"],ja:!0,features:[Hr([{na:nA,zb:HD},{na:kz,zb:HD}]),Hp,Cg,Jr],Yb:["mat-select-trigger","*"],ya:11,za:8,Ba:[["fallbackOverlayOrigin","cdkOverlayOrigin","trigger",""],["panel",""],["cdk-overlay-origin","",1,"mat-mdc-select-trigger",
3,"click"],[1,"mat-mdc-select-value"],[1,"mat-mdc-select-placeholder","mat-mdc-select-min-line"],[1,"mat-mdc-select-value-text"],[1,"mat-mdc-select-arrow-wrapper"],[1,"mat-mdc-select-arrow"],"viewBox;0 0 24 24;width;24px;height;24px;focusable;false;aria-hidden;true".split(";"),["d","M7 10l5 5 5-5z"],["cdk-connected-overlay","","cdkConnectedOverlayLockPosition","","cdkConnectedOverlayHasBackdrop","","cdkConnectedOverlayBackdropClass","cdk-overlay-transparent-backdrop",3,"backdropClick","attach","detach",
"cdkConnectedOverlayPanelClass","cdkConnectedOverlayScrollStrategy","cdkConnectedOverlayOrigin","cdkConnectedOverlayOpen","cdkConnectedOverlayPositions","cdkConnectedOverlayWidth"],[1,"mat-mdc-select-min-line"],["role","listbox","tabindex","-1",3,"keydown","ngClass"]],sa:function(a,b){if(a&1){const c=Tg();Vq(uD);R(0,"div",2,0);V("click",function(){u(c);return x(b.open())});R(3,"div",3);yp(4,vD,2,1,"span",4)(5,yD,3,1,"span",5);S();R(6,"div",6)(7,"div",7);eh();R(8,"svg",8);Kq(9,"path",9);S()()()();
yp(10,zD,3,9,"ng-template",10);V("backdropClick",function(){u(c);return x(b.close())})("attach",function(){u(c);return x(b.mA())})("detach",function(){u(c);return x(b.close())})}a&2&&(a=wr(1),D(3),Ip("id",b.yu),D(),Cq(b.empty?4:5),D(6),H("cdkConnectedOverlayPanelClass",b.wA)("cdkConnectedOverlayScrollStrategy",b.Jc)("cdkConnectedOverlayOrigin",b.Hp||a)("cdkConnectedOverlayOpen",b.pb)("cdkConnectedOverlayPositions",b.yA)("cdkConnectedOverlayWidth",b.eu))},Ga:[Zv,bw,Ts],styles:['.mat-mdc-select{display:inline-block;width:100%;outline:none;-moz-osx-font-smoothing:grayscale;-webkit-font-smoothing:antialiased;color:var(--mat-select-enabled-trigger-text-color);font-family:var(--mat-select-trigger-text-font);line-height:var(--mat-select-trigger-text-line-height);font-size:var(--mat-select-trigger-text-size);font-weight:var(--mat-select-trigger-text-weight);letter-spacing:var(--mat-select-trigger-text-tracking)}div.mat-mdc-select-panel{box-shadow:var(--mat-select-container-elevation-shadow)}.mat-mdc-select-disabled{color:var(--mat-select-disabled-trigger-text-color)}.mat-mdc-select-trigger{display:inline-flex;align-items:center;cursor:pointer;position:relative;box-sizing:border-box;width:100%}.mat-mdc-select-disabled .mat-mdc-select-trigger{-webkit-user-select:none;user-select:none;cursor:default}.mat-mdc-select-value{width:100%;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.mat-mdc-select-value-text{white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.mat-mdc-select-arrow-wrapper{height:24px;flex-shrink:0;display:inline-flex;align-items:center}.mat-form-field-appearance-fill .mdc-text-field--no-label .mat-mdc-select-arrow-wrapper{transform:none}.mat-mdc-form-field .mat-mdc-select.mat-mdc-select-invalid .mat-mdc-select-arrow,.mat-form-field-invalid:not(.mat-form-field-disabled) .mat-mdc-form-field-infix::after{color:var(--mat-select-invalid-arrow-color)}.mat-mdc-select-arrow{width:10px;height:5px;position:relative;color:var(--mat-select-enabled-arrow-color)}.mat-mdc-form-field.mat-focused .mat-mdc-select-arrow{color:var(--mat-select-focused-arrow-color)}.mat-mdc-form-field .mat-mdc-select.mat-mdc-select-disabled .mat-mdc-select-arrow{color:var(--mat-select-disabled-arrow-color)}.mat-mdc-select-arrow svg{fill:currentColor;position:absolute;top:50%;left:50%;transform:translate(-50%, -50%)}.cdk-high-contrast-active .mat-mdc-select-arrow svg{fill:CanvasText}.mat-mdc-select-disabled .cdk-high-contrast-active .mat-mdc-select-arrow svg{fill:GrayText}div.mat-mdc-select-panel{width:100%;max-height:275px;outline:0;overflow:auto;padding:8px 0;border-radius:4px;box-sizing:border-box;position:static;background-color:var(--mat-select-panel-background-color)}.cdk-high-contrast-active div.mat-mdc-select-panel{outline:solid 1px}.cdk-overlay-pane:not(.mat-mdc-select-panel-above) div.mat-mdc-select-panel{border-top-left-radius:0;border-top-right-radius:0;transform-origin:top center}.mat-mdc-select-panel-above div.mat-mdc-select-panel{border-bottom-left-radius:0;border-bottom-right-radius:0;transform-origin:bottom center}div.mat-mdc-select-panel .mat-mdc-option{--mdc-list-list-item-container-color: var(--mat-select-panel-background-color)}.mat-mdc-select-placeholder{transition:color 400ms 133.3333333333ms cubic-bezier(0.25, 0.8, 0.25, 1);color:var(--mat-select-placeholder-text-color)}._mat-animation-noopable .mat-mdc-select-placeholder{transition:none}.mat-form-field-hide-placeholder .mat-mdc-select-placeholder{color:rgba(0,0,0,0);-webkit-text-fill-color:rgba(0,0,0,0);transition:none;display:block}.mat-mdc-form-field-type-mat-select:not(.mat-form-field-disabled) .mat-mdc-text-field-wrapper{cursor:pointer}.mat-mdc-form-field-type-mat-select.mat-form-field-appearance-fill .mat-mdc-floating-label{max-width:calc(100% - 18px)}.mat-mdc-form-field-type-mat-select.mat-form-field-appearance-fill .mdc-floating-label--float-above{max-width:calc(100%/0.75 - 24px)}.mat-mdc-form-field-type-mat-select.mat-form-field-appearance-outline .mdc-notched-outline__notch{max-width:calc(100% - 60px)}.mat-mdc-form-field-type-mat-select.mat-form-field-appearance-outline .mdc-text-field--label-floating .mdc-notched-outline__notch{max-width:calc(100% - 24px)}.mat-mdc-select-min-line:empty::before{content:" ";white-space:pre;width:1px;display:inline-block;visibility:hidden}.mat-form-field-appearance-fill .mat-mdc-select-arrow-wrapper{transform:var(--mat-select-arrow-transform)}\n'],
ob:2,data:{animation:[rD]},Qa:0});var ID=class{};ID.J=function(a){return new (a||ID)};ID.Wa=Mf({type:ID});ID.Va=Md({Ua:[DD],imports:[et,dw,Tz,fz,uu,WA,Tz,fz]});var JD={na:CD,zc:[[new Qh,new Rh,new Ph(CD)],[new Qh,new Ph(qD)]],Ec:(a,b)=>!b||b.qc?a||{}:a?Object.assign({},a,{Wh:Ms(a.Wh).concat("gmat-mdc-select")}):{Wh:"gmat-mdc-select"}},KD=class{};KD.J=function(a){return new (a||KD)};KD.Wa=Mf({type:KD});KD.Va=Md({Ua:[JD],imports:[ID,tC]});var LD=new df("GMAT_SLIDE_TOGGLE_OPTIONS",{da:"root",aa:()=>({qc:!1})});var MD=class{constructor(a){this.options=a}};MD.J=function(a){return new (a||MD)(y(LD))};MD.Ea=Of({type:MD,ga:[["mat-slide-toggle"]],Xa:2,Ha:function(a,b){a&2&&lq("gmat-mdc-slide-toggle",!b.options.qc)}});var ND=new df("mat-slide-toggle-default-options",{da:"root",aa:()=>({CB:!1,In:!1})});const OD=["switch"];function PD(a){a&1&&(R(0,"div",10),eh(),R(1,"svg",12),Kq(2,"path",13),S(),R(3,"svg",14),Kq(4,"path",15),S()())}var RD={na:jw,zb:af(()=>QD),Db:!0},SD=class{constructor(a,b){this.source=a;this.checked=b}};let TD=0;
var QD=class{kp(a){return new SD(this,a)}get Ou(){return`${this.id||this.Dk}-button`}focus(){this.KA.P.focus()}get checked(){return this.xf}set checked(a){this.xf=a;Zm(this.Aa)}get Yq(){return`${this.id||this.Dk}-input`}constructor(a,b,c,d,e,f){this.qa=a;this.C=b;this.Aa=c;this.defaults=e;this.i=()=>{};this.Yd=()=>{};this.D=()=>{};this.xf=!1;this.name=null;this.Lh="after";this.ad=this.ariaLabel=null;this.Lc=this.disabled=!1;this.tabIndex=0;this.vb=new Dk;this.ny=new Dk;this.tabIndex=parseInt(d)||
0;this.color=e.color||"accent";this.Dp="NoopAnimations"===f;this.id=this.Dk=`mat-mdc-slide-toggle-${++TD}`;let g;this.In=null!=(g=e.In)?g:!1;this.Te=this.Dk+"-label"}yj(){Fx(this.C,this.qa,!0).subscribe(a=>{"keyboard"===a||"program"===a?(this.Pe=!0,Zm(this.Aa)):a||Promise.resolve().then(()=>{this.Pe=!1;this.Yd();Zm(this.Aa)})})}rc(a){a.required&&this.D()}ua(){Gx(this.C,this.qa)}pi(a){this.checked=!!a}Lg(a){this.i=a}Ij(a){this.Yd=a}validate(a){return this.required&&!0!==a.value?{required:!0}:null}Xr(a){this.D=
a}gi(a){this.disabled=a;Zm(this.Aa)}toggle(){this.checked=!this.checked;this.i(this.checked)}Gi(){this.i(this.checked);this.vb.emit(this.kp(this.checked))}pk(){this.ny.emit();this.defaults.CB||(this.checked=!this.checked,this.i(this.checked),this.vb.emit(new SD(this,this.checked)))}Uz(){return this.ad?this.ad:this.ariaLabel?null:this.Te}};QD.J=function(a){return new (a||QD)(y(qi),y(Ix),y(Pr),xh("tabindex"),y(ND),y(ki,8))};
QD.Ca=Gf({type:QD,ga:[["mat-slide-toggle"]],eb:function(a,b){a&1&&rr(OD,5);if(a&2){let c;sr(c=tr())&&(b.KA=c.first)}},Ja:[1,"mat-mdc-slide-toggle"],Xa:13,Ha:function(a,b){a&2&&(Oq("id",b.id),Ip("tabindex",null)("aria-label",null)("name",null)("aria-labelledby",null),oq(rq,b.color?"mat-"+b.color:""),lq("mat-mdc-slide-toggle-focused",b.Pe)("mat-mdc-slide-toggle-checked",b.checked)("_mat-animation-noopable",b.Dp))},inputs:{name:"name",id:"id",Lh:"labelPosition",ariaLabel:[0,"aria-label","ariaLabel"],
ad:[0,"aria-labelledby","ariaLabelledby"],Hk:[0,"aria-describedby","ariaDescribedby"],required:[2,"required","required",ws],color:"color",disabled:[2,"disabled","disabled",ws],Lc:[2,"disableRipple","disableRipple",ws],tabIndex:[2,"tabIndex","tabIndex",a=>null==a?0:xs(a)],checked:[2,"checked","checked",ws],In:[2,"hideIcon","hideIcon",ws]},outputs:{vb:"change",ny:"toggleChange"},hb:["matSlideToggle"],ja:!0,features:[Hr([RD,{na:pw,zb:QD,Db:!0}]),Hp,Cg,Jr],Yb:["*"],ya:13,za:24,Ba:[["switch",""],["mat-internal-form-field",
"",3,"labelPosition"],["role","switch","type","button",1,"mdc-switch",3,"click","tabIndex","disabled"],[1,"mdc-switch__track"],[1,"mdc-switch__handle-track"],[1,"mdc-switch__handle"],[1,"mdc-switch__shadow"],[1,"mdc-elevation-overlay"],[1,"mdc-switch__ripple"],["mat-ripple","",1,"mat-mdc-slide-toggle-ripple","mat-mdc-focus-indicator",3,"matRippleTrigger","matRippleDisabled","matRippleCentered"],[1,"mdc-switch__icons"],[1,"mdc-label",3,"click","for"],["viewBox","0 0 24 24","aria-hidden","true",1,"mdc-switch__icon",
"mdc-switch__icon--on"],["d","M19.69,5.23L8.96,15.96l-4.23-4.23L2.96,13.5l6,6L21.46,7L19.69,5.23z"],["viewBox","0 0 24 24","aria-hidden","true",1,"mdc-switch__icon","mdc-switch__icon--off"],["d","M20 13H4v-2h16v2z"]],sa:function(a,b){if(a&1){const c=Tg();Vq();R(0,"div",1)(1,"button",2,0);V("click",function(){u(c);return x(b.pk())});Kq(3,"div",3);R(4,"div",4)(5,"div",5)(6,"div",6);Kq(7,"div",7);S();R(8,"div",8);Kq(9,"div",9);S();yp(10,PD,5,0,"div",10);S()()();R(11,"label",11);V("click",function(d){u(c);
return x(d.stopPropagation())});Wq(12);S()()}a&2&&(a=wr(2),H("labelPosition",b.Lh),D(),lq("mdc-switch--selected",b.checked)("mdc-switch--unselected",!b.checked)("mdc-switch--checked",b.checked)("mdc-switch--disabled",b.disabled),H("tabIndex",b.disabled?-1:b.tabIndex)("disabled",b.disabled),Ip("id",b.Ou)("name",b.name)("aria-label",b.ariaLabel)("aria-labelledby",b.Uz())("aria-describedby",b.Hk)("aria-required",b.required||null)("aria-checked",b.checked),D(8),H("matRippleTrigger",a)("matRippleDisabled",
b.Lc||b.disabled)("matRippleCentered",!0),D(),Cq(b.In?-1:10),D(),H("for",b.Ou),Ip("id",b.Te))},Ga:[Ez,jz],styles:['.mdc-switch{align-items:center;background:none;border:none;cursor:pointer;display:inline-flex;flex-shrink:0;margin:0;outline:none;overflow:visible;padding:0;position:relative}.mdc-switch[hidden]{display:none}.mdc-switch:disabled{cursor:default;pointer-events:none}.mdc-switch__track{overflow:hidden;position:relative;width:100%}.mdc-switch__track::before,.mdc-switch__track::after{border:1px solid rgba(0,0,0,0);border-radius:inherit;box-sizing:border-box;content:"";height:100%;left:0;position:absolute;width:100%}@media screen and (forced-colors: active){.mdc-switch__track::before,.mdc-switch__track::after{border-color:currentColor}}.mdc-switch__track::before{transition:transform 75ms 0ms cubic-bezier(0, 0, 0.2, 1);transform:translateX(0)}.mdc-switch__track::after{transition:transform 75ms 0ms cubic-bezier(0.4, 0, 0.6, 1);transform:translateX(-100%)}[dir=rtl] .mdc-switch__track::after,.mdc-switch__track[dir=rtl]::after{transform:translateX(100%)}.mdc-switch--selected .mdc-switch__track::before{transition:transform 75ms 0ms cubic-bezier(0.4, 0, 0.6, 1);transform:translateX(100%)}[dir=rtl] .mdc-switch--selected .mdc-switch__track::before,.mdc-switch--selected .mdc-switch__track[dir=rtl]::before{transform:translateX(-100%)}.mdc-switch--selected .mdc-switch__track::after{transition:transform 75ms 0ms cubic-bezier(0, 0, 0.2, 1);transform:translateX(0)}.mdc-switch__handle-track{height:100%;pointer-events:none;position:absolute;top:0;transition:transform 75ms 0ms cubic-bezier(0.4, 0, 0.2, 1);left:0;right:auto;transform:translateX(0)}[dir=rtl] .mdc-switch__handle-track,.mdc-switch__handle-track[dir=rtl]{left:auto;right:0}.mdc-switch--selected .mdc-switch__handle-track{transform:translateX(100%)}[dir=rtl] .mdc-switch--selected .mdc-switch__handle-track,.mdc-switch--selected .mdc-switch__handle-track[dir=rtl]{transform:translateX(-100%)}.mdc-switch__handle{display:flex;pointer-events:auto;position:absolute;top:50%;transform:translateY(-50%);left:0;right:auto}[dir=rtl] .mdc-switch__handle,.mdc-switch__handle[dir=rtl]{left:auto;right:0}.mdc-switch__handle::before,.mdc-switch__handle::after{border:1px solid rgba(0,0,0,0);border-radius:inherit;box-sizing:border-box;content:"";width:100%;height:100%;left:0;position:absolute;top:0;transition:background-color 75ms 0ms cubic-bezier(0.4, 0, 0.2, 1),border-color 75ms 0ms cubic-bezier(0.4, 0, 0.2, 1);z-index:-1}@media screen and (forced-colors: active){.mdc-switch__handle::before,.mdc-switch__handle::after{border-color:currentColor}}.mdc-switch__shadow{border-radius:inherit;bottom:0;left:0;position:absolute;right:0;top:0}.mdc-elevation-overlay{bottom:0;left:0;right:0;top:0}.mdc-switch__ripple{left:50%;position:absolute;top:50%;transform:translate(-50%, -50%);z-index:-1}.mdc-switch:disabled .mdc-switch__ripple{display:none}.mdc-switch__icons{height:100%;position:relative;width:100%;z-index:1}.mdc-switch__icon{bottom:0;left:0;margin:auto;position:absolute;right:0;top:0;opacity:0;transition:opacity 30ms 0ms cubic-bezier(0.4, 0, 1, 1)}.mdc-switch--selected .mdc-switch__icon--on,.mdc-switch--unselected .mdc-switch__icon--off{opacity:1;transition:opacity 45ms 30ms cubic-bezier(0, 0, 0.2, 1)}.mat-mdc-slide-toggle .mdc-switch--disabled+label{color:var(--mdc-switch-disabled-label-text-color)}.mdc-switch{width:var(--mdc-switch-track-width)}.mdc-switch.mdc-switch--selected:enabled .mdc-switch__handle::after{background:var(--mdc-switch-selected-handle-color)}.mdc-switch.mdc-switch--selected:enabled:hover:not(:focus):not(:active) .mdc-switch__handle::after{background:var(--mdc-switch-selected-hover-handle-color)}.mdc-switch.mdc-switch--selected:enabled:focus:not(:active) .mdc-switch__handle::after{background:var(--mdc-switch-selected-focus-handle-color)}.mdc-switch.mdc-switch--selected:enabled:active .mdc-switch__handle::after{background:var(--mdc-switch-selected-pressed-handle-color)}.mdc-switch.mdc-switch--selected:disabled .mdc-switch__handle::after{background:var(--mdc-switch-disabled-selected-handle-color)}.mdc-switch.mdc-switch--unselected:enabled .mdc-switch__handle::after{background:var(--mdc-switch-unselected-handle-color)}.mdc-switch.mdc-switch--unselected:enabled:hover:not(:focus):not(:active) .mdc-switch__handle::after{background:var(--mdc-switch-unselected-hover-handle-color)}.mdc-switch.mdc-switch--unselected:enabled:focus:not(:active) .mdc-switch__handle::after{background:var(--mdc-switch-unselected-focus-handle-color)}.mdc-switch.mdc-switch--unselected:enabled:active .mdc-switch__handle::after{background:var(--mdc-switch-unselected-pressed-handle-color)}.mdc-switch.mdc-switch--unselected:disabled .mdc-switch__handle::after{background:var(--mdc-switch-disabled-unselected-handle-color)}.mdc-switch .mdc-switch__handle::before{background:var(--mdc-switch-handle-surface-color)}.mdc-switch:enabled .mdc-switch__shadow{box-shadow:var(--mdc-switch-handle-elevation)}.mdc-switch:disabled .mdc-switch__shadow{box-shadow:var(--mdc-switch-disabled-handle-elevation)}.mdc-switch .mdc-switch__focus-ring-wrapper,.mdc-switch .mdc-switch__handle{height:var(--mdc-switch-handle-height)}.mdc-switch .mdc-switch__handle{border-radius:var(--mdc-switch-handle-shape)}.mdc-switch .mdc-switch__handle{width:var(--mdc-switch-handle-width)}.mdc-switch .mdc-switch__handle-track{width:calc(100% - var(--mdc-switch-handle-width))}.mdc-switch.mdc-switch--selected:enabled .mdc-switch__icon{fill:var(--mdc-switch-selected-icon-color)}.mdc-switch.mdc-switch--selected:disabled .mdc-switch__icon{fill:var(--mdc-switch-disabled-selected-icon-color)}.mdc-switch.mdc-switch--unselected:enabled .mdc-switch__icon{fill:var(--mdc-switch-unselected-icon-color)}.mdc-switch.mdc-switch--unselected:disabled .mdc-switch__icon{fill:var(--mdc-switch-disabled-unselected-icon-color)}.mdc-switch.mdc-switch--selected:disabled .mdc-switch__icons{opacity:var(--mdc-switch-disabled-selected-icon-opacity)}.mdc-switch.mdc-switch--unselected:disabled .mdc-switch__icons{opacity:var(--mdc-switch-disabled-unselected-icon-opacity)}.mdc-switch.mdc-switch--selected .mdc-switch__icon{width:var(--mdc-switch-selected-icon-size);height:var(--mdc-switch-selected-icon-size)}.mdc-switch.mdc-switch--unselected .mdc-switch__icon{width:var(--mdc-switch-unselected-icon-size);height:var(--mdc-switch-unselected-icon-size)}.mdc-switch.mdc-switch--selected:enabled:hover:not(:focus) .mdc-switch__ripple::before,.mdc-switch.mdc-switch--selected:enabled:hover:not(:focus) .mdc-switch__ripple::after{background-color:var(--mdc-switch-selected-hover-state-layer-color)}.mdc-switch.mdc-switch--selected:enabled:focus .mdc-switch__ripple::before,.mdc-switch.mdc-switch--selected:enabled:focus .mdc-switch__ripple::after{background-color:var(--mdc-switch-selected-focus-state-layer-color)}.mdc-switch.mdc-switch--selected:enabled:active .mdc-switch__ripple::before,.mdc-switch.mdc-switch--selected:enabled:active .mdc-switch__ripple::after{background-color:var(--mdc-switch-selected-pressed-state-layer-color)}.mdc-switch.mdc-switch--unselected:enabled:hover:not(:focus) .mdc-switch__ripple::before,.mdc-switch.mdc-switch--unselected:enabled:hover:not(:focus) .mdc-switch__ripple::after{background-color:var(--mdc-switch-unselected-hover-state-layer-color)}.mdc-switch.mdc-switch--unselected:enabled:focus .mdc-switch__ripple::before,.mdc-switch.mdc-switch--unselected:enabled:focus .mdc-switch__ripple::after{background-color:var(--mdc-switch-unselected-focus-state-layer-color)}.mdc-switch.mdc-switch--unselected:enabled:active .mdc-switch__ripple::before,.mdc-switch.mdc-switch--unselected:enabled:active .mdc-switch__ripple::after{background-color:var(--mdc-switch-unselected-pressed-state-layer-color)}.mdc-switch.mdc-switch--selected:enabled:hover:not(:focus):hover .mdc-switch__ripple::before,.mdc-switch.mdc-switch--selected:enabled:hover:not(:focus).mdc-ripple-surface--hover .mdc-switch__ripple::before{opacity:var(--mdc-switch-selected-hover-state-layer-opacity)}.mdc-switch.mdc-switch--selected:enabled:focus.mdc-ripple-upgraded--background-focused .mdc-switch__ripple::before,.mdc-switch.mdc-switch--selected:enabled:focus:not(.mdc-ripple-upgraded):focus .mdc-switch__ripple::before{transition-duration:75ms;opacity:var(--mdc-switch-selected-focus-state-layer-opacity)}.mdc-switch.mdc-switch--selected:enabled:active:not(.mdc-ripple-upgraded) .mdc-switch__ripple::after{transition:opacity 150ms linear}.mdc-switch.mdc-switch--selected:enabled:active:not(.mdc-ripple-upgraded):active .mdc-switch__ripple::after{transition-duration:75ms;opacity:var(--mdc-switch-selected-pressed-state-layer-opacity)}.mdc-switch.mdc-switch--selected:enabled:active.mdc-ripple-upgraded{--mdc-ripple-fg-opacity:var(--mdc-switch-selected-pressed-state-layer-opacity)}.mdc-switch.mdc-switch--unselected:enabled:hover:not(:focus):hover .mdc-switch__ripple::before,.mdc-switch.mdc-switch--unselected:enabled:hover:not(:focus).mdc-ripple-surface--hover .mdc-switch__ripple::before{opacity:var(--mdc-switch-unselected-hover-state-layer-opacity)}.mdc-switch.mdc-switch--unselected:enabled:focus.mdc-ripple-upgraded--background-focused .mdc-switch__ripple::before,.mdc-switch.mdc-switch--unselected:enabled:focus:not(.mdc-ripple-upgraded):focus .mdc-switch__ripple::before{transition-duration:75ms;opacity:var(--mdc-switch-unselected-focus-state-layer-opacity)}.mdc-switch.mdc-switch--unselected:enabled:active:not(.mdc-ripple-upgraded) .mdc-switch__ripple::after{transition:opacity 150ms linear}.mdc-switch.mdc-switch--unselected:enabled:active:not(.mdc-ripple-upgraded):active .mdc-switch__ripple::after{transition-duration:75ms;opacity:var(--mdc-switch-unselected-pressed-state-layer-opacity)}.mdc-switch.mdc-switch--unselected:enabled:active.mdc-ripple-upgraded{--mdc-ripple-fg-opacity:var(--mdc-switch-unselected-pressed-state-layer-opacity)}.mdc-switch .mdc-switch__ripple{height:var(--mdc-switch-state-layer-size);width:var(--mdc-switch-state-layer-size)}.mdc-switch .mdc-switch__track{height:var(--mdc-switch-track-height)}.mdc-switch:disabled .mdc-switch__track{opacity:var(--mdc-switch-disabled-track-opacity)}.mdc-switch:enabled .mdc-switch__track::after{background:var(--mdc-switch-selected-track-color)}.mdc-switch:enabled:hover:not(:focus):not(:active) .mdc-switch__track::after{background:var(--mdc-switch-selected-hover-track-color)}.mdc-switch:enabled:focus:not(:active) .mdc-switch__track::after{background:var(--mdc-switch-selected-focus-track-color)}.mdc-switch:enabled:active .mdc-switch__track::after{background:var(--mdc-switch-selected-pressed-track-color)}.mdc-switch:disabled .mdc-switch__track::after{background:var(--mdc-switch-disabled-selected-track-color)}.mdc-switch:enabled .mdc-switch__track::before{background:var(--mdc-switch-unselected-track-color)}.mdc-switch:enabled:hover:not(:focus):not(:active) .mdc-switch__track::before{background:var(--mdc-switch-unselected-hover-track-color)}.mdc-switch:enabled:focus:not(:active) .mdc-switch__track::before{background:var(--mdc-switch-unselected-focus-track-color)}.mdc-switch:enabled:active .mdc-switch__track::before{background:var(--mdc-switch-unselected-pressed-track-color)}.mdc-switch:disabled .mdc-switch__track::before{background:var(--mdc-switch-disabled-unselected-track-color)}.mdc-switch .mdc-switch__track{border-radius:var(--mdc-switch-track-shape)}.mdc-switch:enabled .mdc-switch__shadow{box-shadow:var(--mdc-switch-handle-elevation-shadow)}.mdc-switch:disabled .mdc-switch__shadow{box-shadow:var(--mdc-switch-disabled-handle-elevation-shadow)}.mat-mdc-slide-toggle{display:inline-block;-webkit-tap-highlight-color:rgba(0,0,0,0);outline:0}.mat-mdc-slide-toggle .mat-mdc-slide-toggle-ripple,.mat-mdc-slide-toggle .mdc-switch__ripple::after{top:0;left:0;right:0;bottom:0;position:absolute;border-radius:50%;pointer-events:none}.mat-mdc-slide-toggle .mat-mdc-slide-toggle-ripple:not(:empty),.mat-mdc-slide-toggle .mdc-switch__ripple::after:not(:empty){transform:translateZ(0)}.mat-mdc-slide-toggle .mdc-switch__ripple::after{content:"";opacity:0}.mat-mdc-slide-toggle .mdc-switch:hover .mdc-switch__ripple::after{opacity:.04;transition:opacity 75ms 0ms cubic-bezier(0, 0, 0.2, 1)}.mat-mdc-slide-toggle.mat-mdc-slide-toggle-focused .mdc-switch .mdc-switch__ripple::after{opacity:.12}.mat-mdc-slide-toggle.mat-mdc-slide-toggle-focused .mat-mdc-focus-indicator::before{content:""}.mat-mdc-slide-toggle .mat-ripple-element{opacity:.12}.mat-mdc-slide-toggle .mat-mdc-focus-indicator::before{border-radius:50%}.mat-mdc-slide-toggle._mat-animation-noopable .mdc-switch__handle-track,.mat-mdc-slide-toggle._mat-animation-noopable .mdc-elevation-overlay,.mat-mdc-slide-toggle._mat-animation-noopable .mdc-switch__icon,.mat-mdc-slide-toggle._mat-animation-noopable .mdc-switch__handle::before,.mat-mdc-slide-toggle._mat-animation-noopable .mdc-switch__handle::after,.mat-mdc-slide-toggle._mat-animation-noopable .mdc-switch__track::before,.mat-mdc-slide-toggle._mat-animation-noopable .mdc-switch__track::after{transition:none}.mat-mdc-slide-toggle .mdc-switch:enabled+.mdc-label{cursor:pointer}.mdc-switch__handle{transition:width 75ms cubic-bezier(0.4, 0, 0.2, 1),height 75ms cubic-bezier(0.4, 0, 0.2, 1),margin 75ms cubic-bezier(0.4, 0, 0.2, 1)}.mdc-switch--selected .mdc-switch__track::before{opacity:var(--mat-switch-hidden-track-opacity);transition:var(--mat-switch-hidden-track-transition)}.mdc-switch--selected .mdc-switch__track::after{opacity:var(--mat-switch-visible-track-opacity);transition:var(--mat-switch-visible-track-transition)}.mdc-switch--unselected .mdc-switch__track::before{opacity:var(--mat-switch-visible-track-opacity);transition:var(--mat-switch-visible-track-transition)}.mdc-switch--unselected .mdc-switch__track::after{opacity:var(--mat-switch-hidden-track-opacity);transition:var(--mat-switch-hidden-track-transition)}.mat-mdc-slide-toggle .mdc-switch--unselected .mdc-switch__handle{width:var(--mat-switch-unselected-handle-size);height:var(--mat-switch-unselected-handle-size)}.mat-mdc-slide-toggle .mdc-switch--selected .mdc-switch__handle{width:var(--mat-switch-selected-handle-size);height:var(--mat-switch-selected-handle-size)}.mat-mdc-slide-toggle .mdc-switch__handle:has(.mdc-switch__icons){width:var(--mat-switch-with-icon-handle-size);height:var(--mat-switch-with-icon-handle-size)}.mat-mdc-slide-toggle:active .mdc-switch:not(.mdc-switch--disabled) .mdc-switch__handle{width:var(--mat-switch-pressed-handle-size);height:var(--mat-switch-pressed-handle-size)}.mat-mdc-slide-toggle .mdc-switch--selected .mdc-switch__handle{margin:var(--mat-switch-selected-handle-horizontal-margin)}.mat-mdc-slide-toggle .mdc-switch--selected .mdc-switch__handle:has(.mdc-switch__icons){margin:var(--mat-switch-selected-with-icon-handle-horizontal-margin)}.mat-mdc-slide-toggle .mdc-switch--unselected .mdc-switch__handle{margin:var(--mat-switch-unselected-handle-horizontal-margin)}.mat-mdc-slide-toggle .mdc-switch--unselected .mdc-switch__handle:has(.mdc-switch__icons){margin:var(--mat-switch-unselected-with-icon-handle-horizontal-margin)}.mat-mdc-slide-toggle:active .mdc-switch--selected:not(.mdc-switch--disabled) .mdc-switch__handle{margin:var(--mat-switch-selected-pressed-handle-horizontal-margin)}.mat-mdc-slide-toggle:active .mdc-switch--unselected:not(.mdc-switch--disabled) .mdc-switch__handle{margin:var(--mat-switch-unselected-pressed-handle-horizontal-margin)}.mdc-switch__track::after,.mdc-switch__track::before{border-width:var(--mat-switch-track-outline-width);border-color:var(--mat-switch-track-outline-color)}.mdc-switch--selected .mdc-switch__track::after,.mdc-switch--selected .mdc-switch__track::before{border-width:var(--mat-switch-selected-track-outline-width);border-color:var(--mat-switch-selected-track-outline-color)}.mdc-switch--disabled .mdc-switch__track::after,.mdc-switch--disabled .mdc-switch__track::before{border-width:var(--mat-switch-disabled-unselected-track-outline-width);border-color:var(--mat-switch-disabled-unselected-track-outline-color)}.mdc-switch--disabled.mdc-switch--selected .mdc-switch__handle::after{opacity:var(--mat-switch-disabled-selected-handle-opacity)}.mdc-switch--disabled.mdc-switch--unselected .mdc-switch__handle::after{opacity:var(--mat-switch-disabled-unselected-handle-opacity)}\n'],
ob:2,Qa:0});var UD=class{};UD.J=function(a){return new (a||UD)};UD.Wa=Mf({type:UD});UD.Va=Md({imports:[QD,fz,fz]});var VD=class{};VD.J=function(a){return new (a||VD)};VD.Wa=Mf({type:VD});VD.Va=Md({Ua:[{na:ND,mb:{color:"primary"}}],imports:[UD]});var WD=new df("GMAT_SNACK_BAR_OPTIONS",{da:"root",aa:()=>({qc:!1})});var XD=new df("MatSnackBarData"),YD=class{constructor(){this.Nl="assertive";this.Si="";this.duration=0;this.data=null;this.Mn="center";this.QE="bottom"}};var ZD=class{};ZD.J=function(a){return new (a||ZD)};ZD.Ea=Of({type:ZD,ga:[["","matSnackBarLabel",""]],Ja:[1,"mat-mdc-snack-bar-label","mdc-snackbar__label"],ja:!0});var $D=class{};$D.J=function(a){return new (a||$D)};$D.Ea=Of({type:$D,ga:[["","matSnackBarActions",""]],Ja:[1,"mat-mdc-snack-bar-actions","mdc-snackbar__actions"],ja:!0});var aE=class{};aE.J=function(a){return new (a||aE)};aE.Ea=Of({type:aE,ga:[["","matSnackBarAction",""]],Ja:[1,"mat-mdc-snack-bar-action","mdc-snackbar__action"],ja:!0});const bE=Math.pow(2,31)-1;function cE(a){a.i.closed||a.rg.Dq();clearTimeout(a.F)}var dE=class{constructor(a,b){this.ka=b;this.i=new aj;this.lh=new aj;this.C=new aj;this.D=!1;this.rg=a;a.Fm.subscribe(()=>this.K())}G(a){this.F=setTimeout(()=>cE(this),Math.min(a,bE))}N(){this.lh.closed||(this.lh.next(),this.lh.complete())}K(){this.ka.dispose();this.C.closed||this.C.complete();this.i.next({FF:this.D});this.i.complete();this.D=!1}pg(){return this.rg.du}};function eE(a){if(a&1){const b=Tg();R(0,"div",1)(1,"button",2);V("click",function(){u(b);const c=Y();return x(c.action())});Z(2);S()()}a&2&&(a=Y(),D(2),yr(" ",a.data.action," "))}var fE=class{constructor(a,b){this.Tx=a;this.data=b}action(){var a=this.Tx;a.C.closed||(a.D=!0,a.C.next(),a.C.complete(),cE(a));clearTimeout(a.F)}get XB(){return!!this.data.action}};fE.J=function(a){return new (a||fE)(y(dE),y(XD))};
fE.Ca=Gf({type:fE,ga:[["simple-snack-bar"]],Ja:[1,"mat-mdc-simple-snack-bar"],hb:["matSnackBar"],ja:!0,features:[Jr],ya:3,za:2,Ba:[["matSnackBarLabel",""],["matSnackBarActions",""],["mat-button","","matSnackBarAction","",3,"click"]],sa:function(a,b){a&1&&(R(0,"div",0),Z(1),S(),yp(2,eE,3,1,"div",1));a&2&&(D(),yr(" ",b.data.message,"\n"),D(),Cq(b.XB?2:-1))},Ga:[oB,ZD,$D,aE],styles:[".mat-mdc-simple-snack-bar{display:flex}\n"],ob:2,Qa:0});var gE=Ry("state",[Uy("void, hidden",Ty({transform:"scale(0.8)",opacity:0})),Uy("visible",Ty({transform:"scale(1)",opacity:1})),Vy("* => visible",Sy("150ms cubic-bezier(0, 0, 0.2, 1)")),Vy("* => void, * => hidden",Sy("75ms cubic-bezier(0.4, 0.0, 1, 1)",Ty({opacity:0})))]);const hE=["label"];function iE(){}let jE=0;function kE(a,b){const c=b.zg;b=b.le;("void"===b&&"void"!==c||"hidden"===b)&&a.rt();if("visible"===b){const d=a.du;a.pa.run(()=>{d.next();d.complete()})}}
var lE=class extends Rv{constructor(a,b,c,d,e){super();this.pa=a;this.qa=b;this.Aa=c;this.Ka=d;this.Sx=e;this.ha=lf(gt);this.Op=new Set;this.zz=150;this.Fa=!1;this.Ep=new aj;this.Fm=new aj;this.du=new aj;this.bp="void";this.Bp=`mat-snack-bar-container-live-${jE++}`;this.Ii="assertive"!==e.Nl||e.Si?"off"===e.Nl?"off":"polite":"assertive";this.Ka.K&&("polite"===this.Ii&&(this.ku="status"),"assertive"===this.Ii&&(this.ku="alert"))}Zd(a){a=this.Ue.Zd(a);this.jt();return a}Ze(a){a=this.Ue.Ze(a);this.jt();
return a}rn(){this.Fa||(this.bp="visible",Zm(this.Aa),$m(this.Aa),this.EA())}Dq(){this.pa.run(()=>{this.bp="hidden";Zm(this.Aa);this.qa.P.setAttribute("mat-exit","");clearTimeout(this.lt)});return this.Fm}ua(){this.Fa=!0;this.Dz();this.rt()}rt(){queueMicrotask(()=>{this.Fm.next();this.Fm.complete()})}jt(){const a=this.qa.P;var b=this.Sx.gb;b&&(Array.isArray(b)?b.forEach(c=>a.classList.add(c)):a.classList.add(b));this.Nz();b=this.fA.P;b.classList.toggle("mdc-snackbar__label",!b.querySelector(".mdc-snackbar__label"))}Nz(){const a=
this.Bp,b=this.ha.querySelectorAll('body > .cdk-overlay-container [aria-modal="true"]');for(let c=0;c<b.length;c++){const d=b[c],e=d.getAttribute("aria-owns");this.Op.add(d);e?-1===e.indexOf(a)&&d.setAttribute("aria-owns",e+" "+a):d.setAttribute("aria-owns",a)}}Dz(){this.Op.forEach(a=>{var b=a.getAttribute("aria-owns");b&&(b=b.replace(this.Bp,"").trim(),0<b.length?a.setAttribute("aria-owns",b):a.removeAttribute("aria-owns"))});this.Op.clear()}lF(){}EA(){this.lt||Kk(this.pa,()=>{this.lt=setTimeout(()=>
{const a=this.qa.P.querySelector("[aria-hidden]"),b=this.qa.P.querySelector("[aria-live]");if(a&&b){let c=null;this.Ka.isBrowser&&document.activeElement instanceof HTMLElement&&a.contains(document.activeElement)&&(c=document.activeElement);a.removeAttribute("aria-hidden");b.appendChild(a);let d;null==(d=c)||d.focus();this.Ep.next();this.Ep.complete()}},this.zz)})}};lE.J=function(a){return new (a||lE)(y(Ok),y(qi),y(Pr),y(St),y(YD))};
lE.Ca=Gf({type:lE,ga:[["mat-snack-bar-container"]],eb:function(a,b){a&1&&(rr(Tv,7),rr(hE,7));if(a&2){let c;sr(c=tr())&&(b.Ue=c.first);sr(c=tr())&&(b.fA=c.first)}},Ja:[1,"mdc-snackbar","mat-mdc-snack-bar-container","mdc-snackbar--open"],Xa:1,Ha:function(a,b){a&1&&Rq("@state.done",function(c){return kE(b,c)});a&2&&Pq("@state",b.bp)},ja:!0,features:[Ap,Jr],ya:6,za:3,Ba:[["label",""],[1,"mdc-snackbar__surface"],[1,"mat-mdc-snack-bar-label"],["aria-hidden","true"],["cdkPortalOutlet",""]],sa:function(a,
b){a&1&&(R(0,"div",1)(1,"div",2,0)(3,"div",3),yp(4,iE,0,0,"ng-template",4),S(),Kq(5,"div"),S()());a&2&&(D(5),Ip("aria-live",b.Ii)("role",b.ku)("id",b.Bp))},Ga:[Tv],styles:['.mdc-snackbar{display:none;position:fixed;right:0;bottom:0;left:0;align-items:center;justify-content:center;box-sizing:border-box;pointer-events:none;-webkit-tap-highlight-color:rgba(0,0,0,0)}.mdc-snackbar--opening,.mdc-snackbar--open,.mdc-snackbar--closing{display:flex}.mdc-snackbar--open .mdc-snackbar__label,.mdc-snackbar--open .mdc-snackbar__actions{visibility:visible}.mdc-snackbar__surface{padding-left:0;padding-right:8px;display:flex;align-items:center;justify-content:flex-start;box-sizing:border-box;transform:scale(0.8);opacity:0}.mdc-snackbar__surface::before{position:absolute;box-sizing:border-box;width:100%;height:100%;top:0;left:0;border:1px solid rgba(0,0,0,0);border-radius:inherit;content:"";pointer-events:none}@media screen and (forced-colors: active){.mdc-snackbar__surface::before{border-color:CanvasText}}[dir=rtl] .mdc-snackbar__surface,.mdc-snackbar__surface[dir=rtl]{padding-left:8px;padding-right:0}.mdc-snackbar--open .mdc-snackbar__surface{transform:scale(1);opacity:1;pointer-events:auto}.mdc-snackbar--closing .mdc-snackbar__surface{transform:scale(1)}.mdc-snackbar__label{padding-left:16px;padding-right:8px;width:100%;flex-grow:1;box-sizing:border-box;margin:0;visibility:hidden;padding-top:14px;padding-bottom:14px}[dir=rtl] .mdc-snackbar__label,.mdc-snackbar__label[dir=rtl]{padding-left:8px;padding-right:16px}.mdc-snackbar__label::before{display:inline;content:attr(data-mdc-snackbar-label-text)}.mdc-snackbar__actions{display:flex;flex-shrink:0;align-items:center;box-sizing:border-box;visibility:hidden}.mdc-snackbar__action+.mdc-snackbar__dismiss{margin-left:8px;margin-right:0}[dir=rtl] .mdc-snackbar__action+.mdc-snackbar__dismiss,.mdc-snackbar__action+.mdc-snackbar__dismiss[dir=rtl]{margin-left:0;margin-right:8px}.mat-mdc-snack-bar-container{margin:8px;position:static}.mat-mdc-snack-bar-container .mdc-snackbar__surface{min-width:344px}@media(max-width: 480px),(max-width: 344px){.mat-mdc-snack-bar-container .mdc-snackbar__surface{min-width:100%}}@media(max-width: 480px),(max-width: 344px){.mat-mdc-snack-bar-container{width:100vw}}.mat-mdc-snack-bar-container .mdc-snackbar__surface{max-width:672px}.mat-mdc-snack-bar-container .mdc-snackbar__surface{box-shadow:0px 3px 5px -1px rgba(0, 0, 0, 0.2), 0px 6px 10px 0px rgba(0, 0, 0, 0.14), 0px 1px 18px 0px rgba(0, 0, 0, 0.12)}.mat-mdc-snack-bar-container .mdc-snackbar__surface{background-color:var(--mdc-snackbar-container-color)}.mat-mdc-snack-bar-container .mdc-snackbar__surface{border-radius:var(--mdc-snackbar-container-shape)}.mat-mdc-snack-bar-container .mdc-snackbar__label{color:var(--mdc-snackbar-supporting-text-color)}.mat-mdc-snack-bar-container .mdc-snackbar__label{font-size:var(--mdc-snackbar-supporting-text-size);font-family:var(--mdc-snackbar-supporting-text-font);font-weight:var(--mdc-snackbar-supporting-text-weight);line-height:var(--mdc-snackbar-supporting-text-line-height)}.mat-mdc-snack-bar-container .mat-mdc-button.mat-mdc-snack-bar-action:not(:disabled){color:var(--mat-snack-bar-button-color);--mat-text-button-state-layer-color:currentColor;--mat-text-button-ripple-color:currentColor}.mat-mdc-snack-bar-container .mat-mdc-button.mat-mdc-snack-bar-action:not(:disabled) .mat-ripple-element{opacity:.1}.mat-mdc-snack-bar-container .mdc-snackbar__label::before{display:none}.mat-mdc-snack-bar-handset,.mat-mdc-snack-bar-container,.mat-mdc-snack-bar-label{flex:1 1 auto}.mat-mdc-snack-bar-handset .mdc-snackbar__surface{width:100%}\n'],
ob:2,data:{animation:[gE]}});/*

 Copyright Google LLC All Rights Reserved.

 Use of this source code is governed by an MIT-style license that can be
 found in the LICENSE file at https://angular.io/license
 @type {{XSmall: string, Small: string, Medium: string, Large: string, XLarge: string, Handset: string, Tablet: string, Web: string, HandsetPortrait: string, TabletPortrait: string, WebPortrait: string, HandsetLandscape: string, TabletLandscape: string, WebLandscape: string}}
*/
var mE=new df("mat-snack-bar-default-options",{da:"root",aa:function(){return new YD}});function nE(a,b){const c=new xu;c.direction=b.direction;let d=Kv(a.F.position());var e="rtl"===b.direction;e="left"===b.Mn||"start"===b.Mn&&!e||"end"===b.Mn&&e;const f=!e&&"center"!==b.Mn;e?d.left("0"):f?d.right("0"):Hv(d);"top"===b.QE?d.top("0"):d.bottom("0");c.sc=d;return a.F.create(c)}
var oE=class{get i(){const a=this.D;return a?a.i:this.C}set i(a){this.D?this.D.i=a:this.C=a}constructor(a,b,c,d,e,f){this.F=a;this.Ii=b;this.Ya=c;this.R=d;this.D=e;this.G=f;this.C=null;this.T=fE;this.ba=lE}open(a,b="",c){const d=Object.assign({},this.G,c);d.data={message:a,action:b};d.Si===a&&(d.Si=void 0);return this.N(this.T,d)}ua(){this.C&&cE(this.C)}O(a,b){const c=Uh({parent:b&&b.wb&&b.wb.wa||this.Ya,Ua:[{na:YD,mb:b}]});a=a.attach(new Ov(this.ba,b.wb,c));a.instance.Sx=b;return a.instance}N(a,
b){const c=Object.assign({},new YD,this.G,b),d=nE(this,c);b=this.O(d,c);const e=new dE(b,d);if(a instanceof $q)e.instance=b.Ze(new Pv(a,null,{ca:c.data,Tx:e}));else{const f=Uh({parent:c&&c.wb&&c.wb.wa||this.Ya,Ua:[{na:dE,mb:e},{na:XD,mb:c.data}]});a=b.Zd(new Ov(a,void 0,f));e.instance=a.instance}C(this.R.observe("(max-width: 599.98px) and (orientation: portrait)"),Jo(d.G)).subscribe(f=>{d.K.classList.toggle("mat-mdc-snack-bar-handset",f.matches)});c.Si&&b.Ep.subscribe(()=>{iy(this.Ii,c.Si,c.Nl)});
this.K(e,c);return this.i=e}K(a,b){a.i.subscribe(()=>{this.i==a&&(this.i=null);b.Si&&this.Ii.clear()});this.i?(this.i.i.subscribe(()=>{a.rg.rn()}),cE(this.i)):a.rg.rn();b.duration&&0<b.duration&&a.pg().subscribe(()=>a.G(b.duration))}};oE.J=function(a){return new (a||oE)(q(Wv),q(jy),q(Vh),q($x),q(oE,12),q(mE))};oE.oa=Ld({la:oE,aa:oE.J,da:"root"});var pE=class{};pE.J=function(a){return new (a||pE)};pE.Wa=Mf({type:pE});pE.Va=Md({Ua:[oE],imports:[dw,Uv,sB,fz,fE,fz]});var qE=class extends oE{constructor(a,b,c,d,e,f,g){g.qc||ew(a,"gmat-mdc-snack-bar");super(a,b,c,d,e,f)}};qE.J=function(a){return new (a||qE)(q(Wv),q(jy),q(Vh),q($x),q(oE,12),q(mE),q(WD))};qE.oa=Ld({la:qE,aa:qE.J});var rE=class{};rE.J=function(a){return new (a||rE)};rE.Wa=Mf({type:rE});rE.Va=Md({Ua:[{na:oE,Dc:qE},{na:Wv,Dc:fw}],imports:[pE]});var sE=new df("GMAT_TOOLTIP_OPTIONS",{da:"root",aa:()=>({qc:!1})});var tE=class{constructor(a,b){a.qc||ew(b,"gmat-mdc-tooltip")}};tE.J=function(a){return new (a||tE)(y(sE),y(Wv))};tE.Ea=Of({type:tE,ga:[["","matTooltip",""]],features:[Hr([{na:Wv,Dc:fw}])]});const uE=["tooltip"];var vE=new df("mat-tooltip-scroll-strategy",{da:"root",aa:()=>{const a=lf(Wv);return()=>a.i.i({Cx:20})}}),wE={na:vE,zc:[Wv],Ec:function(a){return()=>a.i.i({Cx:20})}},xE=new df("mat-tooltip-default-options",{da:"root",aa:function(){return{Xl:0,nl:0,wE:1500}}});const QF=Ht({passive:!0});function RF(a){a.ka&&a.ka.fc()&&a.ka.detach();a.i=null}function SF(a,b=a.nl){const c=a.i;c&&(c.isVisible()?TF(c,b):(c.F(),RF(a)))}
function UF(a,b=a.Xl,c){if(a.disabled||!a.message||a.F()){let d;null==(d=a.i)||d.F()}else c=VF(a,c),RF(a),a.ta=a.ta||new Ov(a.Gc,a.Cc),c=a.i=c.attach(a.ta).instance,c.Pi=a.qa.P,c.T=a.G,C(c.O,Jo(a.Fa)).subscribe(()=>RF(a)),a.rb(a.ba),a.Mb(),WF(c,b)}
function VF(a,b){if(a.ka){var c=a.ka.xa.sc;if((!a.Zh||!b)&&c.rb instanceof qi)return a.ka;RF(a)}c=gu(a.uc,a.qa);b=Gu(Iu(wv(Bv(Lv(a.ra.position(),a.Zh?b||a.qa:a.qa),".mat-mdc-tooltip"),!1),a.va),c);C(b.fb,Jo(a.Fa)).subscribe(e=>{a.Hc(e.i);a.i&&e.C.gr&&a.i.isVisible()&&a.pa.run(()=>SF(a,0))});a.ka=a.ra.create({direction:a.C,sc:b,gb:"mat-mdc-tooltip-panel",tc:a.Jc()});a.ia(a.ka);C(a.ka.G,Jo(a.Fa)).subscribe(()=>RF(a));C(a.ka.Kl(),Jo(a.Fa)).subscribe(()=>{let e;return null==(e=a.i)?void 0:e.ea()});C(a.ka.df(),
Jo(a.Fa)).subscribe(e=>{a.F()&&27===e.keyCode&&!yu(e)&&(e.preventDefault(),e.stopPropagation(),a.pa.run(()=>SF(a,0)))});let d;(null==(d=a.N)?0:d.EF)&&a.ka.og("mat-mdc-tooltip-panel-non-interactive");return a.ka}
var YF=class{get position(){return this.O}set position(a){if(a!==this.O&&(this.O=a,this.ka)){this.ia(this.ka);let b;null==(b=this.i)||WF(b,0);this.ka.Uc()}}get Zh(){return this.kb}set Zh(a){this.kb=Ns(a);RF(this);this.ka=null}get disabled(){return this.Hb}set disabled(a){(this.Hb=Ns(a))?SF(this,0):this.T()}get Xl(){return this.Kb}set Xl(a){this.Kb=Qs(a)}get nl(){return this.G}set nl(a){this.G=Qs(a);this.i&&(this.i.T=this.G)}get message(){return this.K}set message(a){sy(this.R,this.qa.P,this.K);this.K=
null!=a?String(a).trim():"";!this.K&&this.F()?SF(this,0):(this.T(),this.Mb(),Kk(this.pa,()=>{Promise.resolve().then(()=>{py(this.R,this.qa.P,this.message,"tooltip")})}))}get Io(){return this.ba}set Io(a){this.ba=a;this.i&&this.rb(this.ba)}constructor(a,b,c,d,e,f,g,k,m,p,t,v){this.ra=a;this.qa=b;this.uc=c;this.Cc=d;this.pa=e;this.Ka=f;this.R=g;this.ma=k;this.C=p;this.N=t;this.O="below";this.fb=this.Nb=this.Hb=this.kb=!1;this.Gc=XF;this.va=8;this.Vc="mat-mdc";this.ni="auto";this.K="";this.D=[];this.Fa=
new aj;this.Ya=lf(Vh);this.Jc=m;this.ha=v;t&&(this.Kb=t.Xl,this.G=t.nl,t.position&&(this.position=t.position),t.Zh&&(this.Zh=t.Zh),t.ni&&(this.ni=t.ni));C(p.vb,Jo(this.Fa)).subscribe(()=>{this.ka&&this.ia(this.ka)});this.va=8}nd(){this.Nb=!0;this.T();C(Fx(this.ma,this.qa),Jo(this.Fa)).subscribe(a=>{a?"keyboard"===a&&this.pa.run(()=>UF(this)):this.pa.run(()=>SF(this,0))})}ua(){const a=this.qa.P;clearTimeout(this.ea);this.ka&&(this.ka.dispose(),this.i=null);this.D.forEach(([b,c])=>{a.removeEventListener(b,
c,QF)});this.D.length=0;this.Fa.next();this.Fa.complete();sy(this.R,a,this.message);Gx(this.ma,a)}toggle(a){this.F()?SF(this):UF(this,void 0,a)}F(){return!!this.i&&this.i.isVisible()}ia(a){a=a.xa.sc;const b=this.Fc();var c=!this.C||"ltr"==this.C.value;const d=this.position;let e;if("above"==d)e={La:"center",Sa:"bottom"};else if("below"==d)e={La:"center",Sa:"top"};else if("before"==d||"left"==d&&c||"right"==d&&!c)e={La:"end",Sa:"center"};else if("after"==d||"right"==d&&c||"left"==d&&!c)e={La:"start",
Sa:"center"};const {x:f,y:g}=this.Ta(e.La,e.Sa);c={La:f,Sa:g};Hu(a,[this.Ia(Object.assign({},b.JC,e)),this.Ia(Object.assign({},b.fallback,c))])}Ia(a){const b=!this.C||"ltr"==this.C.value;"top"===a.cb?a.offsetY=-8:"bottom"===a.cb?a.offsetY=8:"start"===a.bb?a.offsetX=b?-8:8:"end"===a.bb&&(a.offsetX=b?8:-8);return a}Fc(){const a=!this.C||"ltr"==this.C.value,b=this.position;let c;if("above"==b||"below"==b)c={bb:"center",cb:"above"==b?"top":"bottom"};else if("before"==b||"left"==b&&a||"right"==b&&!a)c=
{bb:"start",cb:"center"};else if("after"==b||"right"==b&&a||"left"==b&&!a)c={bb:"end",cb:"center"};const {x:d,y:e}=this.Ta(c.bb,c.cb);return{JC:c,fallback:{bb:d,cb:e}}}Mb(){this.i&&(this.i.message=this.message,this.i.N(),Zk(()=>{this.i&&this.ka.Uc()},{wa:this.Ya}))}rb(a){this.i&&(this.i.Io=a,this.i.N())}Ta(a,b){"above"===this.position||"below"===this.position?"top"===b?b="bottom":"bottom"===b&&(b="top"):"end"===a?a="start":"start"===a&&(a="end");return{x:a,y:b}}Hc(a){var b=a.Sa,c=a.bb;a=a.cb;b="center"===
b?this.C&&"rtl"===this.C.value?"end"===c?"left":"right":"start"===c?"left":"right":"bottom"===b&&"top"===a?"above":"below";if(b!==this.Oa){if(c=this.ka)c.Jj("mat-mdc-tooltip-panel-"+this.Oa),c.og("mat-mdc-tooltip-panel-"+b);this.Oa=b}}T(){!this.Hb&&this.message&&this.Nb&&!this.D.length&&(this.ab()?this.D.push(["mouseenter",a=>{this.Jb();let b=void 0;void 0!==a.x&&void 0!==a.y&&(b=a);UF(this,void 0,b)}]):"off"!==this.ni&&(this.Ra(),this.D.push(["touchstart",a=>{let b;const c=(a=null==(b=a.targetTouches)?
void 0:b[0])?{x:a.clientX,y:a.clientY}:void 0;this.Jb();clearTimeout(this.ea);let d;this.ea=setTimeout(()=>UF(this,void 0,c),null!=(d=this.N.zG)?d:500)}])),this.Da(this.D))}Jb(){if(!this.fb){this.fb=!0;var a=[];if(this.ab())a.push(["mouseleave",b=>{b=b.relatedTarget;let c;b&&(null==(c=this.ka)?0:c.K.contains(b))||SF(this)}],["wheel",b=>this.Ic(b)]);else if("off"!==this.ni){this.Ra();const b=()=>{clearTimeout(this.ea);SF(this,this.N.wE)};a.push(["touchend",b],["touchcancel",b])}this.Da(a);this.D.push(...a)}}Da(a){a.forEach(([b,
c])=>{this.qa.P.addEventListener(b,c,QF)})}ab(){return!this.Ka.i&&!this.Ka.O}Ic(a){if(this.F()){a=this.ha.elementFromPoint(a.clientX,a.clientY);const b=this.qa.P;a===b||b.contains(a)||SF(this)}}Ra(){const a=this.ni;if("off"!==a){const b=this.qa.P,c=b.style;if("on"===a||"INPUT"!==b.nodeName&&"TEXTAREA"!==b.nodeName)c.userSelect=c.msUserSelect=c.webkitUserSelect=c.MozUserSelect="none";"on"!==a&&b.draggable||(c.webkitUserDrag="none");c.touchAction="none";c.webkitTapHighlightColor="transparent"}}};
YF.J=function(a){return new (a||YF)(y(Wv),y(qi),y(hu),y(ip),y(Ok),y(St),y(ty),y(Ix),y(vE),y(lu),y(xE,8),y(gt))};
YF.Ea=Of({type:YF,ga:[["","matTooltip",""]],Ja:[1,"mat-mdc-tooltip-trigger"],Xa:2,Ha:function(a,b){a&2&&lq("mat-mdc-tooltip-disabled",b.disabled)},inputs:{position:[0,"matTooltipPosition","position"],Zh:[0,"matTooltipPositionAtOrigin","positionAtOrigin"],disabled:[0,"matTooltipDisabled","disabled"],Xl:[0,"matTooltipShowDelay","showDelay"],nl:[0,"matTooltipHideDelay","hideDelay"],ni:[0,"matTooltipTouchGestures","touchGestures"],message:[0,"matTooltip","message"],Io:[0,"matTooltipClass","tooltipClass"]},
hb:["matTooltip"],ja:!0});function WF(a,b){null!=a.i&&clearTimeout(a.i);a.C=setTimeout(()=>{a.ba(!0);a.C=void 0},b)}function TF(a,b){null!=a.C&&clearTimeout(a.C);a.i=setTimeout(()=>{a.ba(!1);a.i=void 0},b)}
var XF=class{constructor(a,b,c){this.Aa=a;this.qa=b;this.K=this.R=this.Zt=!1;this.O=new aj;this.ta="mat-mdc-tooltip-show";this.ra="mat-mdc-tooltip-hide";this.D="NoopAnimations"===c}isVisible(){return this.K}ua(){this.F();this.O.complete();this.Pi=null}ea(){this.R&&TF(this,0)}N(){Zm(this.Aa)}aA({relatedTarget:a}){a&&this.Pi.contains(a)||(this.isVisible()?TF(this,this.T):this.G(!1))}ma(){this.Zt=this.ia();this.N()}ia(){const a=this.qa.P.getBoundingClientRect();return 24<a.height&&200<=a.width}Wz({animationName:a}){"mat-mdc-tooltip-show"!==
a&&"mat-mdc-tooltip-hide"!==a||this.G("mat-mdc-tooltip-show"===a)}F(){null!=this.C&&clearTimeout(this.C);null!=this.i&&clearTimeout(this.i);this.C=this.i=void 0}G(a){a?this.R=!0:this.isVisible()||this.O.next()}ba(a){const b=this.OA.P;b.classList.remove(a?"mat-mdc-tooltip-hide":"mat-mdc-tooltip-show");b.classList.add(a?"mat-mdc-tooltip-show":"mat-mdc-tooltip-hide");this.K!==a&&(this.K=a,Zm(this.Aa));if(a&&!this.D&&"function"===typeof getComputedStyle){const c=getComputedStyle(b);if("0s"===c.getPropertyValue("animation-duration")||
"none"===c.getPropertyValue("animation-name"))this.D=!0}a&&this.ma();this.D&&(b.classList.add("_mat-animation-noopable"),this.G(a))}};XF.J=function(a){return new (a||XF)(y(Pr),y(qi),y(ki,8))};
XF.Ca=Gf({type:XF,ga:[["mat-tooltip-component"]],eb:function(a,b){a&1&&rr(uE,7);if(a&2){let c;sr(c=tr())&&(b.OA=c.first)}},Ja:["aria-hidden","true"],Xa:2,Ha:function(a,b){a&1&&V("mouseleave",function(c){return b.aA(c)});a&2&&jq("zoom",b.isVisible()?1:null)},ja:!0,features:[Jr],ya:4,za:4,Ba:[["tooltip",""],[1,"mdc-tooltip","mdc-tooltip--shown","mat-mdc-tooltip",3,"animationend","ngClass"],[1,"mdc-tooltip__surface","mdc-tooltip__surface-animation"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",1,
0);V("animationend",function(d){u(c);return x(b.Wz(d))});R(2,"div",2);Z(3);S()()}a&2&&(lq("mdc-tooltip--multiline",b.Zt),H("ngClass",b.Io),D(3),xr(b.message))},Ga:[Ts],styles:['.mdc-tooltip__surface{word-break:break-all;word-break:var(--mdc-tooltip-word-break, normal);overflow-wrap:anywhere}.mdc-tooltip--showing-transition .mdc-tooltip__surface-animation{transition:opacity 150ms 0ms cubic-bezier(0, 0, 0.2, 1),transform 150ms 0ms cubic-bezier(0, 0, 0.2, 1)}.mdc-tooltip--hide-transition .mdc-tooltip__surface-animation{transition:opacity 75ms 0ms cubic-bezier(0.4, 0, 1, 1)}.mdc-tooltip{position:fixed;display:none;z-index:9}.mdc-tooltip-wrapper--rich{position:relative}.mdc-tooltip--shown,.mdc-tooltip--showing,.mdc-tooltip--hide{display:inline-flex}.mdc-tooltip--shown.mdc-tooltip--rich,.mdc-tooltip--showing.mdc-tooltip--rich,.mdc-tooltip--hide.mdc-tooltip--rich{display:inline-block;left:-320px;position:absolute}.mdc-tooltip__surface{line-height:16px;padding:4px 8px;min-width:40px;max-width:200px;min-height:24px;max-height:40vh;box-sizing:border-box;overflow:hidden;text-align:center}.mdc-tooltip__surface::before{position:absolute;box-sizing:border-box;width:100%;height:100%;top:0;left:0;border:1px solid rgba(0,0,0,0);border-radius:inherit;content:"";pointer-events:none}@media screen and (forced-colors: active){.mdc-tooltip__surface::before{border-color:CanvasText}}.mdc-tooltip--rich .mdc-tooltip__surface{align-items:flex-start;display:flex;flex-direction:column;min-height:24px;min-width:40px;max-width:320px;position:relative}.mdc-tooltip--multiline .mdc-tooltip__surface{text-align:left}[dir=rtl] .mdc-tooltip--multiline .mdc-tooltip__surface,.mdc-tooltip--multiline .mdc-tooltip__surface[dir=rtl]{text-align:right}.mdc-tooltip__surface .mdc-tooltip__title{margin:0 8px}.mdc-tooltip__surface .mdc-tooltip__content{max-width:calc(200px - 2*8px);margin:8px;text-align:left}[dir=rtl] .mdc-tooltip__surface .mdc-tooltip__content,.mdc-tooltip__surface .mdc-tooltip__content[dir=rtl]{text-align:right}.mdc-tooltip--rich .mdc-tooltip__surface .mdc-tooltip__content{max-width:calc(320px - 2*8px);align-self:stretch}.mdc-tooltip__surface .mdc-tooltip__content-link{text-decoration:none}.mdc-tooltip--rich-actions,.mdc-tooltip__content,.mdc-tooltip__title{z-index:1}.mdc-tooltip__surface-animation{opacity:0;transform:scale(0.8);will-change:transform,opacity}.mdc-tooltip--shown .mdc-tooltip__surface-animation{transform:scale(1);opacity:1}.mdc-tooltip--hide .mdc-tooltip__surface-animation{transform:scale(1)}.mdc-tooltip__caret-surface-top,.mdc-tooltip__caret-surface-bottom{position:absolute;height:24px;width:24px;transform:rotate(35deg) skewY(20deg) scaleX(0.9396926208)}.mdc-tooltip__caret-surface-top .mdc-elevation-overlay,.mdc-tooltip__caret-surface-bottom .mdc-elevation-overlay{width:100%;height:100%;top:0;left:0}.mdc-tooltip__caret-surface-bottom{box-shadow:0px 3px 1px -2px rgba(0, 0, 0, 0.2), 0px 2px 2px 0px rgba(0, 0, 0, 0.14), 0px 1px 5px 0px rgba(0, 0, 0, 0.12);outline:1px solid rgba(0,0,0,0);z-index:-1}@media screen and (forced-colors: active){.mdc-tooltip__caret-surface-bottom{outline-color:CanvasText}}.mat-mdc-tooltip .mdc-tooltip__surface{background-color:var(--mdc-plain-tooltip-container-color)}.mat-mdc-tooltip .mdc-tooltip__surface{border-radius:var(--mdc-plain-tooltip-container-shape)}.mat-mdc-tooltip .mdc-tooltip__caret-surface-top,.mat-mdc-tooltip .mdc-tooltip__caret-surface-bottom{border-radius:var(--mdc-plain-tooltip-container-shape)}.mat-mdc-tooltip .mdc-tooltip__surface{color:var(--mdc-plain-tooltip-supporting-text-color)}.mat-mdc-tooltip .mdc-tooltip__surface{font-family:var(--mdc-plain-tooltip-supporting-text-font);line-height:var(--mdc-plain-tooltip-supporting-text-line-height);font-size:var(--mdc-plain-tooltip-supporting-text-size);font-weight:var(--mdc-plain-tooltip-supporting-text-weight);letter-spacing:var(--mdc-plain-tooltip-supporting-text-tracking)}.mat-mdc-tooltip{position:relative;transform:scale(0)}.mat-mdc-tooltip::before{content:"";top:0;right:0;bottom:0;left:0;z-index:-1;position:absolute}.mat-mdc-tooltip-panel-below .mat-mdc-tooltip::before{top:-8px}.mat-mdc-tooltip-panel-above .mat-mdc-tooltip::before{bottom:-8px}.mat-mdc-tooltip-panel-right .mat-mdc-tooltip::before{left:-8px}.mat-mdc-tooltip-panel-left .mat-mdc-tooltip::before{right:-8px}.mat-mdc-tooltip._mat-animation-noopable{animation:none;transform:scale(1)}.mat-mdc-tooltip-panel.mat-mdc-tooltip-panel-non-interactive{pointer-events:none}@keyframes mat-mdc-tooltip-show{0%{opacity:0;transform:scale(0.8)}100%{opacity:1;transform:scale(1)}}@keyframes mat-mdc-tooltip-hide{0%{opacity:1;transform:scale(1)}100%{opacity:0;transform:scale(0.8)}}.mat-mdc-tooltip-show{animation:mat-mdc-tooltip-show 150ms cubic-bezier(0, 0, 0.2, 1) forwards}.mat-mdc-tooltip-hide{animation:mat-mdc-tooltip-hide 75ms cubic-bezier(0.4, 0, 1, 1) forwards}\n'],
ob:2,Qa:0});var ZF=class{};ZF.J=function(a){return new (a||ZF)};ZF.Wa=Mf({type:ZF});ZF.Va=Md({Ua:[wE],imports:[ky,et,dw,fz,fz,uu]});var $F=class{};$F.J=function(a){return new (a||$F)};$F.Wa=Mf({type:$F});$F.Va=Md({imports:[ZF]});const aG=Ty({opacity:0}),bG=Ty({opacity:1});var cG=Ry("dialogContainer",[Uy("void, hidden",aG),Uy("visible",bG),Vy("void => *, * => visible",Sy("200ms cubic-bezier(0.0,0.0,0.2,1)",bG)),Vy("* => void, * => hidden",Sy("200ms cubic-bezier(0.4,0.0,0.2,1)",aG))]);function dG(a){a&1&&Kq(0,"a",1)}var eG=new df("XAP_IDCO");function fG(a,b){a.Hu=b?"visible":"hidden";Zm(a.i)}var gG=class extends Rv{constructor(){super(...arguments);this.Hu="hidden";this.options=lf(eG);this.i=lf(Pr)}nd(){}Zd(a){return this.ex.Zd(a)}Ze(a){return this.ex.Ze(a)}};gG.J=(()=>{let a;return function(b){return(a||(a=Lh(gG)))(b||gG)}})();
gG.Ca=Gf({type:gG,ga:[["xap-inline-dialog-container"]],eb:function(a,b){a&1&&rr(Tv,7);if(a&2){let c;sr(c=tr())&&(b.ex=c.first)}},Ja:["role","dialog",1,"xap-inline-dialog-container","gmat-body-2"],Xa:3,Ha:function(a,b){a&2&&(Pq("@dialogContainer",b.Hu),Ip("aria-label",b.options.jn)("tabindex",b.options.kn))},features:[Ap],ya:2,za:0,Ba:[["cdkPortalOutlet",""],["cdkFocusInitial","","tabindex","0"]],sa:function(a){a&1&&(R(0,"div"),yp(1,dG,1,0,"ng-template",0),S())},Ga:[Tv],styles:[".xap-inline-dialog-container{box-shadow:0 1px 2px 0 rgba(60,64,67,.3),0 1px 3px 1px rgba(60,64,67,.15);border-radius:8px;overflow:auto}"],
ob:2,data:{animation:[cG]},Qa:0});var hG=[{bb:"start",cb:"bottom",La:"start",Sa:"top",offsetY:8},{bb:"start",cb:"top",La:"start",Sa:"bottom",offsetY:-8},{bb:"end",cb:"top",La:"end",Sa:"bottom",offsetY:-8},{bb:"end",cb:"bottom",La:"end",Sa:"top",offsetY:8}],iG={minWidth:220,maxWidth:420,minHeight:64,maxHeight:420};
function jG(a){let b;null==(b=a.Ub)||!b.fc()||a.Tj&&!a.Tj.i(a.ta)||(fG(a.F.instance,!1),setTimeout(()=>{a.D.run(()=>{a.Ub&&a.Ub.detach();a.G&&(a.G.destroy(),a.G=void 0);a.Ng();a.F&&(a.F.destroy(),a.F=void 0);a.closed.emit()})},200))}function kG(a,b){Kk(a.D,()=>{C(jk(b,"keydown"),Jo(a.i)).subscribe(c=>{switch(c.keyCode){case 13:lG(a);c.preventDefault();break;case 32:c.preventDefault()}});C(jk(b,"keyup"),Jo(a.i)).subscribe(({keyCode:c})=>{switch(c){case 32:lG(a)}})})}
function mG(a,b){Kk(a.D,()=>{C(jk(b,"focus"),rk(()=>0<a.zh.kc.length),Jo(a.i)).subscribe(()=>{a.D.run(()=>{a.zh.emit()})})})}function lG(a){if(!a.disabled){var b;if(null==(b=a.Ub)||!b.fc()){var c=a.Jd;null!=c&&(a.Tj&&(a.ta=a.Tj.register()),a.D.run(()=>{a.F=nG(a);a.F.instance.attach(c);const d=a.F.location.P;a.O(d);a.T(d);oG(a,d);fG(a.F.instance,!0);a.gf.kc.length&&setTimeout(()=>{a.gf.emit()},200)}))}}}
function nG(a){var b=Uh({parent:a.wa,Ua:[{na:eG,mb:{jn:a.jn,kn:a.kn}}]});b=new Ov(gG,null,b);null==a.Ub&&(a.Ub=a.R.create(a.ia(hG)));a.Vw&&a.Ub.me(a.Vw);if(a.Kr&&0<a.Kr.length){var c=a.Ub,d=pG(a,a.Kr);d!==c.D&&(c.D&&c.D.dispose(),c.D=d,c.fc()&&(d.attach(c),c.Uc()))}return a.Ub.attach(b)}function oG(a,b){const c=a.document.activeElement,d=a.dc.P;if(a.Sv||c&&c===d)a.document&&(a.ea=a.document.activeElement),a.G=a.Da.create(b),Px(a.G),a.uq||qG(a)}function qG(a){a.G&&Qx(a.G).then(()=>{})}
function pG(a,b){let c,d;return Eu(Hu(Lv(a.R.position(),null!=(c=a.Ku)?c:a.dc),b),null!=(d=a.Ku)?d:a.dc)}function rG(a){const b=a.R.i;switch(a.tc){case "noop":return b.F();case "block":return b.block();case "reposition":return b.i();default:return b.close()}}
var sG=class{set Gh(a){a&&(this.Jd=a instanceof $q?new Pv(a,this.wb):new Ov(a,this.wb))}set disabled(a){(this.ba=a)&&jG(this)}get disabled(){return this.ba}set uq(a){this.ma=Ns(a)}get uq(){return this.ma}set gb(a){if(this.K!==a){if(this.K){let b;null==(b=this.Ub)||b.Jj(this.K)}if(a){let b;null==(b=this.Ub)||b.og(a)}this.K=a}}constructor(a,b,c,d,e,f,g,k){this.D=a;this.R=b;this.dc=c;this.wb=d;this.document=e;this.Da=f;this.va=g;this.wa=k;this.ba=!1;this.jn=null;this.kn=-1;this.Jr=iG;this.ty="Press space for more information.";
this.Sv=this.ma=!1;this.tc="close";this.ta=0;this.zh=new Dk;this.gf=new Dk;this.closed=new Dk;this.i=new kj;this.C=new cj(!1);this.ra=C(this.C,rk(m=>m&&!this.disabled));this.ea=void 0;kG(this,c.P);this.T(c.P);mG(this,c.P)}Eb(){var a=this.dc.P;a.hasAttribute("aria-haspopup")||a.setAttribute("aria-haspopup","dialog");a.hasAttribute("aria-describedby")||py(this.va,a,this.ty)}ua(){jG(this);this.C.complete();this.i.next();this.i.complete();this.Ub&&this.Ub.dispose()}Ng(){const a=this.ea;if(a&&"function"===
typeof a.focus){var b,c=null==(b=this.F)?void 0:b.location.P;(b=this.document.activeElement)&&null!=c&&c.contains(b)&&(a.focus(),this.ea=void 0)}}};sG.J=function(a){return new (a||sG)(y(Ok),y(Wv),y(qi),y(ip),y(Document),y(By),y(ty),y(Vh))};
sG.Ea=Of({type:sG,Xa:1,Ha:function(a,b){a&2&&Ip("data-disabled",b.disabled)},inputs:{Ku:"attachedTo",jn:"dialogLabel",kn:"dialogTabIndex",Vw:"overlaySize",Kr:"overlayPositions",Jr:"overlayDimensions",ty:"triggerDescription",uq:"disableAutoFocus",Sv:"forceTrapFocus",gb:"panelClass",tc:"scrollStrategy",Tj:"stackManager"},outputs:{zh:"beforeOpened",gf:"opened",closed:"closed"}});function tG(a,b){const c=C(a.C,Fn(()=>C(a.N,Mn(b))));C(c,Jo(a.i)).subscribe(d=>{d?lG(a):jG(a)});C(a.ra,rk(d=>d&&0<a.zh.kc.length),Ro(()=>C(c,rk(d=>!d))),Jo(a.i)).subscribe(()=>{a.D.run(()=>{a.zh.emit()})})}function uG(a){a.disabled||(a.C.next(!0),a.N.next())}function vG(a){a.C.next(!1);a.N.next()}
var wG=class extends sG{constructor(a,b,c,d,e,f,g,k){super(a,b,c,d,e,f,g,k);this.Tq=500;this.N=new aj;this.O(c.P)}Eb(){super.Eb();tG(this,this.Tq)}O(a){this.Tj&&C(this.Tj.C(),Mn(this.Tq),Jo(this.i)).subscribe(()=>{a.matches(":hover")||this.wb.element.P.matches(":hover")?uG(this):vG(this)});Kk(this.D,()=>{C(jk(a,"mouseenter"),Jo(this.i)).subscribe(()=>{uG(this)});C(jk(a,"click"),Jo(this.i)).subscribe(b=>{b.target.closest("[xapInlineDialogClose]")?vG(this):(uG(this),lG(this))});C(jk(a,"mouseleave"),
Jo(this.i)).subscribe(()=>{vG(this)});C(jk(a,"mousemove"),Jo(this.i)).subscribe(()=>{this.N.next()})})}T(a){Kk(this.D,()=>{C(jk(a,"keydown"),Jo(this.i)).subscribe(b=>{switch(b.keyCode){case 27:let c;(null==(c=this.Ub)?0:c.fc())&&b.stopPropagation();jG(this)}})})}ia(a){return new xu(Object.assign({},this.Jr,{sc:pG(this,a),tc:rG(this),gb:this.K}))}};wG.J=function(a){return new (a||wG)(y(Ok),y(Wv),y(qi),y(ip),y(gt),y(By),y(ty),y(Vh))};
wG.Ea=Of({type:wG,ga:[["","xapInlineDialog",""]],Ja:[1,"xap-inline-dialog"],inputs:{Gh:[0,"xapInlineDialog","dialog"],disabled:[0,"xapInlineDialogDisabled","disabled"],Tq:"hoverDelayMs"},hb:["xapInlineDialog"],features:[Ap]});function xG(a){C(a.C,Jo(a.i)).subscribe(b=>{b?lG(a):jG(a)});C(a.ra,rk(b=>b&&0<a.zh.kc.length),Ro(()=>C(a.C,rk(b=>!b))))}
var yG=class extends sG{constructor(a,b,c,d,e,f,g,k){super(a,b,c,d,e,f,g,k);this.O(c.P)}Eb(){super.Eb();xG(this)}O(a){Kk(this.D,()=>{C(jk(a,"mouseenter"),Jo(this.i)).subscribe(()=>{this.D.run(()=>{this.zh.emit()})});C(jk(a,"click"),Jo(this.i)).subscribe(c=>{c.target.closest("[xapInlineDialogClose]")?this.C.next(!1):this.disabled||this.C.next(!0)});let b;null==(b=this.Ub)||C(b.bd(),Jo(this.i)).subscribe(()=>{this.C.next(!1)})})}T(a){Kk(this.D,()=>{C(jk(a,"keyup"),Jo(this.i)).subscribe(b=>{const c=
b.target;switch(b.keyCode){case 27:this.C.next(!1);break;case 32:c.closest("[xapInlineDialogClose]")&&this.C.next(!1)}});C(jk(a,"keydown"),Jo(this.i)).subscribe(b=>{const c=b.target;switch(b.keyCode){case 13:c.closest("[xapInlineDialogClose]")&&this.C.next(!1)}})})}ia(a){return new xu(Object.assign({},this.Jr,{sc:pG(this,a),tc:rG(this),Sb:!0,bc:"cdk-overlay-transparent-backdrop",gb:this.K}))}};yG.J=function(a){return new (a||yG)(y(Ok),y(Wv),y(qi),y(ip),y(gt),y(By),y(ty),y(Vh))};
yG.Ea=Of({type:yG,ga:[["","xapInlineDialogClick",""]],Ja:[1,"xap-inline-dialog-click"],inputs:{Gh:[0,"xapInlineDialogClick","dialog"],disabled:[0,"xapInlineDialogDisabled","disabled"]},hb:["xapInlineDialogClick"],features:[Ap]});var zG=class{};zG.J=function(a){return new (a||zG)};zG.Wa=Mf({type:zG});zG.Va=Md({imports:[ky,et,dw,Uv]});var AG=class extends it{constructor(){super(...arguments)}};function mt(a,b){return"window"===b?window:"document"===b?a:"body"===b?a.body:null}function BG(a,b,c){a.addEventListener(b,c);return()=>{a.removeEventListener(b,c)}}var CG=class extends AG{dispatchEvent(a,b){a.dispatchEvent(b)}remove(a){a.parentNode&&a.parentNode.removeChild(a)}createElement(a,b){b=b||document;return b.createElement(a)}};let vt=null;function Cn(a){ef.getAngularTestability=(b,c=!0)=>{b=a.fl(b,c);if(null==b)throw new Yd(5103,!1);return b};ef.getAllAngularTestabilities=()=>Array.from(a.i.values());ef.getAllAngularRootElements=()=>Array.from(a.i.keys());ef.frameworkStabilizers||(ef.frameworkStabilizers=[]);ef.frameworkStabilizers.push(b=>{function c(){e--;0==e&&b()}const d=ef.getAllAngularTestabilities();let e=d.length;d.forEach(f=>{f.whenStable(c)})})}
var DG=class{fl(a,b,c){if(null==b)return null;const d=a.i.get(b)||null;if(null!=d)a=d;else{var e;c?e=b instanceof DocumentFragment?this.fl(a,b.host,!0):this.fl(a,b.parentElement,!0):e=null;a=e}return a}};var EG=class{C(){return new XMLHttpRequest}};EG.J=function(a){return new (a||EG)};EG.oa=Ld({la:EG,aa:EG.J});var FG=new df(""),GG=class{constructor(a,b){this.xb=b;this.i=new Map;a.forEach(c=>{c.manager=this});this.D=a.slice().reverse()}addEventListener(a,b,c){return this.C(b).addEventListener(a,b,c)}C(a){let b=this.i.get(a);if(b)return b;b=this.D.find(c=>c.supports(a));if(!b)throw new Yd(5101,!1);this.i.set(a,b);return b}};GG.J=function(a){return new (a||GG)(q(FG),q(Ok))};GG.oa=Ld({la:GG,aa:GG.J});var HG=class{};function IG(a){let b;const c=null==(b=a.D.head)?void 0:b.querySelectorAll(`style[${"ng-app-id"}="${a.F}"]`);if(null==c?0:c.length){const d=new Map;c.forEach(e=>{null!=e.textContent&&d.set(e.textContent,e)});return d}return null}function JG(a){const b=a.C;b.clear();b.add(a.D.head)}function KG(a,b,c){a=a.i;if(a.has(b))return b=a.get(b),b.usage+=c,b.usage;a.set(b,{usage:c,elements:[]});return c}function LG(a,b){for(const c of b)if(1===KG(a,c,1)){b=a;for(const d of b.C)MG(b,d,c)}}
function NG(a,b){a=a.i;let c,d;null==(c=a.get(b))||null==(d=c.elements)||d.forEach(e=>e.remove());a.delete(b)}function MG(a,b,c){{var d=a.G;const f=null==d?void 0:d.get(c);(null==f?void 0:f.parentNode)===b?(d.delete(c),f.removeAttribute("ng-app-id"),b=f):(d=a.D.createElement("style"),a.nonce&&d.setAttribute("nonce",a.nonce),d.textContent=c,a.K&&d.setAttribute("ng-app-id",a.F),b.appendChild(d),b=d)}a=a.i;let e;(d=null==(e=a.get(c))?void 0:e.elements)?d.push(b):a.set(c,{elements:[b],usage:1})}
var OG=class{constructor(a,b,c,d={}){this.D=a;this.F=b;this.nonce=c;this.i=new Map;this.C=new Set;this.G=IG(this);this.K="server"===d;JG(this)}ua(){const a=this.G;a&&(a.forEach(b=>b.remove()),a.clear());for(const b of this.i.keys())NG(this,b);JG(this)}};OG.J=function(a){return new (a||OG)(q(gt),q(hi),q(li,8),q(ji))};OG.oa=Ld({la:OG,aa:OG.J});var PG={svg:"http://www.w3.org/2000/svg",xhtml:"http://www.w3.org/1999/xhtml",xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/",math:"http://www.w3.org/1998/Math/MathML"};const QG=/%COMP%/g;var RG=new df("",{da:"root",aa:()=>!0});function SG(a,b){return b.map(c=>c.replace(QG,a))}
var XG=class{constructor(a,b,c,d,e,f,g,k=null){this.G=a;this.O=b;this.D=c;this.N=d;this.F=e;this.K=g;this.nonce=k;this.C=new Map;this.i="server"===f;this.defaultRenderer=new TG(a,e,g,this.i)}Uk(a,b){if(!a||!b)return this.defaultRenderer;this.i&&3===b.ob&&(b=Object.assign({},b,{ob:0}));a:{const d=this.C;var c=d.get(b.id);if(!c){c=this.F;const e=this.K,f=this.G,g=this.O,k=this.N,m=this.i;switch(b.ob){case 0:c=new UG(f,g,b,this.D,k,c,e,m);break;case 3:b=new VG(f,g,a,b,c,e,this.nonce,m);break a;default:c=
new WG(f,g,b,k,c,e,m)}d.set(b.id,c)}b=c}b instanceof UG?(LG(b.C,b.styles),b.setAttribute(a,b.O,"")):b instanceof WG&&LG(b.C,b.styles);return b}ua(){this.C.clear()}};XG.J=function(a){return new (a||XG)(q(GG),q(OG),q(hi),q(RG),q(gt),q(ji),q(Ok),q(li))};XG.oa=Ld({la:XG,aa:XG.J});function YG(a,b){return c=>{if("__ngUnwrap__"===c)return b;!1===(a.G?a.F.runGuarded(()=>b(c)):b(c))&&c.preventDefault()}}
class TG{constructor(a,b,c,d){this.D=a;this.i=b;this.F=c;this.G=d;this.data=Object.create(null);this.Xk=null}destroy(){}createElement(a,b){return b?this.i.createElementNS(PG[b]||b,a):this.i.createElement(a)}createComment(a){return this.i.createComment(a)}lq(a){return this.i.createTextNode(a)}appendChild(a,b){("TEMPLATE"===a.tagName&&void 0!==a.content?a.content:a).appendChild(b)}insertBefore(a,b,c){a&&("TEMPLATE"===a.tagName&&void 0!==a.content?a.content:a).insertBefore(b,c)}removeChild(a,b){a&&a.removeChild(b)}ns(a,
b){a="string"===typeof a?this.i.querySelector(a):a;if(!a)throw new Yd(-5104,!1);b||(a.textContent="");return a}parentNode(a){return a.parentNode}nextSibling(a){return a.nextSibling}setAttribute(a,b,c,d){d?(b=d+":"+b,(d=PG[d])?a.setAttributeNS(d,b,c):a.setAttribute(b,c)):a.setAttribute(b,c)}removeAttribute(a,b,c){if(c){const d=PG[c];d?a.removeAttributeNS(d,b):a.removeAttribute(`${c}:${b}`)}else a.removeAttribute(b)}Ri(a,b){a.classList.add(b)}wo(a,b){a.classList.remove(b)}setStyle(a,b,c,d){d&3?a.style.setProperty(b,
c,d&1?"important":""):a.style[b]=c}Zr(a,b,c){c&2?a.style.removeProperty(b):a.style[b]=""}setProperty(a,b,c){null!=a&&(a[b]=c)}setValue(a,b){a.nodeValue=b}Ed(a,b,c){if("string"===typeof a&&(a=mt(this.i,a),!a))throw Error(`Unsupported event target ${a} for event ${b}`);return this.D.addEventListener(a,b,YG(this,c))}}function ZG(a,b){return b===a.K?a.shadowRoot:b}
class VG extends TG{constructor(a,b,c,d,e,f,g,k){super(a,e,f,k);this.C=b;this.K=c;this.shadowRoot=c.attachShadow({mode:"open"});a=this.C;b=this.shadowRoot;a.C.add(b);for(const m of a.i.keys())MG(a,b,m);d=SG(d.id,d.styles);for(const m of d)d=document.createElement("style"),g&&d.setAttribute("nonce",g),d.textContent=m,this.shadowRoot.appendChild(d)}appendChild(a,b){return super.appendChild(ZG(this,a),b)}insertBefore(a,b,c){return super.insertBefore(ZG(this,a),b,c)}removeChild(a,b){return super.removeChild(ZG(this,
a),b)}parentNode(a){return ZG(this,super.parentNode(ZG(this,a)))}destroy(){this.C.C.delete(this.shadowRoot)}}class WG extends TG{constructor(a,b,c,d,e,f,g,k){super(a,e,f,g);this.C=b;this.K=d;this.styles=k?SG(k,c.styles):c.styles}destroy(){if(this.K){var a=this.C,b=this.styles;for(const c of b)0>=KG(a,c,-1)&&NG(a,c)}}}
class UG extends WG{constructor(a,b,c,d,e,f,g,k){d=d+"-"+c.id;super(a,b,c,e,f,g,k,d);this.N="_ngcontent-%COMP%".replace(QG,d);this.O="_nghost-%COMP%".replace(QG,d)}createElement(a,b){a=super.createElement(a,b);super.setAttribute(a,this.N,"");return a}};var $G=class extends HG{supports(){return!0}addEventListener(a,b,c){a.addEventListener(b,c,!1);return()=>this.removeEventListener(a,b,c)}removeEventListener(a,b,c){return a.removeEventListener(b,c)}};$G.J=function(a){return new (a||$G)(q(gt))};$G.oa=Ld({la:$G,aa:$G.J});const aH=["alt","control","meta","shift"],bH={"\b":"Backspace","\t":"Tab","\u007f":"Delete","\u001b":"Escape",Del:"Delete",Esc:"Escape",Left:"ArrowLeft",Right:"ArrowRight",Up:"ArrowUp",Down:"ArrowDown",Menu:"ContextMenu",Scroll:"ScrollLock",Win:"OS"},cH={alt:a=>a.altKey,control:a=>a.ctrlKey,meta:a=>a.metaKey,shift:a=>a.shiftKey};
function dH(a){const b=a.toLowerCase().split(".");a=b.shift();if(0===b.length||"keydown"!==a&&"keyup"!==a)return null;const c=eH(b.pop());let d="",e=b.indexOf("code");-1<e&&(b.splice(e,1),d="code.");aH.forEach(f=>{const g=b.indexOf(f);-1<g&&(b.splice(g,1),d+=f+".")});d+=c;if(0!=b.length||0===c.length)return null;a={domEventName:a};a.fullKey=d;return a}function fH(a,b,c){return d=>{gH(d,a)&&c.runGuarded(()=>b(d))}}function eH(a){return"esc"===a?"escape":a}
function gH(a,b){let c=bH[a.key]||a.key,d="";-1<b.indexOf("code.")&&(c=a.code,d="code.");if(null==c||!c)return!1;c=c.toLowerCase();" "===c?c="space":"."===c&&(c="dot");aH.forEach(e=>{e!==c&&(0,cH[e])(a)&&(d+=e+".")});d+=c;return d===b}var hH=class extends HG{supports(a){return null!=dH(a)}addEventListener(a,b,c){const d=dH(b),e=fH(d.fullKey,c,this.manager.xb);return Kk(this.manager.xb,()=>BG(a,d.domEventName,e))}};hH.J=function(a){return new (a||hH)(q(gt))};hH.oa=Ld({la:hH,aa:hH.J});var iH=[{na:ji,mb:"browser"},{na:ii,mb:function(){var a=new CG;null!=ht||(ht=a)},Db:!0},{na:gt,Ec:function(){return ci=document},zc:[]}];rs(Is,"browser",iH);const jH=new df(""),kH=[{na:xn,Dc:DG,zc:[]},{na:wn,Dc:Dn,zc:[Ok,En,xn]},{na:Dn,Dc:Dn,zc:[Ok,En,xn]}],lH=[{na:dg,mb:"root"},{na:ui,Ec:function(){return new ui},zc:[]},{na:FG,Dc:$G,Db:!0,zc:[gt,Ok,ji]},{na:FG,Dc:hH,Db:!0,zc:[gt]},XG,OG,GG,{na:si,zb:XG},{na:Ct,Dc:EG,zc:[]},[]];var mH=class{};mH.J=function(a){return new (a||mH)(q(jH,12))};mH.Wa=Mf({type:mH});
mH.Va=Md({Ua:[...lH,...kH],imports:[et,Or]});var nH=class{constructor(a){this.i=a}};nH.J=function(a){return new (a||nH)(q(gt))};nH.oa=Ld({la:nH,aa:nH.J,da:"root"});new df("HammerGestureConfig");new df("HammerLoader");var oH=class{};function pH(a,b,c){a.Uf.has(c)||a.Uf.set(c,b)}function qH(a,b,c){c=(Array.isArray(c)?c:[c]).map(e=>e.toString());const d=b.toLowerCase();a.headers.set(d,c);pH(a,b,d)}function rH(a,b){b.init();Array.from(b.headers.keys()).forEach(c=>{a.headers.set(c,b.headers.get(c));a.Uf.set(c,b.Uf.get(c))})}
function sH(a,b){const c=b.name.toLowerCase();switch(b.op){case "a":case "s":var d=b.value;"string"===typeof d&&(d=[d]);if(0===d.length)break;pH(a,b.name,c);b=("a"===b.op?a.headers.get(c):void 0)||[];b.push(...d);a.headers.set(c,b);break;case "d":const e=b.value;if(e){if(d=a.headers.get(c))d=d.filter(f=>-1===e.indexOf(f)),0===d.length?(a.headers.delete(c),a.Uf.delete(c)):a.headers.set(c,d)}else a.headers.delete(c),a.Uf.delete(c)}}
var tH=class{constructor(a){this.Uf=new Map;this.yl=null;a?"string"===typeof a?this.ef=()=>{this.headers=new Map;a.split("\n").forEach(b=>{const c=b.indexOf(":");if(0<c){const d=b.slice(0,c),e=d.toLowerCase();b=b.slice(c+1).trim();pH(this,d,e);this.headers.has(e)?this.headers.get(e).push(b):this.headers.set(e,[b])}})}:"undefined"!==typeof Headers&&a instanceof Headers?(this.headers=new Map,a.forEach((b,c)=>{qH(this,c,b)})):this.ef=()=>{this.headers=new Map;Object.entries(a).forEach(([b,c])=>{qH(this,
b,c)})}:this.headers=new Map}has(a){this.init();return this.headers.has(a.toLowerCase())}get(a){this.init();return(a=this.headers.get(a.toLowerCase()))&&0<a.length?a[0]:null}keys(){this.init();return Array.from(this.Uf.values())}getAll(a){this.init();return this.headers.get(a.toLowerCase())||null}append(a,b){return this.clone({name:a,value:b,op:"a"})}set(a,b){return this.clone({name:a,value:b,op:"s"})}delete(a,b){return this.clone({name:a,value:b,op:"d"})}init(){this.ef&&(this.ef instanceof tH?rH(this,
this.ef):this.ef(),this.ef=null,this.yl&&(this.yl.forEach(a=>sH(this,a)),this.yl=null))}clone(a){const b=new tH;b.ef=this.ef&&this.ef instanceof tH?this.ef:this;b.yl=(this.yl||[]).concat([a]);return b}forEach(a){this.init();Array.from(this.Uf.keys()).forEach(b=>a(this.Uf.get(b),this.headers.get(b)))}};var uH=class{};function vH(a){const b=new Map;0<a.length&&a.replace(/^\?/,"").split("&").forEach(c=>{const d=c.indexOf("="),[e,f]=-1==d?[decodeURIComponent(c),""]:[decodeURIComponent(c.slice(0,d)),decodeURIComponent(c.slice(d+1))];c=b.get(e)||[];c.push(f);b.set(e,c)});return b}const wH=/%(\d[a-f0-9])/gi,xH={40:"@","3A":":",24:"$","2C":",","3B":";","3D":"=","3F":"?","2F":"/"};function yH(a){return encodeURIComponent(a).replace(wH,(b,c)=>{let d;return null!=(d=xH[c])?d:b})}
function zH(a){return`${a}`}
var AH=class{constructor(a={}){this.i=this.C=null;this.Bq=a.Bq||new uH;if(a.SB){if(a.An)throw Error("Cannot specify both fromString and fromObject.");this.map=vH(a.SB)}else a.An?(this.map=new Map,Object.keys(a.An).forEach(b=>{var c=a.An[b];c=Array.isArray(c)?c.map(zH):[`${c}`];this.map.set(b,c)})):this.map=null}has(a){this.init();return this.map.has(a)}get(a){this.init();return(a=this.map.get(a))?a[0]:null}getAll(a){this.init();return this.map.get(a)||null}keys(){this.init();return Array.from(this.map.keys())}append(a,
b){return this.clone({Hg:a,value:b,op:"a"})}set(a,b){return this.clone({Hg:a,value:b,op:"s"})}delete(a,b){return this.clone({Hg:a,value:b,op:"d"})}toString(){this.init();return this.keys().map(a=>{const b=yH(a);return this.map.get(a).map(c=>b+"="+yH(c)).join("&")}).filter(a=>""!==a).join("&")}clone(a){const b=new AH({Bq:this.Bq});b.i=this.i||this;b.C=(this.C||[]).concat(a);return b}init(){null===this.map&&(this.map=new Map);null!==this.i&&(this.i.init(),this.i.keys().forEach(a=>this.map.set(a,this.i.map.get(a))),
this.C.forEach(a=>{switch(a.op){case "a":case "s":var b=("a"===a.op?this.map.get(a.Hg):void 0)||[];b.push(`${a.value}`);this.map.set(a.Hg,b);break;case "d":if(void 0!==a.value){b=this.map.get(a.Hg)||[];const c=b.indexOf(`${a.value}`);-1!==c&&b.splice(c,1);0<b.length?this.map.set(a.Hg,b):this.map.delete(a.Hg)}else this.map.delete(a.Hg)}}),this.i=this.C=null)}};var BH=class{constructor(){this.map=new Map}set(a,b){this.map.set(a,b);return this}get(a){this.map.has(a)||this.map.set(a,a.defaultValue());return this.map.get(a)}delete(a){this.map.delete(a);return this}has(a){return this.map.has(a)}keys(){return this.map.keys()}};var CH=class{constructor(a,b,c,d){this.url=b;this.body=null;this.withCredentials=this.ei=!1;this.responseType="json";this.method=a.toUpperCase();a:switch(this.method){case "DELETE":case "GET":case "HEAD":case "OPTIONS":case "JSONP":a=!1;break a;default:a=!0}if(a||d)this.body=void 0!==c?c:null,c=d;c&&(this.ei=!!c.ei,this.withCredentials=!!c.withCredentials,c.responseType&&(this.responseType=c.responseType),c.headers&&(this.headers=c.headers),c.context&&(this.context=c.context),c.params&&(this.params=
c.params),this.Vj=c.Vj);null!=this.headers||(this.headers=new tH);null!=this.context||(this.context=new BH);this.params||(this.params=new AH)}clone(a={}){const b=a.method||this.method,c=a.url||this.url,d=a.responseType||this.responseType;var e;const f=null!=(e=a.Vj)?e:this.Vj;e=void 0!==a.body?a.body:this.body;var g;const k=null!=(g=a.withCredentials)?g:this.withCredentials;var m;g=null!=(m=a.ei)?m:this.ei;m=a.headers||this.headers;let p=a.params||this.params,t;const v=null!=(t=a.context)?t:this.context;
void 0!==a.Ix&&(m=Object.keys(a.Ix).reduce((B,G)=>B.set(G,a.Ix[G]),m));a.Jx&&(p=Object.keys(a.Jx).reduce((B,G)=>B.set(G,a.Jx[G]),p));return new CH(b,c,e,{params:p,headers:m,context:v,ei:g,responseType:d,withCredentials:k,Vj:f})}};function DH(a,b,c,d={}){if(b instanceof CH)c=b;else{var e=void 0;e=d.headers instanceof tH?d.headers:new tH(d.headers);let f=void 0;d.params&&(f=d.params instanceof AH?d.params:new AH({An:d.params}));c=new CH(b,c,void 0!==d.body?d.body:null,{headers:e,context:d.context,params:f,ei:d.ei,responseType:d.responseType||"json",withCredentials:d.withCredentials,Vj:d.Vj})}e=C(hj(c),Rj(f=>a.handler.handle(f),1));if(b instanceof CH||"events"===d.observe)return e;b=C(e,rk(()=>!1));switch(d.observe||"body"){case "body":switch(c.responseType){case "arraybuffer":return C(b,
vj(f=>{if(null!==f.body&&!(f.body instanceof ArrayBuffer))throw Error("Response is not an ArrayBuffer.");return f.body}));case "blob":return C(b,vj(f=>{if(null!==f.body&&!(f.body instanceof Blob))throw Error("Response is not a Blob.");return f.body}));case "text":return C(b,vj(f=>{if(null!==f.body&&"string"!==typeof f.body)throw Error("Response is not a string.");return f.body}));default:return C(b,vj(f=>f.body))}case "response":return b;default:throw Error(`Unreachable: unhandled observe type ${d.observe}}`);
}}var EH=class{constructor(a){this.handler=a}delete(a,b={}){return DH(this,"DELETE",a,b)}get(a,b={}){return DH(this,"GET",a,b)}head(a,b={}){return DH(this,"HEAD",a,b)}options(a,b={}){return DH(this,"OPTIONS",a,b)}};EH.J=function(a){return new (a||EH)(q(oH))};EH.oa=Ld({la:EH,aa:EH.J});new df("");new df("");new df("");new df("",{da:"root",aa:()=>!0});new df("");new df("",{da:"root",aa:()=>"XSRF-TOKEN"});new df("",{da:"root",aa:()=>"X-XSRF-TOKEN"});new df("");new df("");new df("");var FH=class{};FH.J=function(a){return new (a||FH)};FH.oa=Ld({la:FH,aa:function(a){return a?new (a||FH):q(GH)},da:"root"});
var GH=class extends FH{constructor(a){super();this.C=a}i(a,b){if(null==b)return null;switch(a){case 0:return b;case 1:if(Al(b,"HTML"))var c=zl(b);else{a:{a=this.C;var d=String(b);b=null;try{var e;if(!(e=pm)){var f=new Fl(a);try{var g=!!(new window.DOMParser).parseFromString(Dl(""),"text/html")}catch(t){g=!1}e=g?new El(f):f}pm=e;var k=d?String(d):"";b=pm.Cn(k);e=5;g=k;do{if(0===e)throw Error("Failed to sanitize html because the input is unstable");e--;k=g;g=b.innerHTML;b=pm.Cn(k)}while(k!==g);var m=
new Wl;let p=(qm(b)||b).firstChild;k=!0;for(e=[];p;){if(p.nodeType===Node.ELEMENT_NODE)b:{g=m;f=p;const t=Yl(f).toLowerCase();if(!Ql.hasOwnProperty(t)){k=!Vl.hasOwnProperty(t);break b}g.i.push("<");g.i.push(t);const v=f.attributes;for(f=0;f<v.length;f++){const B=v.item(f),G=B.name,K=G.toLowerCase();if(!Ul.hasOwnProperty(K))continue;let N=B.value;Rl[K]&&(N=Hl(N));g.i.push(" ",G,'="',Xl(N),'"')}g.i.push(">");k=!0}else p.nodeType===Node.TEXT_NODE&&m.chars(p.nodeValue);if(k&&p.firstChild){e.push(p);const t=
p.firstChild;if(t&&(p.compareDocumentPosition(t)&Node.DOCUMENT_POSITION_CONTAINED_BY)!==Node.DOCUMENT_POSITION_CONTAINED_BY)throw Zl(t);p=t}else for(;p;){if(p.nodeType===Node.ELEMENT_NODE){g=m;const v=Yl(p).toLowerCase();Ql.hasOwnProperty(v)&&!Kl.hasOwnProperty(v)&&(g.i.push("</"),g.i.push(v),g.i.push(">"))}const t=p.nextSibling;if(t&&p!==t.previousSibling)throw Zl(t);if(g=t){p=g;break}p=e.pop()}}c=Dl(m.i.join(""));break a}finally{if(b)for(m=qm(b)||b;m.firstChild;)m.removeChild(m.firstChild)}c=void 0}c=
c.toString()}return c;case 2:return Al(b,"Style")?zl(b):b;case 3:if(Al(b,"Script"))return zl(b);throw new Yd(5200,!1);case 4:return Al(b,"URL")?zl(b):Hl(String(b));case 5:if(Al(b,"ResourceURL"))return zl(b);throw new Yd(5201,!1);default:throw new Yd(5202,!1);}}F(a){return new xl(a)}D(a){return new yl(a)}};GH.J=function(a){return new (a||GH)(q(gt))};GH.oa=Ld({la:GH,aa:GH.J,da:"root"});function HH(a,...b){if(0===b.length)return gd(a[0]);let c=a[0];for(let d=0;d<b.length;d++)c+=encodeURIComponent(b[d])+a[d+1];return gd(c)};function IH(a,b){switch(b){case 1:return!1;case 4:return a instanceof hd||a instanceof ad;case 5:return a instanceof ad;case 3:return!1;default:return!1}}
var JH=class extends FH{constructor(a){super();this.C=new GH(a)}i(a,b){if(null==b)return null;if(b instanceof ad||b instanceof hd){if(IH(b,a)){var c=this.C,d=c.i;a:{if(null!=b){if(b instanceof hd){b=this.C.F(id(b));break a}if(b instanceof ad){b=this.C.D(String(b));break a}}b=null}return d.call(c,a,b)}throw Error(`Required a safe value for ${rm[a]}, got ${b} `+"(see http://g.co/ng/security#xss)");}return this.C.i(a,b)}F(){throw Error("bypassSecurityTrust* functions are prohibited in the google3 version of Angular. Use LegacyDomSanitizer if you need to disable auto sanitization and get a security from ise-hardening-reviews.");
}D(){throw Error("bypassSecurityTrust* functions are prohibited in the google3 version of Angular. Use LegacyDomSanitizer if you need to disable auto sanitization and get a security from ise-hardening-reviews.");}};JH.J=function(a){return new (a||JH)(q(gt))};JH.oa=Ld({la:JH,aa:JH.J});const KH=[{na:bn,zb:FH},{na:FH,Dc:JH}];var LH=class{};LH.J=function(a){return new (a||LH)};LH.Wa=Mf({type:LH});LH.Va=Md({Ua:KH,imports:[mH]});let MH;function NH(){if(void 0===MH&&(MH=null,"undefined"!==typeof window)){const a=window;void 0!==a.trustedTypes&&(MH=a.trustedTypes.createPolicy("angular#components",{createHTML:b=>b}))}return MH}function OH(a){let b;return(null==(b=NH())?void 0:b.createHTML(a))||a};function PH(a){return Error(`Unable to find icon with the name "${a}"`)}class QH{constructor(a,b){this.url=a;this.Ug=null;this.options=b}}function RH(a,b){return a.va.get(b)||b}function SH(a,b,c=""){const d=c+":"+b;let e=a.D.get(d);return e?a.T(e):(e=a.Da(c,b))?(a.D.set(d,e),a.T(e)):(c=a.i.get(c))?a.Ia(b,c):ij(PH(d))}
var TH=class{constructor(a,b,c,d){this.ba=a;this.ea=b;this.ia=d;this.D=new Map;this.i=new Map;this.ma=new Map;this.F=new Map;this.va=new Map;this.G=[];this.ra=["material-icons","mat-ligature-font"];this.ha=c}ua(){this.G=[];this.D.clear();this.i.clear();this.ma.clear()}T(a){return a.Ug?hj(this.K(a).cloneNode(!0)):C(this.Oa(a),vj(b=>b.cloneNode(!0)))}Ia(a,b){var c=this.O(a,b);if(c)return hj(c);c=b.filter(d=>!d.Ug).map(d=>C(this.Ra(d),Kn(e=>{e=`Loading icon set URL: ${this.ea.i(5,d.url)} failed: ${e.message}`;
this.ia.handleError(Error(e));return hj(null)})));return C(hk(c),vj(()=>{const d=this.O(a,b);if(!d)throw PH(a);return d}))}O(a,b){for(let d=b.length-1;0<=d;d--){var c=b[d];if(c.Ug&&-1<c.Ug.toString().indexOf(a)){const e=this.K(c);if(c=this.ta(e,a,c.options))return c}}return null}Oa(a){return C(this.R(a),No(b=>a.Ug=b),vj(()=>this.K(a)))}Ra(a){return a.Ug?hj(null):C(this.R(a),No(b=>a.Ug=b))}ta(a,b,c){a=a.querySelector(`[id="${b}"]`);if(!a)return null;a=a.cloneNode(!0);a.removeAttribute("id");if("svg"===
a.nodeName.toLowerCase())return this.C(a,c);if("symbol"===a.nodeName.toLowerCase())return this.C(this.Ta(a),c);b=this.N(OH("<svg></svg>"));b.appendChild(a);return this.C(b,c)}N(a){const b=this.ha.createElement("DIV");b.innerHTML=a;a=b.querySelector("svg");if(!a)throw Error("<svg> tag not found");return a}Ta(a){const b=this.N(OH("<svg></svg>"));var c=a.attributes;for(let d=0;d<c.length;d++){const {name:e,value:f}=c[d];"id"!==e&&b.setAttribute(e,f)}for(c=0;c<a.childNodes.length;c++)a.childNodes[c].nodeType===
this.ha.ELEMENT_NODE&&b.appendChild(a.childNodes[c].cloneNode(!0));return b}C(a,b){a.setAttribute("fit","");a.setAttribute("height","100%");a.setAttribute("width","100%");a.setAttribute("preserveAspectRatio","xMidYMid meet");a.setAttribute("focusable","false");b&&b.viewBox&&a.setAttribute("viewBox",b.viewBox);return a}R(a){var b=a.url;let c,d;a=null!=(d=null==(c=a.options)?void 0:c.withCredentials)?d:!1;if(!this.ba)throw Error("Could not find HttpClient provider for use with Angular Material icons. Please include the HttpClientModule from @angular/common/http in your app imports.");
if(null==b)throw Error(`Cannot fetch icon from URL "${b}".`);const e=this.ea.i(5,b);if(!e)throw Error("The URL provided to MatIconRegistry was not trusted as a resource URL "+`via Angular's DomSanitizer. Attempted URL was "${b}".`);if(b=this.F.get(e))return b;b=C(this.ba.get(e,{responseType:"text",withCredentials:a}),vj(f=>OH(f)),ko(()=>this.F.delete(e)),zo());this.F.set(e,b);return b}ab(a,b,c){this.D.set(a+":"+b,c);return this}fb(a,b){const c=this.i.get(a);c?c.push(b):this.i.set(a,[b]);return this}K(a){if(!a.jy){const b=
this.N(a.Ug);this.C(b,a.options);a.jy=b}return a.jy}Da(a,b){for(let c=0;c<this.G.length;c++){const d=this.G[c](b,a);if(d)return d.url&&d.options?new QH(d.url,d.options):new QH(d)}}};TH.J=function(a){return new (a||TH)(q(EH,8),q(FH),q(gt,8),q(ui))};TH.oa=Ld({la:TH,aa:TH.J,da:"root"});new Qh;new Rh;new Qh;new Qh;var UH=new df("MAT_ICON_DEFAULT_OPTIONS"),WH=new df("mat-icon-location",{da:"root",aa:VH});function VH(){const a=lf(gt),b=a?a.location:null;return{Wv:()=>b?b.pathname+b.search:""}}const XH="clip-path color-profile src cursor fill filter marker marker-start marker-mid marker-end mask stroke".split(" "),YH=XH.map(a=>`[${a}]`).join(", "),ZH=/^url\(['"]?#(.*?)['"]?\)$/;
var $H=class{get color(){return this.mh||this.ra}set color(a){this.mh=a}get Cs(){return this.G}set Cs(a){a!==this.G&&(a?this.Oa(a):this.G&&this.R(),this.G=a)}get yg(){return this.ba}set yg(a){a=this.O(a);a!==this.ba&&(this.ba=a,this.K())}get xg(){return this.T}set xg(a){a=this.O(a);a!==this.T&&(this.T=a,this.K())}constructor(a,b,c,d,e,f){this.qa=a;this.D=b;this.N=d;this.ta=e;this.inline=!1;this.ia=[];this.C=Li.EMPTY;f&&(f.color&&(this.color=this.ra=f.color),f.yg&&(this.yg=f.yg));c||a.P.setAttribute("aria-hidden",
"true")}Ia(a){if(!a)return["",""];const b=a.split(":");switch(b.length){case 1:return["",b[0]];case 2:return b;default:throw Error(`Invalid icon name: "${a}"`);}}Eb(){this.K()}Lw(){var a=this.i;a&&a.size&&(a=this.N.Wv(),a!==this.ma&&(this.ma=a,this.ea(a)))}ua(){this.C.unsubscribe();this.i&&this.i.clear()}Tp(){return!this.Cs}Da(a){this.R();const b=this.N.Wv();this.ma=b;this.va(a);this.ea(b);this.qa.P.appendChild(a)}R(){const a=this.qa.P;let b=a.childNodes.length;for(this.i&&this.i.clear();b--;){const c=
a.childNodes[b];1===c.nodeType&&"svg"!==c.nodeName.toLowerCase()||c.remove()}}K(){if(this.Tp()){var a=this.qa.P,b=(this.yg?RH(this.D,this.yg).split(/ +/):this.D.ra).filter(c=>0<c.length);this.ia.forEach(c=>a.classList.remove(c));b.forEach(c=>a.classList.add(c));this.ia=b;this.xg===this.F||b.includes("mat-ligature-font")||(this.F&&a.classList.remove(this.F),this.xg&&a.classList.add(this.xg),this.F=this.xg)}}O(a){return"string"===typeof a?a.trim().split(" ")[0]:a}ea(a){const b=this.i;b&&b.forEach((c,
d)=>{c.forEach(e=>{d.setAttribute(e.name,`url('${a}#${e.value}')`)})})}va(a){const b=a.querySelectorAll(YH),c=this.i=this.i||new Map;for(let d=0;d<b.length;d++)XH.forEach(e=>{const f=b[d];var g=f.getAttribute(e);if(g=g?g.match(ZH):null){let k=c.get(f);k||(k=[],c.set(f,k));k.push({name:e,value:g[1]})}})}Oa(a){this.ou=this.pu=null;this.C.unsubscribe();if(a){const [b,c]=this.Ia(a);b&&(this.pu=b);c&&(this.ou=c);this.C=C(SH(this.D,c,b),co()).subscribe(d=>this.Da(d),d=>{this.ta.handleError(Error(`Error retrieving icon ${b}:${c}! ${d.message}`))})}}};
$H.J=function(a){return new (a||$H)(y(qi),y(TH),xh("aria-hidden"),y(WH),y(ui),y(UH,8))};
$H.Ca=Gf({type:$H,ga:[["mat-icon"]],Ja:["role","img",1,"mat-icon","notranslate"],Xa:10,Ha:function(a,b){a&2&&(Ip("data-mat-icon-type",b.Tp()?"font":"svg")("data-mat-icon-name",b.ou||b.xg)("data-mat-icon-namespace",b.pu||b.yg)("fontIcon",b.Tp()?b.xg:null),oq(rq,b.color?"mat-"+b.color:""),lq("mat-icon-inline",b.inline)("mat-icon-no-color","primary"!==b.color&&"accent"!==b.color&&"warn"!==b.color))},inputs:{color:"color",inline:[2,"inline","inline",ws],Cs:"svgIcon",yg:"fontSet",xg:"fontIcon"},hb:["matIcon"],
ja:!0,features:[Hp,Jr],Yb:["*"],ya:1,za:0,sa:function(a){a&1&&(Vq(),Wq(0))},styles:["mat-icon,mat-icon.mat-primary,mat-icon.mat-accent,mat-icon.mat-warn{color:var(--mat-icon-color)}.mat-icon{-webkit-user-select:none;user-select:none;background-repeat:no-repeat;display:inline-block;fill:currentColor;height:24px;width:24px;overflow:hidden}.mat-icon.mat-icon-inline{font-size:inherit;height:inherit;line-height:inherit;width:inherit}.mat-icon.mat-ligature-font[fontIcon]::before{content:attr(fontIcon)}[dir=rtl] .mat-icon-rtl-mirror{transform:scale(-1, 1)}.mat-form-field:not(.mat-form-field-appearance-legacy) .mat-form-field-prefix .mat-icon,.mat-form-field:not(.mat-form-field-appearance-legacy) .mat-form-field-suffix .mat-icon{display:block}.mat-form-field:not(.mat-form-field-appearance-legacy) .mat-form-field-prefix .mat-icon-button .mat-icon,.mat-form-field:not(.mat-form-field-appearance-legacy) .mat-form-field-suffix .mat-icon-button .mat-icon{margin:auto}\n"],
ob:2,Qa:0});var aI=class{};aI.J=function(a){return new (a||aI)};aI.Wa=Mf({type:aI});aI.Va=Md({imports:[fz,fz]});function bI(a){if(a&1){const b=Tg();R(0,"button",1);V("click",function(){u(b);Y();var c=new URL(window.location.href),d=new URLSearchParams(c.search);d.delete("show_open_in_new_tab");c.search=d.toString();d=window;c=rd(c.toString());c=td(c);void 0!==c&&d.open(c,"_blank",void 0);return x()});R(1,"mat-icon");Z(2,"open_in_new");S();Z(3," Open in new tab ");S()}}var cI=class{constructor(){this.Co="1"===(new URLSearchParams(window.location.search)).get("show_open_in_new_tab")}};
cI.J=function(a){return new (a||cI)};cI.Ca=Gf({type:cI,ga:[["open-in-new-tab-button"]],ja:!0,features:[Jr],ya:1,za:1,Ba:[["mat-flat-button","","color","primary",1,"btn-open-in-tab"],["mat-flat-button","","color","primary",1,"btn-open-in-tab",3,"click"]],sa:function(a,b){a&1&&yp(0,bI,4,0,"button",0);a&2&&Cq(b.Co?0:-1)},Ga:[et,uB,tB,oB,aI,$H]});var dI={aliceblue:"#f0f8ff",antiquewhite:"#faebd7",aqua:"#00ffff",aquamarine:"#7fffd4",azure:"#f0ffff",beige:"#f5f5dc",bisque:"#ffe4c4",black:"#000000",blanchedalmond:"#ffebcd",blue:"#0000ff",blueviolet:"#8a2be2",brown:"#a52a2a",burlywood:"#deb887",cadetblue:"#5f9ea0",chartreuse:"#7fff00",chocolate:"#d2691e",coral:"#ff7f50",cornflowerblue:"#6495ed",cornsilk:"#fff8dc",crimson:"#dc143c",cyan:"#00ffff",darkblue:"#00008b",darkcyan:"#008b8b",darkgoldenrod:"#b8860b",darkgray:"#a9a9a9",darkgreen:"#006400",
darkkhaki:"#bdb76b",darkmagenta:"#8b008b",darkolivegreen:"#556b2f",darkorange:"#ff8c00",darkorchid:"#9932cc",darkred:"#8b0000",darksalmon:"#e9967a",darkseagreen:"#8fbc8f",darkslateblue:"#483d8b",darkslategray:"#2f4f4f",darkturquoise:"#00ced1",darkviolet:"#9400d3",deeppink:"#ff1493",deepskyblue:"#00bfff",dimgray:"#696969",dodgerblue:"#1e90ff",firebrick:"#b22222",floralwhite:"#fffaf0",forestgreen:"#228b22",fuchsia:"#ff00ff",gainsboro:"#dcdcdc",ghostwhite:"#f8f8ff",gold:"#ffd700",goldenrod:"#daa520",
gray:"#808080",green:"#008000",greenyellow:"#adff2f",honeydew:"#f0fff0",hotpink:"#ff69b4","indianred ":"#cd5c5c",indigo:"#4b0082",ivory:"#fffff0",khaki:"#f0e68c",lavender:"#e6e6fa",lavenderblush:"#fff0f5",lawngreen:"#7cfc00",lemonchiffon:"#fffacd",lightblue:"#add8e6",lightcoral:"#f08080",lightcyan:"#e0ffff",lightgoldenrodyellow:"#fafad2",lightgrey:"#d3d3d3",lightgreen:"#90ee90",lightpink:"#ffb6c1",lightsalmon:"#ffa07a",lightseagreen:"#20b2aa",lightskyblue:"#87cefa",lightslategray:"#778899",lightsteelblue:"#b0c4de",
lightyellow:"#ffffe0",lime:"#00ff00",limegreen:"#32cd32",linen:"#faf0e6",magenta:"#ff00ff",maroon:"#800000",mediumaquamarine:"#66cdaa",mediumblue:"#0000cd",mediumorchid:"#ba55d3",mediumpurple:"#9370d8",mediumseagreen:"#3cb371",mediumslateblue:"#7b68ee",mediumspringgreen:"#00fa9a",mediumturquoise:"#48d1cc",mediumvioletred:"#c71585",midnightblue:"#191970",mintcream:"#f5fffa",mistyrose:"#ffe4e1",moccasin:"#ffe4b5",navajowhite:"#ffdead",navy:"#000080",oldlace:"#fdf5e6",olive:"#808000",olivedrab:"#6b8e23",
orange:"#ffa500",orangered:"#ff4500",orchid:"#da70d6",palegoldenrod:"#eee8aa",palegreen:"#98fb98",paleturquoise:"#afeeee",palevioletred:"#d87093",papayawhip:"#ffefd5",peachpuff:"#ffdab9",peru:"#cd853f",pink:"#ffc0cb",plum:"#dda0dd",powderblue:"#b0e0e6",purple:"#800080",rebeccapurple:"#663399",red:"#ff0000",rosybrown:"#bc8f8f",royalblue:"#4169e1",saddlebrown:"#8b4513",salmon:"#fa8072",sandybrown:"#f4a460",seagreen:"#2e8b57",seashell:"#fff5ee",sienna:"#a0522d",silver:"#c0c0c0",skyblue:"#87ceeb",slateblue:"#6a5acd",
slategray:"#708090",snow:"#fffafa",springgreen:"#00ff7f",steelblue:"#4682b4",tan:"#d2b48c",teal:"#008080",thistle:"#d8bfd8",tomato:"#ff6347",turquoise:"#40e0d0",violet:"#ee82ee",wheat:"#f5deb3",white:"#ffffff",whitesmoke:"#f5f5f5",yellow:"#ffff00",yellowgreen:"#9acd32"};var eI={dt:"regex",Us:"attr_value_range",lz:"node_type"};function fI(a){return 0===(null==a?void 0:a.nodeType)}function gI(a){return 1===(null==a?void 0:a.nodeType)}function hI(a){const b=[];for(const [c,d]of Object.entries(a))switch(a=d,c){case "Op node id":a.selected&&b.push("id")}return b}function iI(a){const b=[];for(const [c,d]of Object.entries(a))switch(a=d,c){case "Layer node children count":a.selected&&b.push("#children");break;case "Layer node descendants count":a.selected&&b.push("#descendants")}return b}
function jI(a,b){if(fI(a))switch(b.toLowerCase()){case "id":return a.id;case "namespace":return kI(a)}else if(gI(a))switch(b.toLowerCase()){case "namespace":return kI(a);case "#children":return String((a.nsChildrenIds||[]).length);case "#descendants":return String((a.descendantsNodeIds||[]).length)}return""}function kI(a){return a.savedNamespace||a.namespace||"<root>"}function lI(){return Math.random().toString(36).slice(-6)}
function mI(a,b,c){let d=[];d=null==a?b.rootNodes.map(e=>e.id):a.nsChildrenIds||[];for(const e of d)(a=b.nodesById[e])&&gI(a)&&a.expanded&&((a.nsChildrenIds||[]).filter(f=>gI(b.nodesById[f])).every(f=>!b.nodesById[f].expanded)&&c.push(a.id),mI(a,b,c))}
function nI(a){var b=oI,c=pI,d=THREE,e=[];if(2===a.length)e=a;else if(3===a.length&&a[0].x===a[1].x&&a[1].x===a[2].x)e=a;else{e=!0;var f=0;for(var g=0;g<a.length-1;g++){var k=a[g+1]>a[g]?1:-1;if(0!==f&&f!==k){e=!1;break}f=k}const p=d.Vector3;if(e){a=b().x(t=>t.x).y(t=>t.y).curve(c)(a).split(/M|C/).filter(t=>""!==t).map(t=>t.split(",").map(v=>Number(v)));b=new p(a[0][0],a[0][1],0);c=new d.CurvePath;for(e=1;e<a.length;e++){var m=a[e];6===m.length&&(f=b,g=new p(m[0],m[1]),k=new p(m[2],m[3]),b=m=new p(m[4],
m[5]),f=new d.CubicBezierCurve3(f,g,k,m),c.add(f))}e=c.getPoints(25)}else a=a.map(t=>new p(t.x,t.y,0)),e=(new d.CatmullRomCurve3(a,!1,"catmullrom",.1)).getPoints(25)}return e}function qI(){const a=rI();return a?"INPUT"===a.tagName||"SELECT"===a.tagName||"TEXTAREA"===a.tagName||"true"===a.contentEditable:!1}function rI(a=document){return(a=a.activeElement)?a.shadowRoot?rI(a.shadowRoot):a:null}function sI(a){a=((a||{}).shape||"").replace(/ /g,"").replace(/\u00d7/g,"x");""===a&&(a="?");return a}
function tI(a,b=""){a=a.attrs||{};const c=[],d=new RegExp(b,"i");for(const e of Object.keys(a)){const f=e,g=a[e],k=[`${f}:${g}`,`${f}=${g}`];(""===b.trim()||k.some(m=>d.test(m)))&&c.push({key:f,value:g})}return c}
function uI(a,b){const c=a.incomingEdges||[],d=[];for(let k=0;k<Math.min(10,c.length);k++){var e=c[k],f=b.nodesById[e.sourceNodeId];const m=sI((f.outputsMetadata||{})[e.sourceNodeOutputId]);var g=k;e=((a.inputsMetadata||{})[e.targetNodeInputId]||{}).__tensor_tag;d.push({key:e?`Input${g}:${e} (${f.label})`:`Input${g} (${f.label})`,value:m})}10<c.length&&(a=c.length-10,d.push({key:`(${a} more input${1===a?"":"s"} omitted)`,value:"..."}));return d}
function vI(a){const b=[],c=Object.values(a.outputsMetadata||{});for(let e=0;e<Math.min(10,c.length);e++){var d=c[e];const f=sI(d);let g=`Output${e}`;"GraphInputs"===a.label?(d=d.tensor_name,null!=d&&(g=`${g} (${d})`)):(d=d.__tensor_tag)&&(g=`Output${e}:${d}`);b.push({key:g,value:f})}10<c.length&&(a=c.length-10,b.push({key:`(${a} more output${1===a?"":"s"} omitted)`,value:"..."}));return b}
function wI(a,b,c,d){const e=[],f=Object.keys(c).filter(g=>c[g].selected).filter(g=>g.startsWith("Node data provider: ")).map(g=>g.replace("Node data provider: ",""));d=Object.values(d).filter(g=>f.includes(g.runName));for(const g of d){let k,m;d=(null==(k=g.results||{})?void 0:null==(m=k[b][a.id])?void 0:m.strValue)||"-";e.push({key:g.runName,value:d})}return e}
function xI(a,b){a=a.split("/");b=b.split("/");let c="";for(let d=Math.min(a.length,b.length);0<d;d--){const e=b.slice(0,d).join("/");if(a.slice(0,d).join("/")===e){c=e;break}}return c}function yI(){var a=zI;return sa(function*(){return new Promise(b=>{const c=document.createElement("script");vd(c,a);c.onload=()=>{c.remove();b()};document.body.appendChild(c)})})}
function AI(a){return(new RegExp(/Only `SavedModel`s with \d+ MetaGraph are supported. Instead, it has \d+/)).test(a)?`${a}. Try using the "TF adapter (direct)" adapter.`:a}
function BI(a,b,c,d){const e=[],f=new Set;a.has("title")&&b.test(c.label)&&(e.push({type:"title"}),f.add("title"));if(a.has("list")){var g=CI(c);for(var k of Object.keys(g)){var m=g[k],p=`${k}=${m}`;if(b.test(`${k}:${m}`)||b.test(p))e.push({type:"list",Dw:k}),f.add("list")}}if(a.has("input")&&fI(c))for(const v of c.incomingEdges||[]){k=d.nodesById[v.sourceNodeId];b.test(k.label)&&(e.push({type:"input",ff:k.label}),f.add("input"));g=c.inputsMetadata||{};(m=(g[v.targetNodeInputId]||{}).__tensor_tag)&&
b.test(m)&&(e.push({type:"input",ff:m}),f.add("input"));k=(k.outputsMetadata||{})[v.sourceNodeOutputId]||{};for(const B of Object.keys(k)){if(B.startsWith("__"))continue;m=k[B];p=`${B}:${m}`;const G=`${B}=${m}`;if(b.test(m)||b.test(p)||b.test(G))e.push({type:"input",ff:m}),f.add("input")}g=g[v.targetNodeInputId]||{};for(const B of Object.keys(g))!B.startsWith("__")&&(k=g[B],m=`${B}:${k}`,p=`${B}=${k}`,b.test(k)||b.test(m)||b.test(p))&&(e.push({type:"input",ff:k}),f.add("input"))}if(a.has("output")&&
fI(c)){a=c.outputsMetadata||{};for(var t of c.outgoingEdges||[])c=d.nodesById[t.targetNodeId],b.test(c.label)&&(e.push({type:"output",ff:c.label}),f.add("output")),(c=(a[t.sourceNodeOutputId]||{}).__tensor_tag)&&b.test(c)&&(e.push({type:"output",ff:c}),f.add("output"));for(const v of Object.values(a))for(const B of Object.keys(v))!B.startsWith("__")&&(d=v[B],t=`${B}:${d}`,c=`${B}=${d}`,b.test(d)||b.test(t)||b.test(c))&&(e.push({type:"output",ff:d}),f.add("output"))}return{matches:e,matchTypes:f}}
function CI(a){let b={};fI(a)?(b=Object.assign({},a.attrs||{}),b.id=a.id):gI(a)&&(b={"#descendants":`${(a.descendantsNodeIds||[]).length}`,"#children":`${(a.nsChildrenIds||[]).length}`});return b}function DI(a){for(const b of a.filter(c=>"node_type"!==c.type))switch(b.type){case "regex":if(""!==b.queryRegex)return!0;break;case "attr_value_range":if(""!==b.attrName)return!0}return!1}
function EI(a){return a.map(b=>({queries:b.queries.map(c=>{switch(c.type){case "regex":let d=RegExp("","i");try{d=new RegExp(c.queryRegex,"i")}catch(e){console.warn("Failed to create regex",e)}return{type:"regex",queryRegex:d,matchTypes:new Set(c.matchTypes)};case "node_type":case "attr_value_range":return c}}),nodeType:b.nodeType,styles:b.styles}))}
function FI(a,b,c){let d=!0;for(const k of b)if("node_type"===k.type){b=!0;if(fI(a)&&"layer_nodes"===k.nodeType||gI(a)&&"op_nodes"===k.nodeType)b=!1;if(!b){d=!1;break}}else if("regex"===k.type){if(0===BI(k.matchTypes,k.queryRegex,a,c).matches.length){d=!1;break}}else if("attr_value_range"===k.type){if(""!==k.attrName){let m,p;b=k.attrName;var e=null!=(m=k.min)?m:Number.NEGATIVE_INFINITY,f=null!=(p=k.max)?p:Number.POSITIVE_INFINITY;const t=[];var g=CI(a)[b];null!=g&&(g=Number(g),!isNaN(g)&&g>=e&&g<=
f&&t.push({type:"list",Dw:b}));if(0===t.length){d=!1;break}}}else d=!1;return d};var GI="Processing nodes and edges;Processing layer namespaces;Processing layout data;Splitting large layers (if any);Laying out root layer;Finding identical layers".split(";");function HI(a,b){window.localStorage.setItem(a,b)}var II=class{};II.J=function(a){return new (a||II)};II.oa=Ld({la:II,aa:II.J,da:"root"});function JI(){return{deepestExpandedGroupNodeIds:[],selectedNodeId:"",selectedGraphId:"",selectedCollectionLabel:"",widthFraction:1,selected:!1}}function KI(a,b,c){a.i.update(d=>{const e=d.paneStates[c];if(!e)return d;e.deepestExpandedGroupNodeIds=b;return Object.assign({},d)})}function LI(a,b,c){a.i.update(d=>{const e=d.paneStates[c];if(!e)return d;e.selectedNodeId=b;return Object.assign({},d)})}
function MI(a,b,c,d){a.i.update(e=>{const f=e.paneStates[d];if(!f)return e;f.selectedGraphId=b;f.selectedCollectionLabel=c;return Object.assign({},e)})}function NI(a,b,c){a.i.update(d=>{const e=d.paneStates[c];if(!e)return d;e.flattenLayers=b;return Object.assign({},d)})}function OI(a){a.i.update(b=>{1<b.paneStates.length&&(b.paneStates=[b.paneStates[0]]);b.paneStates.push(JI());for(const c of b.paneStates)c.widthFraction=.5;return Object.assign({},b)})}
function PI(a,b){a.i.update(c=>{c.paneStates.splice(b,1);1===c.paneStates.length&&(c.paneStates[0].widthFraction=1);return Object.assign({},c)})}function QI(a,b){a.i.update(c=>{2===c.paneStates.length&&(c.paneStates[0].widthFraction=b,c.paneStates[1].widthFraction=1-b);return Object.assign({},c)})}function RI(a){a.i.update(b=>{2===b.paneStates.length&&(b.paneStates=[b.paneStates[1],b.paneStates[0]]);return Object.assign({},b)})}
function SI(a,b){a.i.update(c=>{for(let d=0;d<c.paneStates.length;d++)c.paneStates[d].selected=d===b;return Object.assign({},c)})}var TI=class{constructor(){this.i=ur({paneStates:[JI()]})}};TI.J=function(a){return new (a||TI)};TI.oa=Ld({la:TI,aa:TI.J});var UI=class{constructor(){const a=HH`/static_files/worker_bin.js`;this.i=new Worker(bd(a),void 0)}};UI.J=function(a){return new (a||UI)};UI.oa=Ld({la:UI,aa:UI.J});function VI(a){a.R.i.addEventListener("message",b=>{b=b.data;switch(b.eventType){case 1:WI(a,b.modelGraph,b.paneId)}})}function XI(a){let b={};a.i||(a=window.localStorage.getItem("model_explorer_show_on_node_item_types_v2"))&&(b=JSON.parse(a));return b}function YI(a){let b={};a.i||(a=window.localStorage.getItem("model_explorer_show_on_edge_item_types_v2"))&&(b=JSON.parse(a));return b}
function ZI(a,b){a.N.update(c=>{c=[...c];const d={};for(const e of b){const f={},g={};for(const t of e.graphs){if(null==t.id||""===t.id)t.id="unnamed_graph";const v=t.id;let B=d[v];null==B?B=d[v]=0:(t.id=`${t.id} (${B+1})`,g[v]=t.id);d[v]=B+1;f[t.id]=t;t.collectionLabel=e.label}for(const t of e.graphs)for(const v of t.nodes)if(null!=v.subgraphIds&&0<v.subgraphIds.length){v.subgraphIds=v.subgraphIds.map(B=>g[B]||B);null==t.subGraphIds&&(t.subGraphIds=[]);t.subGraphIds.push(...v.subgraphIds);for(const B of v.subgraphIds)f[B].parentGraphId=
t.id}const k=e.graphs.filter(t=>null==t.parentGraphId),m=[],p=(t,v=0)=>{let B=[];B=null==t?k:(t.subGraphIds||[]).map(G=>f[G]);B.sort((G,K)=>K.nodes.length-G.nodes.length);for(const G of B)G.level=v,m.push(G),p(G,v+1)};p();e.graphs=m}c.push(...b);return c})}
function $I(a,b,c=!1){const d=lI();a.O[d]=b;a.Ma.update(f=>{f[0].widthFraction=.5;f.push({id:d,widthFraction:.5,flattenLayers:c,showOnNodeItemTypes:{[d]:XI(a)},Vb:{[d]:YI(a)}});return[...f]});a.D.set({id:d,Lr:2});const e=aJ(a,d);OI(a.C);bJ(a,d);MI(a.C,b.id,b.collectionLabel||"",e);NI(a.C,c,e);b={eventType:0,graph:b,showOnNodeItemTypes:cJ(a,d,d),nodeDataProviderRuns:{},config:a.config?a.config():void 0,paneId:d,groupNodeChildrenCountThreshold:dJ(a),flattenLayers:c};a.R.i.postMessage(b)}
function aJ(a,b){return a.Ma().findIndex(c=>c.id===b)}function eJ(a,b,c=!1,d){if(null!=d){const e=fJ(a,b);e&&(e.Do=d)}gJ(a,b);b={eventType:0,graph:a.O[b],showOnNodeItemTypes:cJ(a,b,b),nodeDataProviderRuns:{},config:a.config?a.config():void 0,paneId:b,groupNodeChildrenCountThreshold:dJ(a),flattenLayers:c};a.R.i.postMessage(b)}
function hJ(a,b,c,d=!1,e){if(1===c&&1===a.Ma().length)$I(a,b);else{var f;if(((null==(f=a.Ma()[c].modelGraph)?void 0:f.id)||"")!==b.id){c=a.Ma()[c];c.Pg=void 0;c.qs=void 0;f=c.id;a.O[f]=b;MI(a.C,b.id,b.collectionLabel||"",aJ(a,f));if(null!=c.Zf&&0<c.Zf.length){const g=[...c.Zf];g[g.length-1].Ag=b.id;c.Zf=g}eJ(a,f,d,e)}}}function iJ(a,b,c=!1,d){hJ(a,b,aJ(a,a.G()),c,d)}function bJ(a,b){a.G.set(b);SI(a.C,aJ(a,b))}
function cJ(a,b,c){return(a=fJ(a,b))?JSON.parse(JSON.stringify((a.showOnNodeItemTypes||{})[c]||{})):{}}function dJ(a){let b=1E3;if(a.config){let c;b=(null==(c=a.config())?void 0:c.artificialLayerNodeCountThreshold)||1E3}null!=a.ra&&(b=Number(a.ra));return b}function fJ(a,b){return a.Ma().find(c=>c.id===b)}function gJ(a,b){a.Ma.update(c=>{for(const d of c)if(d.id===b){d.modelGraph=void 0;break}return[...c]})}function jJ(a){return fJ(a,a.G())}
function kJ(a,b){const c=jJ(a);if(c){a.Ma.update(e=>{c.flattenLayers=b;c.Pg=void 0;return[...e]});var d=aJ(a,c.id);NI(a.C,b,d);KI(a.C,[],d)}}function lJ(a,b){const c=fJ(a,b);if(c){var d=!0===c.flattenLayers;a.Ma.update(e=>{c.flattenLayers=!d;c.Pg=void 0;return[...e]});b=aJ(a,b);NI(a.C,!d,b);KI(a.C,[],b)}}function mJ(a,b){let c;return!0===(null==(c=fJ(a,b))?void 0:c.flattenLayers)}function nJ(a,b){(b=a.Ma()[b])&&bJ(a,b.id)}
function oJ(a,b,c){a.Ma.update(d=>{const e=fJ(a,b);if(!e)return d;e.Qg=c;return[...d]});LI(a.C,(null==c?void 0:c.nodeId)||"",aJ(a,b))}function pJ(a){let b;return null==(b=fJ(a,a.G()))?void 0:b.modelGraph}function qJ(a,b){let c;return null==(c=fJ(a,b))?void 0:c.modelGraph}function rJ(a){let b;return null==(b=a.Ma()[0])?void 0:b.modelGraph}function sJ(a,b){a.Ma.update(c=>{if(2!==c.length)return c;c[0].widthFraction=b;c[1].widthFraction=1-b;return[...c]});QI(a.C,b)}
function tJ(a,b,c){a.Ma.update(d=>{const e=fJ(a,b);if(!e)return d;e.qs=c;return[...d]})}function uJ(a,b){let c;return null==(c=fJ(a,b))?void 0:c.qs}function vJ(a,b,c){a.Ma.update(d=>{const e=fJ(a,b);if(!e)return d;e.Gn=c;return[...d]})}function wJ(a,b){a.Ma.update(c=>{const d=fJ(a,b);if(!d)return c;d.dD=void 0;return[...c]})}function xJ(a,b){delete a.O[b];a.Ma.update(c=>{const d=c.findIndex(e=>e.id===b);0<=d&&(c.splice(d,1),PI(a.C,d));c[0].widthFraction=1;return[...c]});bJ(a,a.Ma()[0].id)}
function yJ(a){a.Ma.update(b=>2!==b.length?b:[b[1],b[0]]);RI(a.C)}function zJ(a,b,c,d){a.Ma.update(e=>{const f=fJ(a,d);f&&(null==f.Rg&&(f.Rg={}),null==f.Rg[c]&&(f.Rg[c]=[]),f.Rg[c].push(b));return[...e]})}function AJ(a,b,c,d){a.Ma.update(e=>{const f=fJ(a,d);f&&f.Rg&&f.Rg[c]&&f.Rg[c].splice(b,1);return[...e]})}function BJ(a,b){for(const c of a.N())for(const d of c.graphs)if(d.id===b)return d}
function CJ(a,b,c,d,e){a.Ma.update(f=>{const g=fJ(a,b);if(!g)return f;const k=[...(g.Zf||[])];0===k.length?k.push({Ag:c,jb:e}):k[k.length-1]={Ag:c,jb:e};k.push({Ag:d});g.Zf=k;return[...f]})}function DJ(a,b,c){a.Ma.update(d=>{const e=fJ(a,b);if(!e)return d;let f=[...(e.Zf||[])];f.splice(c+1);1===f.length&&(f=[]);e.Zf=f;return[...d]})}function EJ(a,b,c){a.Ma.update(d=>{const e=fJ(a,b);if(!e)return d;e.Pg=c;return[...d]})}
function FJ(a,b){a.Ma.update(c=>{const d=fJ(a,b);if(!d)return c;d.Pg={results:{}};return[...c]})}
function GJ(a,b,c,d){a.Ma.update(e=>{const f=fJ(a,b);if(!f)return e;f.showOnNodeItemTypes||(f.showOnNodeItemTypes={});null==f.showOnNodeItemTypes[c]&&(f.showOnNodeItemTypes[c]={});null==f.showOnNodeItemTypes[c][d]&&(f.showOnNodeItemTypes[c][d]={selected:!1});const g=f.showOnNodeItemTypes[c][d].selected;f.showOnNodeItemTypes[c]=Object.assign({},f.showOnNodeItemTypes[c]);f.showOnNodeItemTypes[c][d].selected=!g;f.showOnNodeItemTypes=Object.assign({},f.showOnNodeItemTypes);return[...e]})}
function HJ(a,b,c,d){a.Ma.update(e=>{const f=fJ(a,b);if(!f)return e;f.Vb||(f.Vb={});null==f.Vb[c]&&(f.Vb[c]={});null==f.Vb[c][d]&&(f.Vb[c][d]={selected:!1});const g=f.Vb[c][d].selected;f.Vb[c]=Object.assign({},f.Vb[c]);f.Vb[c][d].selected=!g;f.Vb=Object.assign({},f.Vb);return[...e]})}
function IJ(a,b,c,d,e){a.Ma.update(f=>{const g=fJ(a,b);if(!g)return f;g.showOnNodeItemTypes||(g.showOnNodeItemTypes={});null==g.showOnNodeItemTypes[c]&&(g.showOnNodeItemTypes[c]={});null==g.showOnNodeItemTypes[c][d]&&(g.showOnNodeItemTypes[c][d]={selected:!1});g.showOnNodeItemTypes[c][d].filterRegex=e;g.showOnNodeItemTypes=Object.assign({},g.showOnNodeItemTypes);return[...f]})}
function JJ(a,b,c,d){a.Ma.update(e=>{const f=fJ(a,b);if(!f)return e;f.showOnNodeItemTypes||(f.showOnNodeItemTypes={});f.showOnNodeItemTypes=Object.assign({},f.showOnNodeItemTypes);f.showOnNodeItemTypes[c]=d;return[...e]})}function KJ(a,b,c,d){a.Ma.update(e=>{const f=fJ(a,b);if(!f)return e;f.Vb||(f.Vb={});f.Vb=Object.assign({},f.Vb);f.Vb[c]=d;return[...e]})}
function LJ(a,b){a.Ma.update(c=>{for(const d of c){d.showOnNodeItemTypes=Object.assign({},d.showOnNodeItemTypes);for(const e of Object.keys(d.showOnNodeItemTypes))for(const f of b){const g=d.showOnNodeItemTypes[e][f];g&&(g.selected=!1)}}return[...c]})}function MJ(a,b,c){return(a=fJ(a,b))?JSON.parse(JSON.stringify((a.Vb||{})[c]||{})):{}}function WI(a,b,c){a.Ma.update(d=>{for(const e of d)if(e.id===c){e.modelGraph=b;break}return[...d]});a.ta.next({fG:aJ(a,c),modelGraph:b})}
var NJ=class{constructor(a,b,c){this.C=b;this.R=c;this.N=ur([]);this.F=ur();this.D=ur();this.ea=new aj;this.va=new aj;this.ia=new aj;this.T=new aj;this.ba=new aj;this.ma=new aj;this.config=ur();this.K=ur();this.Ma=ur([{id:lI(),widthFraction:1}]);this.G=ur(this.Ma()[0].id);this.ta=new aj;this.Mg=ur([]);this.O={};VI(this);this.D.set({id:this.Ma()[0].id,Lr:2});a=new URLSearchParams(document.location.search);this.i="1"===a.get("test_mode");this.ra=a.get("groupNodeChildrenCountThreshold");a=this.Ma()[0];
a.showOnNodeItemTypes={[a.id]:XI(this)};a.Vb={[a.id]:YI(this)}}};NJ.J=function(a){return new (a||NJ)(q(II),q(TI),q(UI))};NJ.oa=Ld({la:NJ,aa:NJ.J});var OJ=class{constructor(){this.Aw=Math.random().toString(36).slice(-6);this.MB=`url(#${this.Aw})`}};OJ.J=function(a){return new (a||OJ)};
OJ.Ca=Gf({type:OJ,ga:[["me-logo"]],ja:!0,features:[Jr],ya:19,za:2,Ba:["width;24;height;24;viewBox;0 0 256 256;fill;none;xmlns;http://www.w3.org/2000/svg".split(";"),"width 256 height 256 fill none".split(" "),["d","M229 64.5V192.5L128 248.5L127.5 115.5L229 64.5Z"],["d","M208 76V99L128 141.5V116L208 76Z","fill","white"],["d","M208 122.5V141.5L128 182.5V161.5L208 122.5Z","fill","white"],["d","M208 164.5V183L128 225.5V206L208 164.5Z","fill","white"],["d","M149 106V214.5L127 226V117.5L149 106Z","fill",
"white"],["d","M26 61L47.5 72.5V200L26 187V61Z","fill","#FBBC04"],["d","M125.5 10.5L145.5 21V60.5L125.5 56.5V10.5Z","fill","#DCA810"],["d","M164 31L184 41.5V81L164 78V31Z","fill","#309C4D"],["d","M164 31L184 41.5L87 94L65 82L164 31Z","fill","#11792D"],["d","M208 54.5L229 64.5L128 116L107 105L208 54.5Z","fill","#2C5CAC"],["d","M125.5 10.5L145.5 21L47.5 72.5L26 61L125.5 10.5Z","fill","#C78B15"],["d","M65 82L87 94V224L65 210.5V82Z","fill","#34A853"],["d","M107 105L128 116V248.5L107 236V105Z","fill",
"#4285F4"],"x1 144.5 y1 232 x2 219 y2 69.5 gradientUnits userSpaceOnUse".split(" "),["stop-color","#4285F4"],["offset","1","stop-color","#2C5CAC"]],sa:function(a,b){a&1&&(eh(),R(0,"svg",0),Kq(1,"rect",1)(2,"path",2)(3,"path",3)(4,"path",4)(5,"path",5)(6,"path",6)(7,"path",7)(8,"path",8)(9,"path",9)(10,"path",10)(11,"path",11)(12,"path",12)(13,"path",13)(14,"path",14),R(15,"defs")(16,"linearGradient",15),Kq(17,"stop",16)(18,"stop",17),S()()());a&2&&(D(2),Ip("fill",b.MB),D(14),Ip("id",b.Aw))},styles:["[_nghost-%COMP%] {display: flex; align-items: center; justify-content: center}"]});var PJ=[Ry("transformPanel",[Uy("void",Ty({opacity:0,transform:"scale(1, 0.8)"})),Vy("void => showing",Sy("120ms cubic-bezier(0, 0, 0.2, 1)",Ty({opacity:1,transform:"scale(1, 1)"}))),Vy("* => void",Sy("100ms linear",Ty({opacity:0})))])];function QJ(a,b){let c=[b];c.push(...RJ(a,b));qu(a.i,...c.map(d=>a.C(d)))}function SJ(a,b){let c=[b];c.push(...RJ(a,b));a.i.select(...c.map(d=>a.C(d)))}var TJ=class{constructor(){this.i=new su(!0)}toggle(a){this.i.toggle(this.C(a))}expand(a){this.i.select(this.C(a))}collapse(a){qu(this.i,this.C(a))}ul(a){return ru(this.i,this.C(a))}C(a){return this.gm?this.gm(a):a}};function RJ(a,b){var c=a.D.indexOf(b);const d=[];for(c+=1;c<a.D.length&&a.xe(b)<a.xe(a.D[c]);c++)d.push(a.D[c]);return d}function UJ(a){a.i.select(...a.D.map(b=>a.C(b)))}var VJ=class extends TJ{constructor(a,b){super();this.xe=a;this.F=b;this.options=void 0}};var WJ=new df("CDK_TREE_NODE_OUTLET_NODE"),XJ=class{constructor(a,b){this.eg=a;this.i=b}};XJ.J=function(a){return new (a||XJ)(y(ip),y(WJ,8))};XJ.Ea=Of({type:XJ,ga:[["","cdkTreeNodeOutlet",""]],ja:!0});var YJ=class{constructor(a){this.ca=a}},ZJ=class{constructor(a){this.sa=a}};ZJ.J=function(a){return new (a||ZJ)(y($q))};ZJ.Ea=Of({type:ZJ,ga:[["","cdkTreeNodeDef",""]],inputs:{Lo:[0,"cdkTreeNodeDefWhen","when"]},ja:!0});function $J(a,b,c=a.N,d=a.Li.eg,e){if(c=c.ln(b))Ur(c,(f,g,k)=>{if(null==f.He){f=b[k];g=a.R(f,k);const m=new YJ(f);a.pd.xe?m.level=a.pd.xe(f):"undefined"!==typeof e&&a.D.has(e)?m.level=a.D.get(e)+1:m.level=0;a.D.set(f,m.level);(d?d:a.Li.eg).vd(g.sa,m,k);aK&&(aK.data=f)}else null==k?(d.remove(g),a.D.delete(f.item)):(f=d.get(g),d.move(f,k))}),$m(a.Aa)}
var bK=class{get Fh(){return this.i}set Fh(a){this.i!==a&&this.T(a)}constructor(a,b){this.G=a;this.Aa=b;this.F=new aj;this.D=new Map;this.Cy=new cj({start:0,end:Number.MAX_VALUE})}Eb(){this.N=this.G.find([]).create(this.gm)}ua(){this.Li.eg.clear();this.Cy.complete();this.F.next();this.F.complete();this.C&&(this.C.unsubscribe(),this.C=null)}Kw(){this.O=this.Ki.filter(a=>!a.Lo)[0];this.Fh&&this.Ki&&!this.C&&this.K()}T(a){this.C&&(this.C.unsubscribe(),this.C=null);a||this.Li.eg.clear();this.i=a;this.Ki&&
this.K()}K(){let a;pu(this.i)?a=this.i.connect(this):Ck(this.i)?a=this.i:Array.isArray(this.i)&&(a=hj(this.i));a&&(this.C=C(a,Jo(this.F)).subscribe(b=>$J(this,b)))}R(a,b){return 1===this.Ki.length?this.Ki.first:this.Ki.find(c=>c.Lo&&c.Lo(b,a))||this.O}};bK.J=function(a){return new (a||bK)(y(cs),y(Pr))};
bK.Ca=Gf({type:bK,ga:[["cdk-tree"]],cc:function(a,b,c){a&1&&qr(c,ZJ,5);if(a&2){let d;sr(d=tr())&&(b.Ki=d)}},eb:function(a,b){a&1&&rr(XJ,7);if(a&2){let c;sr(c=tr())&&(b.Li=c.first)}},Ja:["role","tree",1,"cdk-tree"],inputs:{Fh:"dataSource",pd:"treeControl",gm:"trackBy"},hb:["cdkTree"],ja:!0,features:[Jr],ya:1,za:0,Ba:[["cdkTreeNodeOutlet",""]],sa:function(a){a&1&&Nq(0,0)},Ga:[XJ],ob:2});
var dK=class{get role(){return"treeitem"}set role(a){this.qa.P.setAttribute("role",a)}get data(){return this.oh}set data(a){a!==this.oh&&(this.oh=a,this.GA(),this.lp.next())}get ul(){return this.Df.pd.ul(this.oh)}get level(){return this.Df.pd.xe?this.Df.pd.xe(this.oh):this.xA}constructor(a,b){this.qa=a;this.Df=b;this.Fa=new aj;this.lp=new aj;aK=this;this.role="treeitem"}Eb(){let a=this.qa.P.parentElement;for(;a&&!cK(a);)a=a.parentElement;this.xA=a?a.classList.contains("cdk-nested-tree-node")?xs(a.getAttribute("aria-level")):
0:-1;this.qa.P.setAttribute("aria-level",`${this.level+1}`)}ua(){aK===this&&(aK=null);this.lp.complete();this.Fa.next();this.Fa.complete()}focus(){this.qa.P.focus()}GA(){this.role="treeitem"}},aK=null;dK.J=function(a){return new (a||dK)(y(qi),y(bK))};dK.Ea=Of({type:dK,ga:[["cdk-tree-node"]],Ja:[1,"cdk-tree-node"],Xa:1,Ha:function(a,b){a&2&&Ip("aria-expanded",b.ul)},inputs:{role:"role"},hb:["cdkTreeNode"],ja:!0});
function cK(a){a=a.classList;return!!((null==a?0:a.contains("cdk-nested-tree-node"))||(null==a?0:a.contains("cdk-tree")))};const eK=/([A-Za-z%]+)$/;
var fK=class{get level(){return this.D}set level(a){this.N(a)}get tl(){return this.C}set tl(a){this.K(a)}constructor(a,b,c,d){this.G=a;this.Df=b;this.R=c;this.F=d;this.Fa=new aj;this.O="px";this.C=40;this.i();d&&C(d.vb,Jo(this.Fa)).subscribe(()=>this.i(!0));a.lp.subscribe(()=>this.i())}ua(){this.Fa.next();this.Fa.complete()}ba(){var a=this.G.data&&this.Df.pd.xe?this.Df.pd.xe(this.G.data):null;a=null==this.D?a:this.D;return"number"===typeof a?`${a*this.C}${this.O}`:null}i(a=!1){const b=this.ba();if(b!==
this.T||a){a=this.R.P;const c=this.F&&"rtl"===this.F.value?"paddingRight":"paddingLeft";a.style[c]=b||"";a.style["paddingLeft"===c?"paddingRight":"paddingLeft"]="";this.T=b}}N(a){this.D=isNaN(a)?null:a;this.i()}K(a){let b=a,c="px";"string"===typeof a&&(a=a.split(eK),b=a[0],c=a[1]||c);this.O=c;this.C=xs(b);this.i()}};fK.J=function(a){return new (a||fK)(y(dK),y(bK),y(qi),y(lu,8))};
fK.Ea=Of({type:fK,ga:[["","cdkTreeNodePadding",""]],inputs:{level:[2,"cdkTreeNodePadding","level",xs],tl:[0,"cdkTreeNodePaddingIndent","indent"]},ja:!0,features:[Hp]});var gK=class{constructor(a,b){this.Df=a;this.i=b;this.recursive=!1}NA(a){if(this.recursive){var b=this.Df.pd,c=this.i.data;ru(b.i,b.C(c))?QJ(b,c):SJ(b,c)}else this.Df.pd.toggle(this.i.data);a.stopPropagation()}};gK.J=function(a){return new (a||gK)(y(bK),y(dK))};gK.Ea=Of({type:gK,ga:[["","cdkTreeNodeToggle",""]],Ha:function(a,b){a&1&&V("click",function(c){return b.NA(c)})},inputs:{recursive:[2,"cdkTreeNodeToggleRecursive","recursive",ws]},ja:!0,features:[Hp]});var hK=class{};hK.J=function(a){return new (a||hK)};hK.Wa=Mf({type:hK});hK.Va=Md({});function iK(a,b){let c=[];b.forEach(d=>a.C(d,0,c,[]));return c}function jK(a,b,c){let d=[],e=[!0];b.forEach(f=>{let g=!0;for(let k=0;k<=a.xe(f);k++)g=g&&e[k];g&&d.push(f);a.F(f)&&(e[a.xe(f)+1]=c.ul(f))});return d}
var kK=class{constructor(a,b,c,d){this.G=a;this.xe=b;this.F=c;this.D=d}C(a,b,c,d){const e=this.G(a,b);c.push(e);this.F(e)&&(a=this.D(a))&&(Array.isArray(a)?this.i(a,b,c,d):C(a,co()).subscribe(f=>{this.i(f,b,c,d)}));return c}i(a,b,c,d){a.forEach((e,f)=>{let g=d.slice();g.push(f!=a.length-1);this.C(e,b+1,c,g)})}},lK=class extends ou{get data(){return this.oh.value}set data(a){this.oh.next(a);this.i.next(iK(this.F,this.data));this.C.D=this.i.value}constructor(a,b){super();this.C=a;this.F=b;this.i=new cj([]);
this.D=new cj([]);this.oh=new cj([])}connect(a){return C(pk(a.Cy,this.C.i.Ah,this.i),vj(()=>{this.D.next(jK(this.F,this.i.value,this.C));return this.D.value}))}};var mK=class extends dK{constructor(a,b,c){super(a,b);this.disabled=!1;this.tabIndex=Number(c)||0}Eb(){super.Eb()}ua(){super.ua()}};mK.J=function(a){return new (a||mK)(y(qi),y(bK),xh("tabindex"))};mK.Ea=Of({type:mK,ga:[["mat-tree-node"]],Ja:[1,"mat-tree-node"],inputs:{disabled:[2,"disabled","disabled",ws],tabIndex:[2,"tabIndex","tabIndex",a=>null==a?0:xs(a)]},hb:["matTreeNode"],ja:!0,features:[Hr([{na:dK,zb:mK}]),Hp,Ap]});var nK=class extends ZJ{};
nK.J=(()=>{let a;return function(b){return(a||(a=Lh(nK)))(b||nK)}})();nK.Ea=Of({type:nK,ga:[["","matTreeNodeDef",""]],inputs:{Lo:[0,"matTreeNodeDefWhen","when"],data:[0,"matTreeNode","data"]},ja:!0,features:[Hr([{na:ZJ,zb:nK}]),Ap]});var oK=class{constructor(a,b){this.eg=a;this.i=b}};oK.J=function(a){return new (a||oK)(y(ip),y(WJ,8))};oK.Ea=Of({type:oK,ga:[["","matTreeNodeOutlet",""]],ja:!0,features:[Hr([{na:XJ,zb:oK}])]});var pK=class extends fK{get level(){return this.D}set level(a){this.N(a)}get tl(){return this.C}set tl(a){this.K(a)}};pK.J=(()=>{let a;return function(b){return(a||(a=Lh(pK)))(b||pK)}})();pK.Ea=Of({type:pK,ga:[["","matTreeNodePadding",""]],inputs:{level:[2,"matTreeNodePadding","level",xs],tl:[0,"matTreeNodePaddingIndent","indent"]},ja:!0,features:[Hr([{na:fK,zb:pK}]),Hp,Ap]});var qK=class extends gK{};qK.J=(()=>{let a;return function(b){return(a||(a=Lh(qK)))(b||qK)}})();qK.Ea=Of({type:qK,ga:[["","matTreeNodeToggle",""]],inputs:{recursive:[0,"matTreeNodeToggleRecursive","recursive"]},ja:!0,features:[Hr([{na:gK,zb:qK}]),Ap]});var rK=class extends bK{constructor(){super(...arguments);this.Li=void 0}};rK.J=(()=>{let a;return function(b){return(a||(a=Lh(rK)))(b||rK)}})();
rK.Ca=Gf({type:rK,ga:[["mat-tree"]],eb:function(a,b){a&1&&rr(oK,7);if(a&2){let c;sr(c=tr())&&(b.Li=c.first)}},Ja:["role","tree",1,"mat-tree"],hb:["matTree"],ja:!0,features:[Hr([{na:bK,zb:rK}]),Ap,Jr],ya:1,za:0,Ba:[["matTreeNodeOutlet",""]],sa:function(a){a&1&&Nq(0,0)},Ga:[oK],styles:[".mat-tree{display:block;background-color:var(--mat-tree-container-background-color)}.mat-tree-node,.mat-nested-tree-node{color:var(--mat-tree-node-text-color);font-family:var(--mat-tree-node-text-font);font-size:var(--mat-tree-node-text-size);font-weight:var(--mat-tree-node-text-weight)}.mat-tree-node{display:flex;align-items:center;flex:1;word-wrap:break-word;min-height:var(--mat-tree-node-min-height)}.mat-nested-tree-node{border-bottom-width:0}\n"],ob:2});var sK=class{};sK.J=function(a){return new (a||sK)};sK.Wa=Mf({type:sK});sK.Va=Md({imports:[hK,fz,fz]});const tK=["tree"],uK=a=>({node:a});function vK(a){a&1&&Z(0);a&2&&(a=Y().ca,zr(" ",a.Ui," (",a.label,") "))}function wK(a){a&1&&Z(0);a&2&&(a=Y().ca,yr(" ",a.label," "))}function xK(a){a&1&&Nq(0)}function yK(a){a&1&&yp(0,xK,1,0,"ng-container",15);if(a&2){a=Y().ca;Y();const b=wr(5);H("ngTemplateOutlet",b)("ngTemplateOutletContext",Mr(uK,a))}}function zK(a){a&1&&(R(0,"div",16),Z(1," Hover for values "),S())}
function AK(a,b){a&1&&(R(0,"tr")(1,"td",19)(2,"mat-icon",20),Z(3,"circle"),S(),Z(4),S(),R(5,"td",21),Z(6),S()());if(a&2){a=b.ca;b=Y(2).ca;const c=Y();lq("search-match",BK(c,b.metadata[a]));D(4);yr(" ",a,"");D(2);xr(b.metadata[a])}}function CK(a){a&1&&(R(0,"table",17),yp(1,AK,7,4,"tr",18),S());a&2&&(a=Y().ca,Y(),D(),H("ngForOf",DK(a)))}function EK(a){a&1&&(R(0,"div",22)(1,"mat-icon",23),Z(2,"my_location"),S()());a&2&&(a=Y(2),H("matTooltip",a.Bl)("matTooltipPosition",a.Hs))}
function FK(a){a&1&&(R(0,"div",25),Z(1),S());a&2&&(a=Y(3),D(),yr(" Showing at most ",a.hl()," elements "))}function GK(a){a&1&&(R(0,"div",24),yp(1,FK,2,1,"div",25),R(2,"div",26),Z(3),S()());if(a&2){a=Y().ca;const b=Y();D();Cq(0!==b.hl()?1:-1);D(2);a=a.node;xr(a?fI(a)?(a.attrs||{}).__value||"<empty>":"":"")}}
function HK(a,b){if(a&1){const c=Tg();R(0,"mat-tree-node",6)(1,"div",7);V("click",function(d){const e=u(c).ca,f=Y();return x(f.il(e,d.altKey))});R(2,"div",8)(3,"div",9)(4,"div",10)(5,"span",11);yp(6,vK,1,2)(7,wK,1,1);S();yp(8,yK,1,4,"ng-container");S();yp(9,zK,2,0,"div",12);S();yp(10,CK,2,1,"table",13);S();yp(11,EK,3,2,"div",14);S();yp(12,GK,4,2,"ng-template",null,2,Nr);S()}if(a&2){a=b.ca;b=wr(13);const c=Y();lq("has-locator",a.Ad)("has-values",IK(a))("highlight",a.Kn)("has-metadata",null!=a.metadata&&
0<Object.keys(a.metadata).length);H("xapInlineDialog",b)("overlaySize",c.gq)("overlayPositions",c.gv)("hoverDelayMs",50)("xapInlineDialogDisabled",!IK(a))("matTreeNodePaddingIndent",c.sy);Ip("data-id",a.nodeId);D(2);lq("has-extra-data",null!=a.vg);D(3);lq("color-bold",c.cv)("search-match",BK(c,a.label,a.Ui));D();Cq(a.Ui?6:7);D(2);Cq(a.vg?8:-1);D();H("ngIf",IK(a));D();H("ngIf",null!=a.metadata&&0<Object.keys(a.metadata).length);D();H("ngIf",a.Ad&&c.Ad)}}function JK(a){a&1&&Nq(0)}
function KK(a){a&1&&yp(0,JK,1,0,"ng-container",15);if(a&2){a=Y().ca;Y();const b=wr(5);H("ngTemplateOutlet",b)("ngTemplateOutletContext",Mr(uK,a))}}function LK(a){a&1&&(R(0,"div",22)(1,"mat-icon",23),Z(2,"my_location"),S()());a&2&&(a=Y(2),H("matTooltip",a.Bl)("matTooltipPosition",a.Hs))}
function MK(a,b){if(a&1){const c=Tg();R(0,"mat-tree-node",27)(1,"div",28);V("click",function(d){const e=u(c).ca,f=Y();return x(f.il(e,d.altKey))});R(2,"div",9)(3,"button",29)(4,"mat-icon",30);Z(5);S()();R(6,"div",10);Z(7);yp(8,KK,1,4,"ng-container");S()();yp(9,LK,3,2,"div",14);S()()}a&2&&(a=b.ca,b=Y(),lq("has-locator",a.Ad),H("matTreeNodePaddingIndent",b.sy),Ip("data-id",a.nodeId),D(),lq("highlight",a.QF),D(),lq("has-extra-data",null!=a.vg),D(),Ip("aria-label","Toggle "+a.label),D(2),yr(" ",b.pd.ul(a)?
"keyboard_arrow_down":"chevron_right"," "),D(2),yr(" ",a.label," "),D(),Cq(a.vg?8:-1),D(),H("ngIf",a.Ad&&b.Ad))}function NK(a,b){a&1&&(R(0,"div",32)(1,"mat-icon"),Z(2),S()());a&2&&(a=b.ca,Y(2),H("matTooltip",OK(a)),D(2),xr(a))}function PK(a,b){a&1&&(R(0,"div",31),Hq(1,NK,3,2,"div",32,Fq),S());a&2&&(a=b.node,D(),Jq(a.vg.matchTypes))}function BK(a,b,c){return a.C?null!=a.C.find(d=>d.ff===b||d.ff===c):!1}function DK(a){return Object.keys(a.metadata||{}).filter(b=>!b.startsWith("__")).sort()}
function IK(a){a=a.node;return a?fI(a)&&(a=a.attrs||{},a.__value)?"DATA_ELIDED"!==a.__value:!1:!1}function OK(a){switch(a){case "title":return"Node label matched";case "list":return"Node attribute(s) matched";case "input":return"Input(s) matched";case "output":return"Output(s) matched";default:return""}}function QK(a,b){a.data=b;a.Fh.data=a.data;UJ(a.pd);Zm(a.D)}
var RK=class{constructor(a,b){this.i=a;this.D=b;this.Eo=!1;this.rendererId="";this.Hs="left";this.Ad=!0;this.cv=!1;this.ge=new Dk;this.gq={minWidth:100};this.gv=[{bb:"start",cb:"top",La:"end",Sa:"top"}];this.Bl="Click: locate\nAlt+click: select";this.F=(c,d)=>({nodeId:c.nodeId,node:c.node,un:!!c.children&&0<c.children.length,label:c.label,Ui:c.Ui,level:d,Ad:c.Ad,Kn:c.Kn,metadata:c.metadata,vg:c.vg});this.C=[];this.sy=8;this.pd=new VJ(c=>c.level,c=>c.un);this.G=new kK(this.F,c=>c.level,c=>c.un,c=>
c.children);this.Fh=new lK(this.pd,this.G)}rc(){null!=this.data&&(this.Fh.data=this.data,UJ(this.pd))}il(a,b){a.Ad&&(this.i.F.set({nodeId:a.nodeId||"",rendererId:this.rendererId,zd:a.un,select:b}),this.ge.emit({}))}ZB(a,b){return b.un}hl(){let a,b;return null!=(b=null==(a=this.i.config())?void 0:a.maxConstValueCount)?b:0}};RK.J=function(a){return new (a||RK)(y(NJ),y(Pr))};
RK.Ca=Gf({type:RK,ga:[["io-tree"]],eb:function(a,b){a&1&&rr(tK,5);if(a&2){let c;sr(c=tr())&&(b.qy=c.first)}},inputs:{data:"data",Eo:"solidBackground",rendererId:"rendererId",Hs:"tooltipPosition",Ad:"showLocator",cv:"colorBoldNodeLabel"},outputs:{ge:"onClose"},ja:!0,features:[Cg,Jr],ya:6,za:7,Ba:[["tree",""],["matchTypes",""],["constValuesPopup",""],[1,"io-tree",3,"dataSource","treeControl"],["class","leaf","dialogLabel","const values popup","matTreeNodePadding","",3,"has-locator","has-values","highlight",
"has-metadata","xapInlineDialog","overlaySize","overlayPositions","hoverDelayMs","xapInlineDialogDisabled","matTreeNodePaddingIndent",4,"matTreeNodeDef"],["matTreeNodePadding","",3,"has-locator","matTreeNodePaddingIndent",4,"matTreeNodeDef","matTreeNodeDefWhen"],["dialogLabel","const values popup","matTreeNodePadding","",1,"leaf",3,"xapInlineDialog","overlaySize","overlayPositions","hoverDelayMs","xapInlineDialogDisabled","matTreeNodePaddingIndent"],[1,"edge-node",3,"click"],[1,"label-and-metadata"],
[1,"label-container"],[1,"label"],[1,"node-label"],["class","hover-for-values-label",4,"ngIf"],["class","metadata-table",4,"ngIf"],["class","locator-container","matTooltipClass","multiline-tooltip-left",3,"matTooltip","matTooltipPosition",4,"ngIf"],[4,"ngTemplateOutlet","ngTemplateOutletContext"],[1,"hover-for-values-label"],[1,"metadata-table"],[3,"search-match",4,"ngFor","ngForOf"],[1,"key"],[1,"bullet"],[1,"value"],["matTooltipClass","multiline-tooltip-left",1,"locator-container",3,"matTooltip",
"matTooltipPosition"],[1,"locator-icon"],[1,"model-explorer-const-values-popup"],[1,"values-count-msg"],[1,"content"],["matTreeNodePadding","",3,"matTreeNodePaddingIndent"],[1,"expandable-tree-node",3,"click"],["mat-icon-button","","matTreeNodeToggle","",1,"expand-icon-button"],[1,"expander"],[1,"match-types-container"],[1,"extra-label-container",3,"matTooltip"]],sa:function(a,b){a&1&&(R(0,"mat-tree",3,0),yp(2,HK,14,26,"mat-tree-node",4)(3,MK,10,13,"mat-tree-node",5),S(),yp(4,PK,3,0,"ng-template",
null,1,Nr));a&2&&(lq("solid-background",b.Eo),H("dataSource",b.Fh)("treeControl",b.pd)("@transformPanel","showing")("@.disabled",!b.Eo),D(3),H("matTreeNodeDefWhen",b.ZB))},Ga:[et,Ws,$s,dt,uB,tB,rB,$F,tE,YF,aI,$H,sK,nK,pK,qK,rK,mK,zG,wG],styles:[".io-tree[_ngcontent-%COMP%]{background-color:transparent;padding-top:4px}.io-tree.solid-background[_ngcontent-%COMP%]{-webkit-transform-origin:top center;transform-origin:top center;background-color:#fff;border:1px solid #ccc;border-radius:4px;padding-bottom:8px;min-width:270px;box-shadow:0 4px 6px -1px rgba(0,0,0,.1),0 2px 4px -2px rgba(0,0,0,.1)}.io-tree[_ngcontent-%COMP%]   mat-tree-node.has-locator[_ngcontent-%COMP%], .io-tree[_ngcontent-%COMP%]   mat-tree-node.has-values[_ngcontent-%COMP%]{cursor:pointer}.io-tree[_ngcontent-%COMP%]   mat-tree-node.has-locator[_ngcontent-%COMP%]:hover, .io-tree[_ngcontent-%COMP%]   mat-tree-node.has-values[_ngcontent-%COMP%]:hover{background-color:#f3f3f3}.io-tree[_ngcontent-%COMP%]   mat-tree-node.highlight[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{color:#00639b;font-weight:500}.io-tree[_ngcontent-%COMP%]   mat-tree-node[_ngcontent-%COMP%]:not(:last-child).has-metadata.leaf{margin-bottom:6px}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:start;-webkit-align-items:flex-start;-moz-box-align:start;-ms-flex-align:start;align-items:flex-start;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;width:100%;-moz-box-sizing:border-box;box-sizing:border-box;padding-right:12px;padding-left:27px}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]:hover   .locator-container[_ngcontent-%COMP%]{opacity:.8}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata.has-extra-data[_ngcontent-%COMP%]{width:100%}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata.has-extra-data[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{width:100%;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .label-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .label-container[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .label-container[_ngcontent-%COMP%]   .node-label.color-bold[_ngcontent-%COMP%]{color:#00639b;font-weight:500}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .label-container[_ngcontent-%COMP%]   .node-label.search-match[_ngcontent-%COMP%]{background-color:#f5e25a}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .hover-for-values-label[_ngcontent-%COMP%]{text-decoration:underline;-webkit-text-decoration-style:dotted;-moz-text-decoration-style:dotted;text-decoration-style:dotted;color:#999;margin-left:8px}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]{border-spacing:0;border-collapse:collapse;padding:0;font-size:11px;margin-top:2px}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   tr[_ngcontent-%COMP%]{vertical-align:text-top}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   tr.search-match[_ngcontent-%COMP%]{background-color:#f5e25a}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   tr[_ngcontent-%COMP%]   mat-icon.bullet[_ngcontent-%COMP%]{font-size:4px;width:5px;height:5px;color:#bbb;margin-right:2px}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   td.key[_ngcontent-%COMP%]{color:#999;padding-right:4px;white-space:nowrap;line-height:12px}.io-tree[_ngcontent-%COMP%]   .edge-node[_ngcontent-%COMP%]   .label-and-metadata[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   td.value[_ngcontent-%COMP%]{line-height:12px}.io-tree[_ngcontent-%COMP%]   .expandable-tree-node[_ngcontent-%COMP%], .io-tree[_ngcontent-%COMP%]   mat-tree-node[_ngcontent-%COMP%]{font-size:13px;min-height:22px;word-break:break-word}.io-tree[_ngcontent-%COMP%]   .expandable-tree-node[_ngcontent-%COMP%]{color:#999;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;width:100%;-moz-box-sizing:border-box;box-sizing:border-box;padding-right:12px;padding-left:4px}.io-tree[_ngcontent-%COMP%]   .expandable-tree-node.highlight[_ngcontent-%COMP%]{color:rgba(0,0,0,.87)}.io-tree[_ngcontent-%COMP%]   .expandable-tree-node[_ngcontent-%COMP%]:hover   .locator-container[_ngcontent-%COMP%]{opacity:.8}.io-tree[_ngcontent-%COMP%]   .expandable-tree-node[_ngcontent-%COMP%]   mat-icon.expander[_ngcontent-%COMP%]{color:#999}.io-tree[_ngcontent-%COMP%]   .expandable-tree-node[_ngcontent-%COMP%]   .label-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.io-tree[_ngcontent-%COMP%]   .expandable-tree-node[_ngcontent-%COMP%]   .label-container.has-extra-data[_ngcontent-%COMP%]{width:100%}.io-tree[_ngcontent-%COMP%]   .expandable-tree-node[_ngcontent-%COMP%]   .label-container.has-extra-data[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.io-tree[_ngcontent-%COMP%]   .expandable-tree-node[_ngcontent-%COMP%]   .label-container[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.io-tree[_ngcontent-%COMP%]   .expand-icon-button[_ngcontent-%COMP%]{padding:0;width:24px;height:24px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.io-tree[_ngcontent-%COMP%]   .expand-icon-button[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:18px;margin-top:6px}.io-tree[_ngcontent-%COMP%]   .locator-container[_ngcontent-%COMP%]{height:18px;opacity:.5;cursor:pointer;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.io-tree[_ngcontent-%COMP%]   .locator-container[_ngcontent-%COMP%]   mat-icon.locator-icon[_ngcontent-%COMP%]{color:#333;font-size:16px;width:16px;height:16px}.io-tree[_ngcontent-%COMP%]   .locator-container[_ngcontent-%COMP%]:hover{opacity:.8}.io-tree[_ngcontent-%COMP%]   .match-types-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;justify-self:center;gap:2px;margin-left:8px}.io-tree[_ngcontent-%COMP%]   .extra-label-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;justify-self:center;padding:4px;border-radius:99px;background-color:#e8f0fe;-moz-box-sizing:border-box;box-sizing:border-box}.io-tree[_ngcontent-%COMP%]   .extra-label-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:12px;width:12px;height:12px;color:#9da3a9}.io-tree[_ngcontent-%COMP%]     .mat-mdc-button-touch-target{width:24px;height:24px}.io-tree-invisible[_ngcontent-%COMP%]{display:none}.io-tree[_ngcontent-%COMP%]   li[_ngcontent-%COMP%], .io-tree[_ngcontent-%COMP%]   ul[_ngcontent-%COMP%]{margin-top:0;margin-bottom:0;list-style-type:none}.io-tree[_ngcontent-%COMP%]   .mat-nested-tree-node[_ngcontent-%COMP%]   div[role=group][_ngcontent-%COMP%]{padding-left:8px}.io-tree[_ngcontent-%COMP%]   div[role=group][_ngcontent-%COMP%] > .mat-tree-node[_ngcontent-%COMP%]{padding-left:16px}  xap-inline-dialog-container:has(.model-explorer-const-values-popup){width:100%}  .model-explorer-const-values-popup{padding:8px;font-size:11px;line-height:12px;background-color:#fff}  .model-explorer-const-values-popup .values-count-msg{margin-bottom:8px;color:#999}  .model-explorer-const-values-popup .content{white-space:pre-wrap;font-family:monospace}"],
data:{animation:PJ},Qa:0});
function SK(a,b,c,d=[]){var e=[];let f={label:"<root>",children:[],type:b,zd:!0};const g=[];for(let m=0;m<a.length;m++){const p=a[m];var k=e[m];const t=d[m];if(fI(p)&&p.hideInLayout)g.push({node:p,index:m,metadata:k});else{const v=TK(p.savedNamespace||p.namespace,f);if(v){null==v.children&&(v.children=[]);const B=v.children.find(G=>G.label===p.label&&G.zd);null==B?(k={label:p.label,Ui:UK(k),nodeId:p.id,node:p,type:b,Ad:!0,Kn:p.id===c,zd:1===p.nodeType,metadata:k},null!=t&&(k.vg=t),v.children.push(k)):
(B.nodeId=p.id,B.Ad=!0,B.vg=t)}}}f=VK(f);a=[f];if(0<g.length){d="weights";for(const m of g)if(!m.node.label.toLowerCase().includes("const")){d="<hidden>";break}a.push({label:d,children:g.map(m=>({label:m.node.label,Ui:UK(m.metadata),nodeId:m.node.id,node:m.node,type:b,Ad:!1,Kn:m.node.id===c,zd:!1,metadata:e[m.index]})),type:b,zd:!1})}return a}function UK(a){if(a)return a.__tensor_tag}
function TK(a,b){var c=a?["<root>",...a.split("/")]:["<root>"];let d;a=[];for(const e of c)"<root>"!==e&&a.push(e),"<root>"===e?d=b:(d&&!d.children&&(d.children=[]),c=d.children.find(f=>f.label===e),null==c?(c={label:e,children:[],type:b.type,zd:!0},d.children.push(c),d=c):d=c);return d}
function VK(a){let b=a;const c=[];for(;;){c.push(b.label);let d;if((null==(d=b)?0:d.children)&&1===b.children.length&&0<(b.children[0].children||[]).length&&!b.Ad)b=b.children[0];else break}b!==a&&(b.label=c.join(" / "));return b};var WK={COLOR:"COLOR",Uo:"NUMBER"},XK=[{type:"COLOR",label:"Bg color",id:"node_bg_color",defaultValue:"#ffffff"},{type:"COLOR",label:"Border color",id:"node_border_color",defaultValue:"#777777"},{type:"COLOR",label:"Text color",id:"node_text_color",defaultValue:"#041e49"}];
function YK(a,b){const c=EI(b),d={};if(0<b.length&&b.some(e=>DI(e.queries))){const e=a.i.Ma();for(let f=0;f<e.length;f++){const g=e[f].modelGraph;if(g)for(const k of g.nodes)for(let m=0;m<c.length;m++){const p=c[m];if(DI(b[m].queries)&&FI(k,p.queries,g)){null==d[m]&&(d[m]={});null==d[m][f]&&(d[m][f]=[]);d[m][f].push(k);break}}}}a.C.set(d)}function ZK(a,b){a.rules.set($K(b))}
function aL(a){a.rules.update(b=>{b=[...b];b.push({queries:[{type:"node_type",nodeType:"op_nodes"},{type:"regex",queryRegex:"",matchTypes:["title"]}],nodeType:"op_nodes",styles:{},version:"v2"});return b})}function bL(a,b){a.rules.update(c=>{const d=[...c];c=c[b];d.splice(b,1);d.splice(b-1,0,c);return d})}function cL(a,b){a.rules.update(c=>{const d=[...c];c=c[b];d.splice(b,1);d.splice(b+1,0,c);return d})}
function dL(a,b){a.rules.update(c=>{const d=JSON.parse(JSON.stringify(c[b]));return[...c.slice(0,b),d,...c.slice(b)]})}function $K(a){return a.map(b=>{null==b.version&&(b.queries.unshift({type:"node_type",nodeType:b.nodeType}),b.version="v2");return b})}function eL(a,b,c){a.rules.update(d=>{d[b].queries=c;return[...d]})}
function fL(a,b,c,d){a.rules.update(e=>{const f=e[b];null==d?null==f.styles[c.id]?f.styles[c.id]={id:c.id,value:c.defaultValue}:delete f.styles[c.id]:d?f.styles[c.id]={id:c.id,value:c.defaultValue}:delete f.styles[c.id];return[...e]})}function gL(a,b,c){a.rules.update(d=>{d[b].nodeType=c;return[...d]})}function hL(a,b,c,d){a.rules.update(e=>{e[b].styles[c.id].value=d;return[...e]})}function iL(a,b){a.rules.update(c=>{c=[...c];c.splice(b,1);return c})}
var jL=class{constructor(a){this.i=a;this.rules=ur([]);this.C=ur({});this.jl=ys(()=>0<this.rules().filter(b=>DI(b.queries)&&0<Object.keys(b.styles).length).length);Gs(()=>{const b=this.rules();this.i.i||HI("model_explorer_node_styler_rules",JSON.stringify(b));YK(this,b)},{Wp:!0});this.i.i?(a=new URLSearchParams(document.location.search),a=decodeURIComponent(a.get("test_node_styler_rules")||""),ZK(this,""===a?[]:JSON.parse(a))):(a=window.localStorage.getItem("model_explorer_node_styler_rules")||"",
a=""===a?[]:JSON.parse(a),ZK(this,a))}};jL.J=function(a){return new (a||jL)(q(NJ),q(II))};jL.oa=Ld({la:jL,aa:jL.J});function kL(a){a||(xg(),a=lf(wi));const b=new Vi(c=>a.nb(c.next.bind(c)));return c=>C(c,Jo(b))};function lL(a){xg();const b=lf(Vh),c=new kj(1),d=Gs(()=>{let e;try{e=a()}catch(f){Hs(()=>c.error(f));return}Hs(()=>c.next(e))},{wa:b,KC:!0});b.get(wi).nb(()=>{d.destroy();c.complete()});return Zi(c)};function mL(a,b,c){const d=nL(a,b);if(0<d.length){for(const e of d)null==e.results&&(e.results={}),null==e.results[b.id]&&null!=e.nodeDataProviderData&&(e.results[b.id]=oL(b,e.nodeDataProviderData));tJ(a.i,a.i.Ma()[c].id,d[0].runId)}}
function oL(a,b){pL(a);const c={};b=b[a.id];if(!b)return{};const d=[];for(var e of b.gradient||[]){var f={stop:e.stop};null!=e.bgColor&&(f.bgColor=qL(e.bgColor,"#ffffff"));null!=e.textColor&&(f.textColor=qL(e.textColor,"#000000"));d.push(f)}d.sort((m,p)=>m.stop-p.stop);e=Number.POSITIVE_INFINITY;f=Number.NEGATIVE_INFINITY;if(0<d.length)for(var {value:g}of Object.values(b.results))"number"===typeof g&&(e=Math.min(e,g),f=Math.max(f,g));for(const m of Object.keys(b.results)){g=b.results[m];"number"===
typeof g.value&&null==g.bgColor&&(g.bgColor=rL(g.value,b.thresholds||[],d,e,f));"number"===typeof g.value&&null==g.textColor&&(g.textColor=sL(g.value,b.thresholds||[],d,e,f));if((null==g.textColor||""===g.textColor)&&(g.bgColor||"").startsWith("#")){var k=qL(g.bgColor,"#ffffff");null!=k&&.38>.2126*Math.pow(k.r/255,2.2)+.7152*Math.pow(k.g/255,2.2)+.0722*Math.pow(k.b/255,2.2)&&(g.textColor="#ffffff")}k="-";k=g.value;k="number"===typeof k||"boolean"===typeof k||"string"===typeof k?`${k}`:JSON.stringify(k);
let p;const t=`${null!=(p=(a.outputTensorIdToNodeId||{})[m])?p:m}`,v=c[t];if(v){const B=v.allValues;B[m]=g.value;c[t]={value:g.value,bgColor:g.bgColor,textColor:g.textColor,allValues:B,strValue:`${v.strValue}, ${k}`}}else c[t]=Object.assign({},g,{strValue:k,allValues:{[m]:g.value}})}return c}
function tL(a,b,c,d,e,f=!1,g){const k=d.collectionLabel;a.C.update(m=>{if(f){var p=[];for(const [t,v]of Object.entries(m)){const B=t,G=v;f&&G.collectionId===k&&p.push(B)}for(const t of p)delete m[t]}m[b]={runId:b,runName:c,done:null==e?!1:!0,results:null==e?void 0:{[d.id]:oL(d,e)},extensionId:"",collectionId:k,remotePath:g,nodeDataProviderData:e};p=a.i.Ma();for(const t of p){let v,B;(null==(v=t.modelGraph)?void 0:v.id)===d.id&&(null==(B=t.modelGraph)?void 0:B.collectionLabel)===d.collectionLabel&&
tJ(a.i,t.id,b)}return Object.assign({},m)})}function uL(a,b,c,d,e){a.C.update(f=>{const g=f[b];g.done=!0;g.nodeDataProviderData=c;null==g.results&&(g.results={});g.results[d.id]=oL(d,c);e&&(g.error=e);return Object.assign({},f)})}function vL(a){const b=Object.values(a.C()).filter(c=>null!=c.remotePath).map(c=>c.remotePath);a.i.Mg.set(b)}
function wL(a,b,c){return sa(function*(){a.di.set(!0);var d=b.split("/"),e=d[d.length-1];let f;b.startsWith("node_data://")?(d=b.replace("node_data://","").split("/"),e=d[0],f=`${"/api/v1/load_node_data"}?node_data_index=${Number(d[1])}`):f=`${"/api/v1/read_text_file"}?path=${b}`;d=lI();tL(a,d,e,c,void 0,!1,b);e=yield fetch(f);if(e.ok)if(e=JSON.parse(yield e.text()),e.error)uL(a,d,{[c.id]:{results:{}}},c,`Failed to process JSON file. ${e.error}`);else try{const g=JSON.parse(e.content);e={};null!=
g.results&&null==g.results.results?c&&(e[c.id]=g):e=g;uL(a,d,e,c);vL(a)}catch(g){uL(a,d,{[c.id]:{results:{}}},c,`Failed to process JSON file. ${g}`)}else uL(a,d,{[c.id]:{results:{}}},c,`Failed to load JSON file "${b}"`);a.di.set(!1)})}function nL(a,b){const c=[];a=a.C();for(const d of Object.values(a))d.collectionId===b.collectionLabel&&(a=d.nodeDataProviderData)&&null!=a[b.id]&&c.push(d);return c}
function xL(a,b){a.C.update(c=>{delete c[b];return Object.assign({},c)});vL(a);for(const c of a.i.Ma())if(c.qs===b){const d=nL(a,c.modelGraph);tJ(a.i,c.id,0<d.length?d[0].runId:void 0)}}function yL(a,b,c){const d=uJ(a.i,b);if(d)return nL(a,c).find(e=>e.runId===d)}
function pL(a){if(null==a.outputTensorIdToNodeId){a.outputTensorIdToNodeId={};for(const b of a.nodes)if(fI(b)){const c=b.outputsMetadata||{};for(const d of Object.keys(c)){const e=c[d].tensor_name;null!=e&&(a.outputTensorIdToNodeId[e]=b.id)}}}}function qL(a,b){let c=a;a.startsWith("#")||(c=dI[a]);c||(c=b);c=c.replace("#","");return{r:zL(c.substring(0,2)),g:zL(c.substring(2,4)),b:zL(c.substring(4,6))}}
function rL(a,b,c,d,e){if(0<c.length)return AL(a,c,d,e,!0,"transparent");for(const f of b)if(a<=f.value)return f.bgColor;return"transparent"}function sL(a,b,c,d,e){if(0<c.length)return AL(a,c,d,e,!1,"");for(const f of b)if(a<=f.value)return f.textColor||"";return""}
function AL(a,b,c,d,e,f){d=(a-c)/(d-c);for(let g=0;g<b.length-1;g++){const k=b[g],m=b[g+1];a=e?k.bgColor:k.textColor;c=e?m.bgColor:m.textColor;if(d>=k.stop&&d<=m.stop){if(null==a||null==c)break;b=(d-k.stop)/(m.stop-k.stop);e=Math.floor(a.g+(c.g-a.g)*b);f=Math.floor(a.b+(c.b-a.b)*b);return`#${BL(Math.floor(a.r+(c.r-a.r)*b))}${BL(e)}${BL(f)}`}}return f}function BL(a){a=a.toString(16);return 1===a.length?`0${a}`:a}function zL(a){return/^[a-fA-F0-9]+$/.test(a)?parseInt(a,16):255}
var CL=class{constructor(a){this.i=a;this.C=ur({});this.di=ur(!1);this.D=lL(ys(()=>this.i.Ma()[0].modelGraph));this.F=lL(ys(()=>{const b=this.i.Ma();if(!(1>=b.length))return b[1].modelGraph}));this.D.subscribe(b=>{null!=b&&mL(this,b,0)});this.F.subscribe(b=>{null!=b&&mL(this,b,1)})}};CL.J=function(a){return new (a||CL)(q(NJ))};CL.oa=Ld({la:CL,aa:CL.J});/*

Copyright 2010-2017 Mike Bostock
All rights reserved.

Redistribution and use in source and binary forms, with or without modification,
are permitted provided that the following conditions are met:

 Redistributions of source code must retain the above copyright notice, this
  list of conditions and the following disclaimer.

 Redistributions in binary form must reproduce the above copyright notice,
  this list of conditions and the following disclaimer in the documentation
  and/or other materials provided with the distribution.

 Neither the name of the author nor the names of contributors may be used to
  endorse or promote products derived from this software without specific prior
  written permission.

THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR
ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
*/
var DL,EL,FL,GL,HL,IL,oI,pI,JL,KL;
(function(){function a(l){return function(){return this.matches(l)}}function b(l,h){return l<h?-1:l>h?1:l>=h?0:NaN}function c(l){return function(h,n){return b(l(h),n)}}function d(){for(var l=0,h=arguments.length,n={},r;l<h;++l){if(!(r=arguments[l]+"")||r in n)throw Error("illegal type: "+r);n[r]=[]}return new e(n)}function e(l){this.Fb=l}function f(l,h){return l.trim().split(/^|\s+/).map(function(n){var r="",w=n.indexOf(".");0<=w&&(r=n.slice(w+1),n=n.slice(0,w));if(n&&!h.hasOwnProperty(n))throw Error("unknown type: "+
n);return{type:n,name:r}})}function g(l,h,n){for(var r=0,w=l.length;r<w;++r)if(l[r].name===h){l[r]=YT;l=l.slice(0,r).concat(l.slice(r+1));break}null!=n&&l.push({name:h,value:n});return l}function k(l){return function(){var h=this.ownerDocument,n=this.namespaceURI;return"http://www.w3.org/1999/xhtml"===n&&"http://www.w3.org/1999/xhtml"===h.documentElement.namespaceURI?h.createElement(l):h.createElementNS(n,l)}}function m(l){return function(){return this.ownerDocument.createElementNS(l.space,l.local)}}
function p(l){var h=l,n=h.indexOf(":");0<=n&&"xmlns"!==(h=l.slice(0,n))&&(l=l.slice(n+1));l=Pd.hasOwnProperty(h)?{space:Pd[h],local:l}:l;return(l.local?m:k)(l)}function t(){}function v(l){return null==l?t:function(){return this.querySelector(l)}}function B(l){return Array(l.length)}function G(l,h){this.ownerDocument=l.ownerDocument;this.namespaceURI=l.namespaceURI;this.Na=null;this.Pa=l;this.__data__=h}function K(l){return function(){return l}}function N(l,h,n,r,w,z){for(var A=0,E,J=h.length,L=z.length;A<
L;++A)(E=h[A])?(E.__data__=z[A],r[A]=E):n[A]=new G(l,z[A]);for(;A<J;++A)if(E=h[A])w[A]=E}function aa(l,h,n,r,w,z,A){var E,J,L={},P=h.length,X=z.length,ka=Array(P),oa;for(E=0;E<P;++E)if(J=h[E])ka[E]=oa="$"+A.call(J,J.__data__,E,h),oa in L?w[E]=J:L[oa]=J;for(E=0;E<X;++E)oa="$"+A.call(l,z[E],E,z),(J=L[oa])?(r[E]=J,J.__data__=z[E],L[oa]=null):n[E]=new G(l,z[E]);for(E=0;E<P;++E)(J=h[E])&&L[ka[E]]===J&&(w[E]=J)}function ca(l,h){return l<h?-1:l>h?1:l>=h?0:NaN}function ia(l){return function(){this.style.removeProperty(l)}}
function O(l,h,n){return function(){this.style.setProperty(l,h,n)}}function U(l,h,n){return function(){var r=h.apply(this,arguments);null==r?this.style.removeProperty(l):this.style.setProperty(l,r,n)}}function Q(l,h){return l.style.getPropertyValue(h)||(l.ownerDocument&&l.ownerDocument.defaultView||l.document&&l||l.defaultView).getComputedStyle(l,null).getPropertyValue(h)}function la(l){return function(){delete this[l]}}function F(l,h){return function(){this[l]=h}}function M(l,h){return function(){var n=
h.apply(this,arguments);null==n?delete this[l]:this[l]=n}}function W(){this.textContent=""}function Aa(l){return function(){this.textContent=l}}function qb(l){return function(){var h=l.apply(this,arguments);this.textContent=null==h?"":h}}function wb(){return null}function Ja(){var l=this.parentNode;l&&l.removeChild(this)}function Ub(){return this.parentNode.insertBefore(this.cloneNode(!1),this.nextSibling)}function Na(){return this.parentNode.insertBefore(this.cloneNode(!0),this.nextSibling)}function qa(l,
h,n){l=T(l,h,n);return function(r){var w=r.relatedTarget;w&&(w===this||w.compareDocumentPosition(this)&8)||l.call(this,r)}}function T(l,h,n){return function(r){var w=DL;DL=r;try{l.call(this,this.__data__,h,n)}finally{DL=w}}}function ea(l){return l.trim().split(/^|\s+/).map(function(h){var n="",r=h.indexOf(".");0<=r&&(n=h.slice(r+1),h=h.slice(0,r));return{type:h,name:n}})}function na(l){return function(){var h=this.__on;if(h){for(var n=0,r=-1,w=h.length,z;n<w;++n)(z=h[n],l.type&&z.type!==l.type||z.name!==
l.name)?h[++r]=z:this.removeEventListener(z.type,z.listener,z.capture);++r?h.length=r:delete this.__on}}}function Ka(l,h,n){var r=yE.hasOwnProperty(l.type)?qa:T;return function(w,z,A){w=this.__on;var E;z=r(h,z,A);if(w){A=0;for(var J=w.length;A<J;++A)if((E=w[A]).type===l.type&&E.name===l.name){this.removeEventListener(E.type,E.listener,E.capture);this.addEventListener(E.type,E.listener=z,E.capture=n);E.value=h;return}}this.addEventListener(l.type,z,n);E={type:l.type,name:l.name,value:h,listener:z,
capture:n};w?w.push(E):this.__on=[E]}}function Qa(l,h){this.wc=l;this.ac=h}function Ia(){return new Qa([[document.documentElement]],zE)}function ib(l){return"string"===typeof l?new Qa([[document.querySelector(l)]],[document.documentElement]):new Qa([[l]],zE)}function pa(){this.Fb="@"+(++ZT).toString(36)}function Ga(){for(var l=DL,h;h=l.ys;)l=h;return l}function Sa(l,h){var n=l.ownerSVGElement||l;if(n.createSVGPoint)return n=n.createSVGPoint(),n.x=h.clientX,n.y=h.clientY,n=n.matrixTransform(l.getScreenCTM().inverse()),
[n.x,n.y];n=l.getBoundingClientRect();return[h.clientX-n.left-l.clientLeft,h.clientY-n.top-l.clientTop]}function db(l){var h=Ga();h.changedTouches&&(h=h.changedTouches[0]);return Sa(l,h)}function Xb(l,h,n){3>arguments.length&&(n=h,h=Ga().changedTouches);for(var r=0,w=h?h.length:0,z;r<w;++r)if((z=h[r]).identifier===n)return Sa(l,z);return null}function od(){DL.preventDefault();DL.stopImmediatePropagation()}function vc(l){var h=l.document.documentElement;l=ib(l).on("dragstart.drag",od,!0);if("onselectstart"in
h)l.on("selectstart.drag",od,!0);else h.it=h.style.MozUserSelect,h.style.MozUserSelect="none"}function ec(l,h){var n=l.document.documentElement,r=ib(l).on("dragstart.drag",null);h&&(r.on("click.drag",od,!0),setTimeout(function(){r.on("click.drag",null)},0));if("onselectstart"in n)r.on("selectstart.drag",null);else n.style.MozUserSelect=n.it,delete n.it}function pc(l,h,n){l.prototype=h.prototype=n;n.constructor=l}function Ud(l,h){l=Object.create(l.prototype);for(var n in h)l[n]=h[n];return l}function Dc(){}
function jc(l){var h;l=(l+"").trim().toLowerCase();return(h=$T.exec(l))?(h=parseInt(h[1],16),new Vb(h>>8&15|h>>4&240,h>>4&15|h&240,(h&15)<<4|h&15,1)):(h=aU.exec(l))?re(parseInt(h[1],16)):(h=bU.exec(l))?new Vb(h[1],h[2],h[3],1):(h=cU.exec(l))?new Vb(255*h[1]/100,255*h[2]/100,255*h[3]/100,1):(h=dU.exec(l))?Ze(h[1],h[2],h[3],h[4]):(h=eU.exec(l))?Ze(255*h[1]/100,255*h[2]/100,255*h[3]/100,h[4]):(h=fU.exec(l))?zg(h[1],h[2]/100,h[3]/100,1):(h=gU.exec(l))?zg(h[1],h[2]/100,h[3]/100,h[4]):AE.hasOwnProperty(l)?
re(AE[l]):"transparent"===l?new Vb(NaN,NaN,NaN,0):null}function re(l){return new Vb(l>>16&255,l>>8&255,l&255,1)}function Ze(l,h,n,r){0>=r&&(l=h=n=NaN);return new Vb(l,h,n,r)}function Mk(l){l instanceof Dc||(l=jc(l));if(!l)return new Vb;l=l.nf();return new Vb(l.r,l.g,l.b,l.opacity)}function Sc(l,h,n,r){return 1===arguments.length?Mk(l):new Vb(l,h,n,null==r?1:r)}function Vb(l,h,n,r){this.r=+l;this.g=+h;this.b=+n;this.opacity=+r}function pd(l){l=Math.max(0,Math.min(255,Math.round(l)||0));return(16>l?
"0":"")+l.toString(16)}function zg(l,h,n,r){0>=r?l=h=n=NaN:0>=n||1<=n?l=h=NaN:0>=h&&(l=NaN);return new qd(l,h,n,r)}function Bn(l){if(l instanceof qd)return new qd(l.h,l.s,l.l,l.opacity);l instanceof Dc||(l=jc(l));if(!l)return new qd;if(l instanceof qd)return l;l=l.nf();var h=l.r/255,n=l.g/255,r=l.b/255,w=Math.min(h,n,r),z=Math.max(h,n,r),A=NaN,E=z-w,J=(z+w)/2;E?(A=h===z?(n-r)/E+6*(n<r):n===z?(r-h)/E+2:(h-n)/E+4,E/=.5>J?z+w:2-z-w,A*=60):E=0<J&&1>J?0:A;return new qd(A,E,J,l.opacity)}function fd(l,h,
n,r){return 1===arguments.length?Bn(l):new qd(l,h,n,null==r?1:r)}function qd(l,h,n,r){this.h=+l;this.s=+h;this.l=+n;this.opacity=+r}function Ju(l,h,n){return 255*(60>l?h+(n-h)*l/60:180>l?n:240>l?h+(n-h)*(240-l)/60:h)}function Ku(l){if(l instanceof Ne)return new Ne(l.l,l.a,l.b,l.opacity);if(l instanceof zf){if(isNaN(l.h))return new Ne(l.l,0,0,l.opacity);var h=l.h*BE;return new Ne(l.l,Math.cos(h)*l.c,Math.sin(h)*l.c,l.opacity)}l instanceof Vb||(l=Mk(l));var n=Lu(l.r),r=Lu(l.g),w=Lu(l.b);h=Mu(.2225045*
n+.7168786*r+.0606169*w);if(n===r&&r===w)var z=n=h;else z=Mu((.4360747*n+.3850649*r+.1430804*w)/.96422),n=Mu((.0139322*n+.0971045*r+.7141733*w)/.82521);return new Ne(116*h-16,500*(z-h),200*(h-n),l.opacity)}function Ne(l,h,n,r){this.l=+l;this.a=+h;this.b=+n;this.opacity=+r}function Mu(l){return l>hU?Math.pow(l,1/3):l/CE+DE}function Nu(l){return l>Uj?l*l*l:CE*(l-DE)}function Ou(l){return 255*(.0031308>=l?12.92*l:1.055*Math.pow(l,1/2.4)-.055)}function Lu(l){return.04045>=(l/=255)?l/12.92:Math.pow((l+
.055)/1.055,2.4)}function iU(l){if(l instanceof zf)return new zf(l.h,l.c,l.l,l.opacity);l instanceof Ne||(l=Ku(l));if(0===l.a&&0===l.b)return new zf(NaN,0,l.l,l.opacity);var h=Math.atan2(l.b,l.a)*EE;return new zf(0>h?h+360:h,Math.sqrt(l.a*l.a+l.b*l.b),l.l,l.opacity)}function Pu(l,h,n,r){return 1===arguments.length?iU(l):new zf(l,h,n,null==r?1:r)}function zf(l,h,n,r){this.h=+l;this.c=+h;this.l=+n;this.opacity=+r}function Oe(l,h,n,r){if(1===arguments.length){var w=l;if(w instanceof Fh)w=new Fh(w.h,
w.s,w.l,w.opacity);else{w instanceof Vb||(w=Mk(w));var z=w.g/255,A=w.b/255,E=(FE*A+w.r/255*-1.7884503806-3.5172982438*z)/(FE+-1.7884503806-3.5172982438);A-=E;var J=(1.97294*(z-E)- -.29227*A)/-.90649;A=(z=Math.sqrt(J*J+A*A)/(1.97294*E*(1-E)))?Math.atan2(J,A)*EE-120:NaN;w=new Fh(0>A?A+360:A,z,E,w.opacity)}}else w=new Fh(l,h,n,null==r?1:r);return w}function Fh(l,h,n,r){this.h=+l;this.s=+h;this.l=+n;this.opacity=+r}function GE(l,h,n,r,w){var z=l*l,A=z*l;return((1-3*l+3*z-A)*h+(4-6*z+3*A)*n+(1+3*l+3*z-
3*A)*r+A*w)/6}function Jp(l){return function(){return l}}function HE(l,h){return function(n){return l+n*h}}function jU(l,h,n){return l=Math.pow(l,n),h=Math.pow(h,n)-l,n=1/n,function(r){return Math.pow(l+r*h,n)}}function Qu(l,h){var n=h-l;return n?HE(l,180<n||-180>n?n-360*Math.round(n/360):n):Jp(isNaN(l)?h:l)}function kU(l){return 1===(l=+l)?md:function(h,n){return n-h?jU(h,n,l):Jp(isNaN(h)?n:h)}}function md(l,h){var n=h-l;return n?HE(l,n):Jp(isNaN(l)?h:l)}function IE(l){return function(h){var n=h.length,
r=Array(n),w=Array(n),z=Array(n),A;for(A=0;A<n;++A){var E=Sc(h[A]);r[A]=E.r||0;w[A]=E.g||0;z[A]=E.b||0}r=l(r);w=l(w);z=l(z);E.opacity=1;return function(J){E.r=r(J);E.g=w(J);E.b=z(J);return E+""}}}function lU(l,h){var n=h?h.length:0,r=l?Math.min(n,l.length):0,w=Array(r),z=Array(n),A;for(A=0;A<r;++A)w[A]=Ru(l[A],h[A]);for(;A<n;++A)z[A]=h[A];return function(E){for(A=0;A<r;++A)z[A]=w[A](E);return z}}function mU(l,h){var n=new Date;return l=+l,h-=l,function(r){return n.setTime(l+h*r),n}}function Pe(l,
h){return l=+l,h-=l,function(n){return l+h*n}}function nU(l,h){var n={},r={},w;if(null===l||"object"!==typeof l)l={};if(null===h||"object"!==typeof h)h={};for(w in h)w in l?n[w]=Ru(l[w],h[w]):r[w]=h[w];return function(z){for(w in n)r[w]=n[w](z);return r}}function oU(l){return function(){return l}}function pU(l){return function(h){return l(h)+""}}function JE(l,h){var n=Su.lastIndex=Tu.lastIndex=0,r,w,z,A=-1,E=[],J=[];l+="";for(h+="";(r=Su.exec(l))&&(w=Tu.exec(h));)(z=w.index)>n&&(z=h.slice(n,z),E[A]?
E[A]+=z:E[++A]=z),(r=r[0])===(w=w[0])?E[A]?E[A]+=w:E[++A]=w:(E[++A]=null,J.push({Qf:A,x:Pe(r,w)})),n=Tu.lastIndex;n<h.length&&(z=h.slice(n),E[A]?E[A]+=z:E[++A]=z);return 2>E.length?J[0]?pU(J[0].x):oU(h):(h=J.length,function(L){for(var P=0,X;P<h;++P)E[(X=J[P]).Qf]=X.x(L);return E.join("")})}function Ru(l,h){var n=typeof h,r;return null==h||"boolean"===n?Jp(h):("number"===n?Pe:"string"===n?(r=jc(h))?(h=r,Kp):JE:h instanceof jc?Kp:h instanceof Date?mU:Array.isArray(h)?lU:"function"!==typeof h.valueOf&&
"function"!==typeof h.toString||isNaN(h)?nU:Pe)(l,h)}function KE(l,h,n,r,w,z){var A,E,J;if(A=Math.sqrt(l*l+h*h))l/=A,h/=A;if(J=l*n+h*r)n-=l*J,r-=h*J;if(E=Math.sqrt(n*n+r*r))n/=E,r/=E,J/=E;l*r<h*n&&(l=-l,h=-h,J=-J,A=-A);return{translateX:w,translateY:z,rotate:Math.atan2(h,l)*LE,skewX:Math.atan(J)*LE,js:A,ks:E}}function ME(l,h,n,r){function w(L){return L.length?L.pop()+" ":""}function z(L,P,X,ka,oa,Ba){L!==X||P!==ka?(oa=oa.push("translate(",null,h,null,n),Ba.push({Qf:oa-4,x:Pe(L,X)},{Qf:oa-2,x:Pe(P,
ka)})):(X||ka)&&oa.push("translate("+X+h+ka+n)}function A(L,P,X,ka){L!==P?(180<L-P?P+=360:180<P-L&&(L+=360),ka.push({Qf:X.push(w(X)+"rotate(",null,r)-2,x:Pe(L,P)})):P&&X.push(w(X)+"rotate("+P+r)}function E(L,P,X,ka){L!==P?ka.push({Qf:X.push(w(X)+"skewX(",null,r)-2,x:Pe(L,P)}):P&&X.push(w(X)+"skewX("+P+r)}function J(L,P,X,ka,oa,Ba){L!==X||P!==ka?(oa=oa.push(w(oa)+"scale(",null,",",null,")"),Ba.push({Qf:oa-4,x:Pe(L,X)},{Qf:oa-2,x:Pe(P,ka)})):1===X&&1===ka||oa.push(w(oa)+"scale("+X+","+ka+")")}return function(L,
P){var X=[],ka=[];L=l(L);P=l(P);z(L.translateX,L.translateY,P.translateX,P.translateY,X,ka);A(L.rotate,P.rotate,X,ka);E(L.skewX,P.skewX,X,ka);J(L.js,L.ks,P.js,P.ks,X,ka);L=P=null;return function(oa){for(var Ba=-1,Wa=ka.length,Za;++Ba<Wa;)X[(Za=ka[Ba]).Qf]=Za.x(oa);return X.join("")}}}function NE(l){return((l=Math.exp(l))+1/l)/2}function qU(l,h){var n=l[0],r=l[1],w=l[2];l=h[2];var z=h[0]-n,A=h[1]-r,E=z*z+A*A;if(1E-12>E){var J=Math.log(l/w)/bm;l=function(X){return[n+X*z,r+X*A,w*Math.exp(bm*X*J)]}}else{var L=
Math.sqrt(E);h=(l*l-w*w+4*E)/(4*w*L);l=(l*l-w*w-4*E)/(4*l*L);var P=Math.log(Math.sqrt(h*h+1)-h);J=(Math.log(Math.sqrt(l*l+1)-l)-P)/bm;l=function(X){X*=J;var ka=NE(P),oa=bm*X+P;var Ba=((oa=Math.exp(2*oa))-1)/(oa+1);var Wa=P;oa=((Wa=Math.exp(Wa))-1/Wa)/2;Ba=w/(2*L)*(ka*Ba-oa);return[n+Ba*z,r+Ba*A,w*ka/NE(bm*X+P)]}}l.duration=1E3*J;return l}function OE(l){return function(h,n){var r=l((h=fd(h)).h,(n=fd(n)).h),w=md(h.s,n.s),z=md(h.l,n.l),A=md(h.opacity,n.opacity);return function(E){h.h=r(E);h.s=w(E);h.l=
z(E);h.opacity=A(E);return h+""}}}function PE(l){return function(h,n){var r=l((h=Pu(h)).h,(n=Pu(n)).h),w=md(h.c,n.c),z=md(h.l,n.l),A=md(h.opacity,n.opacity);return function(E){h.h=r(E);h.c=w(E);h.l=z(E);h.opacity=A(E);return h+""}}}function QE(l){return function r(n){function w(z,A){var E=l((z=Oe(z)).h,(A=Oe(A)).h),J=md(z.s,A.s),L=md(z.l,A.l),P=md(z.opacity,A.opacity);return function(X){z.h=E(X);z.s=J(X);z.l=L(Math.pow(X,n));z.opacity=P(X);return z+""}}n=+n;w.gamma=r;return w}(1)}function Lp(){return Gh||
(RE(rU),Gh=cm.now()+Mp)}function rU(){Gh=0}function Np(){this.mk=this.Ck=this.Na=null}function SE(l,h,n){var r=new Np;r.ke(l,h,n);return r}function TE(){Gh=(Op=cm.now())+Mp;Vj=dm=0;try{Lp();++Vj;for(var l=Pp,h;l;)0<=(h=Gh-l.Ck)&&l.mk.call(null,h),l=l.Na;--Vj}finally{Vj=0;l=Pp;for(var n=Infinity;l;)if(l.mk){n>l.Ck&&(n=l.Ck);var r=l;l=l.Na}else h=l.Na,l.Na=null,l=r?r.Na=h:Pp=h;em=r;Uu(n);Gh=0}}function sU(){var l=cm.now(),h=l-Op;1E3<h&&(Mp-=h,Op=l)}function Uu(l){Vj||(dm&&(dm=clearTimeout(dm)),24<l-
Gh?(Infinity>l&&(dm=setTimeout(TE,l-cm.now()-Mp)),fm&&(fm=clearInterval(fm))):(fm||(Op=cm.now(),fm=setInterval(sU,1E3)),Vj=1,RE(TE)))}function UE(l,h,n){var r=new Np;h=null==h?0:+h;r.ke(function(w){r.stop();l(w+h)},h,n);return r}function Vu(l,h,n,r,w,z){var A=l.gg;if(!A)l.gg={};else if(n in A)return;tU(l,n,{name:h,index:r,group:w,on:uU,Nd:vU,time:z.time,delay:z.delay,duration:z.duration,Mf:z.Mf,Vg:null,state:0})}function Wu(l,h){l=Qe(l,h);if(0<l.state)throw Error("too late; already scheduled");return l}
function Hh(l,h){l=Qe(l,h);if(2<l.state)throw Error("too late; already started");return l}function Qe(l,h){l=l.gg;if(!l||!(l=l[h]))throw Error("transition not found");return l}function tU(l,h,n){function r(J){var L,P;if(1!==n.state)return z();for(ka in A){var X=A[ka];if(X.name===n.name){if(3===X.state)return UE(r);4===X.state?(X.state=6,X.Vg.stop(),X.on.call("interrupt",l,l.__data__,X.index,X.group),delete A[ka]):+ka<h&&(X.state=6,X.Vg.stop(),delete A[ka])}}UE(function(){3===n.state&&(n.state=4,n.Vg.ke(w,
n.delay,n.time),w(J))});n.state=2;n.on.call("start",l,l.__data__,n.index,n.group);if(2===n.state){n.state=3;E=Array(P=n.Nd.length);var ka=0;for(L=-1;ka<P;++ka)if(X=n.Nd[ka].value.call(l,l.__data__,n.index,n.group))E[++L]=X;E.length=L+1}}function w(J){J=J<n.duration?n.Mf.call(null,J/n.duration):(n.Vg.ke(z),n.state=5,1);for(var L=-1,P=E.length;++L<P;)E[L].call(null,J);5===n.state&&(n.on.call("end",l,l.__data__,n.index,n.group),z())}function z(){n.state=6;n.Vg.stop();delete A[h];for(var J in A)return;
delete l.gg}var A=l.gg,E;A[h]=n;n.Vg=SE(function(J){n.state=1;n.Vg.ke(r,n.delay,n.time);n.delay<=J&&r(J-n.delay)},0,n.time)}function Qp(l,h){var n=l.gg,r,w=!0,z;if(n){h=null==h?null:h+"";for(z in n)if((r=n[z]).name!==h)w=!1;else{var A=2<r.state&&5>r.state;r.state=6;r.Vg.stop();A&&r.on.call("interrupt",l,l.__data__,r.index,r.group);delete n[z]}w&&delete l.gg}}function wU(l,h){var n,r;return function(){var w=Hh(this,l),z=w.Nd;if(z!==n){r=n=z;z=0;for(var A=r.length;z<A;++z)if(r[z].name===h){r=r.slice();
r.splice(z,1);break}}w.Nd=r}}function xU(l,h,n){var r,w;if("function"!==typeof n)throw Error();return function(){var z=Hh(this,l),A=z.Nd;if(A!==r){w=(r=A).slice();A={name:h,value:n};for(var E=0,J=w.length;E<J;++E)if(w[E].name===h){w[E]=A;break}E===J&&w.push(A)}z.Nd=w}}function VE(l,h,n){var r=l.Wb;l.each(function(){var w=Hh(this,r);(w.value||(w.value={}))[h]=n.apply(this,arguments)});return function(w){return Qe(w,r).value[h]}}function yU(l,h){var n;return("number"===typeof h?Pe:h instanceof jc?Kp:
(n=jc(h))?(h=n,Kp):JE)(l,h)}function zU(l,h){return function(){Wu(this,l).delay=+h.apply(this,arguments)}}function AU(l,h){return h=+h,function(){Wu(this,l).delay=h}}function BU(l,h){return function(){Hh(this,l).duration=+h.apply(this,arguments)}}function CU(l,h){return h=+h,function(){Hh(this,l).duration=h}}function DU(l,h){if("function"!==typeof h)throw Error();return function(){Hh(this,l).Mf=h}}function EU(l){return(l+"").trim().split(/^|\s+/).every(function(h){var n=h.indexOf(".");0<=n&&(h=h.slice(0,
n));return!h||"start"===h})}function FU(l,h,n){var r,w,z=EU(h)?Wu:Hh;return function(){var A=z(this,l),E=A.on;if(E!==r)(w=(r=E).copy()).on(h,n);A.on=w}}function GU(l){return function(){var h=this.parentNode,n;for(n in this.gg)if(+n!==l)return;h&&h.removeChild(this)}}function HU(l,h){var n,r,w;return function(){var z=Q(this,l),A=(this.style.removeProperty(l),Q(this,l));return z===A?null:z===n&&A===r?w:w=h(n=z,r=A)}}function IU(l){return function(){this.style.removeProperty(l)}}function JU(l,h,n){var r,
w;return function(){var z=Q(this,l);return z===n?null:z===r?w:w=h(r=z,n)}}function KU(l,h,n){var r,w,z;return function(){var A=Q(this,l),E=n(this);null==E&&(E=(this.style.removeProperty(l),Q(this,l)));return A===E?null:A===r&&E===w?z:z=h(r=A,w=E)}}function LU(l,h,n){function r(){var w=this,z=h.apply(w,arguments);return z&&function(A){w.style.setProperty(l,z(A),n)}}r.kd=h;return r}function MU(l){return function(){this.textContent=l}}function NU(l){return function(){var h=l(this);this.textContent=null==
h?"":h}}function pg(l,h,n,r){this.wc=l;this.ac=h;this.qh=n;this.Wb=r}function Xu(l){return{type:l}}function Yu(){this.oc=this.xc=this.Ib=this.Lb=null;this.Fb=""}function WE(){return new Yu}function Rp(){}function XE(l,h){var n=new Rp;if(l instanceof Rp)l.each(function(A,E){n.set(E,A)});else if(Array.isArray(l)){var r=-1,w=l.length,z;if(null==h)for(;++r<w;)n.set(r,l[r]);else for(;++r<w;)n.set(h(z=l[r],r,l),z)}else if(l)for(r in l)n.set(r,l[r]);return n}function Sp(){}function YE(l){return function(h){for(var n=
{},r=0;r<l.length;r++)n[l[r]]=h[r]||"";return n}}function OU(l,h){var n=YE(l);return function(r,w){return h(n(r),w,l)}}function PU(l){var h=Object.create(null),n=[];l.forEach(function(r){for(var w in r)w in h||n.push(h[w]=w)});return n}function ZE(l){function h(A,E){function J(){if(Ba)return Zu;if(Wa)return Wa=!1,$E;var lc,ub=X,mc;if(34===A.charCodeAt(ub)){for(;X++<P&&34!==A.charCodeAt(X)||34===A.charCodeAt(++X););(lc=X)>=P?Ba=!0:10===(mc=A.charCodeAt(X++))?Wa=!0:13===mc&&(Wa=!0,10===A.charCodeAt(X)&&
++X);return A.slice(ub+1,lc-1).replace(/""/g,'"')}for(;X<P;){if(10===(mc=A.charCodeAt(lc=X++)))Wa=!0;else if(13===mc)Wa=!0,10===A.charCodeAt(X)&&++X;else if(mc!==z)continue;return A.slice(ub,lc)}return Ba=!0,A.slice(ub,P)}var L=[],P=A.length,X=0,ka=0,oa,Ba=0>=P,Wa=!1;10===A.charCodeAt(P-1)&&--P;for(13===A.charCodeAt(P-1)&&--P;(oa=J())!==Zu;){for(var Za=[];oa!==$E&&oa!==Zu;)Za.push(oa),oa=J();E&&null==(Za=E(Za,ka++))||L.push(Za)}return L}function n(A){return A.map(r).join(l)}function r(A){return null==
A?"":w.test(A)?'"'+A.replace(/"/g,'""')+'"':A}var w=new RegExp('["'+l+"\n\r]"),z=l.charCodeAt(0);return{parse:function(A,E){var J,L;A=h(A,function(P,X){if(J)return J(P,X-1);L=P;J=E?OU(P,E):YE(P)});A.zF=L||[];return A},hG:h,format:function(A,E){null==E&&(E=PU(A));return[E.map(r).join(l)].concat(A.map(function(J){return E.map(function(L){return r(J[L])}).join(l)})).join("\n")},PF:function(A){return A.map(n).join("\n")}}}function QU(l){if(!l.ok)throw Error(l.status+" "+l.statusText);return l.text()}
function aF(l){return function(h,n,r){2===arguments.length&&"function"===typeof n&&(r=n,n=void 0);return fetch(h,n).then(QU).then(function(w){return l(w,r)})}}function bF(l,h,n,r){if(isNaN(h)||isNaN(n))return l;var w,z=l.ub;r={data:r};var A=l.oc,E=l.xc,J=l.Ib,L=l.Lb,P,X,ka,oa,Ba;if(!z)return l.ub=r,l;for(;z.length;)if((ka=h>=(P=(A+J)/2))?A=P:J=P,(oa=n>=(X=(E+L)/2))?E=X:L=X,w=z,!(z=z[Ba=oa<<1|ka]))return w[Ba]=r,l;var Wa=+l.mg.call(null,z.data);var Za=+l.ng.call(null,z.data);if(h===Wa&&n===Za)return r.next=
z,w?w[Ba]=r:l.ub=r,l;do w=w?w[Ba]=Array(4):l.ub=Array(4),(ka=h>=(P=(A+J)/2))?A=P:J=P,(oa=n>=(X=(E+L)/2))?E=X:L=X;while((Ba=oa<<1|ka)===(ka=(Za>=X)<<1|Wa>=P));return w[ka]=z,w[Ba]=r,l}function dd(l,h,n,r,w){this.node=l;this.Mo=h;this.No=n;this.x1=r;this.y1=w}function RU(l){return l[0]}function SU(l){return l[1]}function $u(l,h,n,r,w,z){this.mg=l;this.ng=h;this.oc=n;this.xc=r;this.Ib=w;this.Lb=z;this.ub=void 0}function cF(l){for(var h={data:l.data},n=h;l=l.next;)n=n.next={data:l.data};return h}function Tp(l,
h){if(0>(h=(l=h?l.toExponential(h-1):l.toExponential()).indexOf("e")))return null;var n=l.slice(0,h);return[1<n.length?n[0]+n.slice(2):n,+l.slice(h+1)]}function TU(l){return l=Tp(Math.abs(l)),l?l[1]:NaN}function UU(l,h){return function(n,r){for(var w=n.length,z=[],A=0,E=l[0],J=0;0<w&&0<E;){J+E+1>r&&(E=Math.max(1,r-J));z.push(n.substring(w-=E,w+E));if((J+=E+1)>r)break;E=l[A=(A+1)%l.length]}return z.reverse().join(h)}}function VU(l){return function(h){return h.replace(/[0-9]/g,function(n){return l[+n]})}}
function av(l){return new bv(l)}function bv(l){if(!(h=WU.exec(l)))throw Error("invalid format: "+l);var h;this.fill=h[1]||" ";this.align=h[2]||">";this.sign=h[3]||"-";this.symbol=h[4]||"";this.zero=!!h[5];this.width=h[6]&&+h[6];this.dv=!!h[7];this.precision=h[8]&&+h[8].slice(1);this.trim=!!h[9];this.type=h[10]||""}function dF(l,h){h=Tp(l,h);if(!h)return l+"";l=h[0];h=h[1];return 0>h?"0."+Array(-h).join("0")+l:l.length>h+1?l.slice(0,h+1)+"."+l.slice(h+1):l+Array(h-l.length+2).join("0")}function eF(l){return l}
function XU(l){function h(E){function J(Ma){var Fb=mc,za=Jc,Fa;if("c"===ub)za=Db(Ma)+za,Ma="";else{Ma=+Ma;var I=0>Ma;Ma=Db(Math.abs(Ma),Za);if(lc){var ha=Ma.length;var Ha=1,Va=-1,vb;a:for(;Ha<ha;++Ha)switch(Ma[Ha]){case ".":Va=vb=Ha;break;case "0":0===Va&&(Va=Ha);vb=Ha;break;default:if(!+Ma[Ha])break a;0<Va&&(Va=0)}Ma=0<Va?Ma.slice(0,Va)+Ma.slice(vb+1):Ma}I&&0===+Ma&&(I=!1);Fb=(I?"("===X?X:"-":"-"===X||"("===X?"":X)+Fb;za=("s"===ub?fF[8+gF/3]:"")+za+(I&&"("===X?")":"");if(tb)for(I=-1,ha=Ma.length;++I<
ha;)if(Fa=Ma.charCodeAt(I),48>Fa||57<Fa){za=(46===Fa?w+Ma.slice(I+1):Ma.slice(I))+za;Ma=Ma.slice(0,I);break}}Wa&&!oa&&(Ma=n(Ma,Infinity));Fa=Fb.length+Ma.length+za.length;I=Fa<Ba?Array(Ba-Fa+1).join(L):"";Wa&&oa&&(Ma=n(I+Ma,I.length?Ba-za.length:Infinity),I="");switch(P){case "<":Ma=Fb+Ma+za+I;break;case "=":Ma=Fb+I+Ma+za;break;case "^":Ma=I.slice(0,Fa=I.length>>1)+Fb+Ma+za+I.slice(Fa);break;default:Ma=I+Fb+Ma+za}return z(Ma)}E=av(E);var L=E.fill,P=E.align,X=E.sign,ka=E.symbol,oa=E.zero,Ba=E.width,
Wa=E.dv,Za=E.precision,lc=E.trim,ub=E.type;"n"===ub?(Wa=!0,ub="g"):hF[ub]||(null==Za&&(Za=12),lc=!0,ub="g");if(oa||"0"===L&&"="===P)oa=!0,L="0",P="=";var mc="$"===ka?r[0]:"#"===ka&&/[boxX]/.test(ub)?"0"+ub.toLowerCase():"",Jc="$"===ka?r[1]:/[%p]/.test(ub)?A:"",Db=hF[ub],tb=/[defgprs%]/.test(ub);Za=null==Za?6:/[gprs]/.test(ub)?Math.max(1,Math.min(21,Za)):Math.max(0,Math.min(20,Za));J.toString=function(){return E+""};return J}var n=l.Yv&&l.my?UU(l.Yv,l.my):eF,r=l.currency,w=l.vB,z=l.eD?VU(l.eD):eF,
A=l.iG||"%";return{format:h,OF:function(E,J){var L=h((E=av(E),E.type="f",E));E=3*Math.max(-8,Math.min(8,Math.floor(TU(J)/3)));var P=Math.pow(10,-E),X=fF[8+E/3];return function(ka){return L(P*ka)+X}}}}function ie(){this.reset()}function iF(l,h,n){var r=l.s=h+n,w=r-h;l.t=h-(r-w)+(n-w)}function Up(l){return 1<l?Qd:-1>l?-Qd:Math.asin(l)}function YU(){}function jF(l){var h=l[0];l=l[1];var n=Rd(l);return[n*Rd(h),n*$c(h),$c(l)]}function kF(l,h){return[l[1]*h[2]-l[2]*h[1],l[2]*h[0]-l[0]*h[2],l[0]*h[1]-l[1]*
h[0]]}function lF(l){var h=Vp(l[0]*l[0]+l[1]*l[1]+l[2]*l[2]);l[0]/=h;l[1]/=h;l[2]/=h}function ZU(){var l=[],h;return{point:function(n,r){h.push([n,r])},ic:function(){l.push(h=[])},hc:YU,mG:function(){1<l.length&&l.push(l.pop().concat(l.shift()))},result:function(){var n=l;l=[];h=null;return n}}}function Wp(l,h,n,r){this.x=l;this.z=h;this.fo=n;this.e=r;this.v=!1;this.n=this.p=null}function $U(l,h,n,r,w){var z=[],A=[];l.forEach(function(X){if(!(0>=(ka=X.length-1))){var ka,oa=X[0],Ba=X[ka],Wa=oa;if(1E-6>
qg(Wa[0]-Ba[0])&&1E-6>qg(Wa[1]-Ba[1])){w.ic();for(E=0;E<ka;++E)w.point((oa=X[E])[0],oa[1]);w.hc()}else z.push(ka=new Wp(oa,X,null,!0)),A.push(ka.fo=new Wp(oa,null,ka,!1)),z.push(ka=new Wp(Ba,X,null,!1)),A.push(ka.fo=new Wp(Ba,null,ka,!0))}});if(z.length){A.sort(h);mF(z);mF(A);var E=0;for(l=A.length;E<l;++E)A[E].e=n=!n;n=z[0];for(var J;;){for(var L=n,P=!0;L.v;)if((L=L.n)===n)return;h=L.z;w.ic();do{L.v=L.fo.v=!0;if(L.e){if(P)for(E=0,l=h.length;E<l;++E)w.point((J=h[E])[0],J[1]);else r(L.x,L.n.x,1,w);
L=L.n}else{if(P)for(h=L.p.z,E=h.length-1;0<=E;--E)w.point((J=h[E])[0],J[1]);else r(L.x,L.p.x,-1,w);L=L.p}L=L.fo;h=L.z;P=!P}while(!L.v);w.hc()}}}function mF(l){if(h=l.length){for(var h,n=0,r=l[0],w;++n<h;)r.n=w=l[n],w.p=r,r=w;r.n=w=l[0];w.p=r}}function aV(l){return 1<l.length}function bV(l,h){return(0>(l=l.x)[0]?l[1]-Qd-1E-6:Qd-l[1])-(0>(h=h.x)[0]?h[1]-Qd-1E-6:Qd-h[1])}function cv(){}function nF(l){return function(h,n){var r=Rd(h),w=Rd(n);r=l(r*w);return[r*w*$c(h),r*$c(n)]}}function gm(l){return function(h,
n){var r=Vp(h*h+n*n),w=l(r),z=$c(w);w=Rd(w);return[oF(h*z,r*w),Up(r&&n*z/r)]}}function cV(l){var h=0,n=l.children,r=n&&n.length;if(r)for(;0<=--r;)h+=n[r].value;else h=1;l.value=h}function pF(l,h){var n=new hm(l);l=+l.value&&(n.value=l.value);var r,w=[n],z,A,E,J;for(null==h&&(h=dV);r=w.pop();)if(l&&(r.value=+r.data.value),(A=h(r.data))&&(J=A.length))for(r.children=Array(J),E=J-1;0<=E;--E)w.push(z=r.children[E]=new hm(A[E])),z.parent=r,z.depth=r.depth+1;return n.yq(eV)}function dV(l){return l.children}
function fV(l){l.data=l.data.data}function eV(l){var h=0;do l.height=h;while((l=l.parent)&&l.height<++h)}function hm(l){this.data=l;this.depth=this.height=0;this.parent=null}function Kc(l,h,n,r){function w(z){return l(z=new Date(+z)),z}w.floor=w;w.ceil=function(z){return l(z=new Date(z-1)),h(z,1),l(z),z};w.round=function(z){var A=w(z),E=w.ceil(z);return z-A<E-z?A:E};w.offset=function(z,A){return h(z=new Date(+z),null==A?1:Math.floor(A)),z};w.filter=function(z){return Kc(function(A){if(A>=A)for(;l(A),
!z(A);)A.setTime(A-1)},function(A,E){if(A>=A)if(0>E)for(;0>=++E;)for(;h(A,-1),!z(A););else for(;0<=--E;)for(;h(A,1),!z(A););})};n&&(w.count=function(z,A){dv.setTime(+z);ev.setTime(+A);l(dv);l(ev);return Math.floor(n(dv,ev))},w.every=function(z){z=Math.floor(z);return isFinite(z)&&0<z?1<z?w.filter(r?function(A){return 0===r(A)%z}:function(A){return 0===w.count(0,A)%z}):w:null});return w}function Ih(l){return Kc(function(h){h.setDate(h.getDate()-(h.getDay()+7-l)%7);h.setHours(0,0,0,0)},function(h,n){h.setDate(h.getDate()+
7*n)},function(h,n){return(n-h-6E4*(n.getTimezoneOffset()-h.getTimezoneOffset()))/6048E5})}function Jh(l){return Kc(function(h){h.setUTCDate(h.getUTCDate()-(h.getUTCDay()+7-l)%7);h.setUTCHours(0,0,0,0)},function(h,n){h.setUTCDate(h.getUTCDate()+7*n)},function(h,n){return(n-h)/6048E5})}function gV(l){if(0<=l.y&&100>l.y){var h=new Date(-1,l.fe,l.d,l.tf,l.dh,l.hk,l.vi);h.setFullYear(l.y);return h}return new Date(l.y,l.fe,l.d,l.tf,l.dh,l.hk,l.vi)}function Xp(l){if(0<=l.y&&100>l.y){var h=new Date(Date.UTC(-1,
l.fe,l.d,l.tf,l.dh,l.hk,l.vi));h.setUTCFullYear(l.y);return h}return new Date(Date.UTC(l.y,l.fe,l.d,l.tf,l.dh,l.hk,l.vi))}function im(l){return{y:l,fe:0,d:1,tf:0,dh:0,hk:0,vi:0}}function hV(l){function h(za,Fa){return function(I){var ha=[],Ha=-1,Va=0,vb=za.length,Ra,Qb;for(I instanceof Date||(I=new Date(+I));++Ha<vb;)if(37===za.charCodeAt(Ha)){ha.push(za.slice(Va,Ha));null!=(Va=qF[Ra=za.charAt(++Ha)])?Ra=za.charAt(++Ha):Va="e"===Ra?" ":"0";if(Qb=Fa[Ra])Ra=Qb(I,Va);ha.push(Ra);Va=Ha+1}ha.push(za.slice(Va,
Ha));return ha.join("")}}function n(za,Fa){return function(I){var ha=im(1900);if(r(ha,za,I,0)!=I.length)return null;if("Q"in ha)return new Date(ha.Q);"p"in ha&&(ha.tf=ha.tf%12+12*ha.p);if("V"in ha){if(1>ha.nm||53<ha.nm)return null;"w"in ha||(ha.w=1);if("Z"in ha){I=Xp(im(ha.y));var Ha=I.getUTCDay();I=4<Ha||0===Ha?fv.ceil(I):fv(I);I=rF.offset(I,7*(ha.nm-1));ha.y=I.getUTCFullYear();ha.fe=I.getUTCMonth();ha.d=I.getUTCDate()+(ha.w+6)%7}else I=Fa(im(ha.y)),Ha=I.getDay(),I=4<Ha||0===Ha?gv.ceil(I):gv(I),
I=sF.offset(I,7*(ha.nm-1)),ha.y=I.getFullYear(),ha.fe=I.getMonth(),ha.d=I.getDate()+(ha.w+6)%7}else if("W"in ha||"U"in ha)"w"in ha||(ha.w="u"in ha?ha.JE%7:"W"in ha?1:0),Ha="Z"in ha?Xp(im(ha.y)).getUTCDay():Fa(im(ha.y)).getDay(),ha.fe=0,ha.d="W"in ha?(ha.w+6)%7+7*ha.W-(Ha+5)%7:ha.w+7*ha.U-(Ha+6)%7;return"Z"in ha?(ha.tf+=ha.Z/100|0,ha.dh+=ha.Z%100,Xp(ha)):Fa(ha)}}function r(za,Fa,I,ha){for(var Ha=0,Va=Fa.length,vb=I.length,Ra;Ha<Va;){if(ha>=vb)return-1;Ra=Fa.charCodeAt(Ha++);if(37===Ra){if(Ra=Fa.charAt(Ha++),
Ra=Fb[Ra in qF?Fa.charAt(Ha++):Ra],!Ra||0>(ha=Ra(za,I,ha)))return-1}else if(Ra!=I.charCodeAt(ha++))return-1}return ha}var w=l.dateTime,z=l.tB,A=l.time,E=l.sD,J=l.uB,L=l.SD,P=l.QC,X=l.TD,ka=jm(E),oa=km(E),Ba=jm(J),Wa=km(J),Za=jm(L),lc=km(L),ub=jm(P),mc=km(P),Jc=jm(X),Db=km(X),tb={a:function(za){return L[za.getDay()]},A:function(za){return J[za.getDay()]},b:function(za){return X[za.getMonth()]},B:function(za){return P[za.getMonth()]},c:null,d:tF,e:tF,f:iV,H:jV,I:kV,j:lV,L:uF,m:mV,M:nV,p:function(za){return E[+(12<=
za.getHours())]},Q:vF,s:wF,S:oV,u:pV,U:qV,V:rV,w:sV,W:tV,x:null,X:null,y:uV,Y:vV,Z:wV,"%":xF},Ma={a:function(za){return L[za.getUTCDay()]},A:function(za){return J[za.getUTCDay()]},b:function(za){return X[za.getUTCMonth()]},B:function(za){return P[za.getUTCMonth()]},c:null,d:yF,e:yF,f:xV,H:yV,I:zV,j:AV,L:zF,m:BV,M:CV,p:function(za){return E[+(12<=za.getUTCHours())]},Q:vF,s:wF,S:DV,u:EV,U:FV,V:GV,w:HV,W:IV,x:null,X:null,y:JV,Y:KV,Z:LV,"%":xF},Fb={a:function(za,Fa,I){return(Fa=Za.exec(Fa.slice(I)))?
(za.w=lc[Fa[0].toLowerCase()],I+Fa[0].length):-1},A:function(za,Fa,I){return(Fa=Ba.exec(Fa.slice(I)))?(za.w=Wa[Fa[0].toLowerCase()],I+Fa[0].length):-1},b:function(za,Fa,I){return(Fa=Jc.exec(Fa.slice(I)))?(za.fe=Db[Fa[0].toLowerCase()],I+Fa[0].length):-1},B:function(za,Fa,I){return(Fa=ub.exec(Fa.slice(I)))?(za.fe=mc[Fa[0].toLowerCase()],I+Fa[0].length):-1},c:function(za,Fa,I){return r(za,w,Fa,I)},d:AF,e:AF,f:MV,H:BF,I:BF,j:NV,L:OV,m:PV,M:QV,p:function(za,Fa,I){return(Fa=ka.exec(Fa.slice(I)))?(za.p=
oa[Fa[0].toLowerCase()],I+Fa[0].length):-1},Q:RV,s:SV,S:TV,u:UV,U:VV,V:WV,w:XV,W:YV,x:function(za,Fa,I){return r(za,z,Fa,I)},X:function(za,Fa,I){return r(za,A,Fa,I)},y:ZV,Y:$V,Z:aW,"%":bW};tb.x=h(z,tb);tb.X=h(A,tb);tb.c=h(w,tb);Ma.x=h(z,Ma);Ma.X=h(A,Ma);Ma.c=h(w,Ma);return{format:function(za){var Fa=h(za,tb);Fa.toString=function(){return za};return Fa},parse:function(za){var Fa=n(za,gV);Fa.toString=function(){return za};return Fa},ME:function(za){var Fa=h(za,Ma);Fa.toString=function(){return za};
return Fa},NE:function(za){var Fa=n(za,Xp);Fa.toString=function(){return za};return Fa}}}function Rb(l,h,n){var r=0>l?"-":"";l=(r?-l:l)+"";var w=l.length;return r+(w<n?Array(n-w+1).join(h)+l:l)}function cW(l){return l.replace(dW,"\\$&")}function jm(l){return new RegExp("^(?:"+l.map(cW).join("|")+")","i")}function km(l){for(var h={},n=-1,r=l.length;++n<r;)h[l[n].toLowerCase()]=n;return h}function XV(l,h,n){return(h=Rc.exec(h.slice(n,n+1)))?(l.w=+h[0],n+h[0].length):-1}function UV(l,h,n){return(h=Rc.exec(h.slice(n,
n+1)))?(l.JE=+h[0],n+h[0].length):-1}function VV(l,h,n){return(h=Rc.exec(h.slice(n,n+2)))?(l.U=+h[0],n+h[0].length):-1}function WV(l,h,n){return(h=Rc.exec(h.slice(n,n+2)))?(l.nm=+h[0],n+h[0].length):-1}function YV(l,h,n){return(h=Rc.exec(h.slice(n,n+2)))?(l.W=+h[0],n+h[0].length):-1}function $V(l,h,n){return(h=Rc.exec(h.slice(n,n+4)))?(l.y=+h[0],n+h[0].length):-1}function ZV(l,h,n){return(h=Rc.exec(h.slice(n,n+2)))?(l.y=+h[0]+(68<+h[0]?1900:2E3),n+h[0].length):-1}function aW(l,h,n){return(h=/^(Z)|([+-]\d\d)(?::?(\d\d))?/.exec(h.slice(n,
n+6)))?(l.Z=h[1]?0:-(h[2]+(h[3]||"00")),n+h[0].length):-1}function PV(l,h,n){return(h=Rc.exec(h.slice(n,n+2)))?(l.fe=h[0]-1,n+h[0].length):-1}function AF(l,h,n){return(h=Rc.exec(h.slice(n,n+2)))?(l.d=+h[0],n+h[0].length):-1}function NV(l,h,n){return(h=Rc.exec(h.slice(n,n+3)))?(l.fe=0,l.d=+h[0],n+h[0].length):-1}function BF(l,h,n){return(h=Rc.exec(h.slice(n,n+2)))?(l.tf=+h[0],n+h[0].length):-1}function QV(l,h,n){return(h=Rc.exec(h.slice(n,n+2)))?(l.dh=+h[0],n+h[0].length):-1}function TV(l,h,n){return(h=
Rc.exec(h.slice(n,n+2)))?(l.hk=+h[0],n+h[0].length):-1}function OV(l,h,n){return(h=Rc.exec(h.slice(n,n+3)))?(l.vi=+h[0],n+h[0].length):-1}function MV(l,h,n){return(h=Rc.exec(h.slice(n,n+6)))?(l.vi=Math.floor(h[0]/1E3),n+h[0].length):-1}function bW(l,h,n){return(l=eW.exec(h.slice(n,n+1)))?n+l[0].length:-1}function RV(l,h,n){return(h=Rc.exec(h.slice(n)))?(l.Q=+h[0],n+h[0].length):-1}function SV(l,h,n){return(h=Rc.exec(h.slice(n)))?(l.Q=1E3*+h[0],n+h[0].length):-1}function tF(l,h){return Rb(l.getDate(),
h,2)}function jV(l,h){return Rb(l.getHours(),h,2)}function kV(l,h){return Rb(l.getHours()%12||12,h,2)}function lV(l,h){return Rb(1+sF.count(Wj(l),l),h,3)}function uF(l,h){return Rb(l.getMilliseconds(),h,3)}function iV(l,h){return uF(l,h)+"000"}function mV(l,h){return Rb(l.getMonth()+1,h,2)}function nV(l,h){return Rb(l.getMinutes(),h,2)}function oV(l,h){return Rb(l.getSeconds(),h,2)}function pV(l){l=l.getDay();return 0===l?7:l}function qV(l,h){return Rb(fW.count(Wj(l),l),h,2)}function rV(l,h){var n=
l.getDay();l=4<=n||0===n?hv(l):hv.ceil(l);return Rb(hv.count(Wj(l),l)+(4===Wj(l).getDay()),h,2)}function sV(l){return l.getDay()}function tV(l,h){return Rb(gv.count(Wj(l),l),h,2)}function uV(l,h){return Rb(l.getFullYear()%100,h,2)}function vV(l,h){return Rb(l.getFullYear()%1E4,h,4)}function wV(l){l=l.getTimezoneOffset();return(0<l?"-":(l*=-1,"+"))+Rb(l/60|0,"0",2)+Rb(l%60,"0",2)}function yF(l,h){return Rb(l.getUTCDate(),h,2)}function yV(l,h){return Rb(l.getUTCHours(),h,2)}function zV(l,h){return Rb(l.getUTCHours()%
12||12,h,2)}function AV(l,h){return Rb(1+rF.count(Xj(l),l),h,3)}function zF(l,h){return Rb(l.getUTCMilliseconds(),h,3)}function xV(l,h){return zF(l,h)+"000"}function BV(l,h){return Rb(l.getUTCMonth()+1,h,2)}function CV(l,h){return Rb(l.getUTCMinutes(),h,2)}function DV(l,h){return Rb(l.getUTCSeconds(),h,2)}function EV(l){l=l.getUTCDay();return 0===l?7:l}function FV(l,h){return Rb(gW.count(Xj(l),l),h,2)}function GV(l,h){var n=l.getUTCDay();l=4<=n||0===n?iv(l):iv.ceil(l);return Rb(iv.count(Xj(l),l)+
(4===Xj(l).getUTCDay()),h,2)}function HV(l){return l.getUTCDay()}function IV(l,h){return Rb(fv.count(Xj(l),l),h,2)}function JV(l,h){return Rb(l.getUTCFullYear()%100,h,2)}function KV(l,h){return Rb(l.getUTCFullYear()%1E4,h,4)}function LV(){return"+0000"}function xF(){return"%"}function vF(l){return+l}function wF(l){return Math.floor(+l/1E3)}function pb(l){for(var h=l.length/6|0,n=Array(h),r=0;r<h;)n[r]="#"+l.slice(6*r,6*++r);return n}function Wb(l){return hW(l[l.length-1])}function Yp(l){var h=l.length;
return function(n){return l[Math.max(0,Math.min(h-1,Math.floor(n*h)))]}}function jv(l){return function(){return l}}function CF(l){this.Cb=l}function DF(l){return new CF(l)}function iW(l){return l[0]}function jW(l){return l[1]}function EF(l){this.vm=l}function FF(l,h,n){var r=l.Ib-l.oc;h-=l.Ib;var w=(l.Lb-l.xc)/(r||0>h&&-0);l=(n-l.Lb)/(h||0>r&&-0);return((0>w?-1:1)+(0>l?-1:1))*Math.min(Math.abs(w),Math.abs(l),.5*Math.abs((w*h+l*r)/(r+h)))||0}function GF(l,h){var n=l.Ib-l.oc;return n?(3*(l.Lb-l.xc)/
n-h)/2:h}function kv(l,h,n){var r=l.oc,w=l.Ib,z=l.Lb,A=(w-r)/3;l.Cb.bezierCurveTo(r+A,l.xc+A*h,w-A,z-A*n,w,z)}function lv(l){this.Cb=l}function HF(l){this.Cb=new IF(l)}function IF(l){this.Cb=l}function mv(l){return function(){return l}}function kW(l,h,n){this.target=l;this.type=h;this.transform=n}function rg(l,h,n){this.k=l;this.x=h;this.y=n}function lm(){DL.preventDefault();DL.stopImmediatePropagation()}function lW(){return!DL.button}function mW(){var l=this;if(l instanceof SVGElement){l=l.ownerSVGElement||
l;var h=l.width.baseVal.value;l=l.height.baseVal.value}else h=l.clientWidth,l=l.clientHeight;return[[0,0],[h,l]]}function JF(){return this.__zoom||KF}function nW(){return-DL.deltaY*(DL.deltaMode?120:1)/500}function oW(){return"ontouchstart"in this}function pW(l,h,n){var r=l.lw(h[0][0])-n[0][0],w=l.lw(h[1][0])-n[1][0],z=l.mw(h[0][1])-n[0][1];h=l.mw(h[1][1])-n[1][1];return l.translate(w>r?(r+w)/2:Math.min(0,r)||Math.max(0,w),h>z?(z+h)/2:Math.min(0,z)||Math.max(0,h))}(function(l){1===l.length&&(l=c(l));
return{left:function(h,n,r,w){null==r&&(r=0);null==w&&(w=h.length);for(;r<w;){var z=r+w>>>1;0>l(h[z],n)?r=z+1:w=z}return r},right:function(h,n,r,w){null==r&&(r=0);null==w&&(w=h.length);for(;r<w;){var z=r+w>>>1;0<l(h[z],n)?w=z:r=z+1}return r}}})(b);var YT={value:function(){}};e.prototype=d.prototype={constructor:e,on:function(l,h){var n=this.Fb,r=f(l+"",n),w,z=-1,A=r.length;if(2>arguments.length)for(;++z<A;){var E;if(E=w=(l=r[z]).type){a:{E=n[w];for(var J=0,L=E.length;J<L;++J)if((w=E[J]).name===l.name){w=
w.value;break a}w=void 0}E=w}if(E)return w}else{if(null!=h&&"function"!==typeof h)throw Error("invalid callback: "+h);for(;++z<A;)if(w=(l=r[z]).type)n[w]=g(n[w],l.name,h);else if(null==h)for(w in n)n[w]=g(n[w],l.name,null);return this}},copy:function(){var l={},h=this.Fb,n;for(n in h)l[n]=h[n].slice();return new e(l)},call:function(l,h){if(0<(w=arguments.length-2))for(var n=Array(w),r=0,w,z;r<w;++r)n[r]=arguments[r+2];if(!this.Fb.hasOwnProperty(l))throw Error("unknown type: "+l);z=this.Fb[l];r=0;
for(w=z.length;r<w;++r)z[r].value.apply(h,n)},apply:function(l,h,n){if(!this.Fb.hasOwnProperty(l))throw Error("unknown type: "+l);l=this.Fb[l];for(var r=0,w=l.length;r<w;++r)l[r].value.apply(h,n)}};var Pd={svg:"http://www.w3.org/2000/svg",xhtml:"http://www.w3.org/1999/xhtml",xlink:"http://www.w3.org/1999/xlink",xml:"http://www.w3.org/XML/1998/namespace",xmlns:"http://www.w3.org/2000/xmlns/"};if("undefined"!==typeof document){var mm=document.documentElement;if(!mm.matches){var qW=mm.webkitMatchesSelector||
mm.msMatchesSelector||mm.mozMatchesSelector||mm.oMatchesSelector;a=function(l){return function(){return qW.call(this,l)}}}}var LF=a;G.prototype={constructor:G,appendChild:function(l){return this.Pa.insertBefore(l,this.Na)},insertBefore:function(l,h){return this.Pa.insertBefore(l,h)},querySelector:function(l){return this.Pa.querySelector(l)},querySelectorAll:function(l){return this.Pa.querySelectorAll(l)}};var yE={};DL=null;"undefined"!==typeof document&&("onmouseenter"in document.documentElement||
(yE={mouseenter:"mouseover",mouseleave:"mouseout"}));var zE=[null];Qa.prototype=Ia.prototype={constructor:Qa,select:function(l){"function"!==typeof l&&(l=v(l));for(var h=this.wc,n=h.length,r=Array(n),w=0;w<n;++w)for(var z=h[w],A=z.length,E=r[w]=Array(A),J,L,P=0;P<A;++P)(J=z[P])&&(L=l.call(J,J.__data__,P,z))&&("__data__"in J&&(L.__data__=J.__data__),E[P]=L);return new Qa(r,this.ac)},filter:function(l){"function"!==typeof l&&(l=LF(l));for(var h=this.wc,n=h.length,r=Array(n),w=0;w<n;++w)for(var z=h[w],
A=z.length,E=r[w]=[],J,L=0;L<A;++L)(J=z[L])&&l.call(J,J.__data__,L,z)&&E.push(J);return new Qa(r,this.ac)},data:function(l,h){if(!l)return oa=Array(this.size()),L=-1,this.each(function(ub){oa[++L]=ub}),oa;var n=h?aa:N,r=this.ac,w=this.wc;"function"!==typeof l&&(l=K(l));for(var z=w.length,A=Array(z),E=Array(z),J=Array(z),L=0;L<z;++L){var P=r[L],X=w[L],ka=X.length,oa=l.call(P,P&&P.__data__,L,r),Ba=oa.length,Wa=E[L]=Array(Ba),Za=A[L]=Array(Ba);ka=J[L]=Array(ka);n(P,X,Wa,Za,ka,oa,h);X=P=0;for(var lc;P<
Ba;++P)if(ka=Wa[P]){for(P>=X&&(X=P+1);!(lc=Za[X])&&++X<Ba;);ka.Na=lc||null}}A=new Qa(A,r);A.Lz=E;A.Mz=J;return A},rn:function(){return new Qa(this.Lz||this.wc.map(B),this.ac)},Dq:function(){return new Qa(this.Mz||this.wc.map(B),this.ac)},merge:function(l){var h=this.wc;l=l.wc;for(var n=h.length,r=Math.min(n,l.length),w=Array(n),z=0;z<r;++z)for(var A=h[z],E=l[z],J=A.length,L=w[z]=Array(J),P,X=0;X<J;++X)if(P=A[X]||E[X])L[X]=P;for(;z<n;++z)w[z]=h[z];return new Qa(w,this.ac)},order:function(){for(var l=
this.wc,h=-1,n=l.length;++h<n;)for(var r=l[h],w=r.length-1,z=r[w],A;0<=--w;)if(A=r[w])z&&z!==A.nextSibling&&z.parentNode.insertBefore(A,z),z=A;return this},sort:function(l){function h(X,ka){return X&&ka?l(X.__data__,ka.__data__):!X-!ka}l||(l=ca);for(var n=this.wc,r=n.length,w=Array(r),z=0;z<r;++z){for(var A=n[z],E=A.length,J=w[z]=Array(E),L,P=0;P<E;++P)if(L=A[P])J[P]=L;J.sort(h)}return(new Qa(w,this.ac)).order()},call:function(){var l=arguments[0];arguments[0]=this;l.apply(null,arguments);return this},
nodes:function(){var l=Array(this.size()),h=-1;this.each(function(){l[++h]=this});return l},node:function(){for(var l=this.wc,h=0,n=l.length;h<n;++h)for(var r=l[h],w=0,z=r.length;w<z;++w){var A=r[w];if(A)return A}return null},size:function(){var l=0;this.each(function(){++l});return l},empty:function(){return!this.node()},each:function(l){for(var h=this.wc,n=0,r=h.length;n<r;++n)for(var w=h[n],z=0,A=w.length,E;z<A;++z)(E=w[z])&&l.call(E,E.__data__,z,w);return this},style:function(l,h,n){return 1<
arguments.length?this.each((null==h?ia:"function"===typeof h?U:O)(l,h,null==n?"":n)):Q(this.node(),l)},nx:function(l,h){return 1<arguments.length?this.each((null==h?la:"function"===typeof h?M:F)(l,h)):this.node()[l]},text:function(l){return arguments.length?this.each(null==l?W:("function"===typeof l?qb:Aa)(l)):this.node().textContent},append:function(l){var h="function"===typeof l?l:p(l);return this.select(function(){return this.appendChild(h.apply(this,arguments))})},ar:function(l,h){var n="function"===
typeof l?l:p(l),r=null==h?wb:"function"===typeof h?h:v(h);return this.select(function(){return this.insertBefore(n.apply(this,arguments),r.apply(this,arguments)||null)})},remove:function(){return this.each(Ja)},clone:function(l){return this.select(l?Na:Ub)},on:function(l,h,n){var r=ea(l+""),w=r.length,z;if(2>arguments.length){var A=this.node().__on;if(A)for(var E=0,J=A.length,L;E<J;++E){var P=0;for(L=A[E];P<w;++P)if((z=r[P]).type===L.type&&z.name===L.name)return L.value}}else{A=h?Ka:na;null==n&&(n=
!1);for(P=0;P<w;++P)this.each(A(r[P],h,n));return this}}};var ZT=0;pa.prototype=function(){return new pa}.prototype={constructor:pa,get:function(l){for(var h=this.Fb;!(h in l);)if(!(l=l.parentNode))return;return l[h]},set:function(l,h){return l[this.Fb]=h},remove:function(l){return this.Fb in l&&delete l[this.Fb]},toString:function(){return this.Fb}};var Yj=1/.7,$T=/^#([0-9a-f]{3})$/,aU=/^#([0-9a-f]{6})$/,bU=RegExp("^rgb\\(\\s*([+-]?\\d+)\\s*,\\s*([+-]?\\d+)\\s*,\\s*([+-]?\\d+)\\s*\\)$"),cU=RegExp("^rgb\\(\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*\\)$"),
dU=RegExp("^rgba\\(\\s*([+-]?\\d+)\\s*,\\s*([+-]?\\d+)\\s*,\\s*([+-]?\\d+)\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)\\s*\\)$"),eU=RegExp("^rgba\\(\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)\\s*\\)$"),fU=RegExp("^hsl\\(\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*\\)$"),
gU=RegExp("^hsla\\(\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)%\\s*,\\s*([+-]?\\d*\\.?\\d+(?:[eE][+-]?\\d+)?)\\s*\\)$"),AE={aliceblue:15792383,antiquewhite:16444375,aqua:65535,aquamarine:8388564,azure:15794175,beige:16119260,bisque:16770244,black:0,blanchedalmond:16772045,blue:255,blueviolet:9055202,brown:10824234,burlywood:14596231,cadetblue:6266528,chartreuse:8388352,chocolate:13789470,coral:16744272,cornflowerblue:6591981,
cornsilk:16775388,crimson:14423100,cyan:65535,darkblue:139,darkcyan:35723,darkgoldenrod:12092939,darkgray:11119017,darkgreen:25600,darkgrey:11119017,darkkhaki:12433259,darkmagenta:9109643,darkolivegreen:5597999,darkorange:16747520,darkorchid:10040012,darkred:9109504,darksalmon:15308410,darkseagreen:9419919,darkslateblue:4734347,darkslategray:3100495,darkslategrey:3100495,darkturquoise:52945,darkviolet:9699539,deeppink:16716947,deepskyblue:49151,dimgray:6908265,dimgrey:6908265,dodgerblue:2003199,firebrick:11674146,
floralwhite:16775920,forestgreen:2263842,fuchsia:16711935,gainsboro:14474460,ghostwhite:16316671,gold:16766720,goldenrod:14329120,gray:8421504,green:32768,greenyellow:11403055,grey:8421504,honeydew:15794160,hotpink:16738740,indianred:13458524,indigo:4915330,ivory:16777200,khaki:15787660,lavender:15132410,lavenderblush:16773365,lawngreen:8190976,lemonchiffon:16775885,lightblue:11393254,lightcoral:15761536,lightcyan:14745599,lightgoldenrodyellow:16448210,lightgray:13882323,lightgreen:9498256,lightgrey:13882323,
lightpink:16758465,lightsalmon:16752762,lightseagreen:2142890,lightskyblue:8900346,lightslategray:7833753,lightslategrey:7833753,lightsteelblue:11584734,lightyellow:16777184,lime:65280,limegreen:3329330,linen:16445670,magenta:16711935,maroon:8388608,mediumaquamarine:6737322,mediumblue:205,mediumorchid:12211667,mediumpurple:9662683,mediumseagreen:3978097,mediumslateblue:8087790,mediumspringgreen:64154,mediumturquoise:4772300,mediumvioletred:13047173,midnightblue:1644912,mintcream:16121850,mistyrose:16770273,
moccasin:16770229,navajowhite:16768685,navy:128,oldlace:16643558,olive:8421376,olivedrab:7048739,orange:16753920,orangered:16729344,orchid:14315734,palegoldenrod:15657130,palegreen:10025880,paleturquoise:11529966,palevioletred:14381203,papayawhip:16773077,peachpuff:16767673,peru:13468991,pink:16761035,plum:14524637,powderblue:11591910,purple:8388736,rebeccapurple:6697881,red:16711680,rosybrown:12357519,royalblue:4286945,saddlebrown:9127187,salmon:16416882,sandybrown:16032864,seagreen:3050327,seashell:16774638,
sienna:10506797,silver:12632256,skyblue:8900331,slateblue:6970061,slategray:7372944,slategrey:7372944,snow:16775930,springgreen:65407,steelblue:4620980,tan:13808780,teal:32896,thistle:14204888,tomato:16737095,turquoise:4251856,violet:15631086,wheat:16113331,white:16777215,whitesmoke:16119285,yellow:16776960,yellowgreen:10145074};pc(Dc,jc,{xq:function(){return this.nf().xq()},ew:function(){return this.nf().ew()},toString:function(){return this.nf()+""}});pc(Vb,Sc,Ud(Dc,{Wm:function(l){l=null==l?Yj:
Math.pow(Yj,l);return new Vb(this.r*l,this.g*l,this.b*l,this.opacity)},gn:function(l){l=null==l?.7:Math.pow(.7,l);return new Vb(this.r*l,this.g*l,this.b*l,this.opacity)},nf:function(){return this},xq:function(){return 0<=this.r&&255>=this.r&&0<=this.g&&255>=this.g&&0<=this.b&&255>=this.b&&0<=this.opacity&&1>=this.opacity},ew:function(){return"#"+pd(this.r)+pd(this.g)+pd(this.b)},toString:function(){var l=this.opacity;l=isNaN(l)?1:Math.max(0,Math.min(1,l));return(1===l?"rgb(":"rgba(")+Math.max(0,Math.min(255,
Math.round(this.r)||0))+", "+Math.max(0,Math.min(255,Math.round(this.g)||0))+", "+Math.max(0,Math.min(255,Math.round(this.b)||0))+(1===l?")":", "+l+")")}}));pc(qd,fd,Ud(Dc,{Wm:function(l){l=null==l?Yj:Math.pow(Yj,l);return new qd(this.h,this.s,this.l*l,this.opacity)},gn:function(l){l=null==l?.7:Math.pow(.7,l);return new qd(this.h,this.s,this.l*l,this.opacity)},nf:function(){var l=this.h%360+360*(0>this.h),h=this.l,n=h+(.5>h?h:1-h)*(isNaN(l)||isNaN(this.s)?0:this.s);h=2*h-n;return new Vb(Ju(240<=l?
l-240:l+120,h,n),Ju(l,h,n),Ju(120>l?l+240:l-120,h,n),this.opacity)},xq:function(){return(0<=this.s&&1>=this.s||isNaN(this.s))&&0<=this.l&&1>=this.l&&0<=this.opacity&&1>=this.opacity}}));var BE=Math.PI/180,EE=180/Math.PI,DE=4/29,Uj=6/29,CE=3*Uj*Uj,hU=Uj*Uj*Uj;pc(Ne,function(l,h,n,r){return 1===arguments.length?Ku(l):new Ne(l,h,n,null==r?1:r)},Ud(Dc,{Wm:function(l){return new Ne(this.l+18*(null==l?1:l),this.a,this.b,this.opacity)},gn:function(l){return new Ne(this.l-18*(null==l?1:l),this.a,this.b,this.opacity)},
nf:function(){var l=(this.l+16)/116,h=isNaN(this.a)?l:l+this.a/500,n=isNaN(this.b)?l:l-this.b/200;h=.96422*Nu(h);l=1*Nu(l);n=.82521*Nu(n);return new Vb(Ou(3.1338561*h-1.6168667*l-.4906146*n),Ou(-.9787684*h+1.9161415*l+.033454*n),Ou(.0719453*h-.2289914*l+1.4052427*n),this.opacity)}}));pc(zf,Pu,Ud(Dc,{Wm:function(l){return new zf(this.h,this.c,this.l+18*(null==l?1:l),this.opacity)},gn:function(l){return new zf(this.h,this.c,this.l-18*(null==l?1:l),this.opacity)},nf:function(){return Ku(this).nf()}}));
var FE=1.78277*-.29227-.1347134789;pc(Fh,Oe,Ud(Dc,{Wm:function(l){l=null==l?Yj:Math.pow(Yj,l);return new Fh(this.h,this.s,this.l*l,this.opacity)},gn:function(l){l=null==l?.7:Math.pow(.7,l);return new Fh(this.h,this.s,this.l*l,this.opacity)},nf:function(){var l=isNaN(this.h)?0:(this.h+120)*BE,h=+this.l,n=isNaN(this.s)?0:this.s*h*(1-h),r=Math.cos(l);l=Math.sin(l);return new Vb(255*(h+n*(-.14861*r+1.78277*l)),255*(h+n*(-.29227*r+-.90649*l)),255*(h+1.97294*n*r),this.opacity)}}));var Kp=function n(h){function r(z,
A){var E=w((z=Sc(z)).r,(A=Sc(A)).r),J=w(z.g,A.g),L=w(z.b,A.b),P=md(z.opacity,A.opacity);return function(X){z.r=E(X);z.g=J(X);z.b=L(X);z.opacity=P(X);return z+""}}var w=kU(h);r.gamma=n;return r}(1),hW=IE(function(h){var n=h.length-1;return function(r){var w=0>=r?r=0:1<=r?(r=1,n-1):Math.floor(r*n),z=h[w],A=h[w+1];return GE((r-w/n)*n,0<w?h[w-1]:2*z-A,z,A,w<n-1?h[w+2]:2*A-z)}});IE(function(h){var n=h.length;return function(r){var w=Math.floor((0>(r%=1)?++r:r)*n);return GE((r-w/n)*n,h[(w+n-1)%n],h[w%n],
h[(w+1)%n],h[(w+2)%n])}});var Su=/[-+]?(?:\d+\.?\d*|\.?\d+)(?:[eE][-+]?\d+)?/g,Tu=new RegExp(Su.source,"g"),LE=180/Math.PI,nv={translateX:0,translateY:0,rotate:0,skewX:0,js:1,ks:1},nm,ov,MF,Zp,rW=ME(function(h){if("none"===h)return nv;nm||(nm=document.createElement("DIV"),ov=document.documentElement,MF=document.defaultView);nm.style.transform=h;h=MF.getComputedStyle(ov.appendChild(nm),null).getPropertyValue("transform");ov.removeChild(nm);h=h.slice(7,-1).split(",");return KE(+h[0],+h[1],+h[2],+h[3],
+h[4],+h[5])},"px, ","px)","deg)");ME(function(h){if(null==h)return nv;Zp||(Zp=document.createElementNS("http://www.w3.org/2000/svg","g"));Zp.setAttribute("transform",h);if(!(h=Zp.transform.baseVal.consolidate()))return nv;h=h.matrix;return KE(h.a,h.b,h.c,h.d,h.e,h.f)},", ",")",")");var bm=Math.SQRT2;OE(Qu);OE(md);PE(Qu);PE(md);QE(Qu);var pv=QE(md),Vj=0,dm=0,fm=0,Pp,em,Op=0,Gh=0,Mp=0,cm="object"===typeof performance&&performance.now?performance:Date,RE="object"===typeof window&&window.requestAnimationFrame?
window.requestAnimationFrame.bind(window):function(h){setTimeout(h,17)};Np.prototype=SE.prototype={constructor:Np,ke:function(h,n,r){if("function"!==typeof h)throw new TypeError("callback is not a function");r=(null==r?Lp():+r)+(null==n?0:+n);this.Na||em===this||(em?em.Na=this:Pp=this,em=this);this.mk=h;this.Ck=r;Uu()},stop:function(){this.mk&&(this.mk=null,this.Ck=Infinity,Uu())}};var uU=d("start","end","interrupt"),vU=[],sW=Ia.prototype.constructor,NF=0,Zj=Ia.prototype;pg.prototype=function(h){return Ia().transition(h)}.prototype=
{constructor:pg,select:function(h){var n=this.qh,r=this.Wb;"function"!==typeof h&&(h=v(h));for(var w=this.wc,z=w.length,A=Array(z),E=0;E<z;++E)for(var J=w[E],L=J.length,P=A[E]=Array(L),X,ka,oa=0;oa<L;++oa)(X=J[oa])&&(ka=h.call(X,X.__data__,oa,J))&&("__data__"in X&&(ka.__data__=X.__data__),P[oa]=ka,Vu(P[oa],n,r,oa,P,Qe(X,r)));return new pg(A,this.ac,n,r)},filter:function(h){"function"!==typeof h&&(h=LF(h));for(var n=this.wc,r=n.length,w=Array(r),z=0;z<r;++z)for(var A=n[z],E=A.length,J=w[z]=[],L,P=
0;P<E;++P)(L=A[P])&&h.call(L,L.__data__,P,A)&&J.push(L);return new pg(w,this.ac,this.qh,this.Wb)},merge:function(h){if(h.Wb!==this.Wb)throw Error();var n=this.wc;h=h.wc;for(var r=n.length,w=Math.min(r,h.length),z=Array(r),A=0;A<w;++A)for(var E=n[A],J=h[A],L=E.length,P=z[A]=Array(L),X,ka=0;ka<L;++ka)if(X=E[ka]||J[ka])P[ka]=X;for(;A<r;++A)z[A]=n[A];return new pg(z,this.ac,this.qh,this.Wb)},selection:function(){return new sW(this.wc,this.ac)},transition:function(){for(var h=this.qh,n=this.Wb,r=++NF,
w=this.wc,z=w.length,A=0;A<z;++A)for(var E=w[A],J=E.length,L,P=0;P<J;++P)if(L=E[P]){var X=Qe(L,n);Vu(L,h,r,P,E,{time:X.time+X.delay+X.duration,delay:0,duration:X.duration,Mf:X.Mf})}return new pg(w,this.ac,h,r)},call:Zj.call,nodes:Zj.nodes,node:Zj.node,size:Zj.size,empty:Zj.empty,each:Zj.each,on:function(h,n){var r=this.Wb;return 2>arguments.length?Qe(this.node(),r).on.on(h):this.each(FU(r,h,n))},style:function(h,n,r){var w="transform"===h?rW:yU;return null==n?this.ey(h,HU(h,w)).on("end.style."+h,
IU(h)):this.ey(h,"function"===typeof n?KU(h,w,VE(this,"style."+h,n)):JU(h,w,n+""),r)},ey:function(h,n,r){var w="style."+h;if(2>arguments.length)return(w=this.Nd(w))&&w.kd;if(null==n)return this.Nd(w,null);if("function"!==typeof n)throw Error();return this.Nd(w,LU(h,n,null==r?"":r))},text:function(h){return this.Nd("text","function"===typeof h?NU(VE(this,"text",h)):MU(null==h?"":h+""))},remove:function(){return this.on("end.remove",GU(this.Wb))},Nd:function(h,n){var r=this.Wb;if(2>arguments.length){r=
Qe(this.node(),r).Nd;for(var w=0,z=r.length,A;w<z;++w)if((A=r[w]).name===h)return A.value;return null}return this.each((null==n?wU:xU)(r,h,n))},delay:function(h){var n=this.Wb;return arguments.length?this.each(("function"===typeof h?zU:AU)(n,h)):Qe(this.node(),n).delay},duration:function(h){var n=this.Wb;return arguments.length?this.each(("function"===typeof h?BU:CU)(n,h)):Qe(this.node(),n).duration},Mf:function(h){var n=this.Wb;return arguments.length?this.each(DU(n,h)):Qe(this.node(),n).Mf}};var qv=
{time:null,delay:0,duration:250,Mf:function(h){return(1>=(h*=2)?h*h*h:(h-=2)*h*h+2)/2}};Ia.prototype.rC=function(){return this.each(function(){Qp(this,void 0)})};Ia.prototype.transition=function(h){var n;if(h instanceof pg){var r=h.Wb;h=h.qh}else r=++NF,(n=qv).time=Lp(),h=null==h?null:h+"";for(var w=this.wc,z=w.length,A=0;A<z;++A)for(var E=w[A],J=E.length,L,P=0;P<J;++P)if(L=E[P]){var X=L,ka=h,oa=r,Ba=P,Wa=E,Za;if(!(Za=n))a:{Za=void 0;for(var lc=r;!(Za=L.gg)||!(Za=Za[lc]);)if(!(L=L.parentNode)){Za=
(qv.time=Lp(),qv);break a}}Vu(X,ka,oa,Ba,Wa,Za)}return new pg(w,this.ac,h,r)};["e","w"].map(Xu);["n","s"].map(Xu);"n e s w nw ne se sw".split(" ").map(Xu);Yu.prototype=WE.prototype={constructor:Yu,moveTo:function(h,n){this.Fb+="M"+(this.oc=this.Ib=+h)+","+(this.xc=this.Lb=+n)},closePath:function(){null!==this.Ib&&(this.Ib=this.oc,this.Lb=this.xc,this.Fb+="Z")},lineTo:function(h,n){this.Fb+="L"+(this.Ib=+h)+","+(this.Lb=+n)},bezierCurveTo:function(h,n,r,w,z,A){this.Fb+="C"+ +h+","+ +n+","+ +r+","+
+w+","+(this.Ib=+z)+","+(this.Lb=+A)},rect:function(h,n,r,w){this.Fb+="M"+(this.oc=this.Ib=+h)+","+(this.xc=this.Lb=+n)+"h"+ +r+"v"+ +w+"h"+-r+"Z"},toString:function(){return this.Fb}};Rp.prototype=XE.prototype={constructor:Rp,has:function(h){return" "+h in this},get:function(h){return this[" "+h]},set:function(h,n){this[" "+h]=n;return this},remove:function(h){h=" "+h;return h in this&&delete this[h]},clear:function(){for(var h in this)" "===h[0]&&delete this[h]},keys:function(){var h=[],n;for(n in this)" "===
n[0]&&h.push(n.slice(1));return h},values:function(){var h=[],n;for(n in this)" "===n[0]&&h.push(this[n]);return h},entries:function(){var h=[],n;for(n in this)" "===n[0]&&h.push({key:n.slice(1),value:this[n]});return h},size:function(){var h=0,n;for(n in this)" "===n[0]&&++h;return h},empty:function(){for(var h in this)if(" "===h[0])return!1;return!0},each:function(h){for(var n in this)" "===n[0]&&h(this[n],n.slice(1),this)}};var Kh=XE.prototype;Sp.prototype=function(h,n){var r=new Sp;if(h instanceof
Sp)h.each(function(A){r.add(A)});else if(h){var w=-1,z=h.length;if(null==n)for(;++w<z;)r.add(h[w]);else for(;++w<z;)r.add(n(h[w],w,h))}return r}.prototype={constructor:Sp,has:Kh.has,add:function(h){this[" "+h]=h;return this},remove:Kh.remove,clear:Kh.clear,values:Kh.keys,size:Kh.size,empty:Kh.empty,each:Kh.each};var $E={},Zu={},tW=ZE(",").parse,uW=ZE("\t").parse;aF(tW);aF(uW);var ed=function(h,n,r){n=new $u(null==n?RU:n,null==r?SU:r,NaN,NaN,NaN,NaN);return null==h?n:n.addAll(h)}.prototype=$u.prototype;
ed.copy=function(){var h=new $u(this.mg,this.ng,this.oc,this.xc,this.Ib,this.Lb),n=this.ub,r,w;if(!n)return h;if(!n.length)return h.ub=cF(n),h;for(r=[{source:n,target:h.ub=Array(4)}];n=r.pop();)for(var z=0;4>z;++z)if(w=n.source[z])w.length?r.push({source:w,target:n.target[z]=Array(4)}):n.target[z]=cF(w);return h};ed.add=function(h){var n=+this.mg.call(null,h),r=+this.ng.call(null,h);return bF(this.Tk(n,r),n,r,h)};ed.addAll=function(h){var n,r,w=h.length,z,A,E=Array(w),J=Array(w),L=Infinity,P=Infinity,
X=-Infinity,ka=-Infinity;for(r=0;r<w;++r)isNaN(z=+this.mg.call(null,n=h[r]))||isNaN(A=+this.ng.call(null,n))||(E[r]=z,J[r]=A,z<L&&(L=z),z>X&&(X=z),A<P&&(P=A),A>ka&&(ka=A));X<L&&(L=this.oc,X=this.Ib);ka<P&&(P=this.xc,ka=this.Lb);this.Tk(L,P).Tk(X,ka);for(r=0;r<w;++r)bF(this,E[r],J[r],h[r]);return this};ed.Tk=function(h,n){if(isNaN(h=+h)||isNaN(n=+n))return this;var r=this.oc,w=this.xc,z=this.Ib,A=this.Lb;if(isNaN(r))z=(r=Math.floor(h))+1,A=(w=Math.floor(n))+1;else if(r>h||h>z||w>n||n>A){var E=z-r,
J=this.ub,L;switch(L=(n<(w+A)/2)<<1|h<(r+z)/2){case 0:do{var P=Array(4);P[L]=J;J=P}while(E*=2,z=r+E,A=w+E,h>z||n>A);break;case 1:do P=Array(4),P[L]=J,J=P;while(E*=2,r=z-E,A=w+E,r>h||n>A);break;case 2:do P=Array(4),P[L]=J,J=P;while(E*=2,z=r+E,w=A-E,h>z||w>n);break;case 3:do P=Array(4),P[L]=J,J=P;while(E*=2,r=z-E,w=A-E,r>h||w>n)}this.ub&&this.ub.length&&(this.ub=J)}else return this;this.oc=r;this.xc=w;this.Ib=z;this.Lb=A;return this};ed.data=function(){var h=[];this.Fy(function(n){if(!n.length){do h.push(n.data);
while(n=n.next)}});return h};ed.cl=function(h){return arguments.length?this.Tk(+h[0][0],+h[0][1]).Tk(+h[1][0],+h[1][1]):isNaN(this.oc)?void 0:[[this.oc,this.xc],[this.Ib,this.Lb]]};ed.find=function(h,n,r){var w=this.oc,z=this.xc,A,E,J,L,P=this.Ib,X=this.Lb,ka=[],oa=this.ub,Ba;oa&&ka.push(new dd(oa,w,z,P,X));null==r?r=Infinity:(w=h-r,z=n-r,P=h+r,X=n+r,r*=r);for(;Ba=ka.pop();)if(!(!(oa=Ba.node)||(A=Ba.Mo)>P||(E=Ba.No)>X||(J=Ba.x1)<w||(L=Ba.y1)<z))if(oa.length){Ba=(A+J)/2;var Wa=(E+L)/2;ka.push(new dd(oa[3],
Ba,Wa,J,L),new dd(oa[2],A,Wa,Ba,L),new dd(oa[1],Ba,E,J,Wa),new dd(oa[0],A,E,Ba,Wa));if(oa=(n>=Wa)<<1|h>=Ba)Ba=ka[ka.length-1],ka[ka.length-1]=ka[ka.length-1-oa],ka[ka.length-1-oa]=Ba}else if(Ba=h-+this.mg.call(null,oa.data),Wa=n-+this.ng.call(null,oa.data),Ba=Ba*Ba+Wa*Wa,Ba<r){var Za=Math.sqrt(r=Ba);w=h-Za;z=n-Za;P=h+Za;X=n+Za;Za=oa.data}return Za};ed.remove=function(h){if(isNaN(L=+this.mg.call(null,h))||isNaN(P=+this.ng.call(null,h)))return this;var n,r=this.ub,w,z=this.oc,A=this.xc,E=this.Ib,J=
this.Lb,L,P,X,ka,oa,Ba,Wa;if(!r)return this;if(r.length)for(;;){(oa=L>=(X=(z+E)/2))?z=X:E=X;(Ba=P>=(ka=(A+J)/2))?A=ka:J=ka;if(!(n=r,r=r[Wa=Ba<<1|oa]))return this;if(!r.length)break;if(n[Wa+1&3]||n[Wa+2&3]||n[Wa+3&3]){var Za=n;var lc=Wa}}for(;r.data!==h;)if(!(w=r,r=r.next))return this;(h=r.next)&&delete r.next;if(w)return h?w.next=h:delete w.next,this;if(!n)return this.ub=h,this;h?n[Wa]=h:delete n[Wa];(r=n[0]||n[1]||n[2]||n[3])&&r===(n[3]||n[2]||n[1]||n[0])&&!r.length&&(Za?Za[lc]=r:this.ub=r);return this};
ed.oG=function(h){for(var n=0,r=h.length;n<r;++n)this.remove(h[n]);return this};ed.root=function(){return this.ub};ed.size=function(){var h=0;this.Fy(function(n){if(!n.length){do++h;while(n=n.next)}});return h};ed.Fy=function(h){var n=[],r,w=this.ub,z,A,E,J,L;for(w&&n.push(new dd(w,this.oc,this.xc,this.Ib,this.Lb));r=n.pop();)if(!h(w=r.node,A=r.Mo,E=r.No,J=r.x1,L=r.y1)&&w.length){r=(A+J)/2;var P=(E+L)/2;(z=w[3])&&n.push(new dd(z,r,P,J,L));(z=w[2])&&n.push(new dd(z,A,P,r,L));(z=w[1])&&n.push(new dd(z,
r,E,J,P));(z=w[0])&&n.push(new dd(z,A,E,r,P))}};ed.CG=function(h){var n=[],r=[],w;for(this.ub&&n.push(new dd(this.ub,this.oc,this.xc,this.Ib,this.Lb));w=n.pop();){var z=w.node;if(z.length){var A,E=w.Mo,J=w.No,L=w.x1,P=w.y1,X=(E+L)/2,ka=(J+P)/2;(A=z[0])&&n.push(new dd(A,E,J,X,ka));(A=z[1])&&n.push(new dd(A,X,J,L,ka));(A=z[2])&&n.push(new dd(A,E,ka,X,P));(A=z[3])&&n.push(new dd(A,X,ka,L,P))}r.push(w)}for(;w=r.pop();)h(w.node,w.Mo,w.No,w.x1,w.y1);return this};ed.x=function(h){return arguments.length?
(this.mg=h,this):this.mg};ed.y=function(h){return arguments.length?(this.ng=h,this):this.ng};var WU=/^(?:(.)?([<>=^]))?([+\-( ])?([$#])?(0)?(\d+)?(,)?(\.\d+)?(~)?([a-z%])?$/i;av.prototype=bv.prototype;bv.prototype.toString=function(){return this.fill+this.align+this.sign+this.symbol+(this.zero?"0":"")+(null==this.width?"":Math.max(1,this.width|0))+(this.dv?",":"")+(null==this.precision?"":"."+Math.max(0,this.precision|0))+(this.trim?"~":"")+this.type};var gF,hF={"%":function(h,n){return(100*h).toFixed(n)},
b:function(h){return Math.round(h).toString(2)},c:function(h){return h+""},d:function(h){return Math.round(h).toString(10)},e:function(h,n){return h.toExponential(n)},f:function(h,n){return h.toFixed(n)},g:function(h,n){return h.toPrecision(n)},o:function(h){return Math.round(h).toString(8)},p:function(h,n){return dF(100*h,n)},r:dF,s:function(h,n){var r=Tp(h,n);if(!r)return h+"";var w=r[0];r=r[1];r=r-(gF=3*Math.max(-8,Math.min(8,Math.floor(r/3))))+1;var z=w.length;return r===z?w:r>z?w+Array(r-z+1).join("0"):
0<r?w.slice(0,r)+"."+w.slice(r):"0."+Array(1-r).join("0")+Tp(h,Math.max(0,n+r-1))[0]},X:function(h){return Math.round(h).toString(16).toUpperCase()},x:function(h){return Math.round(h).toString(16)}},fF="y z a f p n \u00b5 m  k M G T P E Z Y".split(" "),vW;(function(h){return vW=XU(h)})({vB:".",my:",",Yv:[3],currency:["$",""]});ie.prototype={constructor:ie,reset:function(){this.s=this.t=0},add:function(h){iF($p,h,this.t);iF(this,$p.s,this.s);this.s?this.t+=$p.t:this.s=$p.t},valueOf:function(){return this.s}};
var $p=new ie,uc=Math.PI,Qd=uc/2,OF=uc/4,wW=2*uc,rv=uc/180,qg=Math.abs,sv=Math.atan,oF=Math.atan2,Rd=Math.cos,$c=Math.sin,Vp=Math.sqrt;new ie;new ie;new ie;var tv=new ie;(function(h,n,r,w){return function(z){function A(Db,tb){h(Db,tb)&&z.point(Db,tb)}function E(Db,tb){oa.point(Db,tb)}function J(){Jc.point=E;oa.ic()}function L(){Jc.point=A;oa.hc()}function P(Db,tb){mc.push([Db,tb]);Wa.point(Db,tb)}function X(){Wa.ic();mc=[]}function ka(){P(mc[0][0],mc[0][1]);Wa.hc();var Db=Wa.fB(),tb=Ba.result(),Ma=
tb.length,Fb;mc.pop();lc.push(mc);mc=null;if(Ma)if(Db&1){if(Ma=tb[0],0<(tb=Ma.length-1)){Za||(z.Dj(),Za=!0);z.ic();for(Db=0;Db<tb;++Db)z.point((Fb=Ma[Db])[0],Fb[1]);z.hc()}}else 1<Ma&&Db&2&&tb.push(tb.pop().concat(tb.shift())),ub.push(tb.filter(aV))}var oa=n(z),Ba=ZU(),Wa=n(Ba),Za=!1,lc,ub,mc,Jc={point:A,ic:J,hc:L,Dj:function(){Jc.point=P;Jc.ic=X;Jc.hc=ka;ub=[];lc=[]},po:function(){Jc.point=A;Jc.ic=J;Jc.hc=L;var Db=ub,tb=Db.length;var Ma=-1;for(var Fb=0,za,Fa;++Ma<tb;)Fb+=Db[Ma].length;for(za=Array(Fb);0<=
--tb;)for(Fa=Db[tb],Ma=Fa.length;0<=--Ma;)za[--Fb]=Fa[Ma];ub=za;Db=lc;tb=w[0];Fb=w[1];var I=$c(Fb);Ma=[$c(tb),-Rd(tb),0];Fa=za=0;tv.reset();1===I?Fb=Qd+1E-6:-1===I&&(Fb=-Qd-1E-6);I=0;for(var ha=Db.length;I<ha;++I)if(Va=(Ha=Db[I]).length){var Ha,Va,vb=Ha[Va-1],Ra=vb[0],Qb=vb[1]/2+OF,nd=$c(Qb),ak=Rd(Qb);for(Qb=0;Qb<Va;++Qb,Ra=zd,nd=bk,ak=om,vb=ck){var ck=Ha[Qb],zd=ck[0];om=ck[1]/2+OF;var bk=$c(om),om=Rd(om),dk=zd-Ra,uv=0<=dk?1:-1,vv=uv*dk,aq=vv>uc;nd*=bk;tv.add(oF(nd*uv*$c(vv),ak*om+nd*Rd(vv)));za+=
aq?dk+uv*wW:dk;aq^Ra>=tb^zd>=tb&&(vb=kF(jF(vb),jF(ck)),lF(vb),Ra=kF(Ma,vb),lF(Ra),Ra=(aq^0<=dk?-1:1)*Up(Ra[2]),Fb>Ra||Fb===Ra&&(vb[0]||vb[1]))&&(Fa+=aq^0<=dk?1:-1)}}Db=(-1E-6>za||1E-6>za&&-1E-6>tv)^Fa&1;ub.length?(Za||(z.Dj(),Za=!0),$U(ub,bV,Db,r,z)):Db&&(Za||(z.Dj(),Za=!0),z.ic(),r(null,null,1,z),z.hc());Za&&(z.po(),Za=!1);ub=lc=null},Yx:function(){z.Dj();z.ic();r(null,null,1,z);z.hc();z.po()}};return Jc}})(function(){return!0},function(h){var n=NaN,r=NaN,w=NaN,z;return{ic:function(){h.ic();z=1},
point:function(A,E){var J=0<A?uc:-uc,L=qg(A-n);if(1E-6>qg(L-uc))h.point(n,r=0<(r+E)/2?Qd:-Qd),h.point(w,r),h.hc(),h.ic(),h.point(J,r),h.point(A,r),z=0;else if(w!==J&&L>=uc){1E-6>qg(n-w)&&(n-=1E-6*w);1E-6>qg(A-J)&&(A-=1E-6*J);L=n;var P=r,X=A,ka,oa,Ba=$c(L-X);r=1E-6<qg(Ba)?sv(($c(P)*(oa=Rd(E))*$c(X)-$c(E)*(ka=Rd(P))*$c(L))/(ka*oa*Ba)):(P+E)/2;h.point(w,r);h.hc();h.ic();h.point(J,r);z=0}h.point(n=A,r=E);w=J},hc:function(){h.hc();n=r=NaN},fB:function(){return 2-z}}},function(h,n,r,w){null==h?(r*=Qd,w.point(-uc,
r),w.point(0,r),w.point(uc,r),w.point(uc,0),w.point(uc,-r),w.point(0,-r),w.point(-uc,-r),w.point(-uc,0),w.point(-uc,r)):1E-6<qg(h[0]-n[0])?(h=h[0]<n[0]?uc:-uc,r=r*h/2,w.point(-h,r),w.point(0,r),w.point(h,r)):w.point(n[0],n[1])},[-uc,-Qd]);new ie;new ie;new ie;new ie;cv.prototype={constructor:cv,point:function(h,n){this.stream.point(h,n)},Yx:function(){this.stream.Yx()},ic:function(){this.stream.ic()},hc:function(){this.stream.hc()},Dj:function(){this.stream.Dj()},po:function(){this.stream.po()}};
Rd(30*rv);(function(h){return function(n){var r=new cv,w;for(w in h)r[w]=h[w];r.stream=n;return r}})({point:function(h,n){this.stream.point(h*rv,n*rv)}});nF(function(h){return Vp(2/(1+h))}).invert=gm(function(h){return 2*Up(h/2)});nF(function(h){return(h=1<h?0:-1>h?uc:Math.acos(h))&&h/$c(h)}).invert=gm(function(h){return h});Vp(3);gm(sv);gm(Up);gm(function(h){return 2*sv(h)});hm.prototype=pF.prototype={constructor:hm,count:function(){return this.Kv(cV)},each:function(h){var n,r=[this],w;do{var z=
r.reverse();for(r=[];n=z.pop();)if(h(n),n=n.children){var A=0;for(w=n.length;A<w;++A)r.push(n[A])}}while(r.length);return this},Kv:function(h){for(var n,r=[this],w=[],z,A;n=r.pop();)if(w.push(n),n=n.children)for(z=0,A=n.length;z<A;++z)r.push(n[z]);for(;n=w.pop();)h(n);return this},yq:function(h){for(var n,r=[this],w;n=r.pop();)if(h(n),n=n.children)for(w=n.length-1;0<=w;--w)r.push(n[w]);return this},li:function(h){return this.Kv(function(n){for(var r=+h(n.data)||0,w=n.children,z=w&&w.length;0<=--z;)r+=
w[z].value;n.value=r})},sort:function(h){return this.yq(function(n){n.children&&n.children.sort(h)})},path:function(h){var n=this;var r=n;var w=h;if(r!==w){var z=r.Gu(),A=w.Gu(),E=null;r=z.pop();for(w=A.pop();r===w;)E=r,r=z.pop(),w=A.pop();r=E}for(w=[n];n!==r;)n=n.parent,w.push(n);for(n=w.length;h!==r;)w.splice(n,0,h),h=h.parent;return w},Gu:function(){for(var h=this,n=[h];h=h.parent;)n.push(h);return n},links:function(){var h=this,n=[];h.each(function(r){r!==h&&n.push({source:r.parent,target:r})});
return n},copy:function(){return pF(this).yq(fV)}};(function(h,n){this.Fb=h;this.VE=this.children=this.parent=null;this.a=this;this.s=this.c=this.fe=this.z=0;this.t=null;this.Qf=n}).prototype=Object.create(hm.prototype);var dv=new Date,ev=new Date,PF=Kc(function(){},function(h,n){h.setTime(+h+n)},function(h,n){return n-h});PF.every=function(h){h=Math.floor(h);return isFinite(h)&&0<h?1<h?Kc(function(n){n.setTime(Math.floor(n/h)*h)},function(n,r){n.setTime(+n+r*h)},function(n,r){return(r-n)/h}):PF:
null};Kc(function(h){h.setTime(1E3*Math.floor(h/1E3))},function(h,n){h.setTime(+h+1E3*n)},function(h,n){return(n-h)/1E3},function(h){return h.getUTCSeconds()});Kc(function(h){h.setTime(6E4*Math.floor(h/6E4))},function(h,n){h.setTime(+h+6E4*n)},function(h,n){return(n-h)/6E4},function(h){return h.getMinutes()});Kc(function(h){var n=6E4*h.getTimezoneOffset()%36E5;0>n&&(n+=36E5);h.setTime(36E5*Math.floor((+h-n)/36E5)+n)},function(h,n){h.setTime(+h+36E5*n)},function(h,n){return(n-h)/36E5},function(h){return h.getHours()});
var sF=Kc(function(h){h.setHours(0,0,0,0)},function(h,n){h.setDate(h.getDate()+n)},function(h,n){return(n-h-6E4*(n.getTimezoneOffset()-h.getTimezoneOffset()))/864E5},function(h){return h.getDate()-1}),fW=Ih(0),gv=Ih(1);Ih(2);Ih(3);var hv=Ih(4);Ih(5);Ih(6);Kc(function(h){h.setDate(1);h.setHours(0,0,0,0)},function(h,n){h.setMonth(h.getMonth()+n)},function(h,n){return n.getMonth()-h.getMonth()+12*(n.getFullYear()-h.getFullYear())},function(h){return h.getMonth()});var Wj=Kc(function(h){h.setMonth(0,
1);h.setHours(0,0,0,0)},function(h,n){h.setFullYear(h.getFullYear()+n)},function(h,n){return n.getFullYear()-h.getFullYear()},function(h){return h.getFullYear()});Wj.every=function(h){return isFinite(h=Math.floor(h))&&0<h?Kc(function(n){n.setFullYear(Math.floor(n.getFullYear()/h)*h);n.setMonth(0,1);n.setHours(0,0,0,0)},function(n,r){n.setFullYear(n.getFullYear()+r*h)}):null};Kc(function(h){h.setUTCSeconds(0,0)},function(h,n){h.setTime(+h+6E4*n)},function(h,n){return(n-h)/6E4},function(h){return h.getUTCMinutes()});
Kc(function(h){h.setUTCMinutes(0,0,0)},function(h,n){h.setTime(+h+36E5*n)},function(h,n){return(n-h)/36E5},function(h){return h.getUTCHours()});var rF=Kc(function(h){h.setUTCHours(0,0,0,0)},function(h,n){h.setUTCDate(h.getUTCDate()+n)},function(h,n){return(n-h)/864E5},function(h){return h.getUTCDate()-1}),gW=Jh(0),fv=Jh(1);Jh(2);Jh(3);var iv=Jh(4);Jh(5);Jh(6);Kc(function(h){h.setUTCDate(1);h.setUTCHours(0,0,0,0)},function(h,n){h.setUTCMonth(h.getUTCMonth()+n)},function(h,n){return n.getUTCMonth()-
h.getUTCMonth()+12*(n.getUTCFullYear()-h.getUTCFullYear())},function(h){return h.getUTCMonth()});var Xj=Kc(function(h){h.setUTCMonth(0,1);h.setUTCHours(0,0,0,0)},function(h,n){h.setUTCFullYear(h.getUTCFullYear()+n)},function(h,n){return n.getUTCFullYear()-h.getUTCFullYear()},function(h){return h.getUTCFullYear()});Xj.every=function(h){return isFinite(h=Math.floor(h))&&0<h?Kc(function(n){n.setUTCFullYear(Math.floor(n.getUTCFullYear()/h)*h);n.setUTCMonth(0,1);n.setUTCHours(0,0,0,0)},function(n,r){n.setUTCFullYear(n.getUTCFullYear()+
r*h)}):null};var qF={"-":"",_:" ",0:"0"},Rc=/^\s*\d+/,eW=/^%/,dW=/[\\^$*+?|[\]().{}]/g,bq;(function(h){bq=hV(h);EL=bq.ME;FL=bq.NE;return bq})({dateTime:"%x, %X",tB:"%-m/%-d/%Y",time:"%-I:%M:%S %p",sD:["AM","PM"],uB:"Sunday Monday Tuesday Wednesday Thursday Friday Saturday".split(" "),SD:"Sun Mon Tue Wed Thu Fri Sat".split(" "),QC:"January February March April May June July August September October November December".split(" "),TD:"Jan Feb Mar Apr May Jun Jul Aug Sep Oct Nov Dec".split(" ")});Date.prototype.toISOString||
EL("%Y-%m-%dT%H:%M:%S.%LZ");+new Date("2000-01-01T00:00:00.000Z")||FL("%Y-%m-%dT%H:%M:%S.%LZ");pb("1f77b4ff7f0e2ca02cd627289467bd8c564be377c27f7f7fbcbd2217becf");pb("393b795254a36b6ecf9c9ede6379398ca252b5cf6bcedb9c8c6d31bd9e39e7ba52e7cb94843c39ad494ad6616be7969c7b4173a55194ce6dbdde9ed6");pb("3182bd6baed69ecae1c6dbefe6550dfd8d3cfdae6bfdd0a231a35474c476a1d99bc7e9c0756bb19e9ac8bcbddcdadaeb636363969696bdbdbdd9d9d9");pb("1f77b4aec7e8ff7f0effbb782ca02c98df8ad62728ff98969467bdc5b0d58c564bc49c94e377c2f7b6d27f7f7fc7c7c7bcbd22dbdb8d17becf9edae5");
pb("7fc97fbeaed4fdc086ffff99386cb0f0027fbf5b17666666");pb("1b9e77d95f027570b3e7298a66a61ee6ab02a6761d666666");pb("a6cee31f78b4b2df8a33a02cfb9a99e31a1cfdbf6fff7f00cab2d66a3d9affff99b15928");pb("fbb4aeb3cde3ccebc5decbe4fed9a6ffffcce5d8bdfddaecf2f2f2");pb("b3e2cdfdcdaccbd5e8f4cae4e6f5c9fff2aef1e2cccccccc");pb("e41a1c377eb84daf4a984ea3ff7f00ffff33a65628f781bf999999");pb("66c2a5fc8d628da0cbe78ac3a6d854ffd92fe5c494b3b3b3");pb("8dd3c7ffffb3bebadafb807280b1d3fdb462b3de69fccde5d9d9d9bc80bdccebc5ffed6f");var xW=
Array(3).concat("d8b365f5f5f55ab4ac","a6611adfc27d80cdc1018571","a6611adfc27df5f5f580cdc1018571","8c510ad8b365f6e8c3c7eae55ab4ac01665e","8c510ad8b365f6e8c3f5f5f5c7eae55ab4ac01665e","8c510abf812ddfc27df6e8c3c7eae580cdc135978f01665e","8c510abf812ddfc27df6e8c3f5f5f5c7eae580cdc135978f01665e","5430058c510abf812ddfc27df6e8c3c7eae580cdc135978f01665e003c30","5430058c510abf812ddfc27df6e8c3f5f5f5c7eae580cdc135978f01665e003c30").map(pb);Wb(xW);var yW=Array(3).concat("af8dc3f7f7f77fbf7b","7b3294c2a5cfa6dba0008837",
"7b3294c2a5cff7f7f7a6dba0008837","762a83af8dc3e7d4e8d9f0d37fbf7b1b7837","762a83af8dc3e7d4e8f7f7f7d9f0d37fbf7b1b7837","762a839970abc2a5cfe7d4e8d9f0d3a6dba05aae611b7837","762a839970abc2a5cfe7d4e8f7f7f7d9f0d3a6dba05aae611b7837","40004b762a839970abc2a5cfe7d4e8d9f0d3a6dba05aae611b783700441b","40004b762a839970abc2a5cfe7d4e8f7f7f7d9f0d3a6dba05aae611b783700441b").map(pb);Wb(yW);var zW=Array(3).concat("e9a3c9f7f7f7a1d76a","d01c8bf1b6dab8e1864dac26","d01c8bf1b6daf7f7f7b8e1864dac26","c51b7de9a3c9fde0efe6f5d0a1d76a4d9221",
"c51b7de9a3c9fde0eff7f7f7e6f5d0a1d76a4d9221","c51b7dde77aef1b6dafde0efe6f5d0b8e1867fbc414d9221","c51b7dde77aef1b6dafde0eff7f7f7e6f5d0b8e1867fbc414d9221","8e0152c51b7dde77aef1b6dafde0efe6f5d0b8e1867fbc414d9221276419","8e0152c51b7dde77aef1b6dafde0eff7f7f7e6f5d0b8e1867fbc414d9221276419").map(pb);Wb(zW);var AW=Array(3).concat("998ec3f7f7f7f1a340","5e3c99b2abd2fdb863e66101","5e3c99b2abd2f7f7f7fdb863e66101","542788998ec3d8daebfee0b6f1a340b35806","542788998ec3d8daebf7f7f7fee0b6f1a340b35806","5427888073acb2abd2d8daebfee0b6fdb863e08214b35806",
"5427888073acb2abd2d8daebf7f7f7fee0b6fdb863e08214b35806","2d004b5427888073acb2abd2d8daebfee0b6fdb863e08214b358067f3b08","2d004b5427888073acb2abd2d8daebf7f7f7fee0b6fdb863e08214b358067f3b08").map(pb);Wb(AW);var BW=Array(3).concat("ef8a62f7f7f767a9cf","ca0020f4a58292c5de0571b0","ca0020f4a582f7f7f792c5de0571b0","b2182bef8a62fddbc7d1e5f067a9cf2166ac","b2182bef8a62fddbc7f7f7f7d1e5f067a9cf2166ac","b2182bd6604df4a582fddbc7d1e5f092c5de4393c32166ac","b2182bd6604df4a582fddbc7f7f7f7d1e5f092c5de4393c32166ac",
"67001fb2182bd6604df4a582fddbc7d1e5f092c5de4393c32166ac053061","67001fb2182bd6604df4a582fddbc7f7f7f7d1e5f092c5de4393c32166ac053061").map(pb);Wb(BW);var CW=Array(3).concat("ef8a62ffffff999999","ca0020f4a582bababa404040","ca0020f4a582ffffffbababa404040","b2182bef8a62fddbc7e0e0e09999994d4d4d","b2182bef8a62fddbc7ffffffe0e0e09999994d4d4d","b2182bd6604df4a582fddbc7e0e0e0bababa8787874d4d4d","b2182bd6604df4a582fddbc7ffffffe0e0e0bababa8787874d4d4d","67001fb2182bd6604df4a582fddbc7e0e0e0bababa8787874d4d4d1a1a1a",
"67001fb2182bd6604df4a582fddbc7ffffffe0e0e0bababa8787874d4d4d1a1a1a").map(pb);Wb(CW);var DW=Array(3).concat("fc8d59ffffbf91bfdb","d7191cfdae61abd9e92c7bb6","d7191cfdae61ffffbfabd9e92c7bb6","d73027fc8d59fee090e0f3f891bfdb4575b4","d73027fc8d59fee090ffffbfe0f3f891bfdb4575b4","d73027f46d43fdae61fee090e0f3f8abd9e974add14575b4","d73027f46d43fdae61fee090ffffbfe0f3f8abd9e974add14575b4","a50026d73027f46d43fdae61fee090e0f3f8abd9e974add14575b4313695","a50026d73027f46d43fdae61fee090ffffbfe0f3f8abd9e974add14575b4313695").map(pb);
Wb(DW);var EW=Array(3).concat("fc8d59ffffbf91cf60","d7191cfdae61a6d96a1a9641","d7191cfdae61ffffbfa6d96a1a9641","d73027fc8d59fee08bd9ef8b91cf601a9850","d73027fc8d59fee08bffffbfd9ef8b91cf601a9850","d73027f46d43fdae61fee08bd9ef8ba6d96a66bd631a9850","d73027f46d43fdae61fee08bffffbfd9ef8ba6d96a66bd631a9850","a50026d73027f46d43fdae61fee08bd9ef8ba6d96a66bd631a9850006837","a50026d73027f46d43fdae61fee08bffffbfd9ef8ba6d96a66bd631a9850006837").map(pb);Wb(EW);var FW=Array(3).concat("fc8d59ffffbf99d594","d7191cfdae61abdda42b83ba",
"d7191cfdae61ffffbfabdda42b83ba","d53e4ffc8d59fee08be6f59899d5943288bd","d53e4ffc8d59fee08bffffbfe6f59899d5943288bd","d53e4ff46d43fdae61fee08be6f598abdda466c2a53288bd","d53e4ff46d43fdae61fee08bffffbfe6f598abdda466c2a53288bd","9e0142d53e4ff46d43fdae61fee08be6f598abdda466c2a53288bd5e4fa2","9e0142d53e4ff46d43fdae61fee08bffffbfe6f598abdda466c2a53288bd5e4fa2").map(pb);Wb(FW);var GW=Array(3).concat("e5f5f999d8c92ca25f","edf8fbb2e2e266c2a4238b45","edf8fbb2e2e266c2a42ca25f006d2c","edf8fbccece699d8c966c2a42ca25f006d2c",
"edf8fbccece699d8c966c2a441ae76238b45005824","f7fcfde5f5f9ccece699d8c966c2a441ae76238b45005824","f7fcfde5f5f9ccece699d8c966c2a441ae76238b45006d2c00441b").map(pb);Wb(GW);var HW=Array(3).concat("e0ecf49ebcda8856a7","edf8fbb3cde38c96c688419d","edf8fbb3cde38c96c68856a7810f7c","edf8fbbfd3e69ebcda8c96c68856a7810f7c","edf8fbbfd3e69ebcda8c96c68c6bb188419d6e016b","f7fcfde0ecf4bfd3e69ebcda8c96c68c6bb188419d6e016b","f7fcfde0ecf4bfd3e69ebcda8c96c68c6bb188419d810f7c4d004b").map(pb);Wb(HW);var IW=Array(3).concat("e0f3dba8ddb543a2ca",
"f0f9e8bae4bc7bccc42b8cbe","f0f9e8bae4bc7bccc443a2ca0868ac","f0f9e8ccebc5a8ddb57bccc443a2ca0868ac","f0f9e8ccebc5a8ddb57bccc44eb3d32b8cbe08589e","f7fcf0e0f3dbccebc5a8ddb57bccc44eb3d32b8cbe08589e","f7fcf0e0f3dbccebc5a8ddb57bccc44eb3d32b8cbe0868ac084081").map(pb);Wb(IW);var JW=Array(3).concat("fee8c8fdbb84e34a33","fef0d9fdcc8afc8d59d7301f","fef0d9fdcc8afc8d59e34a33b30000","fef0d9fdd49efdbb84fc8d59e34a33b30000","fef0d9fdd49efdbb84fc8d59ef6548d7301f990000","fff7ecfee8c8fdd49efdbb84fc8d59ef6548d7301f990000",
"fff7ecfee8c8fdd49efdbb84fc8d59ef6548d7301fb300007f0000").map(pb);Wb(JW);var KW=Array(3).concat("ece2f0a6bddb1c9099","f6eff7bdc9e167a9cf02818a","f6eff7bdc9e167a9cf1c9099016c59","f6eff7d0d1e6a6bddb67a9cf1c9099016c59","f6eff7d0d1e6a6bddb67a9cf3690c002818a016450","fff7fbece2f0d0d1e6a6bddb67a9cf3690c002818a016450","fff7fbece2f0d0d1e6a6bddb67a9cf3690c002818a016c59014636").map(pb);Wb(KW);var LW=Array(3).concat("ece7f2a6bddb2b8cbe","f1eef6bdc9e174a9cf0570b0","f1eef6bdc9e174a9cf2b8cbe045a8d","f1eef6d0d1e6a6bddb74a9cf2b8cbe045a8d",
"f1eef6d0d1e6a6bddb74a9cf3690c00570b0034e7b","fff7fbece7f2d0d1e6a6bddb74a9cf3690c00570b0034e7b","fff7fbece7f2d0d1e6a6bddb74a9cf3690c00570b0045a8d023858").map(pb);Wb(LW);var MW=Array(3).concat("e7e1efc994c7dd1c77","f1eef6d7b5d8df65b0ce1256","f1eef6d7b5d8df65b0dd1c77980043","f1eef6d4b9dac994c7df65b0dd1c77980043","f1eef6d4b9dac994c7df65b0e7298ace125691003f","f7f4f9e7e1efd4b9dac994c7df65b0e7298ace125691003f","f7f4f9e7e1efd4b9dac994c7df65b0e7298ace125698004367001f").map(pb);Wb(MW);var NW=Array(3).concat("fde0ddfa9fb5c51b8a",
"feebe2fbb4b9f768a1ae017e","feebe2fbb4b9f768a1c51b8a7a0177","feebe2fcc5c0fa9fb5f768a1c51b8a7a0177","feebe2fcc5c0fa9fb5f768a1dd3497ae017e7a0177","fff7f3fde0ddfcc5c0fa9fb5f768a1dd3497ae017e7a0177","fff7f3fde0ddfcc5c0fa9fb5f768a1dd3497ae017e7a017749006a").map(pb);Wb(NW);var OW=Array(3).concat("edf8b17fcdbb2c7fb8","ffffcca1dab441b6c4225ea8","ffffcca1dab441b6c42c7fb8253494","ffffccc7e9b47fcdbb41b6c42c7fb8253494","ffffccc7e9b47fcdbb41b6c41d91c0225ea80c2c84","ffffd9edf8b1c7e9b47fcdbb41b6c41d91c0225ea80c2c84",
"ffffd9edf8b1c7e9b47fcdbb41b6c41d91c0225ea8253494081d58").map(pb);Wb(OW);var PW=Array(3).concat("f7fcb9addd8e31a354","ffffccc2e69978c679238443","ffffccc2e69978c67931a354006837","ffffccd9f0a3addd8e78c67931a354006837","ffffccd9f0a3addd8e78c67941ab5d238443005a32","ffffe5f7fcb9d9f0a3addd8e78c67941ab5d238443005a32","ffffe5f7fcb9d9f0a3addd8e78c67941ab5d238443006837004529").map(pb);Wb(PW);var QW=Array(3).concat("fff7bcfec44fd95f0e","ffffd4fed98efe9929cc4c02","ffffd4fed98efe9929d95f0e993404","ffffd4fee391fec44ffe9929d95f0e993404",
"ffffd4fee391fec44ffe9929ec7014cc4c028c2d04","ffffe5fff7bcfee391fec44ffe9929ec7014cc4c028c2d04","ffffe5fff7bcfee391fec44ffe9929ec7014cc4c02993404662506").map(pb);Wb(QW);var RW=Array(3).concat("ffeda0feb24cf03b20","ffffb2fecc5cfd8d3ce31a1c","ffffb2fecc5cfd8d3cf03b20bd0026","ffffb2fed976feb24cfd8d3cf03b20bd0026","ffffb2fed976feb24cfd8d3cfc4e2ae31a1cb10026","ffffccffeda0fed976feb24cfd8d3cfc4e2ae31a1cb10026","ffffccffeda0fed976feb24cfd8d3cfc4e2ae31a1cbd0026800026").map(pb);Wb(RW);var SW=Array(3).concat("deebf79ecae13182bd",
"eff3ffbdd7e76baed62171b5","eff3ffbdd7e76baed63182bd08519c","eff3ffc6dbef9ecae16baed63182bd08519c","eff3ffc6dbef9ecae16baed64292c62171b5084594","f7fbffdeebf7c6dbef9ecae16baed64292c62171b5084594","f7fbffdeebf7c6dbef9ecae16baed64292c62171b508519c08306b").map(pb);Wb(SW);var TW=Array(3).concat("e5f5e0a1d99b31a354","edf8e9bae4b374c476238b45","edf8e9bae4b374c47631a354006d2c","edf8e9c7e9c0a1d99b74c47631a354006d2c","edf8e9c7e9c0a1d99b74c47641ab5d238b45005a32","f7fcf5e5f5e0c7e9c0a1d99b74c47641ab5d238b45005a32",
"f7fcf5e5f5e0c7e9c0a1d99b74c47641ab5d238b45006d2c00441b").map(pb);Wb(TW);var UW=Array(3).concat("f0f0f0bdbdbd636363","f7f7f7cccccc969696525252","f7f7f7cccccc969696636363252525","f7f7f7d9d9d9bdbdbd969696636363252525","f7f7f7d9d9d9bdbdbd969696737373525252252525","fffffff0f0f0d9d9d9bdbdbd969696737373525252252525","fffffff0f0f0d9d9d9bdbdbd969696737373525252252525000000").map(pb);Wb(UW);var VW=Array(3).concat("efedf5bcbddc756bb1","f2f0f7cbc9e29e9ac86a51a3","f2f0f7cbc9e29e9ac8756bb154278f","f2f0f7dadaebbcbddc9e9ac8756bb154278f",
"f2f0f7dadaebbcbddc9e9ac8807dba6a51a34a1486","fcfbfdefedf5dadaebbcbddc9e9ac8807dba6a51a34a1486","fcfbfdefedf5dadaebbcbddc9e9ac8807dba6a51a354278f3f007d").map(pb);Wb(VW);var WW=Array(3).concat("fee0d2fc9272de2d26","fee5d9fcae91fb6a4acb181d","fee5d9fcae91fb6a4ade2d26a50f15","fee5d9fcbba1fc9272fb6a4ade2d26a50f15","fee5d9fcbba1fc9272fb6a4aef3b2ccb181d99000d","fff5f0fee0d2fcbba1fc9272fb6a4aef3b2ccb181d99000d","fff5f0fee0d2fcbba1fc9272fb6a4aef3b2ccb181da50f1567000d").map(pb);Wb(WW);var XW=Array(3).concat("fee6cefdae6be6550d",
"feeddefdbe85fd8d3cd94701","feeddefdbe85fd8d3ce6550da63603","feeddefdd0a2fdae6bfd8d3ce6550da63603","feeddefdd0a2fdae6bfd8d3cf16913d948018c2d04","fff5ebfee6cefdd0a2fdae6bfd8d3cf16913d948018c2d04","fff5ebfee6cefdd0a2fdae6bfd8d3cf16913d94801a636037f2704").map(pb);Wb(XW);pv(Oe(300,.5,0),Oe(-240,.5,1));pv(Oe(-100,.75,.35),Oe(80,1.5,.8));pv(Oe(260,.75,.35),Oe(80,1.5,.8));Oe();Sc();Yp(pb("44015444025645045745055946075a46085c460a5d460b5e470d60470e6147106347116447136548146748166848176948186a481a6c481b6d481c6e481d6f481f70482071482173482374482475482576482677482878482979472a7a472c7a472d7b472e7c472f7d46307e46327e46337f463480453581453781453882443983443a83443b84433d84433e85423f854240864241864142874144874045884046883f47883f48893e49893e4a893e4c8a3d4d8a3d4e8a3c4f8a3c508b3b518b3b528b3a538b3a548c39558c39568c38588c38598c375a8c375b8d365c8d365d8d355e8d355f8d34608d34618d33628d33638d32648e32658e31668e31678e31688e30698e306a8e2f6b8e2f6c8e2e6d8e2e6e8e2e6f8e2d708e2d718e2c718e2c728e2c738e2b748e2b758e2a768e2a778e2a788e29798e297a8e297b8e287c8e287d8e277e8e277f8e27808e26818e26828e26828e25838e25848e25858e24868e24878e23888e23898e238a8d228b8d228c8d228d8d218e8d218f8d21908d21918c20928c20928c20938c1f948c1f958b1f968b1f978b1f988b1f998a1f9a8a1e9b8a1e9c891e9d891f9e891f9f881fa0881fa1881fa1871fa28720a38620a48621a58521a68522a78522a88423a98324aa8325ab8225ac8226ad8127ad8128ae8029af7f2ab07f2cb17e2db27d2eb37c2fb47c31b57b32b67a34b67935b77937b87838b9773aba763bbb753dbc743fbc7340bd7242be7144bf7046c06f48c16e4ac16d4cc26c4ec36b50c46a52c56954c56856c66758c7655ac8645cc8635ec96260ca6063cb5f65cb5e67cc5c69cd5b6ccd5a6ece5870cf5773d05675d05477d1537ad1517cd2507fd34e81d34d84d44b86d54989d5488bd6468ed64590d74393d74195d84098d83e9bd93c9dd93ba0da39a2da37a5db36a8db34aadc32addc30b0dd2fb2dd2db5de2bb8de29bade28bddf26c0df25c2df23c5e021c8e020cae11fcde11dd0e11cd2e21bd5e21ad8e219dae319dde318dfe318e2e418e5e419e7e419eae51aece51befe51cf1e51df4e61ef6e620f8e621fbe723fde725"));
Yp(pb("00000401000501010601010802010902020b02020d03030f03031204041405041606051806051a07061c08071e0907200a08220b09240c09260d0a290e0b2b100b2d110c2f120d31130d34140e36150e38160f3b180f3d19103f1a10421c10441d11471e114920114b21114e22115024125325125527125829115a2a115c2c115f2d11612f116331116533106734106936106b38106c390f6e3b0f703d0f713f0f72400f74420f75440f764510774710784910784a10794c117a4e117b4f127b51127c52137c54137d56147d57157e59157e5a167e5c167f5d177f5f187f601880621980641a80651a80671b80681c816a1c816b1d816d1d816e1e81701f81721f817320817521817621817822817922827b23827c23827e24828025828125818326818426818627818827818928818b29818c29818e2a81902a81912b81932b80942c80962c80982d80992d809b2e7f9c2e7f9e2f7fa02f7fa1307ea3307ea5317ea6317da8327daa337dab337cad347cae347bb0357bb2357bb3367ab5367ab73779b83779ba3878bc3978bd3977bf3a77c03a76c23b75c43c75c53c74c73d73c83e73ca3e72cc3f71cd4071cf4070d0416fd2426fd3436ed5446dd6456cd8456cd9466bdb476adc4869de4968df4a68e04c67e24d66e34e65e44f64e55064e75263e85362e95462ea5661eb5760ec5860ed5a5fee5b5eef5d5ef05f5ef1605df2625df2645cf3655cf4675cf4695cf56b5cf66c5cf66e5cf7705cf7725cf8745cf8765cf9785df9795df97b5dfa7d5efa7f5efa815ffb835ffb8560fb8761fc8961fc8a62fc8c63fc8e64fc9065fd9266fd9467fd9668fd9869fd9a6afd9b6bfe9d6cfe9f6dfea16efea36ffea571fea772fea973feaa74feac76feae77feb078feb27afeb47bfeb67cfeb77efeb97ffebb81febd82febf84fec185fec287fec488fec68afec88cfeca8dfecc8ffecd90fecf92fed194fed395fed597fed799fed89afdda9cfddc9efddea0fde0a1fde2a3fde3a5fde5a7fde7a9fde9aafdebacfcecaefceeb0fcf0b2fcf2b4fcf4b6fcf6b8fcf7b9fcf9bbfcfbbdfcfdbf"));
Yp(pb("00000401000501010601010802010a02020c02020e03021004031204031405041706041907051b08051d09061f0a07220b07240c08260d08290e092b10092d110a30120a32140b34150b37160b39180c3c190c3e1b0c411c0c431e0c451f0c48210c4a230c4c240c4f260c51280b53290b552b0b572d0b592f0a5b310a5c320a5e340a5f3609613809623909633b09643d09653e0966400a67420a68440a68450a69470b6a490b6a4a0c6b4c0c6b4d0d6c4f0d6c510e6c520e6d540f6d550f6d57106e59106e5a116e5c126e5d126e5f136e61136e62146e64156e65156e67166e69166e6a176e6c186e6d186e6f196e71196e721a6e741a6e751b6e771c6d781c6d7a1d6d7c1d6d7d1e6d7f1e6c801f6c82206c84206b85216b87216b88226a8a226a8c23698d23698f24699025689225689326679526679727669827669a28659b29649d29649f2a63a02a63a22b62a32c61a52c60a62d60a82e5fa92e5eab2f5ead305dae305cb0315bb1325ab3325ab43359b63458b73557b93556ba3655bc3754bd3853bf3952c03a51c13a50c33b4fc43c4ec63d4dc73e4cc83f4bca404acb4149cc4248ce4347cf4446d04545d24644d34743d44842d54a41d74b3fd84c3ed94d3dda4e3cdb503bdd513ade5238df5337e05536e15635e25734e35933e45a31e55c30e65d2fe75e2ee8602de9612bea632aeb6429eb6628ec6726ed6925ee6a24ef6c23ef6e21f06f20f1711ff1731df2741cf3761bf37819f47918f57b17f57d15f67e14f68013f78212f78410f8850ff8870ef8890cf98b0bf98c0af98e09fa9008fa9207fa9407fb9606fb9706fb9906fb9b06fb9d07fc9f07fca108fca309fca50afca60cfca80dfcaa0ffcac11fcae12fcb014fcb216fcb418fbb61afbb81dfbba1ffbbc21fbbe23fac026fac228fac42afac62df9c72ff9c932f9cb35f8cd37f8cf3af7d13df7d340f6d543f6d746f5d949f5db4cf4dd4ff4df53f4e156f3e35af3e55df2e661f2e865f2ea69f1ec6df1ed71f1ef75f1f179f2f27df2f482f3f586f3f68af4f88ef5f992f6fa96f8fb9af9fc9dfafda1fcffa4"));
Yp(pb("0d088710078813078916078a19068c1b068d1d068e20068f2206902406912605912805922a05932c05942e05952f059631059733059735049837049938049a3a049a3c049b3e049c3f049c41049d43039e44039e46039f48039f4903a04b03a14c02a14e02a25002a25102a35302a35502a45601a45801a45901a55b01a55c01a65e01a66001a66100a76300a76400a76600a76700a86900a86a00a86c00a86e00a86f00a87100a87201a87401a87501a87701a87801a87a02a87b02a87d03a87e03a88004a88104a78305a78405a78606a68707a68808a68a09a58b0aa58d0ba58e0ca48f0da4910ea3920fa39410a29511a19613a19814a099159f9a169f9c179e9d189d9e199da01a9ca11b9ba21d9aa31e9aa51f99a62098a72197a82296aa2395ab2494ac2694ad2793ae2892b02991b12a90b22b8fb32c8eb42e8db52f8cb6308bb7318ab83289ba3388bb3488bc3587bd3786be3885bf3984c03a83c13b82c23c81c33d80c43e7fc5407ec6417dc7427cc8437bc9447aca457acb4679cc4778cc4977cd4a76ce4b75cf4c74d04d73d14e72d24f71d35171d45270d5536fd5546ed6556dd7566cd8576bd9586ada5a6ada5b69db5c68dc5d67dd5e66de5f65de6164df6263e06363e16462e26561e26660e3685fe4695ee56a5de56b5de66c5ce76e5be76f5ae87059e97158e97257ea7457eb7556eb7655ec7754ed7953ed7a52ee7b51ef7c51ef7e50f07f4ff0804ef1814df1834cf2844bf3854bf3874af48849f48948f58b47f58c46f68d45f68f44f79044f79143f79342f89441f89540f9973ff9983ef99a3efa9b3dfa9c3cfa9e3bfb9f3afba139fba238fca338fca537fca636fca835fca934fdab33fdac33fdae32fdaf31fdb130fdb22ffdb42ffdb52efeb72dfeb82cfeba2cfebb2bfebd2afebe2afec029fdc229fdc328fdc527fdc627fdc827fdca26fdcb26fccd25fcce25fcd025fcd225fbd324fbd524fbd724fad824fada24f9dc24f9dd25f8df25f8e125f7e225f7e425f6e626f6e826f5e926f5eb27f4ed27f3ee27f3f027f2f227f1f426f1f525f0f724f0f921"));
CF.prototype={ic:function(){this.qe=0},hc:function(){(this.Bf||0!==this.Bf&&1===this.qe)&&this.Cb.closePath();this.Bf=1-this.Bf},point:function(h,n){h=+h;n=+n;switch(this.qe){case 0:this.qe=1;this.Bf?this.Cb.lineTo(h,n):this.Cb.moveTo(h,n);break;case 1:this.qe=2;default:this.Cb.lineTo(h,n)}}};(function(h){function n(r){return new EF(h(r))}n.vm=h;return n})(DF);EF.prototype={ic:function(){this.vm.ic()},hc:function(){this.vm.hc()},point:function(h,n){this.vm.point(n*Math.sin(h),n*-Math.cos(h))}};lv.prototype=
{ic:function(){this.oc=this.Ib=this.xc=this.Lb=this.Nm=NaN;this.qe=0},hc:function(){switch(this.qe){case 2:this.Cb.lineTo(this.Ib,this.Lb);break;case 3:kv(this,this.Nm,GF(this,this.Nm))}(this.Bf||0!==this.Bf&&1===this.qe)&&this.Cb.closePath();this.Bf=1-this.Bf},point:function(h,n){var r=NaN;h=+h;n=+n;if(h!==this.Ib||n!==this.Lb){switch(this.qe){case 0:this.qe=1;this.Bf?this.Cb.lineTo(h,n):this.Cb.moveTo(h,n);break;case 1:this.qe=2;break;case 2:this.qe=3;kv(this,GF(this,r=FF(this,h,n)),r);break;default:kv(this,
this.Nm,r=FF(this,h,n))}this.oc=this.Ib;this.Ib=h;this.xc=this.Lb;this.Lb=n;this.Nm=r}}};(HF.prototype=Object.create(lv.prototype)).point=function(h,n){lv.prototype.point.call(this,n,h)};IF.prototype={moveTo:function(h,n){this.Cb.moveTo(n,h)},closePath:function(){this.Cb.closePath()},lineTo:function(h,n){this.Cb.lineTo(n,h)},bezierCurveTo:function(h,n,r,w,z,A){this.Cb.bezierCurveTo(n,h,w,r,A,z)}};rg.prototype={constructor:rg,scale:function(h){return 1===h?this:new rg(this.k*h,this.x,this.y)},translate:function(h,
n){return 0===h&0===n?this:new rg(this.k,this.x+this.k*h,this.y+this.k*n)},apply:function(h){return[h[0]*this.k+this.x,h[1]*this.k+this.y]},invert:function(h){return[(h[0]-this.x)/this.k,(h[1]-this.y)/this.k]},lw:function(h){return(h-this.x)/this.k},mw:function(h){return(h-this.y)/this.k},toString:function(){return"translate("+this.x+","+this.y+") scale("+this.k+")"}};var KF=new rg(1,0,0);GL=function(h){return 1-Math.pow(2,-10*h)};HL=Ru;IL=ib;oI=function(){function h(J){var L,P=J.length,X,ka=!1,oa;
null==z&&(E=A(oa=WE()));for(L=0;L<=P;++L)!(L<P&&w(X=J[L],L,J))===ka&&((ka=!ka)?E.ic():E.hc()),ka&&E.point(+n(X,L,J),+r(X,L,J));if(oa)return E=null,oa+""||null}var n=iW,r=jW,w=jv(!0),z=null,A=DF,E=null;h.x=function(J){return arguments.length?(n="function"===typeof J?J:jv(+J),h):n};h.y=function(J){return arguments.length?(r="function"===typeof J?J:jv(+J),h):r};h.curve=function(J){return arguments.length?(A=J,null!=z&&(E=A(z)),h):A};h.context=function(J){return arguments.length?(null==J?z=E=null:E=A(z=
J),h):z};return h};pI=function(h){return new HF(h)};JL=function(){function h(I){I.nx("__zoom",JF).on("wheel.zoom",E).on("mousedown.zoom",J).on("dblclick.zoom",L).filter(lc).on("touchstart.zoom",P).on("touchmove.zoom",X).on("touchend.zoom touchcancel.zoom",ka).style("touch-action","none").style("-webkit-tap-highlight-color","rgba(0,0,0,0)")}function n(I,ha){ha=Math.max(ub[0],Math.min(ub[1],ha));return ha===I.k?I:new rg(ha,I.x,I.y)}function r(I,ha,Ha){var Va=ha[0]-Ha[0]*I.k;ha=ha[1]-Ha[1]*I.k;return Va===
I.x&&ha===I.y?I:new rg(I.k,Va,ha)}function w(I,ha,Ha){I.on("start.zoom",function(){z(this,arguments).start()}).on("interrupt.zoom end.zoom",function(){z(this,arguments).end()}).Nd("zoom",function(){var Va=arguments,vb=z(this,Va),Ra=Ba.apply(this,Va),Qb=Ha||[(+Ra[0][0]+ +Ra[1][0])/2,(+Ra[0][1]+ +Ra[1][1])/2],nd=Math.max(Ra[1][0]-Ra[0][0],Ra[1][1]-Ra[0][1]);Ra=this.__zoom;var ak="function"===typeof ha?ha.apply(this,Va):ha,ck=Db(Ra.invert(Qb).concat(nd/Ra.k),ak.invert(Qb).concat(nd/ak.k));return function(zd){if(1===
zd)zd=ak;else{zd=ck(zd);var bk=nd/zd[2];zd=new rg(bk,Qb[0]-zd[0]*bk,Qb[1]-zd[1]*bk)}vb.zoom(null,zd)}})}function z(I,ha){for(var Ha=0,Va=tb.length,vb;Ha<Va;++Ha)if((vb=tb[Ha]).mi===I)return vb;return new A(I,ha)}function A(I,ha){this.mi=I;this.Xe=ha;this.index=-1;this.active=0;this.cl=Ba.apply(I,ha)}function E(){if(oa.apply(this,arguments)){var I=z(this,arguments),ha=this.__zoom,Ha=Math.max(ub[0],Math.min(ub[1],ha.k*Math.pow(2,Za.apply(this,arguments)))),Va=db(this);if(I.Ss){if(I.Gd[0][0]!==Va[0]||
I.Gd[0][1]!==Va[1])I.Gd[1]=ha.invert(I.Gd[0]=Va);clearTimeout(I.Ss)}else{if(ha.k===Ha)return;I.Gd=[Va,ha.invert(Va)];Qp(this);I.start()}lm();I.Ss=setTimeout(function(){I.Ss=null;I.end()},150);I.zoom("mouse",Wa(r(n(ha,Ha),I.Gd[0],I.Gd[1]),I.cl,mc))}}function J(){if(!za&&oa.apply(this,arguments)){var I=z(this,arguments),ha=ib(DL.view).on("mousemove.zoom",function(){lm();if(!I.xj){var Ra=DL.clientX-Va,Qb=DL.clientY-vb;I.xj=Ra*Ra+Qb*Qb>Fa}I.zoom("mouse",Wa(r(I.mi.__zoom,I.Gd[0]=db(I.mi),I.Gd[1]),I.cl,
mc))},!0).on("mouseup.zoom",function(){ha.on("mousemove.zoom mouseup.zoom",null);ec(DL.view,I.xj);lm();I.end()},!0),Ha=db(this),Va=DL.clientX,vb=DL.clientY;vc(DL.view);DL.stopImmediatePropagation();I.Gd=[Ha,this.__zoom.invert(Ha)];Qp(this);I.start()}}function L(){if(oa.apply(this,arguments)){var I=this.__zoom,ha=db(this),Ha=I.invert(ha);I=Wa(r(n(I,I.k*(DL.shiftKey?.5:2)),ha,Ha),Ba.apply(this,arguments),mc);lm();0<Jc?ib(this).transition().duration(Jc).call(w,I,ha):ib(this).call(h.transform,I)}}function P(){if(oa.apply(this,
arguments)){var I=z(this,arguments),ha=DL.changedTouches,Ha=ha.length,Va;DL.stopImmediatePropagation();for(Va=0;Va<Ha;++Va){var vb=ha[Va];var Ra=Xb(this,ha,vb.identifier);Ra=[Ra,this.__zoom.invert(Ra),vb.identifier];if(I.vc)I.Sc||(I.Sc=Ra);else{I.vc=Ra;var Qb=!0}}if(Fb&&(Fb=clearTimeout(Fb),!I.Sc)){I.end();(Ra=ib(this).on("dblclick.zoom"))&&Ra.apply(this,arguments);return}Qb&&(Fb=setTimeout(function(){Fb=null},500),Qp(this),I.start())}}function X(){var I=z(this,arguments),ha=DL.changedTouches,Ha=
ha.length,Va;lm();Fb&&(Fb=clearTimeout(Fb));for(Va=0;Va<Ha;++Va){var vb=ha[Va];var Ra=Xb(this,ha,vb.identifier);I.vc&&I.vc[2]===vb.identifier?I.vc[0]=Ra:I.Sc&&I.Sc[2]===vb.identifier&&(I.Sc[0]=Ra)}vb=I.mi.__zoom;if(I.Sc){Ra=I.vc[0];ha=I.vc[1];Va=I.Sc[0];Ha=I.Sc[1];var Qb=(Qb=Va[0]-Ra[0])*Qb+(Qb=Va[1]-Ra[1])*Qb;var nd=(nd=Ha[0]-ha[0])*nd+(nd=Ha[1]-ha[1])*nd;vb=n(vb,Math.sqrt(Qb/nd));Ra=[(Ra[0]+Va[0])/2,(Ra[1]+Va[1])/2];Qb=[(ha[0]+Ha[0])/2,(ha[1]+Ha[1])/2]}else if(I.vc)Ra=I.vc[0],Qb=I.vc[1];else return;
I.zoom("touch",Wa(r(vb,Ra,Qb),I.cl,mc))}function ka(){var I=z(this,arguments),ha=DL.changedTouches,Ha=ha.length,Va;DL.stopImmediatePropagation();za&&clearTimeout(za);za=setTimeout(function(){za=null},500);for(Va=0;Va<Ha;++Va){var vb=ha[Va];I.vc&&I.vc[2]===vb.identifier?delete I.vc:I.Sc&&I.Sc[2]===vb.identifier&&delete I.Sc}I.Sc&&!I.vc&&(I.vc=I.Sc,delete I.Sc);I.vc?I.vc[1]=this.__zoom.invert(I.vc[0]):I.end()}var oa=lW,Ba=mW,Wa=pW,Za=nW,lc=oW,ub=[0,Infinity],mc=[[-Infinity,-Infinity],[Infinity,Infinity]],
Jc=250,Db=qU,tb=[],Ma=d("start","zoom","end"),Fb,za,Fa=0;h.transform=function(I,ha){var Ha=I.selection?I.selection():I;Ha.nx("__zoom",JF);I!==Ha?w(I,ha):Ha.rC().each(function(){z(this,arguments).start().zoom(null,"function"===typeof ha?ha.apply(this,arguments):ha).end()})};h.HE=function(I,ha,Ha){h.transform(I,function(){return Wa(this.__zoom.translate("function"===typeof ha?ha.apply(this,arguments):ha,"function"===typeof Ha?Ha.apply(this,arguments):Ha),Ba.apply(this,arguments),mc)})};A.prototype=
{start:function(){1===++this.active&&(this.index=tb.push(this)-1,this.emit("start"));return this},zoom:function(I,ha){this.Gd&&"mouse"!==I&&(this.Gd[1]=ha.invert(this.Gd[0]));this.vc&&"touch"!==I&&(this.vc[1]=ha.invert(this.vc[0]));this.Sc&&"touch"!==I&&(this.Sc[1]=ha.invert(this.Sc[0]));this.mi.__zoom=ha;this.emit("zoom");return this},end:function(){0===--this.active&&(tb.splice(this.index,1),this.index=-1,this.emit("end"));return this},emit:function(I){var ha=new kW(h,I,this.mi.__zoom),Ha=Ma.apply;
I=[I,this.mi,this.Xe];var Va=DL;ha.ys=DL;DL=ha;try{Ha.apply(Ma,I)}finally{DL=Va}}};h.wheelDelta=function(I){return arguments.length?(Za="function"===typeof I?I:mv(+I),h):Za};h.filter=function(I){return arguments.length?(oa="function"===typeof I?I:mv(!!I),h):oa};h.cl=function(I){return arguments.length?(Ba="function"===typeof I?I:mv([[+I[0][0],+I[0][1]],[+I[1][0],+I[1][1]]]),h):Ba};h.OD=function(I){return arguments.length?(ub[0]=+I[0],ub[1]=+I[1],h):[ub[0],ub[1]]};h.duration=function(I){return arguments.length?
(Jc=+I,h):Jc};h.interpolate=function(I){return arguments.length?(Db=I,h):Db};h.on=function(){var I=Ma.on.apply(Ma,arguments);return I===Ma?h:I};return h};KL=KF;Pd.wG=Pd.svg;Pd.DG=Pd.xhtml;Pd.EG=Pd.xlink;Pd.xml=Pd.xml;Pd.FG=Pd.xmlns})();function LL(a){0<=a.Rd&&(clearTimeout(a.Rd),a.Rd=-1);var b=a.qx;b.i&&cE(b.i);$m(a.O)}function ML(a,b,c,d=!1,e=!1){NL(a);a.T(b)?(LL(a),a.kh(c,a.fa,b,[],d,e,!0)):a.si.i.postMessage({eventType:6,modelGraphId:a.fa.id,showOnNodeItemTypes:a.D,nodeDataProviderRuns:a.kb,nodeId:b,rendererId:c,noNodeShake:d,select:e})}
function OL(a,b,c,d=!1,e,f=!1,g,k){NL(a);a.si.i.postMessage({eventType:4,modelGraphId:a.fa.id,showOnNodeItemTypes:g||a.D,nodeDataProviderRuns:a.kb,selectedNodeId:b,targetDeepestGroupNodeIdsToExpand:c,rendererId:a.rendererId,forRestoringUiState:d,rectToZoomFit:e,clearAllExpandStates:f,forRestoringSnapshotAfterTogglingFlattenLayers:k})}
function PL(a,b,c=!1,d){NL(a);b={eventType:2,modelGraphId:a.fa.id,groupNodeId:null==b?void 0:b.id,expand:null==d?!(null==b?0:b.expanded):d,showOnNodeItemTypes:a.D,nodeDataProviderRuns:a.kb,rendererId:a.rendererId,paneId:a.paneId,all:c,ts:Date.now()};a.si.i.postMessage(b)}
function QL(a,b){const c=IL(b);let d=0,e=0;a.zoom.OD([1E-4,20]).wheelDelta(()=>-DL.deltaY*(DL.deltaMode?120:1)/150).filter(()=>{"mousedown"===DL.type&&(d=a.hh,e=a.ih);if(2===DL.button||a.ml&&DL.ctrlKey&&0===DL.button&&"mousedown"===DL.type)return!1;if("dblclick"===DL.type)return DL.stopPropagation(),a.Ik(DL.altKey),!1;if("wheel"===DL.type&&!DL.ctrlKey){const f=.5/a.G;a.zoom.HE(c,-Number(DL.deltaX)*f,-Number(DL.deltaY)*f);DL.preventDefault();return!1}return!0}).on("zoom",()=>{a.dl()}).on("end",()=>
{a.By(d,e)});a.zoom.interpolate(HL);c.call(a.zoom)}function NL(a){LL(a);a.Rd=window.setTimeout(()=>{0>a.Rd||(a.qx.open("Processing. Please wait..."),$m(a.O))},1E3)}function RL(a,b){b=a.fa.nodesById[b];null==b||b.expanded||PL(a,b,!1,!0)}function SL(a,b){oJ(a.i,a.paneId,{nodeId:b,rendererId:a.rendererId,zd:""===b?!1:gI(a.fa.nodesById[b])})}function TL(a,b){a.fa=Object.assign({},b,{edgesByGroupNodeIds:Object.assign({},a.fa.edgesByGroupNodeIds,b.edgesByGroupNodeIds)})}
function UL(a){if(a.fa){a.Ta=[];a.K=[];a.ra={};a.Kb=[];var b=!0,c=!1,d=e=>{const f=a.fa.nodesById[e||""];if(b&&f){a.Ta.push({type:0,id:f.id,node:f});var g={node:f,index:a.Ta.length-1};a.K.push(g);a.ra[g.node.id]=g;gI(f)&&f.sectionContainer&&(c=!0)}b=!1;if(e&&f&&f.expanded||!e)for(const k of a.fa.edgesByGroupNodeIds[e||""]||[])a.Ta.push({type:1,id:k.id,edge:k}),a.Kb.push({edge:k,index:a.Ta.length-1});g=[];e?f.expanded&&(g=(f.nsChildrenIds||[]).map(k=>a.fa.nodesById[k])):g=a.fa.rootNodes;for(const k of g)e=
{type:0,id:k.id,node:k},!c&&gI(k)&&k.sectionContainer&&(c=!0),a.Ta.push(e),e={node:k,index:a.Ta.length-1},a.K.push(e),a.ra[e.node.id]=e,gI(k)&&k.expanded&&d(k.id)};d(a.Ul);vJ(a.i,a.paneId,c)}}function VL(a){return(a.x||0)+(a.globalX||0)}function WL(a){return(a.y||0)+(a.globalY||0)}function XL(a,b,c,d){b?setTimeout(()=>{const e=c.nodesById[b];a.Wc({x:VL(e),y:WL(e),width:e.width||0,height:e.height||0},.9,d,!1,!0,!0)},0):setTimeout(()=>{a.Vd(.9,d)})}
function YL(a,b,c=!1,d){1===b.nodeType&&0!==(b.nsChildrenIds||[]).length&&PL(a,b,c,d)}function ZL(a){if(!a.selectedNodeId||gI(a.fa.nodesById[a.selectedNodeId]))return!1;const b=a.fa.nodesById[a.Ul||""];return b&&gI(b)&&!(b.descendantsOpNodeIds||[]).includes(a.selectedNodeId)||!a.T(a.selectedNodeId)?!1:!0}function $L(a,b,c,d){return a.fa.edgesByGroupNodeIds[""===b?"":`${b}___group___`].find(e=>{var f=a.fa.nodesById[e.toNodeId];e=aM(a.fa.nodesById[e.fromNodeId],c);f=aM(f,d);return e&&f})}
function bM(a,b,c){let d=b;const e=[];for(;d;){gI(d)&&!d.expanded&&e.push(d);if(d.namespace===c)break;d=a.fa.nodesById[d.nsParentId||""]}return 0<e.length?e[e.length-1]:b}
function cM(a,b,c){var d=VL(c);const e=WL(c),f=c.width||0;c=c.height||0;d=[{point:{x:d+f/2,y:e},distance:0,direction:"horizontal"},{point:{x:d+f,y:e+c/2},distance:0,direction:"vertical"},{point:{x:d+f/2,y:e+c},distance:0,direction:"horizontal"},{point:{x:d,y:e+c/2},distance:0,direction:"vertical"}];for(const g of d)g.distance=Math.pow(a-g.point.x,2)+Math.pow(b-g.point.y,2);d.sort((g,k)=>g.distance-k.distance);return d[0].direction!==d[1].direction?dM(a,b,d[0].point.x,d[0].point.y,d[0].direction)>=
dM(a,b,d[1].point.x,d[1].point.y,d[1].direction)?d[0].point:d[1].point:d[0].point}
function eM(a){const b=a.fa.nodesById[a.selectedNodeId],c=[],d=[],e={},f=[];for(const p of b.incomingEdges||[]){var g=a.fa.nodesById[p.sourceNodeId];if(!g)continue;var k=xI(g.namespace,b.namespace),m=$L(a,k,g.id,b.id);if(!m)continue;c.push(m);const t=bM(a,g,k);d.push(t);null==e[t.id]&&(e[t.id]=[]);e[t.id].push(g);g=[];const v=a.fa.nodesById[m.fromNodeId];m.fromNodeId!==t.id&&(k=cM(m.points[0].x+(v.globalX||0),m.points[0].y+(v.globalY||0),t),g.push({x:k.x-(t.globalX||0),y:k.y-(t.globalY||0)}));g.push(...m.points.map(B=>
({x:B.x-(t.globalX||0)+(v.globalX||0),y:B.y-(t.globalY||0)+(v.globalY||0)})));m.toNodeId!==a.selectedNodeId&&(m=cM(m.points[m.points.length-1].x+(v.globalX||0),m.points[m.points.length-1].y+(v.globalY||0),b),g.push({x:m.x-(t.globalX||0),y:m.y-(t.globalY||0)}));f.push({id:`overlay_${t.id}___${b.id}`,fromNodeId:t.id,toNodeId:b.id,points:g,type:"incoming"})}return{cs:c,gC:d,De:e,Ll:f}}
function fM(a){const b=a.fa.nodesById[a.selectedNodeId],c=[],d=[],e={},f=[];for(const p of b.outgoingEdges||[]){var g=a.fa.nodesById[p.targetNodeId];if(!g)continue;var k=xI(g.namespace,b.namespace),m=$L(a,k,b.id,g.id);if(!m)continue;c.push(m);k=bM(a,g,k);d.push(k);null==e[k.id]&&(e[k.id]=[]);e[k.id].push(g);g=[];const t=a.fa.nodesById[m.fromNodeId];if(m.fromNodeId!==a.selectedNodeId){const v=cM(m.points[0].x+(t.globalX||0),m.points[0].y+(t.globalY||0),b);g.push({x:v.x-(b.globalX||0),y:v.y-(b.globalY||
0)})}g.push(...m.points.map(v=>({x:v.x-(b.globalX||0)+(t.globalX||0),y:v.y-(b.globalY||0)+(t.globalY||0)})));m.toNodeId!==k.id&&(m=cM(m.points[m.points.length-1].x+(t.globalX||0),m.points[m.points.length-1].y+(t.globalY||0),k),g.push({x:m.x-(b.globalX||0),y:m.y-(b.globalY||0)}));f.push({id:`overlay_${b.id}___${k.id}`,fromNodeId:b.id,toNodeId:k.id,points:g,type:"outgoing"})}return{cs:c,gC:d,jf:e,Ll:f}}
function gM(a){if(a.selectedNodeId&&fI(a.fa.nodesById[a.selectedNodeId])){for(var b=new Set,c=new Set,d=[a.selectedNodeId];0<d.length;){var e=d.shift();if(!c.has(e)){c.add(e);var f=a.fa.nodesById[e];f.hideInLayout||b.add(e);for(const g of f.incomingEdges||[])d.push(g.sourceNodeId)}}c=new Set;for(d=[a.selectedNodeId];0<d.length;)if(e=d.shift(),!c.has(e)){c.add(e);f=a.fa.nodesById[e];f.hideInLayout||b.add(e);for(const g of f.outgoingEdges||[])d.push(g.targetNodeId)}for(const g of[...b])for(d=g;;){d=
a.fa.nodesById[d];if(!d.nsParentId||b.has(d.nsParentId))break;d=d.nsParentId;b.add(d)}a.ta={AG:a.selectedNodeId,Os:b}}}function hM(a){const b=a.gh()||{},c={},d=new Set;for(const {node:e}of a.K)if(gI(e)&&!e.expanded){const f={};for(const g of e.descendantsOpNodeIds||[]){let k;const m=(null==(k=b[a.fa.nodesById[g].id])?void 0:k.bgColor)||"";m&&(null==f[m]&&(f[m]=0),f[m]++,d.add(m))}c[e.id]=f}return{WB:c,oE:[...d].sort((e,f)=>e.localeCompare(f))}}
function iM(a,b){b=new xu({sc:Iu(Av(Hu(Lv(a.ox.position(),b),[{bb:"start",cb:"bottom",La:"start",Sa:"top"},{bb:"start",cb:"top",La:"start",Sa:"bottom"}]),b.clientWidth),20),Sb:!0,bc:"cdk-overlay-transparent-backdrop",maxHeight:"400px",gb:"io-tree-popup-container"});const c=a.ox.create(b);a.Jd=new Ov(RK,a.wb);c.bd().subscribe(()=>{c.dispose()});return c}
function jM(a,b,c,d){const e=iM(a,b);b=e.attach(a.Jd);c=SK(c,d);b.instance.Eo=!0;b.instance.rendererId=a.rendererId;QK(b.instance,c);b.instance.ge.subscribe(()=>{e.dispose()})}function kM(a){return fI(a)?"Placeholder"===a.label?a.id:a.label:gI(a)?a.label:"-"}function aM(a,b){return fI(a)&&a.id===b||gI(a)&&(a.descendantsOpNodeIds||[]).includes(b)}function dM(a,b,c,d,e){return"horizontal"===e?Math.atan(Math.abs(d-b)/Math.abs(c-a)):Math.atan(Math.abs(c-a)/Math.abs(d-b))}
var lM=class{constructor(){this.Pb=!1;this.Jl=new Dk;this.Ag="";this.Wg=!1;this.Ta=[];this.K=[];this.ra={};this.Kb=[];this.zoom=JL();this.G=1;this.ih=this.hh=0;this.Gl=this.selectedNodeId="";this.kb={};this.Jd=null;this.Rd=-1;this.Py=void 0;this.i=lf(NJ);this.si=lf(UI);this.Zw=lf(CL);this.F=lf(wi);this.Ne=lf(TI);this.ox=lf(Wv);this.wb=lf(ip);this.O=lf(Pr);this.qx=lf(oE);this.ml="undefined"!==typeof navigator&&/Macintosh/.test(navigator.userAgent);this.D={};this.ia={};this.Oy=a=>{LL(this);a=a.data;
switch(a.eventType){case 3:this.rendererId===a.rendererId&&this.Nk(a.modelGraph,a.rendererId,a.groupNodeId,a.expanded,a.deepestExpandedGroupNodeIds);break;case 5:this.rendererId===a.rendererId&&this.al(a.rendererId,a.modelGraph,a.selectedNodeId,a.forRestoringUiState,a.rectToZoomFit,a.forRestoringSnapshotAfterTogglingFlattenLayers,a.targetDeepestGroupNodeIdsToExpand);break;case 7:this.rendererId===a.rendererId&&this.kh(a.rendererId,a.modelGraph,a.nodeId,a.deepestExpandedGroupNodeIds,!0===a.noNodeShake,
!0===a.select);break;case 10:this.paneId===a.paneId&&this.Jl.emit({id:a.rendererId,En:a.modelGraph.nodesById[a.groupNodeId],initialPosition:a.initialPosition,fa:a.modelGraph})}};this.Qg=ys(()=>{const a=fJ(this.i,this.paneId);if(a)return a.Qg});this.gh=ys(()=>{let a;return((null==(a=yL(this.Zw,this.paneId,this.fa))?void 0:a.results)||{})[this.fa.id]});this.si.i.addEventListener("message",this.Oy);Gs(()=>{this.iz=this.i.D()});C(this.i.ea,kL(this.F)).subscribe(()=>{let a;this.rendererId===(null==(a=
this.iz)?void 0:a.id)&&this.Vd()});Gs(()=>{const a=this.i.F();(null==a?void 0:a.rendererId)===this.rendererId&&(a&&ML(this,a.nodeId,a.rendererId,a.noNodeShake,a.select),this.i.F.set(void 0))},{Wp:!0});Gs(()=>{var a=fJ(this.i,this.paneId);if(a&&a.modelGraph&&(a=a.dD)){{const b=this.fa.nodesById[a];b?(OL(this,a,b.nsParentId?[b.nsParentId]:[]),a=!0):a=!1}a&&wJ(this.i,this.paneId)}},{Wp:!0});Gs(()=>{const a=nL(this.Zw,this.fa);this.kb={};for(const b of a)this.kb[b.runId]=b});Gs(()=>{const a=this.gh();
a!==this.Py&&(this.uy(),this.Py=a)});Gs(()=>{if(fJ(this.i,this.paneId)){var a=cJ(this.i,this.paneId,this.rendererId);JSON.stringify(a)!==JSON.stringify(this.D)&&(this.D=a,OL(this,this.selectedNodeId))}});C(this.i.ba,kL(this.F)).subscribe(a=>{a.rendererId===this.rendererId&&PL(this,void 0,!0,a.Ov)})}ua(){this.si.i.removeEventListener("message",this.Oy)}Ik(){}Gk(){}dl(){this.G=DL.transform.k;this.hh=DL.transform.x;this.ih=DL.transform.y}By(){}Nk(a){TL(this,a);UL(this);this.selectedNodeId&&!this.T(this.selectedNodeId)&&
oJ(this.i,this.paneId,{nodeId:"",rendererId:this.rendererId,zd:!1})}al(a,b){TL(this,b);UL(this)}kh(a,b,c,d,e,f){TL(this,b);UL(this);f&&oJ(this.i,this.paneId,{nodeId:c,rendererId:a,zd:gI(this.fa.nodesById[c])})}Wc(){}Vd(){}uy(){}T(){return!1}Dl(){(this.Wg=!this.Wg)?gM(this):this.ta=void 0}};lM.J=function(a){return new (a||lM)};
lM.Ca=Gf({type:lM,ga:[["renderer"]],inputs:{modelGraph:"modelGraph",rendererId:"rendererId",paneId:"paneId",Ul:"rootNodeId",Pb:"inPopup"},outputs:{Jl:"openInPopupClicked"},ja:!0,features:[Jr],ya:0,za:0,sa:function(){},ob:2});HH`https://www.gstatic.com/external_hosted/threejs-r134/three.min.js`;const zI=HH`/static_files/main_deps.js`;
function mM(a){return sa(function*(){"undefined"===typeof THREE&&(yield yI());const b=yield Promise.all([nM("/static_files/GoogleSansTextRegular.png"),nM("/static_files/GoogleSansTextMedium.png"),nM("/static_files/GoogleSansTextBold.png"),nM("/static_files/icons_2024021202.png"),oM("/static_files/GoogleSansTextRegular.json"),oM("/static_files/GoogleSansTextMedium.json"),oM("/static_files/GoogleSansTextBold.json"),oM("/static_files/icons_2024021202.json")]);a.ia=b[0];a.ea=b[1];a.T=b[2];a.ba=b[3];a.C=
b[4].Zm;a.G=b[5].Zm;a.D=b[6].Zm;a.F=b[7].Zm;a.i=b[4].yn;a.R=b[5].yn;a.N=b[6].yn;a.O=b[7].yn})}function nM(a){return sa(function*(){return new Promise(b=>{(new THREE.TextureLoader).load(a,c=>{b(c)})})})}function oM(a){return sa(function*(){const b=yield(yield fetch(a)).json(),c={};for(const d of b.chars)c[d.char]=d;return{yn:b,Zm:c}})}function pM(a,b){switch(b){case 0:return a.C;case 1:return a.G;case 2:return a.D;case 4:return a.F;default:return a.C}}
function qM(a,b){switch(b){case 0:return a.i;case 1:return a.R;case 2:return a.N;case 4:return a.O;default:return a.i}}var rM=class{constructor(){this.C={};this.G={};this.D={};this.F={};this.K=new Promise(a=>{const b=this;return sa(function*(){yield mM(b);a()})})}};rM.J=function(a){return new (a||rM)};rM.oa=Ld({la:rM,aa:rM.J,da:"root"});function sM(a,b,c){if(0===b.length)a.i=void 0,a.C=void 0;else{var d=[],e=[],f=[],g=[],k=[],m=[],p=[],t=[],v={},B={};a.F={};var G=0,K=0;for(const {edge:ia,index:O}of b){b=ia.curvePoints||[];const U=c.nodesById[ia.fromNodeId],Q=c.nodesById[ia.toNodeId],la=U.globalX||0,F=U.globalY||0;for(let M=0;M<b.length-1;M++){var N=b[M],aa=b[M+1],ca=`${U.id}__${Q.id}___${M}`;N=[N.x+la,N.y+F,aa.x+la,aa.y+F];(aa=a.ba[ca])?d.push(...aa.IB):d.push(...N);e.push(...N);m.push(.001*O);k.push(a.color.r,a.color.g,a.color.b);
v[ca]={IB:N,index:G};null==a.F[ia.id]&&(a.F[ia.id]=[]);a.F[ia.id].push(v[ca]);M===b.length-2&&(ca=ia.id,(aa=a.K[ca])?f.push(...aa.GC):f.push(...N),g.push(...N),p.push(.001*O+5E-4),t.push(a.color.r,a.color.g,a.color.b),B[ca]={index:K,GC:N});G++}K++}a.ba=v;a.K=B;a.D=k;a.ra=m;a.ma=p;c=(new THREE.InstancedBufferGeometry).copy(a.ea);c.instanceCount=m.length;c.setAttribute("endPoints",new THREE.InstancedBufferAttribute(new Float32Array(d),4));c.setAttribute("targetEndPoints",new THREE.InstancedBufferAttribute(new Float32Array(e),
4));c.setAttribute("color",new THREE.InstancedBufferAttribute(new Float32Array(k),3));c.setAttribute("yOffset",new THREE.InstancedBufferAttribute(new Float32Array(m),1));a.i=new THREE.Mesh(c,a.material);a.i.frustumCulled=!1;d=(new THREE.InstancedBufferGeometry).copy(a.ia);d.instanceCount=p.length;d.setAttribute("endPoints",new THREE.InstancedBufferAttribute(new Float32Array(f),4));d.setAttribute("targetEndPoints",new THREE.InstancedBufferAttribute(new Float32Array(g),4));d.setAttribute("color",new THREE.InstancedBufferAttribute(new Float32Array(t),
3));d.setAttribute("yOffset",new THREE.InstancedBufferAttribute(new Float32Array(p),1));a.C=new THREE.Mesh(d,a.ta);a.C.frustumCulled=!1}}function tM(a,b){if(a.i){var c=a.i.geometry.getAttribute("color");if(0<b.length)for(const d of b)for(const e of a.F[d]||[])c.setXYZ(e.index,.92,.92,.92),a.O.push(e);c.needsUpdate=!0}if(a.C){c=a.C.geometry.getAttribute("color");if(0<b.length)for(const d of b)b=a.K[d],c.setXYZ(b.index,.92,.92,.92),a.N.push(b);c.needsUpdate=!0}}
function uM(a,b){if(a.i){var c=a.i.geometry.getAttribute("yOffset");if(0<b.length)for(const d of b)for(const e of a.F[d]||[])c.setX(e.index,1E3),a.T.push(e);c.needsUpdate=!0}if(a.C){c=a.C.geometry.getAttribute("yOffset");if(0<b.length)for(const d of b)b=a.K[d],c.setX(b.index,1E3),a.R.push(b);c.needsUpdate=!0}}
function vM(a){if(a.i){var b=a.i.geometry.getAttribute("color");if(0<a.O.length){for(var c of a.O){const d=c.index;b.setXYZ(d,a.D[3*d],a.D[3*d+1],a.D[3*d+2])}b.needsUpdate=!0}a.O=[]}if(a.C){b=a.C.geometry.getAttribute("color");if(0<a.N.length){for(const d of a.N)c=d.index,b.setXYZ(c,a.D[3*c],a.D[3*c+1],a.D[3*c+2]);b.needsUpdate=!0}a.N=[]}}
function wM(a){if(a.i){var b=a.i.geometry.getAttribute("yOffset");if(0<a.T.length){for(var c of a.T){const d=c.index;b.setX(d,a.ra[d])}b.needsUpdate=!0}a.T=[]}if(a.C){b=a.C.geometry.getAttribute("yOffset");if(0<a.R.length){for(const d of a.R)c=d.index,b.setX(c,a.ma[c]);b.needsUpdate=!0}a.R=[]}}function xM(a){a.ba={};a.F={};a.K={}}
var yM=class{constructor(a,b){this.color=a;this.va=b;this.ba={};this.F={};this.K={};this.G={value:-1};this.D=[];this.ra=[];this.ma=[];this.O=[];this.N=[];this.T=[];this.R=[];this.ea=new THREE.PlaneGeometry(1,1);this.ea.rotateX(-Math.PI/2);this.material=new THREE.ShaderMaterial({uniforms:{edgeWidth:{value:this.va},animationProgress:this.G},vertexShader:"\nprecision highp float;\n\n#define PI 3.1415926535897932384626433832795\n\nuniform float edgeWidth;\nuniform float animationProgress;\n\nattribute vec4 endPoints;\nattribute vec4 targetEndPoints;\nattribute vec3 color;\nattribute float yOffset;\n\nvarying vec3 vColor;\n\nfloat atan2(in float y, in float x) {\n  bool s = (abs(x) > abs(y));\n  return mix(PI/2.0 - atan(x,y), atan(y,x), s);\n}\n\nvoid main() {\n  vColor = color;\n\n  vec3 pos = position;\n\n  float curStartX = endPoints.x;\n  float curStartY = endPoints.y;\n  float curEndX = endPoints.z;\n  float curEndY = endPoints.w;\n  float targetStartX = targetEndPoints.x;\n  float targetStartY = targetEndPoints.y;\n  float targetEndX = targetEndPoints.z;\n  float targetEndY = targetEndPoints.w;\n\n  float progress = animationProgress * step(0.0, animationProgress); \n  float startX = curStartX + (targetStartX - curStartX) * progress;\n  float startY = curStartY + (targetStartY - curStartY) * progress;\n  float endX = curEndX + (targetEndX - curEndX) * progress;\n  float endY = curEndY + (targetEndY - curEndY) * progress;\n\n  float length = distance(vec2(startX, startY), vec2(endX, endY));\n  pos.x = (step(0.0, pos.x) * 2.0 - 1.0) * (edgeWidth / 2.0);\n  pos.z = (step(0.0, pos.z) * 2.0 - 1.0) * (length / 2.0);\n\n  float angle = PI / 2.0 - atan2(endY - startY, endX - startX);\n  float c = cos(angle);\n  float s = sin(angle);\n\n  float posX = pos.x;\n  float posZ = pos.z;\n  pos.x = posX * c + posZ * s;\n  pos.z = posZ * c - posX * s;\n\n  float centerX = (startX + endX) / 2.0;\n  float centerZ = (startY + endY) / 2.0;\n\n  gl_Position = projectionMatrix * modelViewMatrix *\n      vec4(pos.x + centerX, yOffset, pos.z + centerZ, 1.0);\n}\n",
fragmentShader:"\nprecision highp float;\n\nvarying vec3 vColor;\n\nvoid main() {\n  gl_FragColor = vec4(vColor, 1.0);\n}\n",transparent:!0});a=new THREE.Shape;a.moveTo(-3,-6).lineTo(0,-4).lineTo(3,-6).lineTo(0,0).lineTo(-3,-6);this.ia=new THREE.ShapeGeometry(a);this.ia.rotateX(-Math.PI/2);this.ta=new THREE.ShaderMaterial({uniforms:{animationProgress:this.G},vertexShader:"\nprecision highp float;\n\n#define PI 3.1415926535897932384626433832795\n\nuniform float animationProgress;\n\n// End points of the last segment of the edge.\nattribute vec4 endPoints;\nattribute vec4 targetEndPoints;\nattribute vec3 color;\nattribute float yOffset;\n\nvarying vec3 vColor;\n\nfloat atan2(in float y, in float x) {\n  bool s = (abs(x) > abs(y));\n  return mix(PI/2.0 - atan(x,y), atan(y,x), s);\n}\n\nvoid main() {\n  vColor = color;\n\n  vec3 pos = position;\n\n  float curStartX = endPoints.x;\n  float curStartY = endPoints.y;\n  float curEndX = endPoints.z;\n  float curEndY = endPoints.w;\n  float targetStartX = targetEndPoints.x;\n  float targetStartY = targetEndPoints.y;\n  float targetEndX = targetEndPoints.z;\n  float targetEndY = targetEndPoints.w;\n\n  float progress = animationProgress * step(0.0, animationProgress); \n  float startX = curStartX + (targetStartX - curStartX) * progress;\n  float startY = curStartY + (targetStartY - curStartY) * progress;\n  float endX = curEndX + (targetEndX - curEndX) * progress;\n  float endY = curEndY + (targetEndY - curEndY) * progress;\n\n  float angle = PI - atan2(endY - startY, endX - startX) + PI / 2.0;\n  float c = cos(angle);\n  float s = sin(angle);\n\n  float posX = pos.x;\n  float posZ = pos.z;\n  pos.x = posX * c + posZ * s;\n  pos.z = posZ * c - posX * s;\n\n  gl_Position = projectionMatrix * modelViewMatrix *\n      vec4(pos.x + endX, yOffset, pos.z + endY, 1.0);\n}\n",
fragmentShader:"\nprecision highp float;\n\nvarying vec3 vColor;\n\nvoid main() {\n  gl_FragColor = vec4(vColor, 1.0);\n}\n",transparent:!0})}clear(){this.i&&this.i.removeFromParent();this.C&&this.C.removeFromParent()}};function zM(a,b,c=!1,d=!1,e=!1,f=!1){if(0===b.length)a.D={},a.i=void 0,a.C=void 0;else{a.ta=b;var g=[],k=[],m=[],p=[],t=[],v=[],B=[],G=[],K=[],N=[],aa=0<Object.keys(a.D).length,ca=Object.assign({},a.D);a.D={};var ia=0;for(let O=0;O<b.length;O++){const U=b[O],Q=U.bound;let la;const F=null==(la=ca[U.id])?void 0:la.bound;if(aa&&!d||e){let M,W,Aa,qb,wb,Ja,Ub,Na;g.push(null!=(wb=null==(M=F)?void 0:M.x)?wb:Q.x,null!=(Ja=null==(W=F)?void 0:W.y)?Ja:Q.y,null!=(Ub=null==(Aa=F)?void 0:Aa.width)?Ub:f?Q.width:
0,null!=(Na=null==(qb=F)?void 0:qb.height)?Na:f?Q.height:0)}else g.push(Q.x,Q.y,Q.width,Q.height);m.push(Q.x,Q.y,Q.width,Q.height);k.push(U.Le);p.push(U.Ee?1:0);t.push(U.borderWidth);v.push(U.bgColor.r,U.bgColor.g,U.bgColor.b);B.push(U.borderColor.r,U.borderColor.g,U.borderColor.b);G.push(0);K.push(U.opacity);N.push(U.aB?1:0);a.D[U.id]=U;ia++}a.G=B;a.F=v;a.ea=t;a.ia=K;d=(new THREE.InstancedBufferGeometry).copy(a.ra);d.instanceCount=b.length;d.setAttribute("bound",new THREE.InstancedBufferAttribute(new Float32Array(g),
4));d.setAttribute("targetBound",new THREE.InstancedBufferAttribute(new Float32Array(m),4));d.setAttribute("yOffset",new THREE.InstancedBufferAttribute(new Float32Array(k),1));d.setAttribute("isRounded",new THREE.InstancedBufferAttribute(new Float32Array(p),1));d.setAttribute("borderWidth",new THREE.InstancedBufferAttribute(new Float32Array(t),1));d.setAttribute("bgColor",new THREE.InstancedBufferAttribute(new Float32Array(v),3));d.setAttribute("borderColor",new THREE.InstancedBufferAttribute(new Float32Array(B),
3));d.setAttribute("angle",new THREE.InstancedBufferAttribute(new Float32Array(G),1));d.setAttribute("opacity",new THREE.InstancedBufferAttribute(new Float32Array(K),1));d.setAttribute("changeColorWhenFar",new THREE.InstancedBufferAttribute(new Float32Array(N),1));a.i=new THREE.Mesh(d,a.material);a.i.frustumCulled=!1;if(c){a.C=new THREE.InstancedMesh(new THREE.BoxGeometry(1,1,1),a.va,b.length);for(t=0;t<b.length;t++)v=b[t].bound,c=a,g=a.C,k=t,m=v.width,p=v.height,c.N.position.set(v.x,-10,v.y),c.N.scale.set(m,
1,p),c.N.updateMatrix(),g.setMatrixAt(k,c.N.matrix),g.instanceMatrix.needsUpdate=!0;a.C.frustumCulled=!1}}}function AM(a,b,c,d=!0){if(a.C){var e=b.intersectObject(a.C);b="";0<e.length&&(e=e[e.length-1].instanceId,null!=e&&(b=a.ta[e].id));a.K!==b&&(a.K=b,d&&(document.body.style.cursor=""===a.K?"default":"pointer"),c(a.K,a.D[a.K]))}}
function BM(a,b,c){if(a.i){b=b.filter(e=>""!==e);var d=a.i.geometry.getAttribute("borderColor");if(0<b.length)for(const e of b)if(b=a.D[e])d.setXYZ(b.index,c.r,c.g,c.b),b.borderColor.r=c.r,b.borderColor.g=c.g,b.borderColor.b=c.b,a.R.push(b);d.needsUpdate=!0}}
function CM(a){if(a.i){var b=a.i.geometry.getAttribute("borderColor");if(0<=a.R.length){for(const c of a.R){const d=c.index;b.setXYZ(d,a.G[3*d],a.G[3*d+1],a.G[3*d+2]);c.borderColor.r=a.G[3*d];c.borderColor.g=a.G[3*d+1];c.borderColor.b=a.G[3*d+2]}b.needsUpdate=!0}a.R=[]}}
function DM(a,b,c,d=!1){if(a.i){b=b.filter(f=>""!==f);var e=a.i.geometry.getAttribute("bgColor");if(0<b.length)for(const f of b){b=a.D[f];if(!b)continue;const g=b.index;if(d){const k=a.F[3*g+1],m=a.F[3*g+2];if(1!==a.F[3*g]||1!==k||1!==m)continue}e.setXYZ(g,c.r,c.g,c.b);b.bgColor.r=c.r;b.bgColor.g=c.g;b.bgColor.b=c.b;a.O.push(b)}e.needsUpdate=!0}}
function EM(a){if(a.i){var b=a.i.geometry.getAttribute("bgColor");if(0<=a.O.length){for(const c of a.O){const d=c.index;b.setXYZ(d,a.F[3*d],a.F[3*d+1],a.F[3*d+2]);c.bgColor.r=a.F[3*d];c.bgColor.g=a.F[3*d+1];c.bgColor.b=a.F[3*d+2]}b.needsUpdate=!0}a.O=[]}}function FM(a,b,c){if(a.i){b=b.filter(e=>""!==e);var d=a.i.geometry.getAttribute("borderWidth");if(0<b.length)for(const e of b)if(b=a.D[e])d.setX(b.index,c),b.borderWidth=c,a.T.push(b);d.needsUpdate=!0}}
function GM(a){if(a.i){var b=a.i.geometry.getAttribute("borderWidth");if(0<=a.T.length){for(const c of a.T){const d=c.index;b.setX(d,a.ea[d]);c.borderWidth=a.ea[d]}b.needsUpdate=!0}a.T=[]}}function HM(a,b,c){if(a.i){b=b.filter(e=>""!==e);var d=a.i.geometry.getAttribute("opacity");if(0<b.length)for(const e of b)if(b=a.D[e])d.setX(b.index,c),b.opacity=c,a.ba.push(b);d.needsUpdate=!0}}
function IM(a){if(a.i){var b=a.i.geometry.getAttribute("opacity");if(0<=a.ba.length){for(const c of a.ba){const d=c.index;b.setX(d,a.ia[d]);c.opacity=a.ia[d]}b.needsUpdate=!0}a.ba=[]}}function JM(a,b,c){if(a.i){var d=a.i.geometry.getAttribute("angle");if(a=a.D[b])d.setX(a.index,c/180*Math.PI),d.needsUpdate=!0}}function KM(a,b){a.i&&(a.ma.value=b)}function LM(a,b,c){a.i&&(a.material.uniforms.bgColorWhenFar.value=[b.r,b.g,b.b,c])}
var MM=class{constructor(a){this.radius=a;this.K="";this.ta=[];this.D={};this.ma={value:-1};this.N=new THREE.Object3D;this.G=[];this.F=[];this.ea=[];this.ia=[];this.R=[];this.O=[];this.T=[];this.ba=[];this.ra=new THREE.PlaneGeometry(1,1);this.ra.rotateX(-Math.PI/2);this.material=new THREE.ShaderMaterial({extensions:{derivatives:!0},uniforms:{borderRadius:{value:this.radius},animationProgress:this.ma,bgColorWhenFar:{value:[0,0,0,0]}},vertexShader:'\nprecision highp float;\n\nuniform float borderRadius;\n// Set this to <0 to disable animation.\nuniform float animationProgress;\nuniform vec4 bgColorWhenFar;\n\nattribute vec4 bound;\nattribute vec4 targetBound;\nattribute float yOffset;\nattribute float isRounded;\nattribute float borderWidth;\nattribute vec3 bgColor;\nattribute vec3 borderColor;\nattribute float angle;\nattribute float opacity;\nattribute float changeColorWhenFar;\n\nvarying vec2 vUv;\nvarying vec2 vSize;\nvarying float vIsRounded;\nvarying float vBorderWidth;\nvarying vec3 vBgColor;\nvarying vec3 vBorderColor;\nvarying float vOpacity;\nvarying float vChangeColorWhenFar;\n\nvoid main() {\n  vUv = uv;\n  vIsRounded = isRounded;\n  vBorderWidth = borderWidth;\n  vBgColor = bgColor;\n  vBorderColor = borderColor;\n  vOpacity = opacity;\n  vChangeColorWhenFar = changeColorWhenFar;\n\n  vec3 pos = position;\n  float curX = bound.x;\n  float curY = bound.y;\n  float curW = bound.z;\n  float curH = bound.w;\n\n  float progress = animationProgress * step(0.0, animationProgress); \n  float x = curX + (targetBound.x - curX) * progress;\n  float y = curY + (targetBound.y - curY) * progress;\n  float w = curW + (targetBound.z - curW) * progress;\n  float h = curH + (targetBound.w - curH) * progress;\n  vSize = vec2(w, h);\n\n  // For each vertex, move it by delta calculated below so that the final\n  // rectangle\'s width and height match the width and height stored in "bound".\n  //\n  // pos.x < 0: the first () below returns -1.\n  // pos.x > 0: the first () below returns 1.\n  pos.x = (step(0.0, pos.x) * 2.0 - 1.0) * (w / 2.0);\n  pos.z = (step(0.0, pos.z) * 2.0 - 1.0) * (h / 2.0);\n\n  // Rotate.\n  //\n  float c = cos(angle);\n  float s = sin(angle);\n  float posX = pos.x * c + pos.z * s;\n  float posZ = pos.z * c - pos.x * s;\n\n  gl_Position = projectionMatrix * modelViewMatrix *\n      vec4(posX + x, yOffset, posZ + y, 1.0);\n}\n',
fragmentShader:"\nprecision highp float;\n\nuniform float borderRadius;\nuniform vec4 bgColorWhenFar;\n\nvarying vec2 vUv;\nvarying vec2 vSize;\nvarying float vIsRounded;\nvarying float vBorderWidth;\nvarying vec3 vBgColor;\nvarying vec3 vBorderColor;\nvarying float vOpacity;\nvarying float vChangeColorWhenFar;\n\n// See:\n// https://www.shadertoy.com/view/4tc3DX#\n\n// Clamp [0..1] range\n#define saturate(a) clamp(a, 0.0, 1.0)\n\n// This function will make a signed distance field that says how far you are\n// from the edge of the line at any point U,V.\n// Pass it UVs, line end points, line thickness (x is along the line and y is\n// perpendicular), How rounded the end points should be (0.0 is rectangular,\n// setting rounded to thick.y will be circular).\nfloat LineDistField(vec2 uv, vec2 pA, vec2 pB, vec2 thick, float rounded, float dashOn) {\n  // Don't let it get more round than circular.\n  rounded = min(thick.y, rounded);\n  // midpoint\n  vec2 mid = (pB + pA) * 0.5;\n  // vector from point A to B\n  vec2 delta = pB - pA;\n  // Distance between endpoints\n  float lenD = length(delta);\n  // unit vector pointing in the line's direction\n  vec2 unit = delta / lenD;\n  // Check for when line endpoints are the same\n  if (lenD < 0.0001) unit = vec2(1.0, 0.0);\t// if pA and pB are same\n  // Perpendicular vector to unit - also length 1.0\n  vec2 perp = unit.yx * vec2(-1.0, 1.0);\n  // position along line from midpoint\n  float dpx = dot(unit, uv - mid);\n  // distance away from line at a right angle\n  float dpy = dot(perp, uv - mid);\n  // Make a distance function that is 0 at the transition from black to white\n  float disty = abs(dpy) - thick.y + rounded;\n  float distx = abs(dpx) - lenD * 0.5 - thick.x + rounded;\n\n  // Too tired to remember what this does. Something like rounded endpoints for distance function.\n  float dist = length(vec2(max(0.0, distx), max(0.0,disty))) - rounded;\n  dist = min(dist, max(distx, disty));\n\n  return dist;\n}\n\n// This makes a line in UV units. A 1.0 thick line will span a whole 0..1 in\n// UV space.\nfloat FillLine(vec2 uv, vec2 pA, vec2 pB, vec2 thick, float rounded) {\n  float df = LineDistField(uv, pA, pB, vec2(thick), rounded, 0.0);\n  return saturate(df / abs(dFdy(uv).y));\n}\n\nvoid main() {\n  // Normalize uv.\n  vec2 uv = vUv;\n  uv -= 0.5;\n  float aspect = vSize.x / vSize.y;\n  uv.x *= aspect;\n\n  vec4 finalColor = vec4(1.0);\n\n  float radius = mix(1.0 / vSize.y, borderRadius / vSize.y, step(0.5, vIsRounded));\n  float borderWidth = vBorderWidth / vSize.y;\n\n  // Border.\n  float c = FillLine(uv,\n    vec2(-0.5 * aspect, 0.0), vec2(0.5 * aspect, 0.0), vec2(0.0, 0.5), radius);\n  finalColor = mix(vec4(vBorderColor.rgb, 1.0), vec4(1.0, 1.0, 1.0, 0.0), c);\n\n  // Body.\n  float c2 = FillLine(uv,\n    vec2(-0.5 * aspect + borderWidth, 0.0),\n    vec2(0.5 * aspect - borderWidth, 0.0), vec2(0.0, 0.5 - borderWidth),\n    radius - 1.0 / vSize.y);\n  finalColor = mix(vec4(vBgColor.rgb, 1.0), finalColor, c2);\n  finalColor = saturate(finalColor);\n  finalColor.rgb = mix(finalColor.rgb, bgColorWhenFar.rgb, bgColorWhenFar.a * vChangeColorWhenFar);\n\n  float alpha = finalColor.w * vOpacity;\n  if (alpha < 0.00001) {\n    discard;\n  }\n  gl_FragColor = vec4(finalColor.rgb, alpha);\n}\n",
transparent:!0});this.va=new THREE.MeshBasicMaterial({color:"",transparent:!0})}};function NM(a,b,c,d,e,f,g,k){let m=`${b}__${c}__${g}`,p=a.ba[m];var t=void 0;if(null==p){p=OM(a,b,c,f,g,k);if(null!=e){t=d/a.F;for(d=0;d<p.Gj.length;d++)if(g=p.Gj[d],(g.x+g.width)*t>e){b=b.substring(0,d-1);b+="...";break}t=b;p=OM(a,b,c,f);m=`${b}__${c}__${void 0}`}a.ba[m]=p}return{sizes:a.ba[m],LE:t}}
function PM(a,b,c=!1,d=!1,e=!1){let f=0;a.N={};a.K={};const g=[],k=[],m=[],p=[],t=[],v=[],B=[],G=[],K=[],N=0<Object.keys(a.G).length,aa=Object.assign({},a.G);a.G={};for(const F of b){b=pM(a.D,F.weight);const M=qM(a.D,F.weight).common.scaleW,W=NM(a,F.label,F.weight,F.height,F.maxWidth,F.hm,F.angle,F.zq).sizes,Aa=F.height/a.F;let qb=F.x,wb=F.z;var ca=(F.hm?{Gj:[{x:0,y:0,width:20,height:F.height}]}:NM(a,"a",F.weight,F.height).sizes).Gj[0].height*Aa;switch(F.vAlign){case "top":wb-=W.Zn*Aa;break;case "bottom":wb-=
W.Yn*Aa;break;case "center":wb-=(W.Zn+W.Yn)/2*Aa+ca/2}switch(F.bf){case "left":qb-=W.Sh*Aa;break;case "right":qb-=W.Ph*Aa;break;case "center":qb-=(W.Sh+W.Ph)/2*Aa}ca=F.y;const Ja=v.length;for(let Ub=0;Ub<W.Gj.length;Ub++){var ia=W.Gj[Ub],O=F.hm?F.label:F.label[Ub],U=b[O]||b["?"];O=`${F.id}_${O}_${Ub}`;var Q=ia.width*Aa,la=ia.height*Aa;const Na=qb+ia.x*Aa;ia=wb+ia.y*Aa;ia={x:F.zq?Na:Na+Q/2,y:F.zq?ia:ia+la/2,width:Q,height:la};Q=aa[O];if(N&&!c||d){let Xb,od,vc,ec,pc,Ud,Dc,jc;m.push(null!=(pc=null==
(Xb=Q)?void 0:Xb.x)?pc:ia.x,null!=(Ud=null==(od=Q)?void 0:od.y)?Ud:ia.y,null!=(Dc=null==(vc=Q)?void 0:vc.width)?Dc:e?ia.width:0,null!=(jc=null==(ec=Q)?void 0:ec.height)?jc:e?ia.height:0)}else m.push(ia.x,ia.y,ia.width,ia.height);p.push(ia.x,ia.y,ia.width,ia.height);t.push(ca);B.push(U.x/M,1-U.y/M-U.height/M,U.width/M,U.height/M);let qa,T;U=null!=(T=null==(qa=F.color)?void 0:qa.r)?T:0;let ea,na;Q=null!=(na=null==(ea=F.color)?void 0:ea.g)?na:0;let Ka,Qa;la=null!=(Qa=null==(Ka=F.color)?void 0:Ka.b)?
Qa:0;k.push(U,Q,la);g.push(F.weight);v.push(1);G.push(F.angle||0);let Ia,ib,pa,Ga,Sa,db;K.push(null!=(Ga=null==(Ia=F.borderColor)?void 0:Ia.r)?Ga:-1,null!=(Sa=null==(ib=F.borderColor)?void 0:ib.g)?Sa:-1,null!=(db=null==(pa=F.borderColor)?void 0:pa.b)?db:-1);a.G[O]=ia;f++}F.nodeId&&(a.N[F.nodeId]||(a.N[F.nodeId]=[]),a.N[F.nodeId].push({Rh:Ja,Oh:v.length-1}),a.K[F.nodeId]||(a.K[F.nodeId]=[]),a.K[F.nodeId].push({Rh:Ja,Oh:v.length-1}))}a.O=k;c=(new THREE.InstancedBufferGeometry).copy(a.ea);c.instanceCount=
t.length;c.setAttribute("bound",new THREE.InstancedBufferAttribute(new Float32Array(m),4));c.setAttribute("targetBound",new THREE.InstancedBufferAttribute(new Float32Array(p),4));c.setAttribute("uvBound",new THREE.InstancedBufferAttribute(new Float32Array(B),4));c.setAttribute("yOffset",new THREE.InstancedBufferAttribute(new Float32Array(t),1));c.setAttribute("weight",new THREE.InstancedBufferAttribute(new Float32Array(g),1));c.setAttribute("color",new THREE.InstancedBufferAttribute(new Float32Array(k),
3));c.setAttribute("opacity",new THREE.InstancedBufferAttribute(new Float32Array(v),1));c.setAttribute("angle",new THREE.InstancedBufferAttribute(new Float32Array(G),1));c.setAttribute("borderColor",new THREE.InstancedBufferAttribute(new Float32Array(K),3));a.i=new THREE.Mesh(c,a.material);a.i.frustumCulled=!1}
function QM(a,b){if(a.i){var c=a.i.geometry.getAttribute("opacity");if(0<b.length)for(const d of b)if(a.N[d])for(const {Rh:e,Oh:f}of a.N[d]){for(b=e;b<=f;b++)c.setX(b,.3);a.T.push({Rh:e,Oh:f})}c.needsUpdate=!0}}function RM(a,b,c){if(a.i){var d=a.i.geometry.getAttribute("color");if(0<b.length)for(const e of b)if(a.K[e])for(const {Rh:f,Oh:g}of a.K[e]){for(b=f;b<=g;b++)d.setXYZ(b,c.r,c.g,c.b);a.R.push({Rh:f,Oh:g})}d.needsUpdate=!0}}
function SM(a){if(a.i){var b=a.i.geometry.getAttribute("opacity");if(0<=a.T.length){for(const {Rh:c,Oh:d}of a.T)for(let e=c;e<=d;e++)b.setX(e,1);b.needsUpdate=!0}a.T=[]}}function TM(a){if(a.i){var b=a.i.geometry.getAttribute("color");if(0<=a.R.length){for(const {Rh:c,Oh:d}of a.R)for(let e=c;e<=d;e++)b.setXYZ(e,a.O[3*e],a.O[3*e+1],a.O[3*e+2]);b.needsUpdate=!0}a.R=[]}}
function OM(a,b,c,d,e,f){c=pM(a.D,c);const g=[];let k=0,m=Number.MAX_VALUE,p=Number.NEGATIVE_INFINITY;for(const t of d?[b]:b)(b=c[t])||(b=c["?"]),d=b.yoffset,f?(k+=Math.sin(e||0)*(b.yoffset+b.height/2),d=Math.cos(e||0)*(b.yoffset+b.height/2)):k+=b.xoffset,d={x:k,y:d,width:b.width,height:b.height},g.push(d),m=Math.min(m,d.x),p=Math.max(p,d.x+d.width),k+=.98*b.xadvance;return{Gj:g,Sh:m,Zn:0,Ph:p,Yn:a.F}}
var UM=class{constructor(a){this.D=a;this.ba={};this.G={};this.N={};this.K={};this.T=[];this.R=[];this.O=[];this.C={value:-1};this.ea=new THREE.PlaneGeometry(1,1);this.ea.rotateX(-Math.PI/2);this.F=this.D.i.info.size;this.distanceRange=this.D.i.distanceField.distanceRange;this.material=new THREE.ShaderMaterial({uniforms:{textureRegular:{value:this.D.ia},textureMedium:{value:this.D.ea},textureBold:{value:this.D.T},textureIcons:{value:this.D.ba},distanceRange:{value:this.distanceRange},animationProgress:this.C},
extensions:{derivatives:!0},vertexShader:'\nprecision highp float;\n\n// Set this to <0 to disable animation.\nuniform float animationProgress;\n\n// 0: regular. 1: medium. 2: bold.\nattribute float weight;\nattribute vec3 color;\nattribute vec4 bound;\nattribute vec4 targetBound;\nattribute vec4 uvBound;\nattribute float yOffset;\nattribute float opacity;\nattribute float angle;\nattribute vec3 borderColor;\n\nvarying vec2 vUv;\nvarying vec3 vColor;\nvarying float vWeight;\nvarying float vOpacity;\nvarying vec3 vBorderColor;\n\nvoid main() {\n  vUv = vec2(0.0, 0.0);\n  vec3 pos = position;\n  if (pos.x < 0.0 && pos.z < 0.0) {\n    vUv = vec2(uvBound.x, uvBound.y + uvBound.w);\n  } else if (pos.x > 0.0 && pos.z < 0.0) {\n    vUv = vec2(uvBound.x + uvBound.z, uvBound.y + uvBound.w);\n  } else if (pos.x > 0.0 && pos.z > 0.0) {\n    vUv = vec2(uvBound.x + uvBound.z, uvBound.y);\n  } else {\n    vUv = vec2(uvBound.x, uvBound.y);\n  }\n\n  vColor = color;\n  vWeight = weight;\n  vOpacity = opacity;\n  vBorderColor = borderColor;\n\n  float curX = bound.x;\n  float curY = bound.y;\n  float curW = bound.z;\n  float curH = bound.w;\n\n  float x = curX;\n  float y = curY;\n  float w = curW;\n  float h = curH;\n\n  if (animationProgress >= 0.0) {\n    x = curX + (targetBound.x - curX) * animationProgress;\n    y = curY + (targetBound.y - curY) * animationProgress;\n    w = curW + (targetBound.z - curW) * animationProgress;\n    h = curH + (targetBound.w - curH) * animationProgress;\n  }\n\n  // For each vertex, move it by delta calculated below so that the final\n  // rectangle\'s width and height match the width and height stored in "bound".\n  //\n  if (pos.x < 0.0) {\n    pos.x = - w / 2.0;\n  } else if (pos.x > 0.0) {\n    pos.x = w / 2.0;\n  }\n\n  if (pos.z < 0.0) {\n    pos.z = - h / 2.0;\n  } else if (pos.z > 0.0) {\n    pos.z = h / 2.0;\n  }\n\n  // Rotate.\n  //\n  float c = cos(angle);\n  float s = sin(angle);\n  float posX = pos.x * c + pos.z * s;\n  float posZ = pos.z * c - pos.x * s;\n\n  gl_Position = projectionMatrix * modelViewMatrix *\n      vec4(posX + x, yOffset, posZ + y, 1.0);\n}\n',
fragmentShader:"\nprecision highp float;\n\nuniform sampler2D textureRegular;\nuniform sampler2D textureMedium;\nuniform sampler2D textureBold;\nuniform sampler2D textureIcons;\nuniform float distanceRange;\nvarying vec2 vUv;\nvarying float vWeight;\nvarying vec3 vColor;\nvarying float vOpacity;\nvarying vec3 vBorderColor;\n\nvec3 getSampleColor() {\n  if (vWeight < 0.5) {\n    return texture2D(textureRegular, vUv).rgb;\n  }\n  if (vWeight < 1.5) {\n    return texture2D(textureMedium, vUv).rgb;\n  }\n  if (vWeight < 2.5) {\n    return texture2D(textureBold, vUv).rgb;\n  }\n  return texture2D(textureIcons, vUv).rgb;\n}\n\nfloat median(float r, float g, float b) {\n  return max(min(r, g), min(max(r, g), b));\n}\n\nfloat screenPxRange() {\n  vec2 unitRange = vec2(distanceRange) / vec2(textureSize(textureRegular, 0));\n  vec2 screenTexSize = vec2(1.0) / fwidth(vUv);\n  return max(0.5 * dot(unitRange, screenTexSize), 1.0);\n}\n\nvoid main() {\n  vec3 sampleColor = getSampleColor();\n\n  float dist = median(sampleColor.r, sampleColor.g, sampleColor.b);\n  vec3 color = vColor;\n  float threshold = step(0.0, vBorderColor.r) * 0.35;\n  float pxDist = screenPxRange() * (dist - 0.5 + threshold) + 0.5 - threshold;\n\n  // Has border.\n  if (vBorderColor.r >= 0.0) {\n    float blur = fwidth(dist) / 2.0;\n    color = mix(vBorderColor, vColor, smoothstep(0.5 - blur, 0.5 + blur, dist));\n  }\n\n  float opacity = clamp(pxDist, 0.0, 1.0);\n  if (opacity > 0.001) {\n    opacity *= vOpacity;\n  }\n  gl_FragColor = vec4(color, opacity);\n}\n",
transparent:!0,alphaToCoverage:!0})}};const VM=["container"],WM=["canvas"],XM=["snapshotCanvas"],YM=["pngDownloaderCanvas"],ZM=["hoverToolbar"],$M=["ioPicker"],aN=["subgraphMenuTrigger"],bN=["groupNodeIconMatTooltip"],cN=["ioPickerMatTooltip"],dN=["moreActionsMenuTrigger"];function eN(a){if(a&1){const b=Tg();R(0,"div",30);V("click",function(){u(b);const c=Y();var d=c.rl;if(d=null!=d?d:c.Ae)SL(c,d),YL(c,c.fa.nodesById[d],!0,!1);return x()});R(1,"mat-icon");Z(2,"unfold_less_double");S();Z(3," Collapse layer & all sub-layers ");S()}}
function fN(a){if(a&1){const b=Tg();R(0,"div",31);V("click",function(){u(b);const c=Y();var d=c.rl;d=c.fa.nodesById[null!=d?d:c.Ae];var e=VL(d);const f=d.width||0;if(d.expanded){const g=NM(c.Bd,kM(d),2,11).sizes;e=gN(c,e+f/2+11/c.Bd.F*(g.Ph-g.Sh)/2+22,0).x}else e=gN(c,e+f+1,0).x;d={eventType:9,modelGraphId:c.fa.id,paneId:c.paneId,rendererId:lI(),groupNodeId:d.id,initialPosition:{x:e,y:gN(c,0,WL(d)).y}};c.si.i.postMessage(d);return x()});R(1,"mat-icon");Z(2,"open_in_new");S();Z(3," Open layer in popup ");
S()}}function hN(a,b){if(a&1){const c=Tg();R(0,"div",32);V("click",function(){const d=u(c).ca,e=Y();iN(e,d);return x()});R(1,"mat-icon");Z(2,"subdirectory_arrow_right");S();Z(3);S()}a&2&&(a=b.ca,D(3),yr(" ",a," "))}function jN(a){a&1&&Kq(0,"div",33);a&2&&(a=Y(),jq("top",a.FD,"px")("left",a.ED,"px")("width",a.GD,"px")("height",a.DD,"px"))}function kN(a){a&1&&(R(0,"div",29),Z(1),S());a&2&&(a=Y(),D(),yr("FPS: ",a.Tv,""))}
function lN(a){if(a.fa)if(mN(a),ZL(a)){var b=eM(a);if(0<b.Ll.length){var c=b.Ll.map(f=>({edge:Object.assign({},f,{curvePoints:nI(f.points)}),index:95E3}));sM(a.va,c,a.fa);a.va.i&&a.scene.add(a.va.i);a.va.C&&a.scene.add(a.va.C);var d;if(null==(d=a.ia["Tensor shape"])?0:d.selected)c=nN(a,c,a.Yy),PM(a.Nb,c,!1,!0,!0),a.Nb.i&&a.scene.add(a.Nb.i)}a.De=b.De;a.gl=b.cs;b=fM(a);if(0<b.Ll.length){c=b.Ll.map(f=>({edge:Object.assign({},f,{curvePoints:nI(f.points)}),index:95E3}));sM(a.Da,c,a.fa);a.Da.i&&a.scene.add(a.Da.i);
a.Da.C&&a.scene.add(a.Da.C);var e;if(null==(e=a.ia["Tensor shape"])?0:e.selected)e=nN(a,c,a.Zy),PM(a.Cc,e,!1,!0,!0),a.Cc.i&&a.scene.add(a.Cc.i)}a.jf=b.jf;a.wl=b.cs;e=[];b=[];for(const f of Object.keys(Object.assign({},a.De,a.jf)))if(c=a.fa.nodesById[f],gI(c)){const g=(d=null!=a.De[f])?a.De[f].length:a.jf[f].length;e.push({id:`${f}${"||||"}${d?"input":"output"}`,index:e.length,bound:{x:VL(c)+20,y:WL(c)-3.5,width:40,height:14},Le:95,Ee:!0,borderColor:{r:1,g:1,b:1},bgColor:d?a.jd:a.qd,borderWidth:0,
opacity:1});b.push({id:`${f}${"||||"}${d?"input":"output"}`,nodeId:f,label:`${g} ${d?"input":"output"}${1!==g?"s":""}`,height:8,bf:"center",vAlign:"center",weight:1,color:{r:1,g:1,b:1},x:VL(c)+20,y:96,z:WL(c)-3.5+1})}PM(a.uc,b,!1,!0,!0);a.uc.i&&a.scene.add(a.uc.i);zM(a.N,e,!0,!1,!1,!0);a.N.i&&a.scene.add(a.N.i);a.N.C&&a.scene.add(a.N.C);oN(a,f=>{var g=a.va;g.i&&(g.G.value=f);g=a.Da;g.i&&(g.G.value=f);a.Nb.C.value=f;a.Cc.C.value=f;KM(a.N,f);a.uc.C.value=f})}else xM(a.va),xM(a.Da),a.Nb.G={},a.Cc.G=
{},a.N.D={},a.uc.G={}}
function pN(a){if(a.fa){qN(a);var b=a.fa.nodesById[a.selectedNodeId],c=[],d=[];if(gI(b)&&null!=(null==b?void 0:b.identicalGroupIndex)){const f=b.identicalGroupIndex;var e=a.K.filter(({node:g})=>gI(g)&&g.identicalGroupIndex===f).map(({node:g})=>a.fa.nodesById[g.id]);for(const g of e){if(g.id===b.id)continue;e=VL(g)+34;const k=WL(g)-7+3.5;c.push({id:g.id,index:c.length,bound:{x:e,y:k,width:68,height:14},Le:95,Ee:!0,borderColor:a.hz,bgColor:a.gz,borderWidth:1,opacity:1});d.push({id:g.id,label:"Identical layer",
height:8,bf:"center",vAlign:"center",weight:1,color:{r:0,g:0,b:0},x:e,y:96,z:k})}}zM(a.Pd,c,!1,!1,!0,!0);a.Pd.i&&a.scene.add(a.Pd.i);PM(a.Qd,d,!1,!0,!0);a.Qd.i&&a.scene.add(a.Qd.i);oN(a,f=>{KM(a.Pd,f);a.Qd.C.value=f})}}
function rN(a){var b=!1;a.selectedNodeId!==a.Gl&&(a.Gl=a.selectedNodeId,b=!0);var c=!1;a.ta!==a.Qy&&(a.Qy=a.ta,c=!0);CM(a.C);EM(a.C);GM(a.C);IM(a.C);IM(a.ma);SM(a.Bd);TM(a.Bd);SM(a.Ra);SM(a.Mb);SM(a.ea);(b||c)&&vM(a.edges);b&&wM(a.edges);var d=a.fa.nodesById[a.selectedNodeId];if(null!=d&&gI(d)){const p=d.identicalGroupIndex;if(null!=p){var e=a.K.filter(({node:t})=>gI(t)&&t.identicalGroupIndex===p).map(({node:t})=>t.id);DM(a.C,e,a.fz)}}e=a.fa.nodesById[a.Ae];let f=gI(e)?a.cz:a.dz,g;fI(e)&&(null==(g=
e.style)?0:g.hoveredBorderColor)&&(f=new THREE.Color(e.style.hoveredBorderColor));BM(a.C,[a.Ae],f);a.selectedNodeId&&null!=d&&(BM(a.C,[a.selectedNodeId],a.sz),FM(a.C,[a.selectedNodeId],2),DM(a.C,[a.selectedNodeId],a.rz,fI(d)));HM(a.ma,[a.pl],.07);d=Object.keys(a.De);if(0<d.length){BM(a.C,d,new THREE.Color(a.jd.r,a.jd.g,a.jd.b));for(var k of d)FM(a.C,[k],1.5)}k=Object.keys(a.jf);if(0<k.length){BM(a.C,k,new THREE.Color(a.qd.r,a.qd.g,a.qd.b));for(const p of k)FM(a.C,[p],1.5)}(b||c)&&uM(a.edges,[...a.gl,
...a.wl].map(p=>p.id));b=a.gh()||{};for(var m of Object.keys(b))a.T(m)&&fI(a.fa.nodesById[m])&&((c=b[m].bgColor)&&"transparent"!==c&&DM(a.C,[m],new THREE.Color(c)),(c=b[m].textColor)&&RM(a.Bd,[m],new THREE.Color(c)));null!=a.ta&&(m=Object.keys(a.fa.nodesById).filter(p=>!a.ta.Os.has(p)&&a.T(p)),HM(a.C,m,.2),QM(a.Bd,m),QM(a.Mb,m),QM(a.ea,m),QM(a.Ra,m),m=a.Kb.filter(({edge:p})=>!a.ta.Os.has(p.fromNodeId)||!a.ta.Os.has(p.toNodeId)).map(({edge:p})=>p.id),tM(a.edges,m))}
function sN(a){sa(function*(){tN(a);const b=yield uN(a);zJ(a.i,b,a.fa.id,a.paneId)})}
function vN(a,b){sa(function*(){var c=a.Za.P.offsetWidth/wN();let d=a.Za.P.offsetHeight/wN();var e=a.camera;if(b){var f=a.sd+20;e=a.rb-20;const g=a.Od+20,k=a.Jb-20;c=f-e;d=g-k;const m=5E3/wN();c>m&&(d=d*m/c,c=m);d>m&&(c=c*m/d,d=m);f=new THREE.OrthographicCamera(e,f,-k,-g,.001,1E3);f.position.y=200;f.lookAt(new THREE.Vector3(0,0,0));f.updateMatrixWorld();f.updateProjectionMatrix();e=f}f=a.wD.P;a.ab||(a.ab=new THREE.WebGLRenderer({canvas:f,powerPreference:"high-performance",precision:"highp",antialias:!0,
alpha:!0,preserveDrawingBuffer:!0}),a.ab.setPixelRatio(wN()));a.ab.setSize(c,d,!1);LM(a.C,a.rd,0);a.ab.render(a.scene,e);LM(a.C,a.rd,a.zl/3);c=document.createElement("a");c.download="model_explorer_graph.png";ud(c,rd(f.toDataURL()));c.click()})}
function xN(a){if(a.fb){yN(a);var b=new Set;for(var c of Object.keys(a.fb.results)){var d=a.fa.nodesById[c];if(a.T(c))b.add(c);else{for(;d&&(d=a.fa.nodesById[d.nsParentId||""],d&&!a.T(d.id)););b.add(d.id)}}c=[];for(var e of b){b=a.fa.nodesById[e];d=(b.width||0)+4;var f=(b.height||0)+4;c.push({id:e,index:c.length,bound:{x:VL(b)-2+d/2,y:WL(b)-2+f/2,width:d,height:f},Le:.001*a.ra[e].index+-3E-4,Ee:!0,borderColor:{r:1,g:1,b:1},bgColor:a.Bx,borderWidth:0,opacity:1})}zM(a.Oa,c);a.Oa.i&&a.scene.add(a.Oa.i);
e=[];b=11/a.Bd.F;for(const g of Object.keys(a.fb.results))if(a.T(g)){d=a.fb.results[g];for(const k of d)if("title"===k.type){d=a.fa.nodesById[g];f=a.ra[g].index;const m=NM(a.Bd,d.label,gI(d)?2:1,11).sizes;e.push({id:g,index:c.length,bound:{x:VL(d)+(d.width||0)/2,y:WL(d)+14-2*b,width:(m.Ph-m.Sh)*b+4,height:(m.Yn-m.Zn)*b+4},Le:.001*f+3E-4,Ee:!0,borderColor:{r:1,g:1,b:1},bgColor:a.Bx,borderWidth:0,opacity:1})}}zM(a.Ic,e);a.Ic.i&&a.scene.add(a.Ic.i);oN(a,g=>{KM(a.Oa,g);KM(a.Ic,g)})}}
function zN(a){var b=[a.Oa.i,a.Ic.i];for(var c=a.scene.children.length-1;0<=c;c--){var d=a.scene.children[c];b.includes(d)||(d.geometry&&d.geometry.dispose(),a.scene.remove(d))}a.Gl="";a.Qy=void 0;0<a.Kb.length&&(sM(a.edges,a.Kb,a.fa),a.edges.i&&a.scene.add(a.edges.i),a.edges.C&&a.scene.add(a.edges.C));b=[];for(const {node:U,index:Q}of a.K){c=a.rd;for(var e of a.jk)if(FI(U,e.queries,a.fa)){var f=void 0;d=(null==(f=e.styles.node_text_color)?void 0:f.value)||"";""!==d&&(c=new THREE.Color(d));break}b.push({id:`${U.id}_label`,
nodeId:U.id,label:kM(U),height:11,bf:"center",vAlign:"center",weight:fI(U)?1:2,x:VL(U)+(U.width||0)/2,y:.001*Q+4E-4,z:WL(U)+14,color:c})}PM(a.Bd,b);a.Bd.i&&a.scene.add(a.Bd.i);var g;if(null==(g=a.ia["Tensor shape"])?0:g.selected)g=nN(a,a.Kb,a.rd),PM(a.Ra,g),a.Ra.i&&a.scene.add(a.Ra.i);AN(a);a.rb=Number.POSITIVE_INFINITY;a.Jb=Number.POSITIVE_INFINITY;a.sd=Number.NEGATIVE_INFINITY;a.Od=Number.NEGATIVE_INFINITY;g=a.K.length;e=[];f=[];b=[];c=[];d=[];const k=11/a.Bd.F;for(let U=0;U<g;U++){const Q=a.K[U].node,
la=a.K[U].index,F=VL(Q),M=WL(Q),W=Q.width||0,Aa=Q.height||0;var m=gI(Q),p=m?BN(a,Q):{r:1,g:1,b:1},t=CN(m?a.az:a.qz);fI(Q)&&Q.style&&(Q.style.backgroundColor&&(p=new THREE.Color(Q.style.backgroundColor)),Q.style.borderColor&&(t=new THREE.Color(Q.style.borderColor)));m=a.bz;for(var v of a.jk)if(FI(Q,v.queries,a.fa)){var B=void 0,G=(null==(B=v.styles.node_bg_color)?void 0:B.value)||"";""!==G&&(p=new THREE.Color(G));var K=void 0;G=(null==(K=v.styles.node_border_color)?void 0:K.value)||"";""!==G&&(t=new THREE.Color(G));
var N=void 0;G=(null==(N=v.styles.node_text_color)?void 0:N.value)||"";""!==G&&(m=new THREE.Color(G));break}G=!0;gI(Q)&&Q.sectionContainer&&(G=!1);e.push({id:Q.id,index:U,bound:{x:F+W/2,y:M+Aa/2,width:W,height:Aa},Le:.001*la,Ee:G,borderColor:t,bgColor:p,borderWidth:1.2,opacity:1,aB:(fI(Q)||!Q.expanded)&&1===p.r&&1===p.g&&1===p.b});fI(Q)&&Q.subgraphIds&&(c.push({id:`${Q.id}`,index:c.length,bound:{x:VL(Q)+(Q.width||0)+9,y:WL(Q)+7,width:14,height:14},Le:.001*a.ra[Q.id].index,Ee:!0,borderColor:a.ky,bgColor:a.uz,
borderWidth:1,opacity:1}),d.push({id:Q.id,nodeId:Q.id,label:"0xe5da",height:28,bf:"center",vAlign:"center",weight:4,color:a.ky,x:VL(Q)+(Q.width||0)+10,y:.001*a.ra[Q.id].index+4E-4,z:WL(Q)+23,hm:!0}));gI(Q)&&(G=NM(a.Bd,kM(Q),2,11).sizes,t=(G.Ph-G.Sh)*k,p=F+W/2-t/2,t=F+W/2+t/2,G=M+14+(G.Yn-G.Zn)*k+7.5,p=Q.expanded?p-13:(F+p+1)/2+1,t=Q.expanded?t+12:(F+W+t-1)/2-1,f.push({id:Q.id,nodeId:Q.id,label:Q.expanded?"0xe5d6":"0xe5d7",height:32,bf:"center",vAlign:"center",weight:4,color:m,x:p,y:.001*la+4E-4,z:G,
hm:!0}),f.push({id:Q.id,nodeId:Q.id,label:"0xe5d4",height:32,bf:"center",vAlign:"center",weight:4,color:m,x:t,y:.001*la+4E-4,z:G,hm:!0}),m=M+14-1,b.push({id:`${Q.id}_${"left"}`,nodeId:Q.id,index:b.length,bound:{x:p,y:m,width:16,height:16},Le:.001*la+3E-4,Ee:!0,borderColor:{r:1,g:1,b:1},bgColor:{r:0,g:0,b:0},borderWidth:0,opacity:0}),b.push({id:`${Q.id}_${"right"}`,nodeId:Q.id,index:b.length,bound:{x:t,y:m,width:16,height:16},Le:.001*la+3E-4,Ee:!0,borderColor:{r:1,g:1,b:1},bgColor:{r:0,g:0,b:0},borderWidth:0,
opacity:0}));a.rb=Math.min(a.rb,F);a.sd=Math.max(a.sd,F+W);a.Jb=Math.min(a.Jb,M);a.Od=Math.max(a.Od,M+Aa)}zM(a.C,e,!0);a.C.i&&a.scene.add(a.C.i);a.C.C&&a.scene.add(a.C.C);PM(a.Mb,f);a.Mb.i&&a.scene.add(a.Mb.i);zM(a.ma,b,!0);a.ma.i&&a.scene.add(a.ma.i);a.ma.C&&a.scene.add(a.ma.C);zM(a.Ud,c,!0);a.Ud.i&&a.scene.add(a.Ud.i);PM(a.zi,d);a.zi.i&&a.scene.add(a.zi.i);v=a.gh()||{};if(0!==Object.keys(v).length){var {WB:aa,oE:ca}=hM(a);v=[];for(const {node:U,index:Q}of a.K)if(aa[U.id]){B=U;K=B.width||0;N=aa[U.id];
g=0;for(var ia of Object.values(N))g+=ia;f=e=0;for(var O of ca)null!=N[O]&&"transparent"!==O&&(b=N[O]/g*K,v.push({id:`${U.id}_${f}`,index:v.length,bound:{x:VL(B)+e+b/2,y:WL(B)+(B.height||0)-5+2.5,width:b,height:5},Le:.001*Q+5E-4,Ee:!1,borderColor:{r:1,g:1,b:1},bgColor:new THREE.Color(O),borderWidth:0,opacity:1}),e+=b,f++)}zM(a.wi,v);a.wi.i&&a.scene.add(a.wi.i)}ia=[];for(const U of a.fa.artificialGroupNodeIds||[])a.T(U)&&(O=a.fa.nodesById[U],v=(O.width||0)+2,B=(O.height||0)+2,ia.push({id:U,index:ia.length,
bound:{x:VL(O)-1+v/2,y:WL(O)-1+B/2,width:v,height:B},Le:.001*a.ra[U].index+-5E-4,Ee:!1,borderColor:{r:1,g:1,b:1},bgColor:a.UE,borderWidth:0,opacity:1}));zM(a.eh,ia,!1,!1,!0);a.eh.i&&a.scene.add(a.eh.i);xN(a);DN(a);oN(a)}
function EN(a){const b=a.canvas.P;a.scene=new THREE.Scene;a.scene.background=new THREE.Color(16777215);a.camera=new THREE.OrthographicCamera(0,b.clientWidth/b.clientHeight*1E3,0,-1E3,.001,1E3);a.camera.position.y=200;a.camera.lookAt(new THREE.Vector3(0,0,0));a.camera.updateMatrixWorld();a.camera.updateProjectionMatrix();a.ba=new THREE.WebGLRenderer({canvas:b,powerPreference:"high-performance",precision:"highp",antialias:!0,alpha:!0});const c=wN();a.ba.setPixelRatio(c);a.ba.setSize(b.clientWidth,b.clientHeight);
a.Vc=new THREE.WebGLRenderer({canvas:a.Ux.P,powerPreference:"high-performance",precision:"highp",antialias:!0,alpha:!0,preserveDrawingBuffer:!0});a.Vc.setPixelRatio(c);a.render();(new ResizeObserver(()=>{requestAnimationFrame(()=>{FN(a)})})).observe(a.Za.P);a.Hc=new THREE.Raycaster;a.Hc.params.Points.threshold=5.5}
function GN(a,b){if(!(0<a.mf)){var c=a.canvas.P;a.sl.x=b.offsetX/c.offsetWidth*2-1;a.sl.y=2*-(b.offsetY/c.offsetHeight)+1;a.Hc.setFromCamera(a.sl,a.camera);AM(a.C,a.Hc,d=>{a.Ae=d;rN(a);a.render()});AM(a.ma,a.Hc,(d,e)=>{a.pl=d;a.eo=(null==e?void 0:e.nodeId)||"";rN(a);HN(a,e);a.render()},!1);AM(a.N,a.Hc,(d,e)=>{a.ql=d;a.Rn=-1E3;a.Qn=-1E3;a.cr="";d=a.ql.endsWith("input");if(""!==a.ql){const {x:f,y:g}=gN(a,e.bound.x-e.bound.width/2,e.bound.y-e.bound.height/2),{x:k,y:m}=gN(a,e.bound.x+e.bound.width/2,
e.bound.y+e.bound.height/2);a.Rn=g;a.Qn=f;a.dr=k-f;a.br=m-g;a.cr=`Click to reveal ${d?"input":"output"} node(s)`}$m(a.O)});AM(a.Ud,a.Hc,(d,e)=>{a.Nn=d;a.Go=-1E3;a.Fo=-1E3;if(""!==a.Nn){const {x:f,y:g}=gN(a,e.bound.x-e.bound.width/2,e.bound.y-e.bound.height/2),{x:k,y:m}=gN(a,e.bound.x+e.bound.width/2,e.bound.y+e.bound.height/2);a.Go=g;a.Fo=f;a.gy=k-f;a.As=m-g}$m(a.O)})}}function IN(a){const b=()=>{a.render(!0);requestAnimationFrame(b)};b()}
function JN(a,b,c){const d=new THREE.Vector3;d.set(b/a.canvas.P.offsetWidth*2-1,2*-(c/a.canvas.P.offsetHeight)+1,-1);a=d.unproject(a.camera);return{x:a.x,y:a.z}}
function KN(a,b){if(a.ml&&(b.metaKey||b.ctrlKey)||!a.ml&&b.ctrlKey){b.preventDefault();b.stopPropagation();a.mf=b.offsetX;a.Ia=b.offsetY;a.Fc=a.mf;a.Gc=a.Ia;b=jk(document,"mousemove");const c=jk(window,"mouseup");let d=0,e=0;C(Nj([b]),Jo(c)).subscribe({next:([f])=>{d=f.offsetX-a.mf;e=f.offsetY-a.Ia;a.Fc=a.mf+d;a.Gc=a.Ia+e;$m(a.O)},complete:()=>{if(5<=Math.abs(d)||5<=Math.abs(e)){const f=JN(a,a.mf,a.Ia),g=JN(a,a.Fc,a.Gc),k=Math.min(f.x,g.x),m=Math.min(f.y,g.y);a.Wc({x:k,y:m,width:Math.max(f.x,g.x)-
k,height:Math.max(f.y,g.y)-m},.9,200,!1,!1)}a.mf=-1;a.Ia=-1;a.Fc=-1;a.Gc=-1;$m(a.O)}})}}
function HN(a,b){a.Ob.top=-1E3;a.Ob.left=-1E3;a.Ob.width=0;a.Ob.height=0;a.Ob.Md=void 0;if(""!==a.pl&&null!=b){const {x:c,y:d}=gN(a,b.bound.x-b.bound.width/2,b.bound.y-b.bound.height/2),{x:e,y:f}=gN(a,b.bound.x+b.bound.width/2,b.bound.y+b.bound.height/2);a.Ob.top=d;a.Ob.left=c;a.Ob.width=e-c;a.Ob.height=f-d;b.id.includes("_left")?a.Ob.Md=a.fa.nodesById[b.nodeId].expanded?"Collapse layer":"Expand layer":b.id.includes("_right")&&(a.Ob.Md="More actions")}$m(a.O)}
function gN(a,b,c){var d=a.Za.P;const e=d.clientWidth;d=d.clientHeight;b=new THREE.Vector3(b,0,c);b.project(a.camera);return{x:b.x*e/2+e/2,y:-(b.y*d/2)+d/2}}function iN(a,b){sa(function*(){CJ(a.i,a.paneId,a.fa.id,b,yield uN(a));const c=BJ(a.i,b);c&&(oJ(a.i,a.paneId),kJ(a.i,!1),a.i.K.set(void 0),a.i.F.set(void 0),iJ(a.i,c))})}function LN(a,b){a=a.fa.nodesById[null!=b?b:a.Ae];return null!=a&&gI(a)?a.expanded:!1}
function MN(a){var b=a.Za.P;const c=b.clientWidth;b=b.clientHeight;const d=c/b,e=a.hh-c/2,f=a.ih-b/2;a.camera.left=-500/a.G*d-e/c*1E3/a.G*d;a.camera.right=500/a.G*d-e/c*1E3/a.G*d;a.camera.top=500/a.G+500*f/a.G/b*2;a.camera.bottom=-500/a.G+500*f/a.G/b*2;a.camera.updateProjectionMatrix()}function DN(a){const b=Math.max(0,Math.min(1,(7.5-(a.Za?30*a.Za.P.clientHeight/500/2:0)*a.G)/.5));1E-5>Math.abs(b-a.zl)||(a.zl=b,LM(a.C,a.rd,b/3))}
function NN(a,b){if(!a.i.i){var c=Date.now(),d=()=>{var e=Date.now()-c;e=Math.min(1,e/1100);e=-(Math.cos(Math.PI*e)-1)/2;const f=8*Math.sin(e*Math.PI*9);JM(a.C,b,f);JM(a.Oa,b,f);a.render();1<=e?(JM(a.C,b,0),JM(a.Oa,b,0),a.render()):requestAnimationFrame(d)};d()}}function ON(a,b,c=1){return a.Za?1E3*b/c/a.Za.P.clientHeight:0}
function PN(a,b,c,d,e=300){if(a.Za){var f=a.Za.P;b=f.clientWidth/f.clientHeight*-1E3/2/d+b;c=-c+500/d;d=KL.scale(d);var g=d.translate;if(a.Za){var k=a.Za.P,m=k.clientWidth;b=b/(m/k.clientHeight*500)/-2*m}else b=0;b=g.call(d,b,a.Za?c*a.Za.P.clientHeight/500/2:0);f=IL(f);0===e?f.call(a.zoom.transform,b):f.transition().duration(a.i.i?0:e).Mf(GL).call(a.zoom.transform,b)}}function wN(){return 1===window.devicePixelRatio?1.5:window.devicePixelRatio}
function FN(a){var b=a.Za.P;const c=a.ba.domElement,d=b.clientWidth;b=b.clientHeight;if(0!==d&&0!==b&&(c.width!==d||c.height!==b)){if(null==a.xi&&null==a.yi){const {x:e,y:f}=JN(a,d/2,b/2);a.xi=e;a.yi=f}a.ba.setSize(d,b,!1);a.canvas.P.style.width="100%";a.canvas.P.style.height="100%";MN(a);a.render();a.Wc({x:a.xi,y:a.yi,width:1E-7,height:1E-7},.9,0,!0);0<=a.xl&&window.clearTimeout(a.xl);a.xl=window.setTimeout(()=>{a.xi=null;a.yi=null},500)}}
function AN(a){if(0!==Object.keys(a.D).filter(k=>a.D[k].selected).length){var b=[],c=9/a.ea.F,d=[];for(const {node:k,index:m}of a.K){const p=[];var e=38,f=0;let t=0;const v=[];if(fI(k)){var g=hI(a.D);for(const N of g)v.push({key:N,value:jI(k,N)});let B;if(null==(B=a.D["Op node attributes"])?0:B.selected){let N;v.push(...tI(k,(null==(N=a.D["Op node attributes"])?void 0:N.filterRegex)||""))}let G;(null==(G=a.D["Op node inputs"])?0:G.selected)&&v.push(...uI(k,a.fa));let K;(null==(K=a.D["Op node outputs"])?
0:K.selected)&&v.push(...vI(k));v.push(...wI(k,a.fa.id,a.D,a.kb))}else if(gI(k)){g=iI(a.D);for(const B of g)v.push({key:B,value:jI(k,B)})}for(const {key:B,value:G}of v){const {sj:K,EC:N,jm:aa,PE:ca}=QN(a,k,m,B,G,e,c);b.push(K,aa);f=Math.max(N,f);t=Math.max(ca,t);p.push({sj:K,jm:aa});e+=12}e=((k.width||0)-(f+t+4))/2;for(const B of p)B.sj.x=VL(k)+f,B.jm.x=VL(k)+f+4,B.sj.x+=e,B.jm.x+=e;0<p.length&&fI(k)&&(f=(k.width||0)-16,e=12*p.length,d.push({id:k.id,index:d.length,bound:{x:VL(k)+8+f/2,y:p[0].sj.z+
e/2-6,width:f,height:e},Le:.001*m+2E-4,Ee:!0,borderColor:{r:1,g:1,b:1},bgColor:{r:1,g:1,b:1},borderWidth:1,opacity:1}))}0<b.length&&(PM(a.ea,b),a.ea.i&&a.scene.add(a.ea.i),zM(a.fh,d),a.fh.i&&a.scene.add(a.fh.i))}}
function oN(a,b=c=>{KM(a.C,c);a.Mb.C.value=c;KM(a.ma,c);KM(a.Ud,c);a.zi.C.value=c;a.Bd.C.value=c;a.Ra.C.value=c;a.ea.C.value=c;KM(a.fh,c);KM(a.wi,c);KM(a.eh,c);var d=a.edges;d.i&&(d.G.value=c)}){const c=Date.now(),d=()=>{var e=Date.now()-c;e=a.i.i?1:Math.min(1,e/200);e=Math.sin(e*Math.PI/2);b(e);a.render();1<=e?(b(e),a.render()):requestAnimationFrame(d)};d()}function BN(a,b){b=(b.namespace||"").split("/").filter(c=>""!==c).length;return CN(a.Ar[Math.min(a.Ar.length-1,b)])}
function CN(a){return{r:a.r,g:a.g,b:a.b}}
function nN(a,b,c){var d;const e=(null==(d=a.i.config())?void 0:d.edgeLabelFontSize)||7.5;var f;d=(null==(f=a.i.config())?void 0:f.disallowVerticalEdgeLabels)||!1;const g=[],k=pM(a.R,1);for(const {edge:ia}of b){var m=a.fa.nodesById[ia.fromNodeId];b=a.fa.nodesById[ia.toNodeId];if(!fI(m)||!fI(b))continue;let O="?";b=m.outputsMetadata||{};for(const Q of Object.keys(b))if(null!=(m.outgoingEdges||[]).find(la=>la.sourceNodeOutputId===Q&&la.targetNodeId===ia.toNodeId)){O=b[Q].shape||"?";O=O.split("").map(la=>
{"x"===la&&(la="x");"\u2217"===la&&(la="*");""===la&&(la="");return null==k[la]?"?":la}).join("");break}b=ia.curvePoints||[];f=m.globalX||0;m=m.globalY||0;const U=new THREE.CurvePath;for(var p=0;p<b.length-1;p++){var t=b[p],v=b[p+1];t=new THREE.LineCurve(new THREE.Vector2(t.x+f,t.y+m),new THREE.Vector2(v.x+f,v.y+m));U.add(t)}b=U.getLength();f=e/2/b;p=()=>{const Q=U.getPointAt(.5);g.push({id:`${ia.id}_${O}`,nodeId:ia.toNodeId,label:O,height:e,bf:"center",vAlign:"center",weight:1,x:Q.x,y:95,z:Q.y,color:c,
borderColor:{r:1,g:1,b:1}})};if(1<f*(O.length+3))p();else{m=[];t=Math.max(0,Math.min(.25,1-O.length*f-5/b));v=Math.max(.05,1-5/b-t-f*O.length);var B=!0;f=e/a.Ra.F;for(var G=0;G<v;G+=.05){var K=t+G;B=!0;var N=void 0;m=[];for(let Q=0;Q<O.length;Q++){var aa=O[Q];const la=U.getPointAt(Math.min(K,1)),F=U.getTangentAt(Math.min(K,1));var ca=(2*Math.PI-Math.atan(F.y/F.x))%(2*Math.PI);0>ca&&(ca+=2*Math.PI);if(d&&ca>=Math.PI/4&&ca<=1.75*Math.PI){B=!1;break}m.push({ro:la,position:Math.min(K,1),angle:ca,tan:F,
char:aa});if(null!=N&&(N=Math.abs(ca-N),.15<Math.min(N,Math.abs(N-Math.PI))&&(B=!1,G+.05<v)))break;N=ca;aa=k[aa];ca=0;Q!==O.length-1&&(ca=k[O[Q+1]].xadvance);K+=(aa.xadvance/2+ca/2)*f/b}if(B)break}if(B){if(p=m[0].ro.x>=m[m.length-1].ro.x){t=[];m=m[0].position;for(v=O.length-1;0<=v;v--)B=O[v],G=U.getPointAt(Math.min(1,m)),N=U.getTangentAt(Math.min(1,m)),K=(2*Math.PI-Math.atan(N.y/N.x))%(2*Math.PI),0>K&&(K+=2*Math.PI),t.push({ro:G,angle:K,tan:N,position:m,char:B}),B=k[B],G=0,1<=v&&(G=k[O[v-1]].xadvance),
m+=(B.xadvance/2+G/2)*f/b;m=t}for(b=0;b<m.length;b++)f=m[b],t=f.char,v=f.ro,B=f.angle,1E-7>Math.abs(f.tan.x)&&(B=(p?1:-1)*Math.PI/2),g.push({id:`${ia.id}_${t}_${b}`,nodeId:ia.toNodeId,label:t,height:e,bf:"",vAlign:"",weight:1,x:v.x+1.5*Math.sin(B)*-e,y:95,z:v.y+1.5*Math.cos(B)*-e,color:c,angle:B,zq:!0,borderColor:{r:1,g:1,b:1}})}else p()}}return g}
function QN(a,b,c,d,e,f,g){const k={id:`${b.id}_attrs_table_${d}_key`,nodeId:b.id,label:`${d}:`,height:9,bf:"right",vAlign:"center",weight:1,x:VL(b),y:.001*c+4E-4,z:WL(b)+f,color:a.Uy};var m=NM(a.ea,k.label,k.weight,k.height).sizes;m=(m.Ph-m.Sh)*g;b={id:`${b.id}_attrs_table_${d}_value`,nodeId:b.id,label:e,height:9,bf:"left",vAlign:"center",weight:0,x:VL(b),y:.001*c+4E-4,z:WL(b)+f,color:a.Wy,maxWidth:200};const {sizes:p,LE:t}=NM(a.ea,b.label,b.weight,b.height,b.maxWidth);null!=t&&(b.label=t);return{sj:k,
EC:m,jm:b,PE:(p.Ph-p.Sh)*g}}function mN(a){a.va.clear();a.Da.clear();a.De={};a.jf={};a.gl=[];a.wl=[];for(const b of[a.N.i,a.N.C,a.uc.i,a.Nb.i,a.Cc.i])b&&(b.geometry&&b.geometry.dispose(),a.scene.remove(b));a.N.C=void 0}function qN(a){for(const b of[a.Pd.i,a.Qd.i])b&&(b.geometry&&b.geometry.dispose(),a.scene.remove(b))}function tN(a){a.Fq=!0;$m(a.O);setTimeout(()=>{a.Fq=!1;$m(a.O)},300)}
function uN(a){return sa(function*(){var b=a.Za.P,c=JN(a,0,0);b=JN(a,b.clientWidth,b.clientHeight);c={x:c.x,y:c.y,width:b.x-c.x,height:b.y-c.y};b=[];mI(void 0,a.fa,b);var d=a.canvas.P,e=a.Ux.P;d=320/d.width*d.height;a.Vc.setSize(320,d,!1);a.Vc.render(a.scene,a.camera);var f=window.devicePixelRatio;d=new OffscreenCanvas(320*f,d*f);f=d.getContext("2d");f.imageSmoothingQuality="high";f.drawImage(e,0,0,e.width,e.height,0,0,d.width,d.height);e=yield createImageBitmap(d);d=mJ(a.i,a.paneId);return{id:lI(),
rect:c,Uq:e,selectedNodeId:a.selectedNodeId,deepestExpandedGroupNodeIds:b,showOnNodeItemTypes:Object.assign({},a.D),Vb:Object.assign({},a.ia),flattenLayers:d}})}function yN(a){for(const b of[a.Oa.i,a.Ic.i])b&&(b.geometry&&b.geometry.dispose(),a.scene.remove(b))}
var RN=class extends lM{constructor(){super();this.yc=!1;this.sz=new THREE.Color("#1A73E8");this.rz=new THREE.Color("#C2E7FF");this.dz=new THREE.Color("#000");this.cz=new THREE.Color("#666");this.fz=new THREE.Color("#e2edff");this.gz=new THREE.Color("#e3e3e3");this.hz=new THREE.Color("#ccc");this.rd=new THREE.Color("#041E49");this.qz=new THREE.Color("#777");this.az=new THREE.Color("#aaa");new THREE.Color("#DADCE0");this.bz=new THREE.Color("#444746");this.Xy=new THREE.Color("#aaa");this.jd=new THREE.Color("#009e73");
this.Yy=new THREE.Color("#125341");this.qd=new THREE.Color("#d55e00");this.Zy=new THREE.Color("#994d11");this.Uy=new THREE.Color("#808080");this.Wy=new THREE.Color("#0d0d0d");this.UE=new THREE.Color("#800080");this.Bx=new THREE.Color("#f5d55a");this.ky=new THREE.Color("#135cbb");this.uz=new THREE.Color("#d5e7ff");this.Ar=(()=>{const a=[];for(let b=0;6>b;b++)a.push(new THREE.Color(`hsl(212, 40%, ${Math.round(96+-2.4*b)}%)`));return a})();new THREE.Color("#C2E7FF");new THREE.Color("#7facc9");this.Ob=
{top:-1E3,left:-1E3,width:0,height:0};this.rl="";this.Qn=this.Rn=-1E3;this.br=this.dr=0;this.cr="";this.Fo=this.Go=-1E3;this.As=this.gy=0;this.vv=[];this.Gc=this.Fc=this.Ia=this.mf=-1;this.Fq=!1;this.jh=-1;this.fg=0;this.Tv="";this.mz=lf(Ok);this.R=lf(rM);this.nz=lf(jL);this.C=new MM(6);this.Mb=new UM(this.R);this.ma=new MM(99);this.wi=new MM(0);this.eh=new MM(6);this.Oa=new MM(8);this.Ic=new MM(4);this.Pd=new MM(99);this.Qd=new UM(this.R);this.N=new MM(99);this.uc=new UM(this.R);this.Ud=new MM(3);
this.zi=new UM(this.R);this.edges=new yM(this.Xy,1);this.va=new yM(this.jd,1.5);this.Da=new yM(this.qd,1.5);this.Nb=new UM(this.R);this.Cc=new UM(this.R);this.Bd=new UM(this.R);this.Ra=new UM(this.R);this.ea=new UM(this.R);this.fh=new MM(4);this.sl=new THREE.Vector2;this.Od=this.Jb=this.sd=this.rb=0;this.De={};this.jf={};this.gl=[];this.wl=[];this.Nn=this.ql=this.eo=this.pl=this.Ae="";this.yi=this.xi=null;this.zl=this.xl=-1;this.fb=void 0;this.ik=[];this.jk=[];Gs(()=>{const a=this.Qg();(null==a?void 0:
a.rendererId)===this.rendererId&&(this.selectedNodeId=(null==a?void 0:a.nodeId)||"",this.Wg&&(this.selectedNodeId&&fI(this.fa.nodesById[this.selectedNodeId])?gM(this):this.ta=void 0),lN(this),pN(this),rN(this),this.render())});C(this.i.ia,kL(this.F)).subscribe(a=>{a.rendererId===this.rendererId&&sN(this)});C(this.i.T,kL(this.F)).subscribe(a=>{if(a.rendererId===this.rendererId){a=a.jb;a.showOnNodeItemTypes&&(this.D=Object.assign({},a.showOnNodeItemTypes),JJ(this.i,this.paneId,this.rendererId,this.D));
a.Vb&&(this.ia=Object.assign({},a.Vb),KJ(this.i,this.paneId,this.rendererId,this.ia));const b=mJ(this.i,this.paneId),c=!0===a.flattenLayers;b!==c?(eJ(this.i,this.paneId,c,a),kJ(this.i,c)):OL(this,a.selectedNodeId||"",a.deepestExpandedGroupNodeIds||[],!1,a.rect,!0,a.showOnNodeItemTypes)}});C(this.i.ma,kL(this.F)).subscribe(a=>{a.rendererId===this.rendererId&&vN(this,a.TB)});Gs(()=>{const a=fJ(this.i,this.paneId);a&&a.modelGraph&&this.fb!==a.Pg&&(this.fb=a.Pg,xN(this),this.render())});Gs(()=>{var a=
this.nz.rules().filter(b=>DI(b.queries)&&0<Object.keys(b.styles).length);a=JSON.stringify(a);JSON.stringify(this.ik)!==a&&(this.ik=JSON.parse(a),this.jk=EI(this.ik),zN(this),lN(this),pN(this),rN(this),this.render())});Gs(()=>{if(fJ(this.i,this.paneId)){var a=MJ(this.i,this.paneId,this.rendererId);JSON.stringify(a)!==JSON.stringify(this.ia)&&(this.ia=a,zN(this),lN(this),pN(this),rN(this),this.render())}})}Eb(){this.Ag=this.modelGraph.id;this.fa=this.modelGraph;this.Pb||(this.D=XI(this.i),this.ia=YI(this.i));
QL(this,this.Za.P);EN(this);Kk(this.mz,()=>{this.canvas.P.addEventListener("mousemove",d=>{GN(this,d)})});var a=this.i.K(),b=d=>{UL(this);zN(this);this.Vd(.9,0);const e=fJ(this.i,this.paneId);if(null!=(null==e?void 0:e.Do)){const f=e.Do;this.D=e.Do.showOnNodeItemTypes||{};JJ(this.i,this.paneId,this.rendererId,this.D);OL(this,f.selectedNodeId||"",f.deepestExpandedGroupNodeIds||[],!1,f.rect,!0,f.showOnNodeItemTypes,!0);e.Do=void 0}else null!=d&&""!==d&&setTimeout(()=>{this.i.F.set({nodeId:d,rendererId:this.rendererId,
zd:!1,noNodeShake:!0})});RL(this,this.Ul||"")};if(!a||0===a.paneStates.length||this.Pb){var c;let d;a=this.Pb?void 0:null==(c=fJ(this.i,this.paneId))?void 0:null==(d=c.Qg)?void 0:d.nodeId;b(a)}else c=aJ(this.i,this.paneId),(a=a.paneStates[c])?(OL(this,a.selectedNodeId,a.deepestExpandedGroupNodeIds,!0),KI(this.Ne,a.deepestExpandedGroupNodeIds,c)):b();b=window;null==b.me_test&&(b.me_test={HD:{}});a=this.Pb?-1:aJ(this.i,this.paneId);b.me_test.HD[a]=this;this.yc&&IN(this)}ua(){super.ua();this.ba&&(this.ba.dispose(),
this.ba.forceContextLoss());this.Vc&&(this.Vc.dispose(),this.Vc.forceContextLoss());this.ab&&(this.ab.dispose(),this.ab.forceContextLoss());document.body.style.cursor="default"}Dl(){super.Dl();lN(this);rN(this);this.render()}get dE(){return!this.Pb}get FD(){return Math.min(this.Ia,this.Gc)}get ED(){return Math.min(this.mf,this.Fc)}get GD(){return Math.abs(this.Fc-this.mf)}get DD(){return Math.abs(this.Gc-this.Ia)}Gk(){super.Gk();this.Ae?this.fa.nodesById[this.Ae]&&SL(this,this.Ae):SL(this,"")}Ik(a){super.Ik(a);
""!==this.selectedNodeId&&YL(this,this.fa.nodesById[this.selectedNodeId],a)}dl(){super.dl();requestAnimationFrame(()=>{this.camera&&(MN(this),DN(this),this.render(),HN(this))})}By(a,b){DL.ys&&"mouseup"===DL.ys.type&&(a=Math.abs(this.hh-a),b=Math.abs(this.ih-b),0<=a&&3>=a&&0<=b&&3>=b&&this.Gk())}Nk(a,b,c,d,e){super.Nk(a,b,c,d,e);zN(this);null!=c?XL(this,c,a,400):this.Vd();lN(this);pN(this);rN(this);this.render();this.Pb||KI(this.Ne,e,aJ(this.i,this.paneId))}al(a,b,c,d,e,f,g){super.al(a,b,c,d,e,f,g);
zN(this);lN(this);pN(this);rN(this);if(e){const k=()=>{this.Wc(e,1,200,!1,!1)};f?setTimeout(()=>{k()}):k()}else"______"!==c&&XL(this,c,b,d?0:400);this.selectedNodeId!==c&&SL(this,c||"");this.Pb||KI(this.Ne,g||[],aJ(this.i,this.paneId))}uy(){zN(this);rN(this);this.render()}kh(a,b,c,d,e,f,g=!1){super.kh(a,b,c,d,e,f);XL(this,c,b,400);g||(zN(this),lN(this),pN(this),rN(this),this.render(),this.Pb||KI(this.Ne,d,aJ(this.i,this.paneId)));e||setTimeout(()=>{NN(this,c)},250)}Wc(a,b=.9,c=300,d=!1,e=!0,f=!1){if(this.Za){var g=
this.Za.P,k=g.clientWidth*b;b*=g.clientHeight;g=a.width/a.height;if(d)k=this.G;else{if(g>k/b){if(this.Za){g=this.Za.P;var m=g.clientWidth;k=k/m*-2*(m/g.clientHeight)*500}else k=0;k/=a.width}else k=ON(this,b)/a.height;k=Math.abs(k)}g=a.x+a.width/2;m=a.y+a.height/2;!d&&e&&(k=Math.min(ON(this,45)/30,k),f&&(d=ON(this,20)/30,k<d&&(m=a.y+ON(this,b/2-60,d),k=Math.max(d,k))));PN(this,g,m,k,c)}}Vd(a=.9,b=200){this.Wc({x:this.rb,y:this.Jb,width:this.sd-this.rb,height:this.Od-this.Jb},a,b)}T(a){return null!=
this.ra[a]}render(a=!1){this.ba&&this.scene&&this.camera&&(this.ba.render(this.scene,this.camera),this.yc&&a&&(0>this.jh&&(this.jh=performance.now()),this.fg+=1,a=performance.now()-this.jh,1E3<a&&(this.Tv=(this.fg/a*1E3).toFixed(1),this.jh=-1,this.fg=0,Zm(this.O))))}};RN.J=function(a){return new (a||RN)};
RN.Ca=Gf({type:RN,ga:[["webgl-renderer"]],eb:function(a,b){a&1&&(rr(VM,7),rr(WM,7),rr(XM,7),rr(YM,7),rr(ZM,7),rr($M,7),rr(aN,7),rr(bN,5),rr(cN,5),rr(dN,7));if(a&2){let c;sr(c=tr())&&(b.Za=c.first);sr(c=tr())&&(b.canvas=c.first);sr(c=tr())&&(b.Ux=c.first);sr(c=tr())&&(b.wD=c.first);sr(c=tr())&&(b.RF=c.first);sr(c=tr())&&(b.nw=c.first);sr(c=tr())&&(b.tE=c.first);sr(c=tr())&&(b.Xv=c.first);sr(c=tr())&&(b.ow=c.first);sr(c=tr())&&(b.RC=c.first)}},inputs:{yc:"benchmark"},ja:!0,features:[Ap,Jr],ya:36,za:60,
Ba:[["container",""],["canvas",""],["snapshotCanvas",""],["pngDownloaderCanvas",""],["groupNodeIconMatTooltip","matTooltip"],["moreActionsMenuTrigger","matMenuTrigger"],["moreActionsMenu","matMenu"],["ioPicker",""],["ioPickerMatTooltip","matTooltip"],["subgraphIndicator",""],["subgraphMenuTrigger","matMenuTrigger"],["menu","matMenu"],[1,"container",3,"mouseleave"],[1,"main",3,"mousedown","contextmenu"],[1,"snapshot"],[1,"download-png"],[1,"group-node-icon",3,"mouseenter","mouseleave","mousedown"],
["matTooltipPosition","above",1,"group-node-icon-tooltip",3,"matTooltip","matTooltipShowDelay","matTooltipDisabled"],[1,"more-actions-menu-trigger",3,"matMenuTriggerFor"],[1,"model-explorer-menu-item-with-icon","expand-all",3,"click"],["class","model-explorer-menu-item-with-icon collapse-all",3,"click",4,"ngIf"],["class","model-explorer-menu-item-with-icon open-in-popup",3,"click",4,"ngIf"],[1,"io-picker",3,"mousedown","mouseenter","mouseleave"],["matTooltipPosition","above",1,"io-picker-tooltip",
3,"matTooltip"],["matTooltip","Jump to subgraph","matTooltipPosition","above",1,"subgraph-indicator",3,"mousedown","click"],[1,"subgraph-indicator-menu-trigger",3,"matMenuTriggerFor"],[1,"model-explorer-menu-item-with-icon"],["class","range-container",3,"top","left","width","height",4,"ngIf"],[1,"flash"],[1,"fps"],[1,"model-explorer-menu-item-with-icon","collapse-all",3,"click"],[1,"model-explorer-menu-item-with-icon","open-in-popup",3,"click"],[1,"model-explorer-menu-item-with-icon",3,"click"],[1,
"range-container"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",12,0);V("mouseleave",function(d){u(c);d=d.relatedTarget;null!=d&&d.classList.contains("cdk-overlay-backdrop")||(b.Ae="",rN(b),HN(b),b.render());return x()});R(2,"canvas",13,1);V("mousedown",function(d){u(c);return x(KN(b,d))})("contextmenu",function(d){u(c);return x(d.preventDefault())});S();Kq(4,"canvas",14,2)(6,"canvas",15,3);R(8,"div",16);V("mouseenter",function(){u(c);UF(b.Xv);return x()})("mouseleave",function(){u(c);SF(b.Xv);
return x()})("mousedown",function(d){u(c);d.stopPropagation();b.pl.includes("_left")?(SL(b,b.eo),YL(b,b.fa.nodesById[b.eo])):b.pl.includes("_right")&&(b.rl=b.eo,PC(b.RC));return x()});S();Kq(9,"div",17,4)(11,"div",18,5);R(13,"mat-menu",null,6)(15,"div",19);V("click",function(){u(c);var d=b.rl;if(d=null!=d?d:b.Ae)SL(b,d),YL(b,b.fa.nodesById[d],!0,!0);return x()});R(16,"mat-icon");Z(17,"unfold_more_double");S();Z(18," Expand layer & all sub-layers ");S();yp(19,eN,4,0,"div",20)(20,fN,4,0,"div",21);S();
R(21,"div",22,7);V("mousedown",function(d){u(c);d.stopPropagation();d=b.ql.split("||||")[0];b.ql.endsWith("input")?1===b.De[d].length?ML(b,b.De[d][0].id,b.rendererId):jM(b,b.nw.P,b.De[d],"incoming"):1===b.jf[d].length?ML(b,b.jf[d][0].id,b.rendererId):jM(b,b.nw.P,b.jf[d],"outgoing");return x()})("mouseenter",function(){u(c);UF(b.ow);return x()})("mouseleave",function(){u(c);SF(b.ow);return x()});S();Kq(23,"div",23,8);R(25,"div",24,9);V("mousedown",function(d){u(c);return x(d.stopPropagation())})("click",
function(){u(c);if(b.Nn){var d=b.fa.nodesById[b.Nn];fI(d)&&(d=d.subgraphIds,1===d.length?iN(b,d[0]):1<d.length&&(b.vv=d,PC(b.tE)))}return x()});S();Kq(27,"div",25,10);R(29,"mat-menu",null,11);Hq(31,hN,4,1,"div",26,Fq);S();yp(33,jN,1,8,"div",27);Kq(34,"div",28);yp(35,kN,2,1,"div",29);S()}if(a&2){a=wr(14);const c=wr(30);D(8);jq("top",b.Ob.top,"px")("left",b.Ob.left,"px")("width",b.Ob.width,"px")("height",b.Ob.height,"px");D();jq("top",b.Ob.top,"px")("left",b.Ob.left,"px")("width",b.Ob.width,"px")("height",
b.Ob.height,"px");H("matTooltip",b.Ob.Md||"")("matTooltipShowDelay",200)("matTooltipDisabled",null==b.Ob.Md);D(2);jq("top",b.Ob.top+b.Ob.height,"px")("left",b.Ob.left,"px");H("matMenuTriggerFor",a);D(8);H("ngIf",LN(b,b.rl));D();H("ngIf",b.dE);D();jq("top",b.Rn,"px")("left",b.Qn,"px")("width",b.dr,"px")("height",b.br,"px");D(2);jq("top",b.Rn,"px")("left",b.Qn,"px")("width",b.dr,"px")("height",b.br,"px");H("matTooltip",b.cr);D(2);jq("top",b.Go,"px")("left",b.Fo,"px")("width",b.gy,"px")("height",b.As,
"px");D(2);jq("top",b.Go+b.As,"px")("left",b.Fo,"px");H("matMenuTriggerFor",c);D(4);Jq(b.vv);D(2);H("ngIf",0<=b.mf);D();lq("flashing",b.Fq);D();Cq(b.yc?35:-1)}},Ga:[et,$s,TC,vC,JC,RC,aI,$H,ZF,YF],styles:[".container[_ngcontent-%COMP%]{width:100%;height:100%;overflow:hidden;position:relative}.container[_ngcontent-%COMP%]   canvas.main[_ngcontent-%COMP%]{width:100%!important;height:100%!important;-moz-box-sizing:border-box;box-sizing:border-box}.container[_ngcontent-%COMP%]   canvas.download-png[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   canvas.snapshot[_ngcontent-%COMP%]{position:absolute;left:0;bottom:0;width:400px;height:300px;border:1px solid red;-moz-box-sizing:border-box;box-sizing:border-box;background-color:#fff;display:none}.container[_ngcontent-%COMP%]   .hover-toolbar[_ngcontent-%COMP%]{position:absolute;width:50px;height:40px;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-transition:opacity .15s;transition:opacity .15s;opacity:1;pointer-events:none}.container[_ngcontent-%COMP%]   .hover-toolbar.hide[_ngcontent-%COMP%]{-webkit-transition:none;transition:none;opacity:0}.container[_ngcontent-%COMP%]   .hover-toolbar[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]{width:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .hover-toolbar[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .main-content-wrapper[_ngcontent-%COMP%]{height:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;pointer-events:all}.container[_ngcontent-%COMP%]   .hover-toolbar[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .main-content[_ngcontent-%COMP%]{font-size:12px;border:1px solid #ccc;background-color:hsla(0,0%,98%,.9);border-radius:99px;padding:0 8px;-moz-box-sizing:border-box;box-sizing:border-box;box-shadow:0 1px 3px 0 rgba(0,0,0,.1),0 1px 2px -1px rgba(0,0,0,.1);display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .hover-toolbar[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .main-content[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;cursor:pointer;opacity:.8;width:24px;padding:4px 0}.container[_ngcontent-%COMP%]   .hover-toolbar[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .main-content[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:1;background-color:#eee}.container[_ngcontent-%COMP%]   .hover-toolbar[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .main-content[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;font-weight:700;width:16px;height:16px;line-height:16px;color:#ea8600}.container[_ngcontent-%COMP%]   .group-node-icon[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .io-picker[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .subgraph-indicator[_ngcontent-%COMP%]{position:absolute;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;background-color:transparent}.container[_ngcontent-%COMP%]   .group-node-icon[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .io-picker[_ngcontent-%COMP%]{z-index:100}.container[_ngcontent-%COMP%]   .group-node-icon-tooltip[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .io-picker-tooltip[_ngcontent-%COMP%]{position:absolute;z-index:50}.container[_ngcontent-%COMP%]   .more-actions-menu-trigger[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .subgraph-indicator-menu-trigger[_ngcontent-%COMP%]{position:absolute;visibility:hidden}.container[_ngcontent-%COMP%]   .range-container[_ngcontent-%COMP%]{position:absolute;z-index:5000;-moz-box-sizing:border-box;box-sizing:border-box;border:1px solid #1976d2;background-color:rgba(97,175,252,.2);pointer-events:none}.container[_ngcontent-%COMP%]   .flash[_ngcontent-%COMP%]{position:absolute;top:0;left:0;width:100%;height:100%;z-index:5000;-moz-box-sizing:border-box;box-sizing:border-box;border:5px solid #1976d2;pointer-events:none;opacity:0}@-webkit-keyframes _ngcontent-%COMP%_flashing{5%{opacity:1}to{opacity:0}}@keyframes _ngcontent-%COMP%_flashing{5%{opacity:1}to{opacity:0}}.container[_ngcontent-%COMP%]   .flashing[_ngcontent-%COMP%]{-webkit-animation:_ngcontent-%COMP%_flashing .3s ease-out;animation:_ngcontent-%COMP%_flashing .3s ease-out}.container[_ngcontent-%COMP%]   .fps[_ngcontent-%COMP%]{position:absolute;top:12px;left:12px;z-index:100;font-size:32px;border:1px solid #777;padding:8px;border-radius:4px;background-color:#fff}  .multiline-tooltip{white-space:pre-line}  .multiline-tooltip-left{white-space:pre-line}  .multiline-tooltip-left>div{text-align:left}  .model-explorer-menu-item-with-icon{font-family:Google Sans Text,Arial,Helvetica,sans-serif;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;font-size:12px;padding:5px 8px;line-height:15px;letter-spacing:normal}  .model-explorer-menu-item-with-icon mat-icon{font-size:16px;width:16px;height:16px;margin-right:4px;color:#999}  .model-explorer-menu-item-with-icon:hover{background-color:rgba(0,0,0,.04)}"],
Qa:0});function SN(a){if(a&1){const b=Tg();R(0,"button",10);V("click",function(){u(b);const c=Y(2);return x(TN(c))});Z(1," Start ");S()}}function UN(a){a&1&&(R(0,"div",9),Z(1,"Generating graph. Please wait..."),S())}
function VN(a){a&1&&(R(0,"div",2)(1,"div",4)(2,"div",5),Z(3,"Node count"),S(),Kq(4,"input",6),S(),R(5,"div",4)(6,"div",5),Z(7,"Edge count"),S(),Kq(8,"input",6),S(),R(9,"div",4)(10,"div",5),Z(11,"Colorize"),S(),Kq(12,"input",7),S(),yp(13,SN,2,0,"button",8)(14,UN,2,0,"div",9),S());a&2&&(a=Y(),D(4),H("formControl",a.ov),D(4),H("formControl",a.mv),D(4),H("formControl",a.lv),D(),Cq(a.Uv?14:13))}function WN(a){a&1&&Kq(0,"webgl-renderer",3);a&2&&(a=Y(),H("modelGraph",a.modelGraph)("benchmark",!0))}
function TN(a){a.Uv=!0;$m(a.i);setTimeout(()=>{const b=a.ov.value,c=a.mv.value;var d=Math.max(500,Math.floor(300*Math.sqrt(b)));const e=[];for(var f=0;f<b;f++){var g=`n${f}`;g={nodeType:0,id:g,label:g,namespace:"",level:0,x:Math.random()*d,y:Math.random()*d,globalX:0,globalY:0,width:150+60*(Math.random()-.5),height:50+30*(Math.random()-.5)};a.lv.value&&(g.style={backgroundColor:`rgb(${Math.floor(255*Math.random())}, ${Math.floor(255*Math.random())}, ${Math.floor(255*Math.random())})`});e.push(g)}d=
{};for(var k of e)d[k.id]=k;k={"":[]};for(f=0;f<c;f++){g=`n${Math.floor(Math.random()*b)}`;const v=`n${Math.floor(Math.random()*b)}`;var m=d[g],p=d[v];const B=`${g}_${v}`;var t=m.x+m.width/2;m=m.y+m.height/2;const G=p.x+p.width/2;p=p.y+p.height/2;t=[{x:t,y:m},{x:(t+G)/2+100*(Math.random()-.5),y:(m+p)/2+100*(Math.random()-.5)},{x:G,y:p}];p=nI(t);k[""].push({id:B,fromNodeId:g,toNodeId:v,points:t,curvePoints:p})}a.modelGraph={id:"benchmark_graph",collectionLabel:"benchmark_collection",nodes:e,nodesById:d,
rootNodes:e,edgesByGroupNodeIds:k,maxDescendantOpNodeCount:0,minDescendantOpNodeCount:0,layoutGraphEdges:{}};$m(a.i)},100)}var XN=class{constructor(a){this.i=a;this.ov=new px(1E4);this.mv=new px(5E3);this.lv=new px(!1);this.Uv=!1}};XN.J=function(a){return new (a||XN)(y(Pr))};
XN.Ca=Gf({type:XN,ga:[["benchmark-runner"]],ja:!0,features:[Jr],ya:6,za:1,Ba:[[1,"container"],[1,"title"],[1,"form"],["rendererId","benchmark","paneId","benchmark",3,"modelGraph","benchmark"],[1,"row"],[1,"label"],["type","text",3,"formControl"],["type","checkbox",3,"formControl"],["mat-flat-button","","color","primary"],[1,"gen-msg"],["mat-flat-button","","color","primary",3,"click"]],sa:function(a,b){a&1&&(R(0,"div",0)(1,"div",1),Kq(2,"me-logo"),Z(3," Model Explorer Benchmark Test "),S(),yp(4,VN,
15,4,"div",2)(5,WN,1,2,"webgl-renderer",3),S());a&2&&(D(4),Cq(b.modelGraph?5:4))},Ga:[et,uB,tB,oB,OJ,wx,mw,kw,Gw,rx,RN],styles:[".container[_ngcontent-%COMP%]{width:100%;height:100%;overflow:hidden;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;position:relative}.container[_ngcontent-%COMP%]   .form[_ngcontent-%COMP%]{margin:12px}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]{font-weight:400;cursor:pointer;color:#444746;font-size:20px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;padding:8px;padding-left:12px;border-bottom:1px solid #ddd}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   me-logo[_ngcontent-%COMP%]{margin-right:6px}.container[_ngcontent-%COMP%]   .row[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;margin-top:12px}.container[_ngcontent-%COMP%]   .row[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{font-size:12px;color:#777}.container[_ngcontent-%COMP%]   .row[_ngcontent-%COMP%]   input[type=text][_ngcontent-%COMP%]{width:200px;font-size:13px}.container[_ngcontent-%COMP%]   .row[_ngcontent-%COMP%]   input[type=checkbox][_ngcontent-%COMP%]{width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}.container[_ngcontent-%COMP%]   .row[_ngcontent-%COMP%]:first-child{margin-top:0}.container[_ngcontent-%COMP%]   button[_ngcontent-%COMP%]{margin-top:12px}.container[_ngcontent-%COMP%]   .gen-msg[_ngcontent-%COMP%]{font-size:12px;margin-top:12px}.container[_ngcontent-%COMP%]   webgl-renderer[_ngcontent-%COMP%]{position:absolute;top:48px;bottom:0;width:100%}"],
Qa:0});var YN=class{constructor(){this.extensions={}}};YN.J=function(a){return new (a||YN)};YN.oa=Ld({la:YN,aa:YN.J});function ZN(a){a&1&&(R(0,"tr")(1,"td"),Kq(2,"div",9),S(),R(3,"td")(4,"div",2),Z(5,"Artificial layer to reduce layout load"),S()()())}function $N(a){a&1&&(R(0,"tr")(1,"td"),Kq(2,"div",10),S(),R(3,"td")(4,"div",2),Z(5),S()()());a&2&&(a=Y(),D(2),lq("group",a.vl),D(3),yr(" Selected ",a.vl?"layer":"op"," "))}function aO(a){a&1&&(R(0,"tr")(1,"td"),Kq(2,"div",11),S(),R(3,"td")(4,"div",2),Z(5,"Identical layer (if any)"),S()()())}
function bO(a){a&1&&(Lq(0),R(1,"tr")(2,"td"),Kq(3,"div",12),S(),R(4,"td")(5,"div",2),Z(6,"Inputs (if any)"),S()()(),R(7,"tr")(8,"td"),Kq(9,"div",13),S(),R(10,"td")(11,"div",2),Z(12,"Outputs (if any)"),S()()(),Mq())}var cO=class{constructor(a,b){this.i=a;this.C=b;this.Gn=this.vl=this.Zl=!1;Gs(()=>{var c=fJ(this.i,this.paneId);c&&(this.Gn=!0===c.Gn,(c=c.Qg)?(this.Zl=""!==c.nodeId,this.vl=c.zd):this.Zl=!1,Zm(this.C))})}};cO.J=function(a){return new (a||cO)(y(NJ),y(Pr))};
cO.Ca=Gf({type:cO,ga:[["legends-panel"]],inputs:{paneId:"paneId"},ja:!0,features:[Jr],ya:35,za:4,Ba:[[1,"container"],[1,"key","op-node-key"],[1,"label"],[1,"key","group-node-key"],[4,"ngIf"],["colspan","2"],[1,"divider"],[1,"key","shortcut"],[1,"label","shortcut"],[1,"key","artificial-layer-key"],[1,"key","selected-node-key"],[1,"key","identical-group-key"],[1,"key","input-key"],[1,"key","output-key"]],sa:function(a,b){a&1&&(R(0,"div",0)(1,"table")(2,"tr")(3,"td"),Kq(4,"div",1),S(),R(5,"td")(6,"div",
2),Z(7,"Op"),S()()(),R(8,"tr")(9,"td"),Kq(10,"div",3),S(),R(11,"td")(12,"div",2),Z(13,"Layer"),S()()(),yp(14,ZN,6,0,"tr",4)(15,$N,6,3,"tr",4)(16,aO,6,0,"tr",4)(17,bO,13,0,"ng-container",4),R(18,"tr")(19,"td",5),Kq(20,"div",6),S()(),R(21,"tr")(22,"td")(23,"div",7),Z(24,"Zoom"),S()(),R(25,"td")(26,"div",8),Z(27,"Ctrl+Scroll"),S()()(),R(28,"tr")(29,"td")(30,"div",7),Z(31,"Pan"),S()(),R(32,"td")(33,"div",8),Z(34,"Drag or scroll"),S()()()()());a&2&&(D(14),H("ngIf",b.Gn),D(),H("ngIf",b.Zl),D(),H("ngIf",
b.Zl&&b.vl),D(),H("ngIf",b.Zl&&!b.vl))},Ga:[et,$s,aI],styles:[".container[_ngcontent-%COMP%]{height:-webkit-fit-content;height:-moz-fit-content;height:fit-content;background-color:hsla(0,0%,100%,.9);padding:8px}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]{border-spacing:0;border-collapse:collapse;padding:0;font-size:11px}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .key[_ngcontent-%COMP%]{margin-right:4px;-moz-box-sizing:border-box;box-sizing:border-box}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .op-node-key[_ngcontent-%COMP%]{width:30px;height:14px;border-radius:5px;border:1px solid #666;background-color:#fff}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .group-node-key[_ngcontent-%COMP%]{width:30px;height:14px;border:1px solid #777;border-radius:5px;background-color:#eaeaf2}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .artificial-layer-key[_ngcontent-%COMP%]{border:1px solid purple;width:30px;height:14px;background-color:#f1f1f1}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .selected-node-key[_ngcontent-%COMP%]{width:30px;height:14px;border:2px solid #1a73e8;border-radius:5px;background-color:#c2e7ff}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .identical-group-key[_ngcontent-%COMP%]{width:30px;height:14px;border:1px solid #777;background-color:#e2edff}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .input-key[_ngcontent-%COMP%]{width:30px;height:14px;border-radius:5px;border:2px solid #009e73}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .output-key[_ngcontent-%COMP%]{width:30px;height:14px;border-radius:5px;border:2px solid #d55e00}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .shortcut[_ngcontent-%COMP%]{color:#777;font-size:10px;line-height:10px}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .divider[_ngcontent-%COMP%]{height:1px;border-top:1px solid #ccc;margin:8px 0 4px}"],
Qa:0});function dO(a,b){const c=b.clientX,d=b.clientY,e=b.offsetX,f=Number(a.i.style.top.replace("px","")),g=Number(a.i.style.left.replace("px","")),k=Number(a.i.style.width.replace("px","")),m=Number(a.i.style.height.replace("px","")),p=jk(document,"mousemove"),t=jk(window,"mouseup"),v=b.target.dataset.position,B=a.i.parentElement.offsetHeight,G=a.i.parentElement.offsetWidth;C(Nj([p]),Jo(t)).subscribe({next:([K])=>{K.preventDefault();var N=K.clientX-c;K=K.clientY-d;if(0!==N||0!==K)null==v?(a.i.style.top=
`${Math.min(B-28,Math.max(f+K,0))}px`,a.i.style.left=`${Math.min(G-e,Math.max(-e,g+N))}px`):(v.includes("right")&&(a.i.style.width=`${Math.max(48,k+N)}px`),v.includes("bottom")&&(a.i.style.height=`${Math.max(48,m+K)}px`),v.includes("left")&&(N=Math.max(48,k-N),a.i.style.width=`${N}px`,a.i.style.left=`${g+(k-N)}px`),v.includes("top")&&(N=Math.max(48,m-K),a.i.style.height=`${N}px`,a.i.style.top=`${f+(m-N)}px`))},complete:()=>{}})}var eO=class{constructor(a){this.i=a}};var fO=class{constructor(a){this.i=a;this.vb=new Dk;this.Cd=0}reset(){this.Cd=0;Zm(this.i)}get AB(){return 0===this.Cd}get zB(){return this.Cd===Math.ceil(this.Tn/this.Ge)-1}get rB(){const a=Math.min(this.Tn,this.Cd*this.Ge+1),b=Math.min((this.Cd+1)*this.Ge,this.Tn);return a===b?`${a}`:`${a} - ${b}`}};fO.J=function(a){return new (a||fO)(y(Pr))};
fO.Ca=Gf({type:fO,ga:[["paginator"]],inputs:{Ge:"pageSize",Tn:"itemsCount"},outputs:{vb:"change"},ja:!0,features:[Jr],ya:9,za:5,Ba:[[1,"container"],[1,"icon-container","prev-page",3,"click"],[1,"range-text"],[1,"icon-container","next-page",3,"click"]],sa:function(a,b){a&1&&(R(0,"div",0)(1,"div",1),V("click",function(){b.Cd--;b.Cd=Math.max(0,b.Cd);b.vb.emit(b.Cd)}),R(2,"mat-icon"),Z(3,"chevron_left"),S()(),R(4,"div",2),Z(5),S(),R(6,"div",3),V("click",function(){b.Cd++;b.Cd=Math.min(Math.ceil(b.Tn/
b.Ge)-1,b.Cd);b.vb.emit(b.Cd)}),R(7,"mat-icon"),Z(8,"chevron_right"),S()()());a&2&&(D(),lq("disabled",b.AB),D(4),yr(" ",b.rB," "),D(),lq("disabled",b.zB))},Ga:[et,aI,$H,zG],styles:[".container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;width:24px;height:24px;border-radius:99px;cursor:pointer}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{background-color:#ddd}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover   mat-icon[_ngcontent-%COMP%]{opacity:1}.container[_ngcontent-%COMP%]   .icon-container.disabled[_ngcontent-%COMP%]{pointer-events:none;opacity:.3}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{opacity:.7;color:#333;font-size:20px;width:20px;height:20px}.container[_ngcontent-%COMP%]   .range-text[_ngcontent-%COMP%]{color:#333;font-size:12px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}"],
Qa:0});const gO=["searchInput"],hO=["content"];function iO(a){if(a&1){const b=Tg();R(0,"div",11);V("click",function(){u(b);const c=Y();c.Ch.setValue("");jO(c,"");return x()});R(1,"mat-icon",12);Z(2,"close");S()()}}function kO(a){if(a&1){const b=Tg();R(0,"paginator",25);V("change",function(c){u(b);const d=Y(2);d.bh=c;lO(d);return x()});S()}a&2&&(a=Y(2),H("pageSize",a.Ge)("itemsCount",a.gs))}
function mO(a,b){if(a&1){const c=Tg();R(0,"div",26);V("click",function(){const d=u(c).ca,e=Y(2);return x(nO(e,d))});R(1,"div",27)(2,"mat-icon");Z(3);S()();R(4,"div",28);Z(5);S()()}a&2&&(a=b.ca,lq("selected",a.selected),D(3),xr(a.Cl),D(2),yr(" ",a.label," "))}function oO(a){a&1&&Kq(0,"io-tree",22);a&2&&(a=Y(2),H("data",a.sv)("rendererId",a.rendererId)("tooltipPosition","right")("showLocator",!1))}function pO(a){a&1&&(R(0,"div",23),Z(1," No matching results "),S())}
function qO(a){a&1&&(R(0,"div",13)(1,"div",14)(2,"div",15)(3,"div",16),Z(4),S(),yp(5,kO,1,2,"paginator",17),S(),R(6,"div",18)(7,"div",19),Hq(8,mO,6,4,"div",20,Fq),S()()(),R(10,"div",21,2),yp(12,oO,1,4,"io-tree",22)(13,pO,2,0,"div",23),S(),R(14,"div",24)(15,"mat-icon"),Z(16,"tips_and_updates"),S(),Z(17," Click to locate node. Alt+Click to locate and select node. "),S()());a&2&&(a=Y(),jq("max-height",a.QD,"px"),D(4),yr(" ",a.RD," "),D(),Cq(a.fE?5:-1),D(3),Jq(a.ms),D(4),Cq(0<a.gs?12:13))}
function rO(a){a&1&&(R(0,"div",29),Z(1," No matching results "),S())}
function sO(a){a&1&&(R(0,"div",30),Z(1," Use regex to match nodes by label, attributes, input/output node label, and input/output metadata. "),Kq(2,"br")(3,"br"),Z(4," For attributes and I/O metadata, regex will try to match "),R(5,"span",31),Z(6),S(),Z(7," or "),R(8,"span",31),Z(9),S(),Z(10,". "),Kq(11,"br")(12,"br"),Z(13," Examples:"),Kq(14,"br"),R(15,"ul")(16,"li")(17,"span",32),Z(18,"axis:"),S(),Z(19," will match attributes whose key is "),R(20,"span",31),Z(21,"axis"),S(),Z(22,". "),S(),R(23,
"li")(24,"span",32),Z(25,"padding=[SAME|VALID]"),S(),Z(26," will match attributes whose key is "),R(27,"span",31),Z(28,"padding"),S(),Z(29," and value is either "),R(30,"span",31),Z(31,"SAME"),S(),Z(32," or "),R(33,"span",31),Z(34,"VALID"),S(),Z(35,". "),S()()());a&2&&(D(6),Ar("","{","key","}",":","{","value","}",""),D(3),Ar("","{","key","}","=","{","value","}",""))}function nO(a,b){b.selected=!b.selected;Zm(a.G);jO(a,a.Ch.value||"");setTimeout(()=>{a.content.P.scrollTop=0})}
function jO(a,b){if(b){var c=[],d=[],e={results:{}},f=new Set(a.ms.filter(g=>g.selected).map(g=>g.Cl));try{const g=new RegExp(b,"i");for(const k of a.fa.nodes){if(fI(k)&&k.hideInLayout)continue;const {matches:m,matchTypes:p}=BI(f,g,k,a.fa);0<m.length&&(c.push(k),d.push({matches:m,matchTypes:p}),e.results[k.id]=m)}EJ(a.C,a.rendererId,e)}catch(g){console.warn("Failed to search",g)}a.bh=0;a.i=[...c];a.K=d;lO(a);a.D=!1;Zm(a.G)}else a.bh=0,a.sv=void 0,a.i=[],Zm(a.G),a.D=!1,FJ(a.C,a.rendererId)}
function lO(a){a.sv=SK(a.i.slice(a.bh*a.Ge,(a.bh+1)*a.Ge),"incoming",void 0,a.K.slice(a.bh*a.Ge,(a.bh+1)*a.Ge))}
var tO=class{constructor(a,b,c){this.C=a;this.G=b;this.F=c;this.Ch=new px("");this.ms=[{Cl:"title",label:"Label",selected:!0},{Cl:"list",label:"Attrs",selected:!0},{Cl:"input",label:"Inputs",selected:!0},{Cl:"output",label:"Outputs",selected:!0}];this.Ge=this.C.i?12:50;this.i=[];this.K=[];this.D=!1;this.bh=0;C(this.Ch.ah,No(()=>{this.D=!0;Zm(this.G)}),Mn(300),kL(this.F)).subscribe(d=>{jO(this,((null==d?void 0:d.toLowerCase())||"").trim())});C(this.C.va,kL(this.F)).subscribe(()=>{let d;this.rendererId===
(null==(d=this.C.D())?void 0:d.id)&&this.PD.P.focus()})}get RD(){let a;const b=(null==(a=this.i)?void 0:a.length)||0;return`${b} result${1===b?"":"s"}`}get VD(){return""!==(this.Ch.value||"").trim()}get gE(){return!this.D&&""!==(this.Ch.value||"").trim()&&!this.Lx}get Lx(){return!this.D&&""!==(this.Ch.value||"").trim()&&0===this.i.length&&this.ms.every(a=>a.selected)}get gs(){return this.i.length}get QD(){return document.body.offsetHeight-300}get fE(){return this.gs>this.Ge}};
tO.J=function(a){return new (a||tO)(y(NJ),y(Pr),y(wi))};
tO.Ca=Gf({type:tO,ga:[["search-bar"]],eb:function(a,b){a&1&&(rr(gO,5),rr(hO,5));if(a&2){let c;sr(c=tr())&&(b.PD=c.first);sr(c=tr())&&(b.content=c.first)}},inputs:{fa:"curModelGraph",rendererId:"rendererId"},ja:!0,features:[Jr],ya:14,za:6,Ba:[["searchInput",""],["helpPopup",""],["content",""],[1,"container"],[1,"input-container"],[1,"search"],["placeholder","Search nodes/layers by regex",3,"formControl"],["class","btn-clear-container",3,"click",4,"ngIf"],["dialogLabel","help popup",1,"icon-container",
3,"xapInlineDialog","hoverDelayMs"],["class","search-results-container",3,"max-height",4,"ngIf"],["class","no-matches",4,"ngIf"],[1,"btn-clear-container",3,"click"],[1,"clear"],[1,"search-results-container"],[1,"title-container"],[1,"title"],[1,"title-label"],[3,"pageSize","itemsCount"],[1,"search-result-type-selector-container"],[1,"options-container"],[1,"option-container",3,"selected"],[1,"content"],[3,"data","rendererId","tooltipPosition","showLocator"],[1,"empty-results"],[1,"footer"],[3,"change",
"pageSize","itemsCount"],[1,"option-container",3,"click"],[1,"icon-container"],[1,"option-label"],[1,"no-matches"],[1,"model-explorer-search-help-popup"],[1,"code"],[1,"code","regex"]],sa:function(a,b){a&1&&(R(0,"div",3)(1,"div",4)(2,"mat-icon",5),Z(3,"search"),S(),Kq(4,"input",6,0),yp(6,iO,3,0,"div",7),R(7,"div",8)(8,"mat-icon"),Z(9,"help_outline"),S()()(),yp(10,qO,18,5,"div",9)(11,rO,2,0,"div",10),S(),yp(12,sO,36,8,"ng-template",null,1,Nr));a&2&&(a=wr(13),D(4),H("formControl",b.Ch),D(2),H("ngIf",
b.VD),D(),H("xapInlineDialog",a)("hoverDelayMs",100),D(3),H("ngIf",b.gE),D(),H("ngIf",b.Lx))},Ga:[et,$s,RK,HB,KD,aI,$H,fO,wx,mw,Gw,rx,zG,wG],styles:[".container[_ngcontent-%COMP%]{position:relative;overflow:visible;background-color:#fff;border-radius:99px;height:30px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;padding:0 8px}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;width:250px}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   mat-icon.clear[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   mat-icon.search[_ngcontent-%COMP%]{font-size:20px;width:20px;height:20px}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   mat-icon.clear[_ngcontent-%COMP%]{opacity:.6;cursor:pointer}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   mat-icon.clear[_ngcontent-%COMP%]:hover{opacity:.9}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]{height:24px;border:none;outline:none;-moz-box-sizing:border-box;box-sizing:border-box;padding:0 4px;font-size:12px;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   .btn-clear-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;cursor:pointer;color:#999;opacity:.8}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:1}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:20px;width:20px;height:20px}.container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]:has(input:focus)   mat-icon.search[_ngcontent-%COMP%]{color:#1a73e8}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]{overflow:hidden;position:absolute;top:calc(100% + 12px);left:-4px;border:1px solid #ccc;border-radius:4px;width:380px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;background-color:#fff;box-shadow:0 4px 6px -1px rgba(0,0,0,.1),0 2px 4px -2px rgba(0,0,0,.1)}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .title-container[_ngcontent-%COMP%]{background-color:#f6f6f6;border-bottom:1px solid #ddd;-moz-box-sizing:border-box;box-sizing:border-box;padding:0 10px 10px}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]{height:28px;min-height:28px;font-size:12px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .title-label[_ngcontent-%COMP%]{white-space:nowrap}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;min-height:0;overflow-y:auto;padding-bottom:6px}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .empty-results[_ngcontent-%COMP%]{padding:12px 8px 6px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;font-size:12px;color:#ccc}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .search-result-type-selector-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;font-size:12px;margin-top:2px}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .search-result-type-selector-container[_ngcontent-%COMP%]   .options-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;gap:6px}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .search-result-type-selector-container[_ngcontent-%COMP%]   .option-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;border:1px solid #ccc;padding:4px 14px;border-radius:6px;background-color:#fff;color:#474747}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .search-result-type-selector-container[_ngcontent-%COMP%]   .option-container.selected[_ngcontent-%COMP%]{border-color:#a3c9ff;background-color:#a3c9ff;color:#001d35}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .search-result-type-selector-container[_ngcontent-%COMP%]   .option-container.selected[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{color:#001d35}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .search-result-type-selector-container[_ngcontent-%COMP%]   .option-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{width:18px;height:18px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;-moz-box-sizing:border-box;box-sizing:border-box;margin-right:4px}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .search-result-type-selector-container[_ngcontent-%COMP%]   .option-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;width:16px;height:16px;color:#474747}.container[_ngcontent-%COMP%]   .search-results-container[_ngcontent-%COMP%]   .search-result-type-selector-container[_ngcontent-%COMP%]   .option-container[_ngcontent-%COMP%]   .option-label[_ngcontent-%COMP%]{font-size:12px;font-family:Google Sans Text,Arial,Helvetica,sans-serif;letter-spacing:normal}.container[_ngcontent-%COMP%]   .footer[_ngcontent-%COMP%]{height:32px;min-height:32px;background-color:#f6f6f6;border-top:1px solid #ddd;-moz-box-sizing:border-box;box-sizing:border-box;padding:0 10px;font-size:12px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;color:#777}.container[_ngcontent-%COMP%]   .footer[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;height:16px;width:16px;color:#777;margin-right:4px}.container[_ngcontent-%COMP%]   .no-matches[_ngcontent-%COMP%]{position:absolute;top:calc(100% + 12px);left:-4px;color:#999;padding:8px;border:1px solid #ccc;border-radius:4px;background-color:#fff;font-size:12px;box-shadow:0 4px 6px -1px rgba(0,0,0,.1),0 2px 4px -2px rgba(0,0,0,.1)}  .model-explorer-search-help-popup{padding:12px;font-size:12px;background-color:#fff}  .model-explorer-search-help-popup ul{-webkit-margin-after:0;margin-block-end:0}  .model-explorer-search-help-popup .code{display:inline-block;background-color:#fffdd0;font-family:monospace}  .model-explorer-search-help-popup .code.regex{background-color:#e6d0ff}"],
Qa:0});const uO=["dialog"],vO=["trigger"];function wO(a){a&1&&Z(0," Maximum state count reached ")}function xO(a){a&1&&Z(0," Save the current graph state ")}function yO(a){a&1&&(R(0,"div",7),yp(1,wO,1,0)(2,xO,1,0),R(3,"div",8),Z(4," The saved state can be restored by clicking the corresponding state number. You can save up to 9 states. "),S()());a&2&&(a=Y(),D(),Cq(a.tq?1:2))}
function zO(a){if(a&1){const c=Tg();R(0,"div",12)(1,"div",13)(2,"div");Z(3);S();R(4,"div",14);V("click",function(){u(c);const d=Y().index,e=Y(2);e.fa&&AJ(e.ak,d,e.fa.id,e.paneId);return x()});R(5,"mat-icon");Z(6,"delete");S();Z(7," Delete ");S()();Kq(8,"canvas");S()}if(a&2){var b=Y();a=b.ca;b=b.index;Y(2);D(3);yr("Shortcut key: ",b+1,"");D(5);jq("width",AO(a,!0),"px")("height",BO(a,!0),"px")}}
function CO(a,b){if(a&1){const c=Tg();R(0,"div",11,1);V("opened",function(){const d=u(c).ca;Y(2);const e=document.querySelector(".model-explorer-snapshot-popup canvas"),f=AO(d),g=BO(d);e.width=f;e.height=g;const k=e.getContext("2d");k.imageSmoothingQuality="high";k.drawImage(d.Uq,0,0,f,g);e.classList.add("show");return x()})("click",function(){const d=u(c).index,e=Y(2);return x(DO(e,d))});Z(3);yp(4,zO,9,5,"ng-template",null,2,Nr);S()}if(a&2){a=b.index;b=wr(5);const c=Y(2);H("xapInlineDialog",b)("overlaySize",
c.nE)("overlayPositions",c.mE)("hoverDelayMs",150);D(3);yr(" ",a+1," ")}}function EO(a){a&1&&(R(0,"div",9),yp(1,CO,6,5,"div",10),S());a&2&&(a=Y(),D(),H("ngForOf",a.bj)("ngForTrackBy",a.EE))}const FO=new Set("123456789".split(""));function AO(a,b=!1){return a.Uq.width/(b?window.devicePixelRatio:1)}function BO(a,b=!1){return a.Uq.height/(b?window.devicePixelRatio:1)}function DO(a,b){const c=a.bj[b];let d;null==(d=a.Vx.get(b))||jG(d);a.ak.T.next({jb:c,rendererId:a.rendererId})}
var GO=class{constructor(a,b){this.ak=a;this.i=b;this.Vx=new Zq;this.Wx=new Zq;this.fd={minWidth:0,minHeight:0,maxWidth:340};this.nE={maxWidth:1E3,maxHeight:1E3};this.mE=[{bb:"start",cb:"bottom",La:"start",Sa:"top",offsetY:12}];this.bj=[];Gs(()=>{const c=fJ(this.ak,this.paneId);this.fa=null==c?void 0:c.modelGraph;null!=(null==c?void 0:c.modelGraph)&&(this.bj=((null==c?void 0:c.Rg)||{})[c.modelGraph.id]||[],Zm(this.i))})}Oq(a){let b;if(FO.has(a.key)&&(null==(b=this.ak.D())?void 0:b.id)===this.rendererId&&
!qI()&&(a=Number(a.key)-1,a<=this.bj.length-1)){DO(this,a);let c;const d=null==(c=this.Wx.get(a))?void 0:c.P;d&&(d.classList.add("clicked"),setTimeout(()=>{d.classList.remove("clicked")},50))}}EE(a,b){return b.id}get tq(){return 9<=this.bj.length}get cC(){return 0<this.bj.length}};GO.J=function(a){return new (a||GO)(y(NJ),y(Pr))};
GO.Ca=Gf({type:GO,ga:[["snapshot-manager"]],eb:function(a,b){a&1&&(rr(uO,5),rr(vO,5));if(a&2){let c;sr(c=tr())&&(b.Vx=c);sr(c=tr())&&(b.Wx=c)}},Ha:function(a,b){a&1&&V("keypress",function(c){return b.Oq(c)},!1,Ai)},inputs:{paneId:"paneId",rendererId:"rendererId"},ja:!0,features:[Jr],ya:7,za:6,Ba:[["help",""],["dialog","xapInlineDialog","trigger",""],["snapshotPopup",""],[1,"container"],["dialogLabel","help",1,"mat-icon-container","take-snapshot",3,"click","xapInlineDialog","overlaySize","hoverDelayMs"],
[1,"toolbar-icon"],["class","snapshots-container",4,"ngIf"],[1,"model-explorer-help-popup"],[1,"description"],[1,"snapshots-container"],["class","snapshot","dialogLabel","snapshot popup",3,"xapInlineDialog","overlaySize","overlayPositions","hoverDelayMs","opened","click",4,"ngFor","ngForOf","ngForTrackBy"],["dialogLabel","snapshot popup",1,"snapshot",3,"opened","click","xapInlineDialog","overlaySize","overlayPositions","hoverDelayMs"],[1,"model-explorer-snapshot-popup"],[1,"info-row"],[1,"icon-container",
"delete",3,"click"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",3)(1,"div",4);V("click",function(){u(c);b.tq||b.ak.ia.next({rendererId:b.rendererId});return x()});R(2,"mat-icon",5);Z(3,"bookmark_add");S()();yp(4,yO,5,1,"ng-template",null,0,Nr)(6,EO,2,2,"div",6);S()}a&2&&(a=wr(5),D(),lq("disabled",b.tq),H("xapInlineDialog",a)("overlaySize",b.fd)("hoverDelayMs",10),D(5),H("ngIf",b.cC))},Ga:[et,Ws,$s,$F,aI,$H,zG,wG],styles:[".container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;margin-right:3px}.container[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]{width:24px;height:24px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;cursor:pointer}.container[_ngcontent-%COMP%]   .mat-icon-container.disabled[_ngcontent-%COMP%]{cursor:default;opacity:.5}.container[_ngcontent-%COMP%]   .mat-icon-container.disabled[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]:hover{opacity:.6}.container[_ngcontent-%COMP%]   mat-icon.toolbar-icon[_ngcontent-%COMP%]{font-size:20px;width:20px;height:20px;opacity:.6}.container[_ngcontent-%COMP%]   mat-icon.toolbar-icon[_ngcontent-%COMP%]:hover{opacity:.9}.container[_ngcontent-%COMP%]   .snapshots-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;font-size:11px;margin-left:6px;margin-right:6px;gap:2px}.container[_ngcontent-%COMP%]   .snapshots-container[_ngcontent-%COMP%]   .snapshot[_ngcontent-%COMP%]{width:16px;height:16px;border-radius:8px;background-color:#7cacf8;color:#fff;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;font-weight:500;cursor:pointer}.container[_ngcontent-%COMP%]   .snapshots-container[_ngcontent-%COMP%]   .snapshot.clicked[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .snapshots-container[_ngcontent-%COMP%]   .snapshot[_ngcontent-%COMP%]:hover{background-color:#0b57d0;color:#fff}  .model-explorer-snapshot-popup{font-size:11px;line-height:12px;background-color:#fff}  .model-explorer-snapshot-popup .info-row{color:#333;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;background-color:#f6f6f6;padding:4px 8px;border-bottom:1px solid #ddd}  .model-explorer-snapshot-popup .info-row .icon-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;cursor:pointer;opacity:.8}  .model-explorer-snapshot-popup .info-row .icon-container:hover{opacity:1}  .model-explorer-snapshot-popup .info-row .icon-container mat-icon{font-size:18px;width:18px;height:19px}  .model-explorer-snapshot-popup canvas{opacity:0;-webkit-transition:opacity .2s ease-out;transition:opacity .2s ease-out}  .model-explorer-snapshot-popup canvas.show{opacity:1}"],
Qa:0});function HO(a){a&1&&(R(0,"mat-icon",2),Z(1,"chevron_right"),S())}
function IO(a,b){if(a&1){const c=Tg();R(0,"div",1);V("click",function(){var d=u(c).Bb;const e=Y();if(d!==e.Lf.length-1){DJ(e.ti,e.paneId,d);var f=e.Lf[d];if(d=f.jb){var g;let k;f.Ag===(null==(g=fJ(e.ti,e.paneId))?void 0:null==(k=g.modelGraph)?void 0:k.id)?e.ti.T.next({rendererId:e.paneId,jb:d}):(g=BJ(e.ti,f.Ag))&&iJ(e.ti,g,d.flattenLayers,d)}}return x()});Z(1);S();yp(2,HO,2,0,"mat-icon",2)}if(a&2){a=b.ca;b=b.Bb;const c=Y();lq("current",b===c.Lf.length-1);D();yr(" ",a.Ag," ");D();Cq(b!==c.Lf.length-
1?2:-1)}}var JO=class{constructor(a,b){this.ti=a;this.i=b;this.Lf=[];Gs(()=>{let c;const d=null==(c=fJ(this.ti,this.paneId))?void 0:c.Zf;d!==this.C&&(this.Lf=(this.C=d)||[],Zm(this.i))})}};JO.J=function(a){return new (a||JO)(y(NJ),y(Pr))};
JO.Ca=Gf({type:JO,ga:[["subgraph-breadcrumbs"]],inputs:{paneId:"paneId"},ja:!0,features:[Jr],ya:3,za:0,Ba:[[1,"container"],[1,"item",3,"click"],[1,"separator"]],sa:function(a,b){a&1&&(R(0,"div",0),Hq(1,IO,3,4,null,null,Fq),S());a&2&&(D(),Jq(b.Lf))},Ga:[et,aI,$H,ZF],styles:[".container[_ngcontent-%COMP%]{border:1px solid #3876c7;background-color:#d5e7ff;border-radius:4px;-moz-box-sizing:border-box;box-sizing:border-box;padding:4px 8px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;font-size:13px}.container[_ngcontent-%COMP%]   .item[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;color:#777}.container[_ngcontent-%COMP%]   .item[_ngcontent-%COMP%]:hover:not(.current){cursor:pointer;text-decoration:underline}.container[_ngcontent-%COMP%]   .item.current[_ngcontent-%COMP%]{color:#000}.container[_ngcontent-%COMP%]   .separator[_ngcontent-%COMP%]{color:#999;font-size:16px;width:16px;height:16px;margin:0 3px}"],
Qa:0});const KO=(a,b)=>b.type;function LO(a){a&1&&(R(0,"div",7),Z(1," Select data to view on nodes / edges "),S())}
function MO(a){if(a&1){const b=Tg();R(0,"div",14)(1,"input",15,3);V("keydown.enter",function(){u(b);const c=wr(2);return x(c.blur())})("input",function(){u(b);const c=wr(2),d=Y(3);return x(d.fn=c.value)})("change",function(){u(b);const c=Y().ca,d=Y(2);IJ(d.Me,d.paneId,d.rendererId,c.type,d.fn);NO(d);return x()});S();R(3,"div",16)(4,"mat-icon");Z(5,"help_outline");S()();R(6,"div",17);V("click",function(){u(b);const c=wr(2);return x(c.blur())});R(7,"mat-icon");Z(8,"done");S()()()}if(a&2){a=Y().ca;const b=
Y(2),c=wr(9);D();H("disabled",!a.selected)("value",b.fn);D(2);H("xapInlineDialog",c)("hoverDelayMs",100)}}function OO(a,b){if(a&1){const c=Tg();R(0,"div",12);V("click",function(){const d=u(c).ca,e=Y(2);GJ(e.Me,e.paneId,e.rendererId,d.type);NO(e);return x()});Kq(1,"input",13);Z(2);S();yp(3,MO,9,4,"div",14)}a&2&&(a=b.ca,Y(2),D(),H("checked",a.selected),D(),yr(" ",a.type," "),D(),Cq("Op node attributes"===a.type?3:-1))}
function PO(a,b){if(a&1){const c=Tg();R(0,"div",12);V("click",function(){var d=u(c).ca;const e=Y(2);HJ(e.Me,e.paneId,e.rendererId,d.type);e.Pb||e.Me.i||(d=MJ(e.Me,e.paneId,e.rendererId),HI("model_explorer_show_on_edge_item_types_v2",JSON.stringify(d)));return x()});Kq(1,"input",13);Z(2);S()}a&2&&(a=b.ca,D(),H("checked",a.selected),D(),yr(" ",a.type," "))}
function QO(a){a&1&&(R(0,"div",8)(1,"div",9)(2,"div"),Z(3,"View on nodes"),S(),R(4,"div",10)(5,"mat-icon"),Z(6,"close"),S()()(),Hq(7,OO,4,3,null,null,KO),R(9,"div",9)(10,"div"),Z(11,"View on edges"),S()(),Hq(12,PO,3,2,"div",11,KO),S());a&2&&(a=Y(),D(7),Jq(a.Ox),D(5),Jq(a.Nx))}
function RO(a){a&1&&(R(0,"div",18),Z(1," Use regex to match "),R(2,"span",19),Z(3),S(),Z(4," or "),R(5,"span",19),Z(6),S(),Z(7,". "),Kq(8,"br")(9,"br"),Z(10," Examples:"),Kq(11,"br"),R(12,"ul")(13,"li")(14,"span",20),Z(15,"axis:"),S(),Z(16," will match attributes whose key is "),R(17,"span",19),Z(18,"axis"),S(),Z(19,". "),S(),R(20,"li")(21,"span",20),Z(22,"padding=[SAME|VALID]"),S(),Z(23," will match attributes whose key is "),R(24,"span",19),Z(25,"padding"),S(),Z(26," and value is either "),R(27,
"span",19),Z(28,"SAME"),S(),Z(29," or "),R(30,"span",19),Z(31,"VALID"),S(),Z(32,". "),S()()());a&2&&(D(3),Ar("","{","key","}",":","{","value","}",""),D(3),Ar("","{","key","}","=","{","value","}",""))}const SO="Op node id;Op node attributes;Op node inputs;Op node outputs;Layer node children count;Layer node descendants count".split(";"),TO=["Tensor shape"];
function NO(a){if(!a.Pb&&!a.Me.i){a=cJ(a.Me,a.paneId,a.rendererId);const b=Object.keys(a).filter(c=>c.startsWith("Node data provider: "));for(const c of b)delete a[c];HI("model_explorer_show_on_node_item_types_v2",JSON.stringify(a))}}
var UO=class{constructor(a,b,c,d){this.Me=a;this.C=b;this.D=d;this.Pb=!1;this.F=ys(()=>{const e=qJ(this.Me,this.paneId);return(e?Object.values(nL(this.D,e)):[]).map(f=>f.runName)});this.i=[];this.fd={minWidth:0,minHeight:0};this.SE={minWidth:280,minHeight:0};this.Ox=[];this.Nx=[];this.fn="";this.gf=!1;Gs(()=>{var e;const f=(null==(e=fJ(this.Me,this.paneId))?void 0:e.showOnNodeItemTypes)||{};e=this.F();if(f!==this.K||JSON.stringify(e)!==JSON.stringify(this.i)){this.i=e;this.K=f;e=[];for(var g of SO){let k;
const m={type:g,selected:null==(k=(f[this.rendererId]||{})[g])?void 0:k.selected};e.push(m);if("Op node attributes"===g){let p;m.filterRegex=(null==(p=(f[this.rendererId]||{})[g])?void 0:p.filterRegex)||"";this.fn=m.filterRegex}}for(const k of this.i){g=`${"Node data provider: "}${k}`;let m;e.push({type:g,selected:null==(m=(f[this.rendererId]||{})[g])?void 0:m.selected})}this.Ox=e;Zm(this.C)}});Gs(()=>{var e;const f=(null==(e=fJ(this.Me,this.paneId))?void 0:e.Vb)||{};if(f!==this.G){this.G=f;e=[];
for(const g of TO){let k;const m={type:g,selected:null==(k=(f[this.rendererId]||{})[g])?void 0:k.selected};e.push(m)}this.Nx=e;Zm(this.C)}})}};UO.J=function(a){return new (a||UO)(y(NJ),y(Pr),y(II),y(CL))};
UO.Ca=Gf({type:UO,ga:[["view-on-node"]],eb:function(a,b){a&1&&rr(yG,5);if(a&2){let c;sr(c=tr())&&(b.xD=c.first)}},inputs:{rendererId:"rendererId",paneId:"paneId",Pb:"inPopup"},ja:!0,features:[Jr],ya:10,za:5,Ba:[["help",""],["viewPopup",""],["helpPopup",""],["input",""],["dialogLabel","help",1,"container",3,"xapInlineDialog","overlaySize","hoverDelayMs"],["dialogLabel","view popup",1,"mat-icon-container","view",3,"opened","closed","click","xapInlineDialogClick","overlaySize"],[1,"toolbar-icon"],[1,
"model-explorer-help-popup"],[1,"model-explorer-view-popup"],[1,"label"],["xapInlineDialogClose","",1,"icon-container","close"],[1,"show-on-node-item"],[1,"show-on-node-item",3,"click"],["type","checkbox",3,"checked"],[1,"show-on-node-filter"],["placeholder","Filter by regex",1,"input-attrs-filter",3,"keydown.enter","input","change","disabled","value"],["dialogLabel","help popup",1,"icon-container",3,"xapInlineDialog","hoverDelayMs"],[1,"icon-container","ok",3,"click"],[1,"model-explorer-view-on-node-help-popup"],
[1,"code"],[1,"code","regex"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",4)(1,"div",5);V("opened",function(){u(c);return x(b.gf=!0)})("closed",function(){u(c);return x(b.gf=!1)})("click",function(){u(c);b.gf&&jG(b.xD);return x()});R(2,"mat-icon",6);Z(3,"visibility");S()()();yp(4,LO,2,0,"ng-template",null,0,Nr)(6,QO,14,0,"ng-template",null,1,Nr)(8,RO,33,8,"ng-template",null,2,Nr)}if(a&2){a=wr(5);const c=wr(7);H("xapInlineDialog",a)("overlaySize",b.fd)("hoverDelayMs",10);D();H("xapInlineDialogClick",
c)("overlaySize",b.SE)}},Ga:[et,$F,aI,$H,zG,wG,yG],styles:[".container[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]{width:20px;height:20px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;cursor:pointer;opacity:.6}.container[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]:hover{opacity:.9}.container[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:20px;width:20px;height:20px}  .model-explorer-view-popup{padding:12px;padding-top:10px;font-size:12px;background-color:#fff;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column}  .model-explorer-view-popup .label{font-weight:500;font-size:11px;text-transform:uppercase;letter-spacing:.0727em;margin-bottom:6px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}  .model-explorer-view-popup .label:not(:first-child){margin-top:12px}  .model-explorer-view-popup .label .icon-container{cursor:pointer;opacity:.7;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}  .model-explorer-view-popup .label .icon-container:hover{opacity:1}  .model-explorer-view-popup .label mat-icon{font-size:20px;width:20px;height:20px;color:#999}  .model-explorer-view-popup .show-on-node-item{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;gap:4px;cursor:pointer;color:#555;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}  .model-explorer-view-popup .show-on-node-item input{cursor:pointer}  .model-explorer-view-popup .show-on-node-filter{margin:1px 0 4px 25px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;position:relative}  .model-explorer-view-popup .show-on-node-filter:focus-within .icon-container.ok{visibility:visible}  .model-explorer-view-popup .show-on-node-filter input{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;-moz-box-sizing:border-box;box-sizing:border-box;border:1px solid #aaa;border-radius:3px;padding:3px 26px 3px 4px;min-width:200px}  .model-explorer-view-popup .show-on-node-filter input::-webkit-input-placeholder{color:#aaa}  .model-explorer-view-popup .show-on-node-filter input::-moz-placeholder{color:#aaa}  .model-explorer-view-popup .show-on-node-filter input:-ms-input-placeholder{color:#aaa}  .model-explorer-view-popup .show-on-node-filter input::-ms-input-placeholder{color:#aaa}  .model-explorer-view-popup .show-on-node-filter input::placeholder{color:#aaa}  .model-explorer-view-popup .show-on-node-filter .icon-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;opacity:.8;cursor:pointer;margin-left:4px}  .model-explorer-view-popup .show-on-node-filter .icon-container:hover{opacity:1}  .model-explorer-view-popup .show-on-node-filter .icon-container.ok{position:absolute;right:26px;visibility:hidden}  .model-explorer-view-popup .show-on-node-filter .icon-container mat-icon{font-size:16px;width:16px;height:16px;color:#999}  .model-explorer-view-on-node-help-popup{padding:12px;font-size:12px;background-color:#fff}  .model-explorer-view-on-node-help-popup ul{-webkit-margin-after:0;margin-block-end:0}  .model-explorer-view-on-node-help-popup .code{display:inline-block;background-color:#fffdd0;font-family:monospace}  .model-explorer-view-on-node-help-popup .code.regex{background-color:#e6d0ff}  .cdk-overlay-container:has(.model-explorer-view-popup) .cdk-overlay-backdrop{pointer-events:none}"],
Qa:0});const VO=["webglRenderer"];function WO(a){a&1&&(Lq(0),Kq(1,"search-bar",21)(2,"div",15),Mq());a&2&&(a=Y(2),D(),H("curModelGraph",a.modelGraph)("rendererId",a.rendererId))}function XO(a){a&1&&(R(0,"div",22),Z(1," Zoom to fit "),R(2,"div",23)(3,"mat-icon"),Z(4,"keyboard"),S(),Z(5," Shortcut: SPACE "),S()())}function YO(a){a&1&&(R(0,"div",22),Z(1," Expand all layers in the graph "),S())}function ZO(a){a&1&&(R(0,"div",22),Z(1," Collapse all layers in the graph "),S())}
function $O(a){if(a&1){const b=Tg();R(0,"div",24);V("click",function(){u(b);const c=Y(2);c.Xc.ba.next({Ov:!0,rendererId:c.rendererId});return x()});R(1,"mat-icon",25);Z(2,"unfold_more_double");S()();yp(3,YO,2,0,"ng-template",null,3,Nr);R(5,"div",26);V("click",function(){u(b);const c=Y(2);c.Xc.ba.next({Ov:!1,rendererId:c.rendererId});return x()});R(6,"mat-icon",27);Z(7,"unfold_less_double");S()();yp(8,ZO,2,0,"ng-template",null,4,Nr);Kq(10,"div",15)}if(a&2){a=wr(4);const b=wr(9),c=Y(2);lq("disable",
c.Hv);H("xapInlineDialog",a)("overlaySize",c.fd)("hoverDelayMs",10);D(5);lq("disable",c.Hv);H("xapInlineDialog",b)("overlaySize",c.fd)("hoverDelayMs",10)}}function aP(a){a&1&&(R(0,"div",22),Z(1," Flatten all layers in the graph "),R(2,"div",30),Z(3," Nodes will be laid out without any layers data "),S()())}
function bP(a){if(a&1){const b=Tg();R(0,"div",28);V("click",function(){u(b);const c=Y(2);let d,e;const f=null==(d=fJ(c.Xc,c.paneId))?void 0:null==(e=d.Qg)?void 0:e.nodeId;null!=f&&gI(c.modelGraph.nodesById[f])&&oJ(c.Xc,c.paneId);lJ(c.Xc,c.paneId);eJ(c.Xc,c.paneId,mJ(c.Xc,c.paneId));c.Xc.K.set(void 0);return x()});R(1,"mat-icon",29);Z(2,"layers_clear");S()();Kq(3,"div",15);yp(4,aP,4,0,"ng-template",null,5,Nr)}if(a&2){a=wr(5);const b=Y(2);lq("enabled",b.QB());H("xapInlineDialog",a)("overlaySize",b.fd)("hoverDelayMs",
10)}}function cP(a){a&1&&(R(0,"mat-icon",19),Z(1," multiple_stop "),S())}function dP(a){a&1&&(R(0,"mat-icon",20),Z(1," multiple_stop "),S())}function eP(a){a&1&&(R(0,"span"),Z(1,"Disable inputs/outputs tracing"),S())}function fP(a){a&1&&(R(0,"span"),Z(1,"Enable inputs/outputs tracing"),S())}function gP(a){a&1&&(R(0,"div",22),yp(1,eP,2,0,"span")(2,fP,2,0,"span"),R(3,"div",30),Z(4," Highlight selected op node's ancestors and descendants and dim the rest "),S()());a&2&&(a=Y(2),D(),Cq(a.Wg?1:2))}
function hP(a){a&1&&(R(0,"div",22),Z(1," Download graph as PNG "),R(2,"div",30),Z(3," The maximum PNG size is limited to 5000 x 5000 "),S()())}
function iP(a){if(a&1){const b=Tg();Kq(0,"div",15);R(1,"div",31);V("menuOpened",function(){u(b);const c=Y(2);return x(c.vq=!0)})("menuClosed",function(){u(b);const c=Y(2);return x(c.vq=!1)});R(2,"mat-icon",32);Z(3," image ");S()();yp(4,hP,4,0,"ng-template",null,6,Nr);R(6,"mat-menu",33,7)(8,"div",34);V("click",function(){u(b);const c=Y(2);return x(jP(c,!1))});Z(9," Graph in current viewport ");S();R(10,"div",34);V("click",function(){u(b);const c=Y(2);return x(jP(c,!0))});Z(11," Full graph ");S()()}if(a&
2){a=wr(5);const b=wr(7),c=Y(2);D();H("xapInlineDialog",a)("overlaySize",c.fd)("hoverDelayMs",10)("xapInlineDialogDisabled",c.vq)("matMenuTriggerFor",b)}}function kP(a){a&1&&(Lq(0),Kq(1,"div",15)(2,"snapshot-manager",35),Mq());a&2&&(a=Y(2),D(2),H("rendererId",a.rendererId)("paneId",a.paneId))}
function lP(a){if(a&1){const b=Tg();R(0,"div",12);yp(1,WO,3,2,"ng-container",13);Kq(2,"view-on-node",14)(3,"div",15);R(4,"div",16);V("click",function(){u(b);Y().Xc.ea.next({});return x()});R(5,"mat-icon",17);Z(6,"fit_screen");S()();Kq(7,"div",15);yp(8,XO,6,0,"ng-template",null,1,Nr)(10,$O,11,10)(11,bP,6,5);R(12,"div",18);V("click",function(){u(b);let c;null==(c=Y().Rs)||c.Dl();return x()});yp(13,cP,2,0,"mat-icon",19)(14,dP,2,0,"mat-icon",20);S();yp(15,gP,5,1,"ng-template",null,2,Nr)(17,iP,12,5)(18,
kP,3,2,"ng-container",13);S()}if(a&2){a=wr(9);const b=wr(16),c=Y();lq("in-popup",c.Pb)("pushed-down",c.Qx);D();H("ngIf",c.hE);D();H("rendererId",c.rendererId)("paneId",c.paneId)("inPopup",c.Pb);D(2);H("xapInlineDialog",a)("overlaySize",c.fd)("hoverDelayMs",10);D(6);Cq(c.XD?10:-1);D();Cq(c.YD?11:-1);D();lq("enabled",c.Wg);H("xapInlineDialog",b)("overlaySize",c.fd)("hoverDelayMs",10);D();Cq(c.BC||c.yd?13:14);D(4);Cq(c.WD?17:-1);D();H("ngIf",c.iE)}}
function mP(a){a&1&&Kq(0,"subgraph-breadcrumbs",36);a&2&&(a=Y(),H("paneId",a.paneId))}function jP(a,b){a.Xc.ma.next({rendererId:a.rendererId,TB:b})}
var nP=class{constructor(a,b){this.Xc=a;this.C=b;this.Pb=!1;this.Jl=new Dk;this.fd={minWidth:0,minHeight:0,maxWidth:340};this.QB=ys(()=>mJ(this.Xc,this.paneId));this.i=0;this.vq=!1;this.Lf=[];Gs(()=>{let c;this.Lf=(null==(c=fJ(this.Xc,this.paneId))?void 0:c.Zf)||[];Zm(this.C)})}Eb(){let a,b;this.i=null!=(b=null==(a=this.Xc.config())?void 0:a.defaultRenderer)?b:0}Qq(a){this.Jl.emit(a)}get hE(){return!this.Pb}get XD(){return!this.Pb}get YD(){return!this.Pb}get WD(){return!this.Pb&&0===this.i}get iE(){return!this.Pb&&
0===this.i}get Qx(){return!this.Pb&&1<this.Lf.length}get Hv(){return mJ(this.Xc,this.paneId)}get Wg(){let a;return!0===(null==(a=this.Rs)?void 0:a.Wg)}get kE(){let a;return!(null==(a=this.Xc.config())?0:a.hideToolBar)}get BC(){return this.Xc.i}get yd(){return!0}};nP.J=function(a){return new (a||nP)(y(NJ),y(Pr))};
nP.Ca=Gf({type:nP,ga:[["renderer-wrapper"]],eb:function(a,b){a&1&&rr(VO,5);if(a&2){let c;sr(c=tr())&&(b.Rs=c.first)}},inputs:{modelGraph:"modelGraph",rendererId:"rendererId",paneId:"paneId",Ul:"rootNodeId",Pb:"inPopup"},outputs:{Jl:"openInPopupClicked"},ja:!0,features:[Jr],ya:5,za:7,Ba:[["webglRenderer",""],["helpZoomToFit",""],["helpTraceIO",""],["helpExpandAll",""],["helpCollapseAll",""],["helpFlattenLayers",""],["helpDownloadPng",""],["menu","matMenu"],[1,"container"],[3,"openInPopupClicked","modelGraph",
"rendererId","paneId","rootNodeId","inPopup"],[1,"toolbar",3,"in-popup","pushed-down"],[3,"paneId",4,"ngIf"],[1,"toolbar"],[4,"ngIf"],[3,"rendererId","paneId","inPopup"],[1,"vertical-divider"],["dialogLabel","help",1,"mat-icon-container","zoom-fit",3,"click","xapInlineDialog","overlaySize","hoverDelayMs"],[1,"toolbar-icon"],["dialogLabel","help",1,"mat-icon-container","trace-io",3,"click","xapInlineDialog","overlaySize","hoverDelayMs"],[1,"toolbar-icon","trace"],["fontSet","google-material-icons",
1,"toolbar-icon","trace","material-icons"],[3,"curModelGraph","rendererId"],[1,"model-explorer-help-popup"],[1,"shortcut"],["dialogLabel","help",1,"mat-icon-container","expand-all",3,"click","xapInlineDialog","overlaySize","hoverDelayMs"],[1,"toolbar-icon","expand-all"],["dialogLabel","help",1,"mat-icon-container","collapse-all",3,"click","xapInlineDialog","overlaySize","hoverDelayMs"],[1,"toolbar-icon","collapse-all"],["dialogLabel","help",1,"mat-icon-container","flatten-layers",3,"click","xapInlineDialog",
"overlaySize","hoverDelayMs"],[1,"toolbar-icon","flatten-layers"],[1,"description"],["dialogLabel","help",1,"mat-icon-container","download-png",3,"menuOpened","menuClosed","xapInlineDialog","overlaySize","hoverDelayMs","xapInlineDialogDisabled","matMenuTriggerFor"],[1,"toolbar-icon","download-png"],[1,"model-explorer-download-png-menu"],[1,"menu-item",3,"click"],[3,"rendererId","paneId"],[3,"paneId"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",8)(1,"webgl-renderer",9,0);V("openInPopupClicked",
function(d){u(c);return x(b.Qq(d))});S();yp(3,lP,19,21,"div",10)(4,mP,1,1,"subgraph-breadcrumbs",11);S()}a&2&&(D(),H("modelGraph",b.modelGraph)("rendererId",b.rendererId)("paneId",b.paneId)("rootNodeId",b.Ul)("inPopup",b.Pb),D(2),Cq(b.kE?3:-1),D(),H("ngIf",b.Qx))},Ga:[et,$s,uB,TC,vC,JC,RC,$F,aI,$H,tO,GO,JO,UO,RN,zG,wG],styles:[".container[_ngcontent-%COMP%]{width:100%;height:100%;overflow:hidden;position:relative}.container[_ngcontent-%COMP%]   svg-rednerer[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   webgl-rednerer[_ngcontent-%COMP%]{width:100%;height:100%}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]{position:absolute;top:8px;left:12px;padding:0 8px 0 6px;-moz-box-sizing:border-box;box-sizing:border-box;height:40px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;background-color:#edf2fa;border-radius:99px;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;outline:2px solid #fff}.container[_ngcontent-%COMP%]   .toolbar.in-popup[_ngcontent-%COMP%]{padding-left:10px}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]:has(search-bar  input:focus){border-color:#1a73e8}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   search-bar[_ngcontent-%COMP%]{margin-right:4px}.container[_ngcontent-%COMP%]   .toolbar.pushed-down[_ngcontent-%COMP%]{top:44px}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]{width:24px;height:24px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   .mat-icon-container.enabled[_ngcontent-%COMP%]{background-color:#ffdeb1;outline:1px solid #ea8600;border-radius:4px}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   .mat-icon-container.disable[_ngcontent-%COMP%]{opacity:.2;pointer-events:none}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   mat-icon.toolbar-icon[_ngcontent-%COMP%]{font-size:20px;width:20px;height:20px;cursor:pointer;opacity:.6}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   mat-icon.toolbar-icon[_ngcontent-%COMP%]:hover{opacity:.9}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   mat-icon.toolbar-icon.collapse-all[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   mat-icon.toolbar-icon.expand-all[_ngcontent-%COMP%]{font-size:18px;width:18px;height:18px}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   mat-icon.toolbar-icon.flatten-layers[_ngcontent-%COMP%]{font-size:20px;width:20px;height:20px;border:1px solid transparent}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   mat-icon.toolbar-icon.trace[_ngcontent-%COMP%]{-webkit-transform:rotate(90deg);transform:rotate(90deg);border:1px solid transparent}.container[_ngcontent-%COMP%]   .toolbar[_ngcontent-%COMP%]   .vertical-divider[_ngcontent-%COMP%]{width:1px;border-left:1px solid #d0d0d0;margin:2px 5px;height:20px}.container[_ngcontent-%COMP%]   subgraph-breadcrumbs[_ngcontent-%COMP%]{position:absolute;top:8px;left:12px}  xap-inline-dialog-container:has(.model-explorer-view-popup){border-top-left-radius:0;border-top-right-radius:0}  .model-explorer-download-png-menu .menu-item{letter-spacing:normal!important;font-family:Google Sans Text,Arial,Helvetica,sans-serif!important;font-size:12px;padding:0 8px;cursor:pointer;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}  .model-explorer-download-png-menu .menu-item:hover{background-color:#eee}"],
Qa:0});const oP=["rendererWrapper"];function pP(a){a.vj=!a.vj;a.vj?(a.D=a.root.P.style.height,a.root.P.style.height="26px"):a.root.P.style.height=a.D}function qP(a,b){b.stopPropagation();2!==b.button&&dO(new eO(a.root.P),b)}
var rP=class{constructor(a,b){this.i=a;this.root=b;this.Xu=new Dk;this.selected=ys(()=>{let c,d;return(null==(c=this.i.D())?void 0:c.id)===(null==(d=this.Sl)?void 0:d.rendererId)&&this.i.G()===this.paneId});this.vj=!1;this.D="";this.C=()=>{if(this.Sl){this.i.D.set({id:this.Sl.rendererId,Lr:1});var c;null==(c=this.Sl.Rs)?c=void 0:c=c.selectedNodeId?{nodeId:c.selectedNodeId,rendererId:c.rendererId,zd:gI(c.fa.nodesById[c.selectedNodeId])}:void 0;oJ(this.i,this.paneId,c);bJ(this.i,this.paneId)}}}Eb(){this.root.P.addEventListener("mousedown",
this.C,!0);const a=this.root.P;a.style.left=`${this.initialPosition.x}px`;a.style.top=`${this.initialPosition.y}px`;a.style.width="400px";a.style.height="400px"}ua(){this.root.P.removeEventListener("mousedown",this.C,!0)}get title(){return this.En.label}};rP.J=function(a){return new (a||rP)(y(NJ),y(qi))};
rP.Ca=Gf({type:rP,ga:[["popup-panel"]],eb:function(a,b){a&1&&rr(oP,5);if(a&2){let c;sr(c=tr())&&(b.Sl=c.first)}},inputs:{id:"id",paneId:"paneId",En:"groupNode",initialPosition:"initialPosition",fa:"curModelGraph"},outputs:{Xu:"closeClicked"},ja:!0,features:[Jr],ya:22,za:13,Ba:[["rendererWrapper",""],[1,"container",3,"mousedown","mouseup"],[1,"title",3,"dblclick"],[1,"label"],[1,"icons-container"],[1,"mat-icon-container","minimize",3,"click"],[1,"mat-icon-container","close",3,"click"],[3,"modelGraph",
"rendererId","paneId","rootNodeId","inPopup"],[1,"resize-box",3,"mousedown","mouseup"],["data-position","top"],["data-position","bottom"],["data-position","left"],["data-position","right"],["data-position","top-right"],["data-position","top-left"],["data-position","bottom-right"],["data-position","bottom-left"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",1);V("mousedown",function(d){u(c);return x(qP(b,d))})("mouseup",function(){u(c);return x()});R(1,"div",2);V("dblclick",function(){u(c);return x(pP(b))});
R(2,"div",3);Z(3);S();R(4,"div",4)(5,"div",5);V("click",function(){u(c);return x(pP(b))});R(6,"mat-icon");Z(7);S()();R(8,"div",6);V("click",function(){u(c);return x(b.Xu.emit(b.id))});R(9,"mat-icon");Z(10,"close");S()()()();Kq(11,"renderer-wrapper",7,0);S();R(13,"div",8);V("mousedown",function(d){u(c);return x(qP(b,d))})("mouseup",function(){u(c);return x()});Kq(14,"div",9)(15,"div",10)(16,"div",11)(17,"div",12)(18,"div",13)(19,"div",14)(20,"div",15)(21,"div",16);S()}a&2&&(lq("selected",b.selected())("minimized",
b.vj),D(3),xr(b.title),D(4),xr(b.vj?"unfold_more":"unfold_less"),D(4),H("modelGraph",b.fa)("rendererId",b.id)("paneId",b.paneId)("rootNodeId",b.En.id)("inPopup",!0),D(2),lq("disabled",b.vj))},Ga:[aI,$H,nP],styles:["[_nghost-%COMP%]{position:absolute;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.container[_ngcontent-%COMP%]{width:100%;height:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;font-size:13px;outline:2px solid transparent;position:relative;background-color:#fff;border-radius:4px;overflow:hidden;border:2px solid #aaa;cursor:pointer}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]{height:27px;border-bottom:1px solid #ccc;-moz-box-sizing:border-box;box-sizing:border-box;background-color:#e7f3ff;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;overflow:hidden;border-top-left-radius:2px;border-top-right-radius:2px;white-space:nowrap}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;overflow:hidden;text-overflow:ellipsis;-moz-box-sizing:border-box;box-sizing:border-box;padding-left:8px;padding-right:4px}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .icons-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]{width:24px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;opacity:.6;cursor:pointer}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]:hover{opacity:1}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;font-weight:700;width:16px;height:16px}.container[_ngcontent-%COMP%]   renderer-wrapper[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;min-height:0}.container.selected[_ngcontent-%COMP%]{box-shadow:0 4px 6px -1px rgba(0,0,0,.1),0 2px 4px -2px rgba(0,0,0,.1)}.container.selected[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]{background-color:#ea8600;color:#fff}.container.minimized[_ngcontent-%COMP%]   svg-renderer[_ngcontent-%COMP%]{display:none}.resize-box[_ngcontent-%COMP%]{position:absolute;inset:-4px;pointer-events:none;z-index:100}.resize-box.disabled[_ngcontent-%COMP%]   [data-position][_ngcontent-%COMP%]{pointer-events:none}.resize-box[_ngcontent-%COMP%]   div[_ngcontent-%COMP%]{position:absolute;pointer-events:all;background-color:transparent}.resize-box[_ngcontent-%COMP%]   [data-position=top][_ngcontent-%COMP%]{top:0;width:100%;height:8px;cursor:ns-resize}.resize-box[_ngcontent-%COMP%]   [data-position=bottom][_ngcontent-%COMP%]{bottom:0;width:100%;height:8px;cursor:ns-resize}.resize-box[_ngcontent-%COMP%]   [data-position=left][_ngcontent-%COMP%]{left:0;height:100%;width:8px;cursor:ew-resize}.resize-box[_ngcontent-%COMP%]   [data-position=right][_ngcontent-%COMP%]{right:0;height:100%;width:8px;cursor:ew-resize}.resize-box[_ngcontent-%COMP%]   [data-position=top-right][_ngcontent-%COMP%]{top:0;right:0;height:8px;width:8px;cursor:nesw-resize}.resize-box[_ngcontent-%COMP%]   [data-position=top-left][_ngcontent-%COMP%]{top:0;left:0;height:8px;width:8px;cursor:nwse-resize}.resize-box[_ngcontent-%COMP%]   [data-position=bottom-left][_ngcontent-%COMP%]{bottom:0;left:0;height:8px;width:8px;cursor:nesw-resize}.resize-box[_ngcontent-%COMP%]   [data-position=bottom-right][_ngcontent-%COMP%]{bottom:0;right:0;height:8px;width:8px;cursor:nwse-resize}"],
Qa:0});const sP=["popupPanel"];function tP(a){if(a&1){const b=Tg();R(0,"renderer-wrapper",5);V("openInPopupClicked",function(c){u(b);const d=Y();return x(d.Qq(c))});S()}a&2&&(a=Y(),H("modelGraph",a.modelGraph)("rendererId",a.rendererId)("paneId",a.paneId))}
function uP(a,b){if(a&1){const c=Tg();R(0,"popup-panel",6,0);V("closeClicked",function(d){u(c);const e=Y();return x(vP(e,d))});S()}a&2&&(a=b.ca,b=Y(),H("id",a.id)("paneId",b.paneId)("groupNode",a.En)("initialPosition",a.initialPosition)("curModelGraph",a.fa))}function wP(a){a&1&&Kq(0,"legends-panel",4);a&2&&(a=Y(),H("paneId",a.paneId))}function vP(a,b){const c=a.qo.findIndex(d=>d.id===b);0<=c&&a.qo.splice(c,1)}
var xP=class{constructor(a,b,c){this.root=a;this.i=b;this.D=c;this.Or=new Zq;this.qo=[];this.vs=!0;this.F=d=>{null==d.target.closest("popup-panel")&&this.i.D.set({id:this.rendererId,Lr:2})};Gs(()=>{const d=this.i.D();var e=this.root.P.querySelector("popup-panel.top");e&&e.classList.remove("top");(e=this.Or.find(f=>{let g;return(null==(g=f.Sl)?void 0:g.rendererId)===(null==d?void 0:d.id)}))&&e.root.P.classList.add("top")})}Eb(){this.root.P.addEventListener("mousedown",this.F,!0)}rc(a){a.modelGraph&&
this.modelGraph&&(this.vs=!1,$m(this.D),this.vs=!0,$m(this.D))}nd(){const a=this.root.P;this.C=new ResizeObserver(()=>{this.handleResize()});this.C.observe(a)}ua(){this.root.P.removeEventListener("mousedown",this.F,!0);this.C&&this.C.unobserve(this.root.P)}BE(a,b){return b.id}Qq(a){this.qo.push(a)}get cE(){let a;return!(null==(a=this.i.config())?0:a.hideLegends)}handleResize(){const a=this.root.P;for(const b of this.Or){const c=b.root.P;if(!c)continue;const d=Number(c.style.width.replace("px","")),
e=Number(c.style.height.replace("px","")),f=Number(c.style.top.replace("px",""))+e;Number(c.style.left.replace("px",""))+d>a.offsetWidth&&(c.style.left=`${a.offsetWidth-d}px`);f>a.offsetHeight&&(c.style.top=`${a.offsetHeight-e}px`)}}};xP.J=function(a){return new (a||xP)(y(qi),y(NJ),y(Pr))};
xP.Ca=Gf({type:xP,ga:[["graph-panel"]],eb:function(a,b){a&1&&rr(sP,5);if(a&2){let c;sr(c=tr())&&(b.Or=c)}},inputs:{modelGraph:"modelGraph",rendererId:"rendererId",paneId:"paneId"},ja:!0,features:[Cg,Jr],ya:4,za:4,Ba:[["popupPanel",""],[1,"container"],[3,"modelGraph","rendererId","paneId","openInPopupClicked",4,"ngIf"],[3,"id","paneId","groupNode","initialPosition","curModelGraph","closeClicked",4,"ngFor","ngForOf","ngForTrackBy"],[3,"paneId"],[3,"openInPopupClicked","modelGraph","rendererId","paneId"],
[3,"closeClicked","id","paneId","groupNode","initialPosition","curModelGraph"]],sa:function(a,b){a&1&&(R(0,"div",1),yp(1,tP,1,3,"renderer-wrapper",2)(2,uP,2,5,"popup-panel",3)(3,wP,1,1,"legends-panel",4),S());a&2&&(D(),H("ngIf",b.vs),D(),H("ngForOf",b.qo)("ngForTrackBy",b.BE),D(),Cq(b.cE?3:-1))},Ga:[et,Ws,$s,cO,rP,nP],styles:[".container[_ngcontent-%COMP%]{width:100%;height:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;position:relative;overflow:hidden}.container[_ngcontent-%COMP%]   renderer-wrapper[_ngcontent-%COMP%]{width:100%;height:100%}.container[_ngcontent-%COMP%]   popup-panel.top[_ngcontent-%COMP%]{z-index:100}.container[_ngcontent-%COMP%]   legends-panel[_ngcontent-%COMP%]{position:absolute;left:8px;bottom:8px;border-radius:6px;border:1px solid #ddd;overflow:hidden}"],
Qa:0});const yP=["container"],zP=["oneLineText"];function AP(a){a&1&&(R(0,"div",7),Z(1," Showing at most "),R(2,"span",8),Z(3),S()());a&2&&(a=Y(2),D(2),H("matTooltipShowDelay",300),D(),yr(" ",a.hl()," elements "))}function BP(a){a&1&&(yp(0,AP,4,2,"div",7),R(1,"div",4),Z(2),S());a&2&&(a=Y(),Cq(0!==a.hl()?0:-1),D(2),xr(a.text))}function CP(a,b){a&1&&(R(0,"div",10)(1,"div",11),Z(2),S(),R(3,"div",12),Z(4),S()());a&2&&(a=b.ca,b=b.Bb,D(2),xr(b),D(2),xr(a))}
function DP(a){a&1&&(R(0,"div",7),Z(1," Namespace hierarchy "),S(),R(2,"div",9),Hq(3,CP,5,2,"div",10,Eq),S());a&2&&(a=Y(),D(3),Jq(a.TC))}function EP(a){a&1&&(R(0,"div",4),Z(1),S());a&2&&(a=Y(),D(),xr(a.RB))}function FP(a){a&1&&Z(0);a&2&&(a=Y(),yr(" ",a.text," "))}function GP(a){a.Gr?(a.i=a.Gr.P.scrollWidth>a.Gr.P.offsetWidth,!a.expanded||"namespace"!==a.type&&"values"!==a.type||(a.i=!0)):a.i=!1}function HP(a,b,c=!1){a.bw&&(b.stopPropagation(),c&&a.expanded||(a.expanded=!a.expanded))}
var IP=class{constructor(a,b){this.F=a;this.C=b;this.type=this.text="";this.bgColor="transparent";this.textColor="inherit";this.i=this.expanded=!1}get hC(){return this.expanded}nd(){setTimeout(()=>{GP(this);Zm(this.C)});this.Za&&(this.D=new ResizeObserver(()=>{GP(this);Zm(this.C)}),this.D.observe(this.Za.P))}rc(){setTimeout(()=>{GP(this);Zm(this.C)})}ua(){this.D&&this.D.disconnect()}hl(){let a,b;return null!=(b=null==(a=this.F.config())?void 0:a.maxConstValueCount)?b:0}get bw(){GP(this);return this.i}get iC(){return this.expanded?
"unfold_less":"unfold_more"}get YB(){return"transparent"!==this.bgColor}get TC(){const a=this.text.split("/");"<root>"!==this.text&&a.unshift("<root>");return a}get RB(){return this.text.replace("[","").replace("]","").split(",").map(a=>a.trim()).join("\n")}};IP.J=function(a){return new (a||IP)(y(NJ),y(Pr))};
IP.Ca=Gf({type:IP,ga:[["expandable-info-text"]],eb:function(a,b){a&1&&(rr(yP,5),rr(zP,5));if(a&2){let c;sr(c=tr())&&(b.Za=c.first);sr(c=tr())&&(b.Gr=c.first)}},Xa:2,Ha:function(a,b){a&2&&lq("expanded",b.hC)},inputs:{text:"text",type:"type",bgColor:"bgColor",textColor:"textColor"},ja:!0,features:[Cg,Jr],ya:13,za:13,Ba:[["container",""],["oneLineText",""],[1,"container",3,"click"],[1,"expanded-text"],[1,"monospace-content"],[1,"one-line-text"],[1,"icon-container","toggle",3,"click"],[1,"info-msg"],
["matTooltip","configurable in Settings in homepage","matTooltipPosition","above",1,"underline",3,"matTooltipShowDelay"],[1,"namespace-content"],[1,"namespace-row"],[1,"index"],[1,"namespace"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",2,0);V("click",function(d){u(c);return x(HP(b,d,!0))});R(2,"div",3);yp(3,BP,3,2,"div",4)(4,DP,5,0)(5,EP,2,1,"div",4)(6,FP,1,1);S();R(7,"div",5,1);Z(9);S();R(10,"div",6);V("click",function(d){u(c);return x(HP(b,d))});R(11,"mat-icon");Z(12);S()()()}a&2&&(jq("background-color",
b.bgColor)("color",b.textColor),lq("has-bg-color",b.YB)("has-overflow",b.bw)("expanded",b.expanded),D(3),Cq("values"===b.type?3:"namespace"===b.type?4:"quantization"===b.type?5:6),D(6),yr(" ",b.text," "),D(3),xr(b.iC))},Ga:[et,$F,tE,YF,aI,$H],styles:["[_nghost-%COMP%]{overflow:hidden}.container[_ngcontent-%COMP%]{overflow:hidden;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:start;-webkit-align-items:flex-start;-moz-box-align:start;-ms-flex-align:start;align-items:flex-start;position:relative}.container.has-overflow[_ngcontent-%COMP%]{cursor:pointer}.container.has-overflow[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex}.container.has-overflow[_ngcontent-%COMP%]:hover   .icon-container[_ngcontent-%COMP%]{opacity:1}.container.has-bg-color[_ngcontent-%COMP%]{border-radius:4px;padding-left:4px}.container.expanded[_ngcontent-%COMP%]   .one-line-text[_ngcontent-%COMP%]{position:absolute;inset:0;visibility:hidden}.container.expanded[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]{display:block;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;cursor:text}.container.expanded[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]   .info-msg[_ngcontent-%COMP%]{margin-bottom:2px;color:#999;font-size:12px}.container.expanded[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]   .info-msg[_ngcontent-%COMP%]   .underline[_ngcontent-%COMP%]{-webkit-text-decoration:underline dashed;-moz-text-decoration:underline dashed;text-decoration:underline dashed}.container.expanded[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]   .monospace-content[_ngcontent-%COMP%]{font-size:11px;white-space:pre-wrap;font-family:monospace;max-height:500px;overflow:auto}.container.expanded[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]   .namespace-content[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:2px}.container.expanded[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]   .namespace-row[_ngcontent-%COMP%]{font-size:12px;line-height:14px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:start;-webkit-align-items:flex-start;-moz-box-align:start;-ms-flex-align:start;align-items:flex-start}.container.expanded[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]   .namespace-row[_ngcontent-%COMP%]   .index[_ngcontent-%COMP%]{width:16px;color:#999;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;line-height:13px}.container.expanded[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]   .namespace-row[_ngcontent-%COMP%]   .namespace[_ngcontent-%COMP%]{line-height:13px}.container.expanded[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]   .namespace-row[_ngcontent-%COMP%]   .namespace.hidden[_ngcontent-%COMP%]{color:#999}.container.expanded[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{background-color:#eee;border:1px solid #999}.container.expanded[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{color:#999}.container[_ngcontent-%COMP%]   .one-line-text[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.container[_ngcontent-%COMP%]   .expanded-text[_ngcontent-%COMP%]{display:none}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{width:12px;height:12px;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;display:none;background-color:#d7f1ff;border-radius:2px;margin-left:2px;cursor:pointer;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;border:1px solid #4e90b5;opacity:.75}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{color:#00639b;font-size:11px;width:11px;height:11px;font-weight:700}"],
Qa:0});const JP=["container"];function KP(a){a&1&&(R(0,"div",3),Z(1),S());a&2&&(a=Y(),D(),yr(" ",a.label," "))}var LP=class{constructor(a){this.i=a;this.label="";this.Px=!1;this.Pr={minWidth:0,minHeight:0};this.yD=[{bb:"end",cb:"top",La:"end",Sa:"top",offsetY:-1}]}nd(){setTimeout(()=>{const a=this.Za.P;this.Px=a.scrollWidth>a.offsetWidth;Zm(this.i)})}};LP.J=function(a){return new (a||LP)(y(Pr))};
LP.Ca=Gf({type:LP,ga:[["hoverable-label"]],eb:function(a,b){a&1&&rr(JP,5);if(a&2){let c;sr(c=tr())&&(b.Za=c.first)}},inputs:{label:"label"},ja:!0,features:[Jr],ya:5,za:6,Ba:[["container",""],["popup",""],["dialogLabel","popup",1,"container",3,"xapInlineDialog","overlaySize","overlayPositions","hoverDelayMs","xapInlineDialogDisabled"],[1,"model-explorer-hoverable-label-popup"]],sa:function(a,b){a&1&&(R(0,"div",2,0),Z(2),S(),yp(3,KP,2,1,"ng-template",null,1,Nr));a&2&&(a=wr(4),H("xapInlineDialog",a)("overlaySize",
b.Pr)("overlayPositions",b.yD)("hoverDelayMs",10)("xapInlineDialogDisabled",!b.Px),D(2),yr(" ",b.label,"\n"))},Ga:[zG,wG],styles:["[_nghost-%COMP%] {\n  overflow: hidden;\n}\n\n.container[_ngcontent-%COMP%] {\n  overflow: hidden;\n  text-overflow: ellipsis;\n}\n\n  xap-inline-dialog-container:has(.model-explorer-hoverable-label-popup) {\n  width: 100%;\n  box-shadow: none;\n  border: 1px solid #ccc;\n  border-radius: 4px;\n}\n\n  .model-explorer-hoverable-label-popup {\n  padding: 2px;\n  font-size: 12px;\n  line-height: 12px;\n  background-color: white;\n  color: #999;\n  font-family: 'Google Sans Text', Arial, Helvetica, sans-serif;\n}"],
Qa:0});var MP=class{constructor(){this.ue=-2;this.ug="asc";this.te=-2;this.sg="asc";this.Tf=this.Hf=this.Sg=!1;this.i=new Set}};MP.J=function(a){return new (a||MP)};MP.oa=Ld({la:MP,aa:MP.J});const NP=["paginator"],OP=["childrenStatsPaginator"];function PP(a){a&1&&(R(0,"div",26),Z(1),S());a&2&&(a=Y().index,D(),xr(a+1))}function QP(a){a&1&&Kq(0,"mat-spinner",27)}function RP(a){a&1&&(R(0,"div",28)(1,"mat-icon"),Z(2,"error"),S()());a&2&&(a=Y().ca,H("matTooltip",a.error)("matTooltipDisabled",!a.error))}
function SP(a){if(a&1){const b=Tg();R(0,"div",29);V("click",function(c){u(b);const d=Y().ca,e=Y();c.stopPropagation();d.runId===e.Kf||tJ(e.ui,e.paneId,d.runId);return x()});R(1,"mat-icon");Z(2);S()()}if(a&2){a=Y().ca;const b=Y();lq("selected",a.runId===b.Kf)("hide",!a.done);H("matTooltip",TP(b,a));D(2);xr(a.runId===b.Kf?"visibility":"visibility_off")}}
function UP(a){if(a&1){const b=Tg();R(0,"div",30);V("click",function(){u(b);const c=Y().ca,d=Y();d.fa&&(xL(d.bk,c.runId),LJ(d.ui,[`${"Node data provider: "}${c.runName}`]));return x()});R(1,"mat-icon");Z(2,"delete");S()()}a&2&&H("matTooltip","Delete")}
function VP(a,b){a&1&&(R(0,"div",17)(1,"div",18),yp(2,PP,2,1,"div",19)(3,QP,1,0,"mat-spinner",20),S(),R(4,"div",21),Z(5),S(),R(6,"div",22),yp(7,RP,3,2,"div",23)(8,SP,3,6,"div",24)(9,UP,3,1,"div",25),S()());a&2&&(a=b.ca,b=Y(),lq("selected",a.runId===b.Kf),D(2),H("ngIf",a.done),D(),H("ngIf",!a.done),D(2),xr(a.runName),D(2),H("ngIf",a.error),D(),H("ngIf",!a.error),D(),H("ngIf",a.done))}function WP(a,b){a&1&&(R(0,"th",35)(1,"div",36)(2,"div",26),Z(3),S()()());a&2&&(a=b.index,D(3),xr(a+1))}
function XP(a,b){a&1&&(R(0,"td",35),Z(1),S());a&2&&(a=b.ca,Y(3),D(),yr(" ",a===Number.POSITIVE_INFINITY||a===Number.NEGATIVE_INFINITY||isNaN(a)?"-":`${a}`," "))}function YP(a,b){a&1&&(R(0,"tr")(1,"td"),Z(2),S(),yp(3,XP,2,1,"td",33),S());a&2&&(a=b.ca,D(2),xr(a.stat),D(),H("ngForOf",a.values))}
function ZP(a){a&1&&(R(0,"table",31)(1,"thead")(2,"tr")(3,"th",32),Z(4," Stat "),S(),yp(5,WP,4,1,"th",33),S()(),R(6,"tbody"),yp(7,YP,4,2,"tr",34),S()());a&2&&(a=Y(),D(5),H("ngForOf",a.Oj),D(2),H("ngForOf",a.cj)("ngForTrackBy",a.FE))}function $P(a){if(a&1){const b=Tg();R(0,"paginator",37,3);V("change",function(c){u(b);const d=Y();return x(aQ(d,c))});S()}a&2&&(a=Y(),H("pageSize",a.bg)("itemsCount",a.Vu))}
function bQ(a){a&1&&(R(0,"mat-icon",43),Z(1),S());a&2&&(a=Y(2),D(),yr(" ","asc"===a.sg?"arrow_upward":"arrow_downward"," "))}function cQ(a){a&1&&(R(0,"mat-icon",43),Z(1),S());a&2&&(a=Y(2),D(),yr(" ","asc"===a.sg?"arrow_upward":"arrow_downward"," "))}function dQ(a){a&1&&(R(0,"mat-icon",43),Z(1),S());a&2&&(a=Y(3),D(),yr(" ","asc"===a.sg?"arrow_upward":"arrow_downward"," "))}
function eQ(a,b){if(a&1){const c=Tg();R(0,"th",44);V("click",function(){const d=u(c).ca,e=Y(2);return x(fQ(e,d.bv))});R(1,"div",36)(2,"div",26);Z(3);S();R(4,"div",45);Z(5);S();yp(6,dQ,2,1,"mat-icon",40);S()()}a&2&&(a=b.ca,b=Y(2),D(3),xr(a.ND+1),D(2),xr(a.label),D(),H("ngIf",a.bv===b.te))}function gQ(a,b){a&1&&(R(0,"td",35),Z(1),S());a&2&&(a=b.ca,D(),yr(" ",a," "))}
function hQ(a,b){if(a&1){const c=Tg();R(0,"tr")(1,"td");Z(2);S();R(3,"td",46);V("click",function(){const d=u(c).ca,e=Y(2);return x(iQ(e,d.id))});Z(4);S();yp(5,gQ,2,1,"td",33);S()}a&2&&(a=b.ca,D(2),xr(a.index),D(2),yr(" ",a.label," "),D(),H("ngForOf",a.iB))}
function jQ(a){if(a&1){const b=Tg();R(0,"table",38)(1,"thead")(2,"tr")(3,"th",39);V("click",function(){u(b);const c=Y();return x(fQ(c,-2))});R(4,"div",36);Z(5," # ");yp(6,bQ,2,1,"mat-icon",40);S()();R(7,"th",41);V("click",function(){u(b);const c=Y();return x(fQ(c,-1))});R(8,"div",36);Z(9," Node ");yp(10,cQ,2,1,"mat-icon",40);S()();yp(11,eQ,7,3,"th",42);S()();R(12,"tbody");yp(13,hQ,6,3,"tr",34);S()()}a&2&&(a=Y(),D(6),H("ngIf",-2===a.te),D(4),H("ngIf",-1===a.te),D(),H("ngForOf",a.bn),D(2),H("ngForOf",
a.qv)("ngForTrackBy",a.oy))}function kQ(a){if(a&1){const b=Tg();R(0,"paginator",37,4);V("change",function(c){u(b);const d=Y();return x(lQ(d,c))});S()}a&2&&(a=Y(),H("pageSize",a.bg)("itemsCount",a.yx))}function mQ(a){a&1&&(R(0,"mat-icon",43),Z(1),S());a&2&&(a=Y(2),D(),yr(" ","asc"===a.ug?"arrow_upward":"arrow_downward"," "))}function nQ(a){a&1&&(R(0,"mat-icon",43),Z(1),S());a&2&&(a=Y(2),D(),yr(" ","asc"===a.ug?"arrow_upward":"arrow_downward"," "))}
function oQ(a){if(a&1){const b=Tg();R(0,"div",49);V("click",function(c){u(b);const d=Y().ca,e=Y(2);c.stopPropagation();d.runId===e.Kf||tJ(e.ui,e.paneId,d.runId);return x()});R(1,"mat-icon");Z(2);S()()}if(a&2){a=Y().ca;const b=Y(2);lq("selected",a.runId===b.Kf)("hide",!a.done);H("matTooltip",TP(b,a));D(2);xr(a.runId===b.Kf?"visibility":"visibility_off")}}function pQ(a){a&1&&(R(0,"mat-icon",43),Z(1),S());a&2&&(a=Y(3),D(),yr(" ","asc"===a.ug?"arrow_upward":"arrow_downward"," "))}
function qQ(a,b){if(a&1){const c=Tg();R(0,"th",44);V("click",function(){const d=u(c).index,e=Y(2);return x(rQ(e,d))});R(1,"div",36)(2,"div",26);Z(3);S();yp(4,oQ,3,6,"div",48)(5,pQ,2,1,"mat-icon",40);S()()}if(a&2){a=b.ca;b=b.index;const c=Y(2);D(3);xr(b+1);D();H("ngIf",!a.error);D();H("ngIf",b===c.ue)}}function sQ(a,b){a&1&&(R(0,"td",35),Z(1),S());a&2&&(a=b.ca,jq("background-color",a.bgColor)("color",a.textColor),D(),yr(" ",a.strValue," "))}
function tQ(a,b){if(a&1){const c=Tg();R(0,"tr")(1,"td");Z(2);S();R(3,"td",46);V("click",function(){const d=u(c).ca,e=Y(2);return x(iQ(e,d.id))});Z(4);S();yp(5,sQ,2,5,"td",50);S()}a&2&&(a=b.ca,D(2),xr(a.index),D(),lq("input",a.wC)("output",a.yC),D(),yr(" ",a.label," "),D(),H("ngForOf",a.cols))}
function uQ(a){if(a&1){const b=Tg();R(0,"table",47)(1,"thead")(2,"tr")(3,"th",39);V("click",function(){u(b);const c=Y();return x(rQ(c,-2))});R(4,"div",36);Z(5," # ");yp(6,mQ,2,1,"mat-icon",40);S()();R(7,"th",41);V("click",function(){u(b);const c=Y();return x(rQ(c,-1))});R(8,"div",36);Z(9," Node ");yp(10,nQ,2,1,"mat-icon",40);S()();yp(11,qQ,6,3,"th",42);S()();R(12,"tbody");yp(13,tQ,6,7,"tr",34);S()()}a&2&&(a=Y(),D(6),H("ngIf",-2===a.ue),D(4),H("ngIf",-1===a.ue),D(),H("ngForOf",a.Oj),D(2),H("ngForOf",
a.rv)("ngForTrackBy",a.oy))}const vQ=["Sum %"];function TP(a,b){return b.runId===a.Kf?"Visualizing in graph":"Click to visualize in graph"}function aQ(a,b){a.qv=a.F.slice(b*a.bg,(b+1)*a.bg);Zm(a.C)}function fQ(a,b){a.i.sg=a.i.te===b?wQ(a.i.sg):0>b?"asc":"desc";a.i.te=b;xQ(a);let c;null==(c=a.eq)||c.reset();aQ(a,0)}function iQ(a,b){a.ui.F.set({nodeId:b,rendererId:a.paneId,zd:!1})}function lQ(a,b){a.rv=null==a.D?[]:a.D.slice(b*a.bg,(b+1)*a.bg);Zm(a.C)}
function rQ(a,b){a.i.ug=a.i.ue===b?wQ(a.ug):0>b?"asc":"desc";a.i.ue=b;yQ(a);let c;null==(c=a.Mr)||c.reset();lQ(a,0)}function zQ(a){return a.map(b=>{const c=[];c.push(b.runId);c.push(String(b.done));c.push(String(Object.keys(b.results||{}).length));return c.join("__")}).join(",")}
function AQ(a){if(a.fa){var b=BQ(a),c=a.K[b];if(null!=c)a.G=c;else{const d=null==a.Og?void 0:a.fa.nodesById[a.Og];let e=new Set;null!=d&&(e=new Set(d.descendantsOpNodeIds||[]));a.G=a.fa.nodes.filter(f=>fI(f)&&!f.hideInLayout&&"GraphInputs"!==f.id&&"GraphOutputs"!==f.id&&(null==d||e.has(f.id)));a.K[b]=a.G}}}
function CQ(a){if(a.fa&&0!==a.G.length){var b=nL(a.bk,a.fa);a.cj=[{stat:"Min",values:[]},{stat:"Max",values:[]},{stat:"Sum",values:[]},{stat:"Avg",values:[]}];var c=[];for(var d=0;d<b.length;d++)c.push({min:Number.POSITIVE_INFINITY,max:Number.NEGATIVE_INFINITY,li:0,count:0});a.D=[];for(d=0;d<a.G.length;d++){var e=a.G[d],f=e.id,g=[];for(var k=0;k<b.length;k++){var m=((b[k].results||{})[a.fa.id]||{})[f],p=void 0,t=null==(p=m)?void 0:p.value,v=void 0,B=(null==(v=m)?void 0:v.strValue)||"-",G=void 0;const aa=
(null==(G=m)?void 0:G.bgColor)||"";var K=void 0;m=(null==(K=m)?void 0:K.textColor)||"black";g.push({value:t,strValue:B,bgColor:aa,textColor:m});null!=t&&"number"===typeof t&&(B=c[k],B.min=Math.min(t,B.min),B.max=Math.max(t,B.max),B.count++,B.li+=t)}k=e.incomingEdges||[];k=0===k.length||k.some(aa=>"GraphInputs"===aa.sourceNodeId);e=e.outgoingEdges||[];e=0===e.length||e.some(aa=>"GraphOutputs"===aa.targetNodeId);a.D.push({id:f,index:d,wC:k,yC:e,label:a.fa.nodesById[f].label||"?",cols:g})}a.T=[...a.D];
yQ(a);lQ(a,0);a.cj[0].values=c.map(aa=>aa.min);a.cj[1].values=c.map(aa=>aa.max);a.cj[2].values=c.map(aa=>aa.li);a.cj[3].values=c.map(aa=>aa.li/aa.count);a.bn=[];p=0;for(v=0;v<b.length;v++)for(var N of vQ)a.bn.push({bv:p,ND:v,label:N}),p++;a.F=[];N=a.Og?a.fa.nodesById[a.Og].nsChildrenIds||[]:a.fa.rootNodes.map(aa=>aa.id);for(p=0;p<N.length;p++){v=N[p];G=a.fa.nodesById[v];K=[];d=[];for(f=0;f<b.length;f++){e=b[f].results||{};k=0;g=!1;if(fI(G)){let aa;e=null==(aa=(e[a.fa.id]||{})[v])?void 0:aa.value;
null!=e&&"number"===typeof e&&(k=e/c[f].li*100,g=!0)}else if(gI(G)){k=0;t=G.descendantsOpNodeIds||[];for(const aa of t){let ca;t=null==(ca=(e[a.fa.id]||{})[aa])?void 0:ca.value;null!=t&&"number"===typeof t&&(k+=t,g=!0)}k=k/c[f].li*100}K.push(k);d.push(g?k.toFixed(1):"-")}a.F.push({id:v,label:G.label,index:p,jB:K,iB:d})}a.O=[...a.F];xQ(a);aQ(a,0);Zm(a.C)}}function wQ(a){switch(a){case "desc":return"asc";case "asc":return"desc";default:return a}}
function yQ(a){a.D=[...(a.T||[])];a.D.sort((b,c)=>DQ(EQ(b,a.i.ue),EQ(c,a.i.ue),a.i.ug))}function xQ(a){a.F=[...(a.O||[])];a.F.sort((b,c)=>DQ(FQ(b,a.i.te),FQ(c,a.i.te),a.i.sg))}function GQ(a,b){b.style.maxHeight=a.i.Sg?`${b.scrollHeight}px`:`${b.offsetHeight}px`;Zm(a.C);setTimeout(()=>{a.i.Sg=!a.i.Sg;Zm(a.C);a.i.Sg||setTimeout(()=>{b.style.maxHeight="fit-content"},150)})}
function HQ(a,b){b.style.maxHeight=a.i.Hf?`${b.scrollHeight}px`:`${b.offsetHeight}px`;Zm(a.C);setTimeout(()=>{a.i.Hf=!a.i.Hf;Zm(a.C);a.i.Hf||setTimeout(()=>{b.style.maxHeight="fit-content"},150)})}function IQ(a,b){b.style.maxHeight=a.i.Tf?`${b.scrollHeight}px`:`${b.offsetHeight}px`;Zm(a.C);setTimeout(()=>{a.i.Tf=!a.i.Tf;Zm(a.C);a.i.Tf||setTimeout(()=>{b.style.maxHeight="fit-content"},150)})}
function BQ(a){let b,c;return`${null==(b=a.fa)?void 0:b.collectionLabel}___${null==(c=a.fa)?void 0:c.id}___${a.Og}`}function DQ(a,b,c){if(null==a&&null==b)return 0;if(null==a&&null!=b)return"asc"===c?-1:1;if(null!=a&&null==b)return"asc"===c?1:-1;if("number"===typeof a&&"number"===typeof b)return"asc"===c?a-b:b-a;a=JSON.stringify(a);b=JSON.stringify(b);return"asc"===c?a.localeCompare(b):b.localeCompare(a)}
function EQ(a,b){switch(b){case -2:return a.index;case -1:return a.label;default:return a.cols[b].value}}function FQ(a,b){switch(b){case -2:return a.index;case -1:return a.label;default:return a.jB[b]}}
var JQ=class{constructor(a,b,c,d){this.ui=a;this.i=b;this.bk=c;this.C=d;this.rv=[];this.cj=[];this.F=[];this.qv=[];this.O=[];this.Oj=[];this.Kf="";this.G=[];this.bn=[];this.bg=50;this.N="";this.K={};a=new URLSearchParams(document.location.search);a.has("nodeDataProviderDataSummaryTablePageSize")&&(this.bg=Number(a.get("nodeDataProviderDataSummaryTablePageSize")));Gs(()=>{let e;const f=null==(e=fJ(this.ui,this.paneId))?void 0:e.modelGraph;if(f){var g;this.Kf=(null==(g=yL(this.bk,this.paneId,f))?void 0:
g.runId)||"";Zm(this.C)}});Gs(()=>{var e,f=(this.fa=null==(e=fJ(this.ui,this.paneId))?void 0:e.modelGraph)?nL(this.bk,this.fa):[];let g=e=!1;this.R!==this.fa&&(this.R=this.fa,e=!0);f=zQ(f);this.N!==f&&(this.N=f,g=!0);if(this.fa&&(e||g)){this.Oj=[];e=nL(this.bk,this.fa);for(const p of e)this.Oj.push({runId:p.runId,runName:p.runName,done:p.done,error:p.error});Zm(this.C);this.i.ue=Math.min(this.i.ue,e.length-1);let k;null==(k=this.Mr)||k.reset();AQ(this);CQ(this);this.i.te=Math.min(this.i.te,this.bn.length-
1);let m;null==(m=this.eq)||m.reset()}})}rc(a){if(a.rootGroupNodeId){let b;null==(b=this.Mr)||b.reset();let c;null==(c=this.eq)||c.reset();AQ(this);CQ(this)}}CE(a,b){return b.runId}oy(a,b){return b.id}FE(a,b){return b.stat}get ws(){return this.Oj.some(a=>a.done)}get yx(){return null==this.D?0:this.D.length}get Vu(){return this.F.length}get qE(){return this.Sg?"arrow_right":"arrow_drop_down"}get pE(){return null==this.Og?"Aggregated stats":"Aggregated stats in selected layer"}get Sg(){return this.i.Sg}get dB(){return this.Hf?
"arrow_right":"arrow_drop_down"}get cB(){return null==this.Og?"Root-level nodes stats":"Child nodes stats in selected layer"}get Hf(){return this.i.Hf}get cD(){return this.Tf?"arrow_right":"arrow_drop_down"}get bD(){return null==this.Og?"Node data":"Node data in selected layer"}get Tf(){return this.i.Tf}get ug(){return this.i.ug}get ue(){return this.i.ue}get sg(){return this.i.sg}get te(){return this.i.te}};JQ.J=function(a){return new (a||JQ)(y(NJ),y(MP),y(CL),y(Pr))};
JQ.Ca=Gf({type:JQ,ga:[["node-data-provider-summary-panel"]],eb:function(a,b){a&1&&(rr(NP,5),rr(OP,5));if(a&2){let c;sr(c=tr())&&(b.Mr=c.first);sr(c=tr())&&(b.eq=c.first)}},inputs:{paneId:"paneId",Og:"rootGroupNodeId"},ja:!0,features:[Cg,Jr],ya:29,za:19,Ba:[["statsTableContainer",""],["childrenStatsTableContainer",""],["nodeDataTableContainer",""],["childrenStatsPaginator",""],["paginator",""],[1,"container"],[1,"index-container"],["class","index-row",3,"selected",4,"ngFor","ngForOf","ngForTrackBy"],
[1,"table-container"],[1,"table-title-container"],[1,"title-label-container",3,"click"],["border","0","cellspacing","0","cellpadding","0",4,"ngIf"],[1,"table-container","children-stats"],[3,"pageSize","itemsCount"],["class","children-stats-results","border","0","cellspacing","0","cellpadding","0",4,"ngIf"],[1,"table-container","results"],["class","results","border","0","cellspacing","0","cellpadding","0",4,"ngIf"],[1,"index-row"],[1,"index-number-container"],["class","index-number",4,"ngIf"],["color",
"primary","diameter","16",4,"ngIf"],[1,"run-name"],[1,"action-icons-container"],["class","error",3,"matTooltip","matTooltipDisabled",4,"ngIf"],["class","icon-container visibility",3,"selected","hide","matTooltip","click",4,"ngIf"],["class","icon-container action",3,"matTooltip","click",4,"ngIf"],[1,"index-number"],["color","primary","diameter","16"],[1,"error",3,"matTooltip","matTooltipDisabled"],[1,"icon-container","visibility",3,"click","matTooltip"],[1,"icon-container","action",3,"click","matTooltip"],
"border 0 cellspacing 0 cellpadding 0".split(" "),[1,"stats"],["class","value-col",4,"ngFor","ngForOf"],[4,"ngFor","ngForOf","ngForTrackBy"],[1,"value-col"],[1,"header-content"],[3,"change","pageSize","itemsCount"],["border","0","cellspacing","0","cellpadding","0",1,"children-stats-results"],[1,"index",3,"click"],["class","sort",4,"ngIf"],[1,"header","node-label",3,"click"],["class","value-col",3,"click",4,"ngFor","ngForOf"],[1,"sort"],[1,"value-col",3,"click"],[1,"stat-label"],[1,"node-label",3,
"click"],["border","0","cellspacing","0","cellpadding","0",1,"results"],["class","icon-container visibility","matTooltipPosition","above",3,"selected","hide","matTooltip","click",4,"ngIf"],["matTooltipPosition","above",1,"icon-container","visibility",3,"click","matTooltip"],["class","value-col",3,"background-color","color",4,"ngFor","ngForOf"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",5)(1,"div",6);yp(2,VP,10,8,"div",7);S();R(3,"div",8,0)(5,"div",9)(6,"div",10);V("click",function(){u(c);const d=
wr(4);return x(GQ(b,d))});R(7,"mat-icon");Z(8);S();Z(9);S()();yp(10,ZP,8,3,"table",11);S();R(11,"div",12,1)(13,"div",9)(14,"div",10);V("click",function(){u(c);const d=wr(12);return x(HQ(b,d))});R(15,"mat-icon");Z(16);S();Z(17);S();yp(18,$P,2,2,"paginator",13);S();yp(19,jQ,14,5,"table",14);S();R(20,"div",15,2)(22,"div",9)(23,"div",10);V("click",function(){u(c);const d=wr(21);return x(IQ(b,d))});R(24,"mat-icon");Z(25);S();Z(26);S();yp(27,kQ,2,2,"paginator",13);S();yp(28,uQ,14,5,"table",16);S()()}a&
2&&(D(2),H("ngForOf",b.Oj)("ngForTrackBy",b.CE),D(),lq("collapsed",b.Sg),D(5),xr(b.qE),D(),yr(" ",b.pE," "),D(),H("ngIf",b.ws),D(),lq("collapsed",b.Hf),D(5),xr(b.dB),D(),yr(" ",b.cB," "),D(),Cq(b.Vu>b.bg&&!b.Hf?18:-1),D(),H("ngIf",b.ws),D(),lq("collapsed",b.Tf),D(5),xr(b.cD),D(),yr(" ",b.bD," "),D(),Cq(b.yx>b.bg&&!b.Tf?27:-1),D(),H("ngIf",b.ws))},Ga:[et,Ws,$s,pD,oD,lD,aI,$H,ZF,YF,fO,wx],styles:[".container[_ngcontent-%COMP%]{padding-top:12px;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;height:100%}.container[_ngcontent-%COMP%]   .index-number[_ngcontent-%COMP%]{font-size:10px;width:16px;height:16px;border-radius:8px;-moz-box-sizing:border-box;box-sizing:border-box;border:1px solid #999;background-color:#eee;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;width:16px;height:16px;opacity:.3;cursor:pointer}.container[_ngcontent-%COMP%]   .icon-container.selected[_ngcontent-%COMP%]{opacity:1;cursor:default}.container[_ngcontent-%COMP%]   .icon-container.selected[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{color:#e1a011}.container[_ngcontent-%COMP%]   .icon-container.hide[_ngcontent-%COMP%]{visibility:hidden}.container[_ngcontent-%COMP%]   .icon-container.action[_ngcontent-%COMP%]{opacity:.7;margin-left:4px}.container[_ngcontent-%COMP%]   .icon-container.action[_ngcontent-%COMP%]:hover{opacity:1}.container[_ngcontent-%COMP%]   .icon-container.visibility[_ngcontent-%COMP%]{margin-left:4px}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;width:16px;height:16px;line-height:16px;color:#000}.container[_ngcontent-%COMP%]   .index-container[_ngcontent-%COMP%]   .index-row[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;overflow:hidden;padding:2px 8px}.container[_ngcontent-%COMP%]   .index-container[_ngcontent-%COMP%]   .index-row.selected[_ngcontent-%COMP%]{background-color:#fff2d5}.container[_ngcontent-%COMP%]   .index-container[_ngcontent-%COMP%]   .index-row[_ngcontent-%COMP%]   .index-number-container[_ngcontent-%COMP%]{width:16px;height:16px;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;margin-right:6px}.container[_ngcontent-%COMP%]   .index-container[_ngcontent-%COMP%]   .index-row[_ngcontent-%COMP%]   .run-name[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;white-space:nowrap;overflow:hidden;text-overflow:ellipsis}.container[_ngcontent-%COMP%]   .index-container[_ngcontent-%COMP%]   .index-row[_ngcontent-%COMP%]   .action-icons-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0}.container[_ngcontent-%COMP%]   select[_ngcontent-%COMP%]{width:100%}.container[_ngcontent-%COMP%]   .running[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;margin-top:16px}.container[_ngcontent-%COMP%]   .running[_ngcontent-%COMP%]   mat-spinner[_ngcontent-%COMP%]{margin-right:4px}.container[_ngcontent-%COMP%]   .running[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{color:#777}.container[_ngcontent-%COMP%]   .error[_ngcontent-%COMP%]{width:16px;height:16px}.container[_ngcontent-%COMP%]   .error[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;height:16px;width:16px;color:#a00}.container[_ngcontent-%COMP%]   .table-container[_ngcontent-%COMP%]{width:100%;-moz-box-sizing:border-box;box-sizing:border-box;padding:8px;margin-top:2px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-transition:max-height .15s ease-out;transition:max-height .15s ease-out;overflow:hidden}.container[_ngcontent-%COMP%]   .table-container.collapsed[_ngcontent-%COMP%]{max-height:30px!important}.container[_ngcontent-%COMP%]   .table-container[_ngcontent-%COMP%]   .table-title-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;line-height:22px}.container[_ngcontent-%COMP%]   .table-container[_ngcontent-%COMP%]   .table-title-container[_ngcontent-%COMP%]   .title-label-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;line-height:15px}.container[_ngcontent-%COMP%]   .table-container[_ngcontent-%COMP%]   .table-title-container[_ngcontent-%COMP%]   .title-label-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{margin-left:-4px}.container[_ngcontent-%COMP%]   .table-container[_ngcontent-%COMP%]   paginator[_ngcontent-%COMP%]{-webkit-align-self:flex-end;-ms-flex-item-align:end;align-self:flex-end}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]{border:1px solid #ccc;border-radius:4px;width:100%;-moz-box-sizing:border-box;box-sizing:border-box;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;background-color:#fdfdfd;overflow:hidden}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]{height:24px;background-color:#f2f2f2}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   .header[_ngcontent-%COMP%]{font-weight:500}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]{font-size:11px;font-family:Arial,Helvetica,sans-serif}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   tr[_ngcontent-%COMP%]:hover{outline:1px solid #999}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   td[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   th[_ngcontent-%COMP%]{padding:1px 4px;text-align:left}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   td.node-label[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   th.node-label[_ngcontent-%COMP%]{border-left:1px solid #ddd}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   td.value-col[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   th.value-col[_ngcontent-%COMP%]{border-left:1px solid #ddd;max-width:80px;text-overflow:ellipsis;overflow:hidden}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .header-content[_ngcontent-%COMP%]{height:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .header-content[_ngcontent-%COMP%]   mat-icon.sort[_ngcontent-%COMP%]{font-size:12px;width:12px;height:12px;color:#999;margin-left:4px}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .header-content[_ngcontent-%COMP%]   .stat-label[_ngcontent-%COMP%]{margin-left:6px;white-space:nowrap}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   th[_ngcontent-%COMP%]{cursor:pointer}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   td.node-label[_ngcontent-%COMP%]{cursor:pointer}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   td.node-label[_ngcontent-%COMP%]:hover{-webkit-text-decoration:underline dotted #0085f2;-moz-text-decoration:underline dotted #0085f2;text-decoration:underline dotted #0085f2}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   td.input[_ngcontent-%COMP%]{color:#009e73;font-weight:500}.container[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   td.output[_ngcontent-%COMP%]{color:#d55e00;font-weight:500}"],
Qa:0});const KQ=["inputValueContent"],LQ=(a,b)=>b.id||b.label,MQ=(a,b)=>b.Vh.id,NQ=(a,b)=>b.key,OQ=(a,b)=>b.lD,PQ=(a,b)=>b.id,QQ=a=>({value:a});function RQ(a,b){a&1&&(R(0,"tr")(1,"td",21),Kq(2,"hoverable-label",22),S(),R(3,"td",23),Kq(4,"expandable-info-text",24),S()());a&2&&(a=b.ca,b=Y(2),lq("search-match",SQ(b,a.label)),D(2),H("label",a.label),D(2),H("text",a.value)("type",a.label)("bgColor",a.bgColor||"transparent")("textColor",a.textColor||"black"))}
function TQ(a,b){if(a&1){const c=Tg();R(0,"div",15,1)(2,"div",16)(3,"button",17);V("click",function(){const d=u(c).ca,e=wr(1),f=Y();return x(UQ(f,d.label,e))});R(4,"mat-icon");Z(5);S()();Z(6);S();R(7,"div",18)(8,"table",19);Hq(9,RQ,5,7,"tr",20,LQ);S()()()}a&2&&(a=b.ca,b=Y(),lq("collapsed",VQ(b,a.label)),D(5),xr(WQ(b,a.label)),D(),yr(" ",a.label," "),D(3),Jq(a.items))}
function XQ(a){if(a&1){const b=Tg();R(0,"div",15,2)(2,"div",16)(3,"button",17);V("click",function(){u(b);const c=wr(1),d=Y();return x(UQ(d,d.Wd.To,c))});R(4,"mat-icon");Z(5);S()();Z(6," Node data providers ");S();Kq(7,"node-data-provider-summary-panel",25);S()}a&2&&(a=Y(),lq("collapsed",VQ(a,a.Wd.To)),D(5),xr(WQ(a,a.Wd.To)),D(2),H("paneId",a.paneId)("rootGroupNodeId",a.tv))}
function YQ(a){if(a&1){const b=Tg();R(0,"paginator",32);V("change",function(c){u(b);const d=Y(2);return x(ZQ(d,c))});S()}a&2&&(a=Y(2),H("pageSize",a.Bc)("itemsCount",a.mq))}function $Q(a){a&1&&(R(0,"div",35),Z(1),S());a&2&&(a=Y().ca,Y(2),D(),xr(aR(a)))}
function bR(a){if(a&1){const b=Tg();R(0,"div",38);V("click",function(c){u(b);const d=Y().ca,e=Y(2);return x(e.il(d.Vh.id,c))});Z(1);R(2,"div",39)(3,"mat-icon",40);Z(4,"my_location");S()()()}if(a&2){a=Y().ca;const b=Y(2);Ip("data-id",a.Vh.id);D();yr(" ",aR(a)," ");D();H("matTooltip",b.Bl)}}
function cR(a){a&1&&(R(0,"tr",null,4)(2,"td",21)(3,"div",41)(4,"mat-icon",42),Z(5,"circle"),S(),Kq(6,"hoverable-label",22),S()(),R(7,"td",23),Kq(8,"expandable-info-text",43),S()());if(a&2){a=Y().ca;const b=Y(3);lq("search-match",dR(b,a.value));D(6);H("label",a.key);D(2);H("text",a.value)("type",a.key)}}function eR(a,b){a&1&&yp(0,cR,9,5,"tr",20);a&2&&(a=b.ca,Y(3),Cq(a.key.startsWith("__")?-1:0))}
function fR(a,b){a&1&&(R(0,"div",31)(1,"div",33)(2,"div",34),Z(3),S(),yp(4,$Q,2,1,"div",35)(5,bR,5,3,"div",36),S(),R(6,"table",37),Hq(7,eR,1,1,null,null,NQ),S()());a&2&&(a=b.ca,b=Y(2),D(),lq("search-match",dR(b,gR(a))||dR(b,a.Vh.label)),D(2),xr(a.index),D(),Cq(a.Vh.hideInLayout?4:5),D(3),Jq(a.uj))}
function hR(a){if(a&1){const b=Tg();R(0,"div",26,3)(2,"div",27)(3,"div",28)(4,"button",17);V("click",function(){u(b);const c=wr(1),d=Y();return x(UQ(d,d.Wd.Ro,c))});R(5,"mat-icon");Z(6);S()();Z(7);S();yp(8,YQ,1,2,"paginator",29);S();R(9,"div",30);Hq(10,fR,9,4,"div",31,MQ);S()()}a&2&&(a=Y(),lq("collapsed",VQ(a,a.Wd.Ro)),D(6),xr(WQ(a,a.Wd.Ro)),D(),yr(" inputs (",a.mq,") "),D(),Cq(a.bE?8:-1),D(2),Jq(a.oj))}
function iR(a){if(a&1){const b=Tg();R(0,"paginator",32);V("change",function(c){u(b);const d=Y(2);d.Ir=d.Vf.slice(c*d.Bc,(c+1)*d.Bc);Zm(d.Sd);return x()});S()}a&2&&(a=Y(2),H("pageSize",a.Bc)("itemsCount",a.Vf.length))}function jR(a){a&1&&Nq(0)}function kR(a){a&1&&(R(0,"div",48),yp(1,jR,1,0,"ng-container",49),S());if(a&2){a=Y().ca;const b=Y(6),c=wr(11);D();H("ngTemplateOutlet",c)("ngTemplateOutletContext",Mr(QQ,b.UB(a)))}}
function lR(a,b){if(a&1){const c=Tg();R(0,"div",47);V("click",function(d){const e=u(c).ca,f=Y(6);return x(f.il(e.id,d))});Z(1);R(2,"div",39)(3,"mat-icon",40);Z(4,"my_location");S()()();yp(5,kR,2,4,"ng-template",null,6,Nr)}if(a&2){a=b.ca;b=wr(6);const c=Y(6);lq("search-match",mR(c,a.label));H("xapInlineDialog",b)("overlaySize",c.gq)("overlayPositions",c.kD)("hoverDelayMs",50);Ip("data-id",a.id);D();yr(" ",a.label," ");D();H("matTooltip",c.Bl)}}
function nR(a){a&1&&Hq(0,lR,7,9,null,null,PQ);a&2&&(a=Y().ca,Jq(a.lB))}function oR(a){a&1&&Kq(0,"expandable-info-text",46);a&2&&(a=Y().ca,H("text",a.value))}function pR(a,b){a&1&&(R(0,"tr")(1,"td",21)(2,"div",41)(3,"mat-icon",42),Z(4,"circle"),S(),Kq(5,"hoverable-label",22),S()(),R(6,"td",23),yp(7,nR,2,0)(8,oR,1,1,"expandable-info-text",46),S()());a&2&&(a=b.ca,b=Y(4),lq("search-match",mR(b,a.value)),D(5),H("label",a.key),D(2),Cq(a.key===b.mD?7:8))}
function qR(a){a&1&&(R(0,"table",37),Hq(1,pR,9,4,"tr",20,NQ),S());a&2&&(a=Y().ca,D(),Jq(a.uj))}function rR(a,b){a&1&&(R(0,"div",31)(1,"div",33)(2,"div",34),Z(3),S(),R(4,"div",35),Z(5),S()(),yp(6,qR,3,0,"table",37),S());a&2&&(a=b.ca,b=Y(2),D(),lq("search-match",mR(b,a.Fs)),D(2),xr(a.index),D(2),xr(""===a.Fs?"output":a.Fs),D(),Cq(0<a.uj.length?6:-1))}
function sR(a){if(a&1){const b=Tg();R(0,"div",44,5)(2,"div",45)(3,"div",28)(4,"button",17);V("click",function(){u(b);const c=wr(1),d=Y();return x(UQ(d,d.Wd.Vo,c))});R(5,"mat-icon");Z(6);S()();Z(7);S();yp(8,iR,1,2,"paginator",29);S();R(9,"div",30);Hq(10,rR,7,5,"div",31,OQ);S()()}a&2&&(a=Y(),lq("collapsed",VQ(a,a.Wd.Vo)),D(6),xr(WQ(a,a.Wd.Vo)),D(),yr(" outputs (",a.pv,") "),D(),Cq(a.eE?8:-1),D(2),Jq(a.Ir))}
function tR(a){if(a&1){const b=Tg();R(0,"paginator",32);V("change",function(c){u(b);const d=Y(2);let e;d.On=SK(d.Kh.slice(c*d.Bc,(c+1)*d.Bc),"incoming",(null==(e=d.Kc)?void 0:e.id)||"");return x()});S()}a&2&&(a=Y(2),H("pageSize",a.Bc)("itemsCount",a.Kh.length))}
function uR(a){if(a&1){const b=Tg();R(0,"div",15,7)(2,"div",50)(3,"div",28)(4,"button",17);V("click",function(){u(b);const c=wr(1),d=Y();return x(UQ(d,d.Wd.Po,c))});R(5,"mat-icon");Z(6);S()();Z(7);S();yp(8,tR,1,2,"paginator",29);S();Kq(9,"io-tree",51);S()}a&2&&(a=Y(),lq("collapsed",VQ(a,a.Wd.Po)),D(6),xr(WQ(a,a.Wd.Po)),D(),yr(" Identical layers (",a.Kh.length,") "),D(),Cq(a.ZD?8:-1),D(),H("data",a.On)("rendererId",a.nq))}
function vR(a,b){a&1&&(R(0,"div",54),Z(1),S());a&2&&(a=b.ca,D(),yr(" ",a," "))}function wR(a,b){a&1&&(R(0,"div",52),Z(1," Namespace hierarchy "),S(),R(2,"div",53),Hq(3,vR,2,1,"div",54,Eq),S());a&2&&(a=b.value,D(3),Jq(a.split("/")))}const xR={aF:"Graph info",dF:"Node info",cF:"Layer info",WE:"Attributes",To:"Node data providers",Po:"Identical groups",Ro:"inputs",Vo:"outputs"};function SQ(a,b){return null!=a.T.find(c=>c.Dw===b)}
function UQ(a,b,c){c&&(VQ(a,b)?c.style.maxHeight=`${c.scrollHeight}px`:(c.style.maxHeight=`${c.offsetHeight}px`,c.style.overflow="hidden"),Zm(a.Sd),setTimeout(()=>{a.G.i.has(b)?a.G.i.delete(b):a.G.i.add(b);Zm(a.Sd);setTimeout(()=>{VQ(a,b)?c.style.overflow="hidden":(c.style.overflow="visible",c.style.maxHeight="fit-content")},150)}))}function VQ(a,b){return a.G.i.has(b)}function WQ(a,b){return VQ(a,b)?"expand_more":"expand_less"}
function ZQ(a,b){a.oj=yR(b*a.Bc,a.i.slice(b*a.Bc,(b+1)*a.Bc),a.D.slice(b*a.Bc,(b+1)*a.Bc));Zm(a.Sd);setTimeout(()=>{zR(a)})}function aR(a){const b=a.uj.find(c=>"__tensor_tag"===c.key);return b?`${b.value} (${a.Vh.label})`:a.Vh.label}function dR(a,b){return a.N?null!=a.N.find(c=>c.ff===b):!1}function gR(a){let b,c;return null!=(c=null==(b=a.uj.find(d=>"__tensor_tag"===d.key))?void 0:b.value)?c:""}function mR(a,b){return a.O?null!=a.O.find(c=>c.ff===b):!1}
function AR(a,b){a.fa&&b?a.Kc=a.fa.nodesById[b]:a.Kc=void 0;BR(a);Zm(a.Sd);setTimeout(()=>{zR(a)})}function CR(a){if(a.Kc&&a.F){var b=a.F.results[a.Kc.id]||[],c=[],d=[],e=[];for(const f of b)switch(f.type){case "input":c.push(f);break;case "output":d.push(f);break;case "list":e.push(f)}a.T=e;a.O=d;a.N=c;Zm(a.Sd)}}
function BR(a){a.fi=[];a.oj=[];a.i=[];a.D=[];a.Vf=[];a.Kh=[];a.On=void 0;if(a.ea){if(a.fa){var b={label:"Graph info",zo:"graph",items:[]};a.fi.push(b);var c=0,d=0;for(var e of a.fa.nodes)fI(e)&&!e.hideInLayout?c++:gI(e)&&d++;b.items.push({pf:b,label:"op node count",value:String(c)},{pf:b,label:"layer count",value:String(d)})}}else if(a.Kc)if(fI(a.Kc)){if(a.fa&&a.Kc){e=a.Kc;var f={label:"Node info",zo:"op",items:[]};a.fi.push(f);f.items.push({pf:f,label:"op name",value:`${e.label}`});var g="id";f.items.push({pf:f,
label:g,value:e.id,Vi:!0,Rj:a.ba.has(g)});g="namespace";f.items.push({pf:f,label:g,value:kI(e),Vi:!0,Rj:a.ba.has(g)});if(0<Object.keys(e.attrs||{}).length){f={label:"Attributes",zo:"op",items:[]};g=e.attrs||{};for(var k of Object.keys(g))k.startsWith("__")||f.items.push({pf:f,label:k,value:g[k],Vi:!0,Rj:a.ma.has(k)});0<f.items.length&&a.fi.push(f)}f=nL(a.K,a.fa);if(0<f.length){k={label:"Node data providers",zo:"op",items:[]};a.fi.push(k);for(b of f){var m=((b.results||{})[a.fa.id]||{})[e.id];f=(null==
(c=m)?void 0:c.strValue)||"-";g=(null==(d=m)?void 0:d.bgColor)||"transparent";let p;m=(null==(p=m)?void 0:p.textColor)||"black";k.items.push({id:b.runId,pf:k,label:b.runName,value:f,Vi:b.done,Rj:null!=a.ia[b.runId],bgColor:g,textColor:m,hd:!b.done})}}}DR(a)}else gI(a.Kc)&&ER(a)}function zR(a){for(let b=0;b<a.Zq.length;b++){let c;const d=null==(c=a.Zq.get(b))?void 0:c.P;d&&d.scrollHeight>d.offsetHeight&&d.classList.add("expandable")}}
function yR(a,b,c){const d=[];for(let e=0;e<b.length;e++){const f=b[e],g=[];Object.entries(c[e]).forEach(([m,p])=>{g.push({key:m,value:p})});g.sort((m,p)=>m.key.localeCompare(p.key));g.push({key:"namespace",value:kI(b[e])});const k=f.attrs||{};k.__value&&g.push({key:"values",value:k.__value});d.push({index:e+a,Vh:f,uj:g})}return d}
function FR(a,b){const c=Date.now(),d=a.width,e=()=>{var f=Date.now()-c;f=a.C.i?1:Math.min(1,f/150);f=Math.sin(f*Math.PI/2);const g=d+(b-d)*f;a.width=g;a.minWidth=g;Zm(a.Sd);1<=f?(a.width=b,a.minWidth=b,Zm(a.Sd)):requestAnimationFrame(e)};e()}
function DR(a){if(a.fa&&a.Kc){var b=a.Kc,c=b.incomingEdges||[];a.D=[];a.i=[];a.oj=[];for(var d of c){var e=void 0,f=null==(e=a.fa)?void 0:e.nodesById[d.sourceNodeId];a.i.push(f);var g=(b.inputsMetadata||{})[d.targetNodeInputId]||{};f=Object.assign({},(f.outputsMetadata||{})[d.sourceNodeOutputId]||{});for(var k of Object.keys(f))null==g[k]&&"__tensor_tag"!==k&&(g[k]=f[k]);a.D.push(g)}a.mq=a.i.length;0<c.length&&(a.oj=yR(0,a.i.slice(0,a.Bc),a.D.slice(0,a.Bc)));a.Vf=[];c=b.outputsMetadata||{};b=b.outgoingEdges||
[];d=0;for(const m of Object.keys(c)){e=[];g="";for(const p of Object.keys(c[m]))k=c[m][p],"__tensor_tag"===p&&(g=k),p.startsWith("__")||e.push({key:p,value:k});e.sort((p,t)=>p.key.localeCompare(t.key));k=b.filter(p=>p.sourceNodeOutputId===m).map(p=>a.fa.nodesById[p.targetNodeId]);e.push({key:"connects to",value:"",lB:k});a.Vf.push({index:d,Fs:g,lD:m,uj:e});d++}a.pv=a.Vf.length;a.Ir=a.Vf.slice(0,a.Bc)}}
function ER(a){if(a.fa&&a.Kc){var b=a.Kc,c={label:"Layer info",zo:"group",items:[]};a.fi.push(c);c.items.push({pf:c,label:"name",value:b.label});var d="namespace";c.items.push({pf:c,label:d,value:kI(b),Vi:!0,Rj:a.R.has(d)});d="#children";c.items.push({pf:c,label:d,value:String((b.nsChildrenIds||[]).length),Vi:!0,Rj:a.R.has(d)});d="#descendants";c.items.push({pf:c,label:d,value:String((b.descendantsNodeIds||[]).length),Vi:!0,Rj:a.R.has(d)});null!=b.identicalGroupIndex&&(a.Kh=a.fa.nodes.filter(e=>gI(e)&&
e.identicalGroupIndex===b.identicalGroupIndex),a.On=SK(a.Kh.slice(0,a.Bc),"incoming",b.id))}}
var GR=class{constructor(a,b,c,d){this.C=a;this.K=b;this.Sd=c;this.G=d;this.Zq=new Zq;this.ba=new Set;this.ma=new Set;this.R=new Set;this.ia={};this.F=void 0;this.minWidth=this.width=370;this.fi=[];this.oj=[];this.Vf=[];this.Ir=[];this.Kh=[];this.nq="";this.pv=this.mq=0;this.ck=this.fs=!1;this.Bc=this.C.i?5:25;this.Wd=xR;this.mD="connects to";this.Bl="Click: locate\nAlt+click: select";this.UB=kI;this.gq={minWidth:100,minHeight:0,maxWidth:600};this.gv=[{bb:"start",cb:"top",La:"end",Sa:"top",offsetX:-32}];
this.kD=[{bb:"start",cb:"top",La:"end",Sa:"top",offsetX:-4}];this.T=[];this.N=[];this.O=[];this.i=[];this.D=[];this.Ax=0;Gs(()=>{var e=fJ(this.C,this.paneId);if(e&&e.modelGraph){this.fa=e.modelGraph;var f;this.nq=(null==(f=e.Qg)?void 0:f.rendererId)||"";var g;e=(null==(g=e.Qg)?void 0:g.nodeId)||"";this.tv!==e&&(AR(this,e),setTimeout(()=>{CR(this)}))}});Gs(()=>{const e=fJ(this.C,this.paneId);e&&e.modelGraph&&this.F!==e.Pg&&(this.F=e.Pg,CR(this))});Gs(()=>{this.K.C();BR(this);Zm(this.Sd);setTimeout(()=>
{zR(this)})})}Pq(a){a.preventDefault();document.body.style.cursor="ew-resize";const b=jk(document,"mousemove"),c=jk(window,"mouseup"),d=this.width,e=a.clientX;this.fs=!0;Zm(this.Sd);C(Nj([b]),Jo(c)).subscribe({next:([f])=>{this.minWidth=this.width=Math.max(64,d-(f.clientX-e));Zm(this.Sd)},complete:()=>{document.body.style.cursor="default";this.fs=!1;Zm(this.Sd)}})}il(a,b){this.C.F.set({nodeId:a,rendererId:this.nq,zd:!1,select:b.altKey})}DE(a,b){return b.label}get ea(){return null!=this.fa&&null==
this.Kc}get Mx(){return this.fa?(null==this.Kc||gI(this.Kc))&&0<nL(this.K,this.fa).length:!1}get tv(){return this.Kc?this.Kc.id:void 0}get bE(){return this.i.length>this.Bc&&!VQ(this,"inputs")}get eE(){return this.Vf.length>this.Bc&&!VQ(this,"outputs")}get ZD(){return this.Kh.length>this.Bc&&!VQ(this,"Identical groups")}get fC(){return this.ck?"Show info panel":"Hide info panel"}get eC(){return this.ck?"chevron_left":"chevron_right"}};GR.J=function(a){return new (a||GR)(y(NJ),y(CL),y(Pr),y(MP))};
GR.Ca=Gf({type:GR,ga:[["info-panel"]],eb:function(a,b){a&1&&rr(KQ,5);if(a&2){let c;sr(c=tr())&&(b.Zq=c)}},Xa:4,Ha:function(a,b){a&2&&jq("width",b.width,"px")("min-width",b.minWidth,"px")},inputs:{paneId:"paneId"},ja:!0,features:[Hr([MP]),Jr],ya:12,za:12,Ba:[["namespaceHierarchy",""],["sectionEle",""],["ndpSectionEle",""],["inputsSectionEle",""],["rowEle",""],["outputsSectionEle",""],["namespacePopup",""],["identicalGroupsSectionEle",""],[1,"container"],["class","section",3,"collapsed",4,"ngFor","ngForOf",
"ngForTrackBy"],["class","section",3,"collapsed",4,"ngIf"],["class","section inputs",3,"collapsed",4,"ngIf"],["class","section outputs",3,"collapsed",4,"ngIf"],[1,"resizer",3,"mousedown"],[1,"hide-toggle",3,"click","matTooltip"],[1,"section"],[1,"header"],["mat-icon-button","",1,"toggle",3,"click"],[1,"items-container"],[1,"metadata-table","info-attrs"],[3,"search-match"],[1,"key"],[3,"label"],[1,"value"],[3,"text","type","bgColor","textColor"],[3,"paneId","rootGroupNodeId"],[1,"section","inputs"],
[1,"header","input"],[1,"header-label-container"],[3,"pageSize","itemsCount"],[1,"flat-items-container"],[1,"flat-item"],[3,"change","pageSize","itemsCount"],[1,"name-row"],[1,"index"],[1,"name"],[1,"name","locator"],[1,"metadata-table"],[1,"name","locator",3,"click"],["matTooltipClass","multiline-tooltip-left","matTooltipPosition","right",1,"locator-icon-container",3,"matTooltip"],[1,"locator-icon"],[1,"key-container"],[1,"bullet"],[3,"text","type"],[1,"section","outputs"],[1,"header","output"],
[3,"text"],["dialogLabel","namespace popup",1,"target-node-container",3,"click","xapInlineDialog","overlaySize","overlayPositions","hoverDelayMs"],[1,"model-explorer-const-values-popup"],[4,"ngTemplateOutlet","ngTemplateOutletContext"],[1,"header","identical-groups"],[3,"data","rendererId"],[1,"values-count-msg"],[1,"namespace-content"],[1,"namespace-row"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",8);yp(1,TQ,11,4,"div",9)(2,XQ,8,5,"div",10)(3,hR,12,5,"div",11)(4,sR,12,5,"div",12)(5,uR,10,7,
"div",10);S();R(6,"div",13);V("mousedown",function(d){u(c);return x(b.Pq(d))});S();R(7,"div",14);V("click",function(){u(c);b.ck=!b.ck;let d=0;b.ck?b.Ax=b.width:d=b.Ax;FR(b,d);return x()});R(8,"mat-icon");Z(9);S()();yp(10,wR,5,0,"ng-template",null,0,Nr)}a&2&&(lq("graph-info",b.Mx),D(),H("ngForOf",b.fi)("ngForTrackBy",b.DE),D(),H("ngIf",b.Mx),D(),H("ngIf",0<b.oj.length),D(),H("ngIf",0<b.Vf.length),D(),H("ngIf",b.On),D(),lq("resizing",b.fs),D(),H("matTooltip",b.fC),D(2),xr(b.eC))},Ga:[et,Ws,$s,dt,IP,
uB,tB,rB,pD,VD,$F,tE,YF,LP,aI,$H,fO,RK,JQ,zG,wG],styles:["[_nghost-%COMP%]{position:relative;width:370px;min-width:370px}.container[_ngcontent-%COMP%]{width:100%;height:100%;-moz-box-sizing:border-box;box-sizing:border-box;border-left:1px solid #e1e3e1;background-color:#fff;font-size:12px;overflow-y:auto;position:relative}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]{-webkit-transition:max-height .15s ease-out;transition:max-height .15s ease-out;padding-bottom:8px;-moz-box-sizing:border-box;box-sizing:border-box}.container[_ngcontent-%COMP%]   .section.collapsed[_ngcontent-%COMP%]{max-height:32px!important;overflow:hidden}.container[_ngcontent-%COMP%]   .section.inputs[_ngcontent-%COMP%]{padding-bottom:16px}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-items-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;margin-top:10px;gap:8px}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-item[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;padding:0 2px 0 12px;font-size:12px}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-item[_ngcontent-%COMP%]   .name-row[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-item[_ngcontent-%COMP%]   .name-row.search-match[_ngcontent-%COMP%]{background-color:#f5e25a}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-item[_ngcontent-%COMP%]   .name-row[_ngcontent-%COMP%]   .index[_ngcontent-%COMP%]{color:#999;min-width:14px;margin-right:2px}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-item[_ngcontent-%COMP%]   .name-row[_ngcontent-%COMP%]   .name[_ngcontent-%COMP%]{color:#00639b;font-weight:500}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-item[_ngcontent-%COMP%]   .name-row[_ngcontent-%COMP%]   .name.locator[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-item[_ngcontent-%COMP%]   .name-row[_ngcontent-%COMP%]   .name.locator[_ngcontent-%COMP%]:hover{background-color:#f6f6f6}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-item[_ngcontent-%COMP%]   .name-row[_ngcontent-%COMP%]   .name.locator[_ngcontent-%COMP%]:hover   .locator-icon-container[_ngcontent-%COMP%]{opacity:.8}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]   .flat-item[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]{margin-top:3px;margin-left:18px;margin-right:0}.container[_ngcontent-%COMP%]   .section[_ngcontent-%COMP%]:not(:first-child){border-top:1px solid #dadce0}.container[_ngcontent-%COMP%]   .header[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;font-size:11px;font-weight:700;padding:4px 12px 0;text-transform:uppercase;letter-spacing:.0327em;position:-webkit-sticky;position:sticky;top:0;z-index:100;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;-moz-box-sizing:border-box;box-sizing:border-box;background-color:#fff;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:rgba(0,0,0,.87)}.container[_ngcontent-%COMP%]   .header.identical-groups[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .header.input[_ngcontent-%COMP%], .container[_ngcontent-%COMP%]   .header.output[_ngcontent-%COMP%]{-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.container[_ngcontent-%COMP%]   .header[_ngcontent-%COMP%]   .header-label-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .header[_ngcontent-%COMP%]   button.toggle[_ngcontent-%COMP%]{padding:0;width:24px;height:24px;margin-left:-8px;margin-right:2px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .header[_ngcontent-%COMP%]   button.toggle[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{color:inherit;font-size:20px;width:20px;height:20px}.container[_ngcontent-%COMP%]   .header[_ngcontent-%COMP%]   button.toggle[_ngcontent-%COMP%]     .mat-mdc-button-touch-target{display:none}.container[_ngcontent-%COMP%]   .output-item-container[_ngcontent-%COMP%]{font-family:Roboto,sans-serif}.container[_ngcontent-%COMP%]   .output-item-container[_ngcontent-%COMP%]:not(.last){margin-top:8px}.container[_ngcontent-%COMP%]   .output-item-label[_ngcontent-%COMP%]{font-size:13px;padding:4px 12px;color:#00639b;font-weight:500}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]{border-spacing:0;border-collapse:collapse;font-size:12px;margin:0 12px;word-break:break-all;max-width:calc(100% - 28px)}.container[_ngcontent-%COMP%]   .metadata-table.info-attrs[_ngcontent-%COMP%]{margin-left:30px}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   tr[_ngcontent-%COMP%]{vertical-align:text-top}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   tr.search-match[_ngcontent-%COMP%]{background-color:#f5e25a}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   tr[_ngcontent-%COMP%]:hover.has-hover-values{cursor:pointer;background-color:#f6f6f6}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   tr[_ngcontent-%COMP%]   mat-icon.bullet[_ngcontent-%COMP%]{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;font-size:4px;width:5px;height:5px;color:#bbb;margin-right:4px;margin-top:6px}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   td.key[_ngcontent-%COMP%]{color:#999;padding-right:6px;white-space:nowrap;min-width:100px;width:100px;max-width:100px;overflow:hidden;text-overflow:ellipsis;position:relative}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   td.key[_ngcontent-%COMP%]   .key-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:start;-webkit-align-items:flex-start;-moz-box-align:start;-ms-flex-align:start;align-items:flex-start;overflow:hidden;position:absolute;inset:0}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   td.value[_ngcontent-%COMP%]{max-width:10px;overflow:hidden;text-overflow:ellipsis;white-space:nowrap}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   td.value[_ngcontent-%COMP%]:has(expandable-info-text.expanded){white-space:normal}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   .target-node-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   .target-node-container[_ngcontent-%COMP%]:hover   .locator-icon-container[_ngcontent-%COMP%]{opacity:.8}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   .target-node-container.search-match[_ngcontent-%COMP%]{background-color:#f5e25a}.container[_ngcontent-%COMP%]   .metadata-table[_ngcontent-%COMP%]   .values-hover-trigger[_ngcontent-%COMP%]{-moz-box-sizing:border-box;box-sizing:border-box;border-radius:99px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;background-color:#d7f1ff;color:#00639b;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;height:16px;padding:0 6px;font-size:10px}.container[_ngcontent-%COMP%]   .items-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:4px;margin-top:10px;margin-bottom:6px}.container[_ngcontent-%COMP%]   .item-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;padding:0 12px}.container[_ngcontent-%COMP%]   .item-container.search-match[_ngcontent-%COMP%]{background-color:#f5e25a}.container[_ngcontent-%COMP%]   .item-container[_ngcontent-%COMP%]   .label-row[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.container[_ngcontent-%COMP%]   .item-container[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{font-weight:500;color:#aaa;font-size:12px;margin-bottom:1px}.container[_ngcontent-%COMP%]   .item-container[_ngcontent-%COMP%]   .show-on-node-toggle[_ngcontent-%COMP%]{height:16px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;font-size:11px;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;-moz-box-sizing:border-box;box-sizing:border-box;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;-webkit-transform:scale(.7);transform:scale(.7);margin-right:-6px;margin-top:-1px}.container[_ngcontent-%COMP%]   .item-container[_ngcontent-%COMP%]   .value[_ngcontent-%COMP%]{font-size:13px;word-break:break-word}.container[_ngcontent-%COMP%]   .item-container[_ngcontent-%COMP%]   .value.big-text[_ngcontent-%COMP%]{font-size:14px;font-weight:500}.container[_ngcontent-%COMP%]   .item-container[_ngcontent-%COMP%]   .value.has-bg-color[_ngcontent-%COMP%]{padding:2px 4px;border-radius:4px;margin-top:2px}.container[_ngcontent-%COMP%]   .locator-icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;opacity:.5;margin-left:4px}.container[_ngcontent-%COMP%]   .locator-icon-container.left[_ngcontent-%COMP%]{margin-right:4px;margin-left:0;display:inline-block}.container[_ngcontent-%COMP%]   .locator-icon-container.left[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{margin-bottom:-2px}.container[_ngcontent-%COMP%]   .locator-icon-container[_ngcontent-%COMP%]:hover{opacity:.8}.container[_ngcontent-%COMP%]   .locator-icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{color:#333;font-size:12px;width:12px;height:12px}.resizer[_ngcontent-%COMP%]{position:absolute;top:0;bottom:0;left:0;width:6px;cursor:ew-resize;background-color:transparent;z-index:200}.resizer.resizing[_ngcontent-%COMP%], .resizer[_ngcontent-%COMP%]:hover{background-color:rgba(0,0,0,.04)}.hide-toggle[_ngcontent-%COMP%]{position:absolute;right:100%;bottom:2px;width:16px;height:20px;border:1px solid #ccc;border-right:none;-moz-box-sizing:border-box;box-sizing:border-box;border-radius:99px;border-top-right-radius:0;border-bottom-right-radius:0;cursor:pointer;background-color:#fff}.hide-toggle[_ngcontent-%COMP%]:hover{background-color:#eee}.hide-toggle[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{width:18px;height:18px;font-size:18px;color:#999}  xap-inline-dialog-container:has(.model-explorer-const-values-popup){width:100%}  .model-explorer-const-values-popup{padding:8px;line-height:12px;background-color:#fff}  .model-explorer-const-values-popup .values-count-msg{margin-bottom:8px;color:#999;font-size:12px}  .model-explorer-const-values-popup .content{font-size:11px;white-space:pre-wrap;font-family:monospace}  .model-explorer-const-values-popup .namespace-row{font-size:12px;padding:3px 0}"],
Qa:0});const HR=["panesContainer"],IR=(a,b)=>b.label;function JR(a){a&1&&Kq(0,"mat-spinner",21)}function KR(a){a&1&&(R(0,"mat-icon"),Z(1,"check_circle"),S())}function LR(a,b){a&1&&(R(0,"div",20),yp(1,JR,1,0,"mat-spinner",21)(2,KR,2,0,"mat-icon"),R(3,"div",22),Z(4),S()());a&2&&(a=b.ca,D(),Cq(a.Tr?1:2),D(3),yr(" ",a.label," "))}function MR(a){a&1&&(R(0,"div",19),Hq(1,LR,5,2,"div",20,IR),S());if(a&2){a=Y(2).ca;const b=Y();D();Jq(b.to[a.id]||[])}}
function NR(a){a&1&&(R(0,"div",11)(1,"div",12),Kq(2,"mat-spinner",13),Z(3," Processing graph... "),S(),R(4,"div",14),Z(5," Please remain on this page while the model is being processed "),S(),R(6,"div",15)(7,"div",16),Kq(8,"div",17),S(),R(9,"div",18)(10,"mat-icon"),Z(11,"info"),S()(),yp(12,MR,3,0,"ng-template",null,1,Nr),S()());if(a&2){a=wr(13);const b=Y().ca,c=Y();H("@hideProcessingPanel",void 0)("@.disabled",c.Gv);D(8);jq("width",OR(c,b.id),"%");D();H("xapInlineDialog",a)("hoverDelayMs",100)}}
function PR(a){if(a&1){const b=Tg();R(0,"div",23)(1,"div",24);Z(2);S();R(3,"div",25)(4,"div",26);V("click",function(){u(b);const c=Y(2);yJ(c.ne);return x()})("mousedown",function(c){u(b);return x(c.stopPropagation())});R(5,"mat-icon");Z(6,"swap_horiz");S()();R(7,"div",27);V("click",function(){u(b);const c=Y().ca,d=Y();xJ(d.ne,c.id);return x()})("mousedown",function(c){u(b);return x(c.stopPropagation())});R(8,"mat-icon");Z(9,"close");S()()()()}a&2&&(a=Y().ca,Y(),D(2),yr(" ",QR(a)," "))}
function RR(a){a&1&&Kq(0,"graph-panel",28);if(a&2){a=Y().ca;const b=Y();H("@showModelGraph",void 0)("@.disabled",b.Gv)("modelGraph",a.modelGraph)("paneId",a.id)("rendererId",a.id)}}function SR(a){a&1&&Kq(0,"info-panel",10);a&2&&(a=Y().ca,H("paneId",a.id))}
function TR(a,b){a&1&&(R(0,"div",5),yp(1,NR,14,6,"div",6)(2,PR,10,1,"div",7),R(3,"div",8),yp(4,RR,1,5,"graph-panel",9)(5,SR,1,1,"info-panel",10),S()());if(a&2){a=b.ca;b=b.index;const c=Y();jq("width",100*(0===b?c.aj:1-c.aj),"%");lq("selected",a.id===c.ne.G());Ip("data-pane-id",a.id);D();H("ngIf",!a.modelGraph);D();H("ngIf",c.dw);D(2);H("ngIf",a.modelGraph);D();Cq(c.aE?5:-1)}}
function UR(a){if(a&1){const b=Tg();R(0,"div",29);V("mousedown",function(c){u(b);const d=Y(),e=wr(1);return x(d.Pq(c,e))});Kq(1,"div",30);S()}a&2&&(a=Y(),jq("left",a.ID))}function OR(a,b){return(a=a.to[b])?a.filter(c=>!c.Tr).length/a.length*100:0}function QR(a){return(a=a.modelGraph)?`${a.collectionLabel} | ${a.id}`:"-"}function VR(a,b){var c=b.paneId;fJ(a.ne,c)&&(c=a.to[c].find(d=>d.label===b.label),null!=c&&(c.Tr=!1,$m(a.i)))}
var WR=class{constructor(a,b,c){this.i=a;this.ne=b;this.C=c;this.to={};this.aj=1;this.Ma=this.ne.Ma;Gs(()=>{const d=this.Ma();1<=d.length&&(this.aj=d[0].widthFraction);for(const e of d)e.modelGraph||(this.to[e.id]=GI.map(f=>({label:f,Tr:!0})));$m(this.i)});this.C.i.addEventListener("message",d=>{switch(d.data.eventType){case 8:VR(this,d.data)}})}nd(){this.qD.P.addEventListener("mousedown",a=>{(a=a.target.closest(".pane-container"))&&bJ(this.ne,a.dataset.paneId||"")},!0)}Pq(a,b){a.preventDefault();
document.body.style.cursor="ew-resize";const c=jk(document,"mousemove"),d=jk(window,"mouseup"),e=this.ne.Ma()[0].widthFraction,f=b.offsetWidth,g=f*e,k=a.clientX;Zm(this.i);C(Nj([c]),Jo(d)).subscribe({next:([m])=>{this.aj=Math.min(f-200,Math.max(200,g+(m.clientX-k)))/f;Zm(this.i)},complete:()=>{document.body.style.cursor="default";sJ(this.ne,this.aj);Zm(this.i)}})}AE(a,b){return b.id}get dw(){return 1<this.ne.Ma().length}get ID(){return`calc(${100*this.aj}% - 5px)`}get aE(){let a;return!(null==(a=
this.ne.config())?0:a.hideInfoPanel)}get Gv(){return this.ne.i}};WR.J=function(a){return new (a||WR)(y(Pr),y(NJ),y(UI))};
WR.Ca=Gf({type:WR,ga:[["split-panes-container"]],eb:function(a,b){a&1&&rr(HR,5);if(a&2){let c;sr(c=tr())&&(b.qD=c.first)}},ja:!0,features:[Jr],ya:4,za:3,Ba:[["panesContainer",""],["progressPopup",""],[1,"container"],["class","pane-container",3,"selected","width",4,"ngFor","ngForOf","ngForTrackBy"],["class","resizer split-pane",3,"left","mousedown",4,"ngIf"],[1,"pane-container"],["class","loading",4,"ngIf"],["class","pane-title-container",4,"ngIf"],[1,"pane-content"],[3,"modelGraph","paneId","rendererId",
4,"ngIf"],[3,"paneId"],[1,"loading"],[1,"processing-msg-container"],["color","primary","diameter","18"],[1,"stay-on-page-info"],[1,"progress-bar-wrapper"],[1,"progress-bar-container"],[1,"progress-bar-body"],["dialogLabel","progress details",1,"icon-container",3,"xapInlineDialog","hoverDelayMs"],[1,"model-explorer-processing-tasks-container"],[1,"processing-task-container"],["color","primary","diameter","16"],[1,"task-label"],[1,"pane-title-container"],[1,"pane-title"],[1,"buttons-container"],["matTooltip",
"Swap pane",1,"icon-container","swap",3,"click","mousedown"],["matTooltip","Close pane",1,"icon-container","close",3,"click","mousedown"],[3,"modelGraph","paneId","rendererId"],[1,"resizer","split-pane",3,"mousedown"],[1,"resizer-line"]],sa:function(a,b){a&1&&(R(0,"div",2,0),yp(2,TR,6,9,"div",3)(3,UR,2,2,"div",4),S());a&2&&(D(2),H("ngForOf",b.Ma())("ngForTrackBy",b.AE),D(),H("ngIf",b.dw))},Ga:[et,Ws,$s,xP,pD,oD,lD,$F,tE,YF,GR,aI,$H,zG,wG],styles:[".container[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;position:relative;width:100%;height:100%}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]{position:relative;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .pane-title-container[_ngcontent-%COMP%]{height:24px;-moz-box-sizing:border-box;box-sizing:border-box;background-color:#eee;padding:0 12px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;font-size:12px;color:#999;cursor:pointer;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .pane-title-container[_ngcontent-%COMP%]   .buttons-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .pane-title-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;cursor:pointer;color:#999;opacity:.8;margin-left:6px}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .pane-title-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:1}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .pane-title-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:18px;height:18px;width:18px}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .pane-content[_ngcontent-%COMP%]{width:100%;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;overflow:hidden}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .pane-content[_ngcontent-%COMP%]   graph-panel[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.container[_ngcontent-%COMP%]   .pane-container.selected[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{color:#fff}.container[_ngcontent-%COMP%]   .pane-container.selected[_ngcontent-%COMP%]   .pane-title-container[_ngcontent-%COMP%]{background-color:#ea8600;color:#fff}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]{position:absolute;top:0;left:0;width:100%;height:100%;z-index:150;color:#999;background-color:#fff;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .processing-msg-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .processing-msg-container[_ngcontent-%COMP%]   mat-spinner[_ngcontent-%COMP%]{margin-right:8px}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .progress-bar-wrapper[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;margin-top:18px;margin-right:-30px}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .progress-bar-wrapper[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{cursor:pointer;opacity:.8;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .progress-bar-wrapper[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:1}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .progress-bar-wrapper[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{color:#ccc;font-size:18px;width:18px;height:18px;margin-left:6px}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .progress-bar-container[_ngcontent-%COMP%]{height:7px;width:280px;border:1px solid #ccc;border-radius:99px;-moz-box-sizing:border-box;box-sizing:border-box;overflow:hidden}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .progress-bar-container[_ngcontent-%COMP%]   .progress-bar-body[_ngcontent-%COMP%]{height:100%;-webkit-transition:width .1s;transition:width .1s;background-color:#ccc}.container[_ngcontent-%COMP%]   .pane-container[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .stay-on-page-info[_ngcontent-%COMP%]{font-size:12px;width:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;margin-top:4px}.container[_ngcontent-%COMP%]   .resizer[_ngcontent-%COMP%]{height:100%;width:10px;top:0;left:50%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;position:absolute;padding-left:1px;cursor:ew-resize;z-index:200}.container[_ngcontent-%COMP%]   .resizer[_ngcontent-%COMP%]:hover{background-color:rgba(0,0,0,.04)}.container[_ngcontent-%COMP%]   .resizer[_ngcontent-%COMP%]:hover   .resizer-line[_ngcontent-%COMP%]{border-color:#fcc986}.container[_ngcontent-%COMP%]   .resizer[_ngcontent-%COMP%]   .resizer-line[_ngcontent-%COMP%]{height:100%;width:1px;border-left:1px solid #999}  .model-explorer-processing-tasks-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;padding:12px}  .model-explorer-processing-tasks-container .processing-task-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;font-size:13px;margin:2px 0}  .model-explorer-processing-tasks-container .processing-task-container mat-spinner{margin-right:8px;width:16px}  .model-explorer-processing-tasks-container .processing-task-container mat-icon{color:#0a0;font-size:16px;width:16px;height:16px;margin-right:8px}"],
data:{animation:[Ry("hideProcessingPanel",[Vy("* => void",Sy("150ms 100ms ease-out",Ty({opacity:0,transform:"scale(0.95, 0.95)"})))]),Ry("showModelGraph",[Uy("void",Ty({opacity:0,transform:"scale(1.03, 1.03)"})),Vy("void => *",Sy("150ms 100ms ease-out",Ty({opacity:1,transform:"scale(1, 1)"})))])]},Qa:0});function YR(a){a&1&&(R(0,"mat-icon",15),Z(1," turn_left "),S())}function ZR(a){if(a&1){const b=Tg();R(0,"div",16);V("click",function(c){u(b);const d=Y().ca,e=Y(2);return x(e.Jq(c,d))});R(1,"div",17);Kq(2,"div",18);S()()}}
function $R(a,b){if(a&1){const c=Tg();R(0,"div",7)(1,"div",8)(2,"div",9);V("click",function(){const d=u(c).ca,e=Y(2);e.ge.next({});e.dk="";e.qj=!1;iJ(e.uf,d.graph);e.uf.K.set(void 0);oJ(e.uf,e.uf.G());e.uf.F.set(void 0);kJ(e.uf,!1);return x()});R(3,"div",10);yp(4,YR,2,0,"mat-icon",11);R(5,"div",12);Z(6);S()();R(7,"div",13);Z(8);S()();yp(9,ZR,3,0,"div",14);S()()}a&2&&(a=b.ca,b=Y(2),Ip("data-id",a.id),D(),jq("padding-left",aS(b,a),"px"),lq("selected",a.id===b.selectedGraphId()),D(3),H("ngIf",bS(b,a)),
D(2),yr(" ",a.id," "),D(2),yr(" ",cS(a.yr)," "),D(),H("ngIf",b.us))}function dS(a,b){a&1&&(R(0,"div",4)(1,"div",5),Z(2),S(),yp(3,$R,10,9,"div",6),S());a&2&&(a=b.ca,b=Y(),D(2),yr(" ",a.label," "),D(),H("ngForOf",a.graphs)("ngForTrackBy",b.yE))}function aS(a,b){if(a.qj)return 24;let c;return 24+12*(null!=(c=b.graph.level)?c:0)}function bS(a,b){let c;return!a.qj&&0<(null!=(c=b.graph.level)?c:0)}function cS(a){return`${a} node${1===a?"":"s"}`}
var eS=class{constructor(a){this.uf=a;this.Jh=[];this.ge=new Dk;this.qj=!1;this.selectedGraphId=ys(()=>{const b=jJ(this.uf);return b&&b.modelGraph?b.modelGraph.id:""});this.dk=""}Nq(a){this.dk=a.toLowerCase()}Jq(a,b){a.stopPropagation();this.ge.next({});this.dk="";this.qj=!1;$I(this.uf,b.graph)}xE(a){return`${a}`}yE(a,b){return`${b.graph.collectionLabel}___${b.graph.id}`}get qB(){const a=[];this.qj=!1;for(const {label:b,collection:c,graphs:d}of this.Jh){const e={label:b,collection:c,graphs:[]};for(const f of d)""===
this.dk||f.id.toLowerCase().includes(this.dk)?e.graphs.push(f):this.qj=!0;0<e.graphs.length&&a.push(e)}return a}get us(){return 1===this.uf.Ma().length}};eS.J=function(a){return new (a||eS)(y(NJ))};
eS.Ca=Gf({type:eS,ga:[["graph-selector-panel"]],inputs:{Jh:"graphCollectionItems"},outputs:{ge:"onClose"},ja:!0,features:[Jr],ya:4,za:3,Ba:[["input",""],[1,"container"],["placeholder","Filter graphs",3,"input"],["class","collection-container",4,"ngFor","ngForOf","ngForTrackBy"],[1,"collection-container"],[1,"collection-label"],["class","graph-item-container",4,"ngFor","ngForOf","ngForTrackBy"],[1,"graph-item-container"],[1,"graph-item"],[1,"graph-info-wrapper",3,"click"],[1,"graph-label-wrapper"],
["class","indent-symbol",4,"ngIf"],[1,"graph-label"],[1,"node-count-label"],["class","action-button","matTooltip","Open in split pane","matTooltipPosition","right",3,"click",4,"ngIf"],[1,"indent-symbol"],["matTooltip","Open in split pane","matTooltipPosition","right",1,"action-button",3,"click"],[1,"block-container"],[1,"right-block"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",1)(1,"input",2,0);V("input",function(){u(c);const d=wr(2);return x(b.Nq(d.value))});S();yp(3,dS,4,3,"div",3);S()}a&
2&&(H("@transformPanel","showing"),D(3),H("ngForOf",b.qB)("ngForTrackBy",b.xE))},Ga:[et,Ws,$s,$F,tE,YF,WA,aI,$H,ID,wx],styles:[".container[_ngcontent-%COMP%]{box-shadow:0 3px 5px -1px rgba(0,0,0,.2),0 6px 10px 0 rgba(0,0,0,.14),0 1px 18px 0 rgba(0,0,0,.12);-webkit-transform-origin:top center;transform-origin:top center;font-size:12px;padding:8px 0;border-radius:4px;border-top-left-radius:0;border-top-right-radius:0;max-height:100%;overflow-y:auto}.container[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]{font-size:12px;margin:4px 10px;width:calc(100% - 20px);-moz-box-sizing:border-box;box-sizing:border-box;pointer-events:all;border:1px solid #ccc;height:20px;border-radius:4px;padding:0 2px}.container[_ngcontent-%COMP%]   .collection-container[_ngcontent-%COMP%]   .collection-label[_ngcontent-%COMP%]{font-weight:700;padding:4px 12px}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;padding:4px 12px 4px 24px;cursor:pointer}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]:hover{background-color:rgba(0,0,0,.04)}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item.selected[_ngcontent-%COMP%]{background-color:#c2e7ff}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]   .graph-info-wrapper[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]   .graph-label-wrapper[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]   .indent-symbol[_ngcontent-%COMP%]{font-size:16px;width:16px;height:16px;color:#999;margin-right:4px;-webkit-transform:rotate(-180deg);transform:rotate(-180deg)}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]   .graph-label[_ngcontent-%COMP%]{overflow:hidden;white-space:nowrap;text-overflow:ellipsis}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]   .node-count-label[_ngcontent-%COMP%]{color:#999;margin-left:12px}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]   .action-button[_ngcontent-%COMP%]{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;width:16px;height:16px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;margin-left:6px;opacity:.8;cursor:pointer}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]   .action-button[_ngcontent-%COMP%]:hover{opacity:1}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]   .action-button[_ngcontent-%COMP%]   .block-container[_ngcontent-%COMP%]{border-radius:3px;border:1px solid #999;height:100%;width:100%;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:end;-webkit-justify-content:flex-end;-moz-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;padding:1px}.container[_ngcontent-%COMP%]   .graph-item-container[_ngcontent-%COMP%]   .graph-item[_ngcontent-%COMP%]   .action-button[_ngcontent-%COMP%]   .block-container[_ngcontent-%COMP%]   .right-block[_ngcontent-%COMP%]{height:100%;width:50%;background-color:#999;border-top-right-radius:2px;border-bottom-right-radius:2px}"],
data:{animation:PJ},Qa:0});const fS=["input"];function gS(a){a&1&&(R(0,"div",15),Z(1),S());a&2&&(a=Y(),D(),yr(" ",a.Fx," nodes "))}function hS(a){if(a&1){const b=Tg();R(0,"mat-optgroup",16)(1,"mat-option")(2,"input",17,1);V("click",function(c){u(b);return x(c.stopPropagation())})("keydown.space",function(c){u(b);return x(c.stopPropagation())})("input",function(){u(b);const c=wr(3),d=Y();return x(d.Nq(c.value))});S()()()}}
function iS(a){if(a&1){const b=Tg();R(0,"div",24);V("click",function(c){u(b);const d=Y().ca,e=Y(2);return x(e.Jq(c,d))});R(1,"div",25);Kq(2,"div",26);S()()}}function jS(a,b){a&1&&(R(0,"mat-option",20)(1,"div",21)(2,"div",22)(3,"div",7),Z(4),S(),R(5,"div",15),Z(6),S()(),yp(7,iS,3,0,"div",23),S()());a&2&&(a=b.ca,b=Y(2),lq("selected",a.graph===b.Xf.value),H("value",a.graph),Ip("data-id",a.id),D(4),xr(a.id),D(2),yr(" ",a.yr," nodes "),D(),H("ngIf",b.us))}
function kS(a,b){a&1&&(R(0,"mat-optgroup",18),yp(1,jS,8,7,"mat-option",19),S());a&2&&(a=b.ca,H("label",a.label),D(),H("ngForOf",a.graphs))}const lS=new OffscreenCanvas(500,300),mS={};function nS(a,b=12,c=!1){var d=mS[a];null==d&&(d=lS.getContext("2d"),d.font=`${b}px "Google Sans Text", Arial, Helvetica, sans-serif`,c&&(d.font=`bold ${d.font}`),b=d.measureText(a).width,d=mS[a]=b);return d}
function oS(a,b){let c=!1;for(const d of a.Jh()){for(const e of d.graphs)if(e.graph.id===b){a.Fx=e.yr;a.os=d.label;a.Ex=d.collection;a.Xf.setValue(e.graph);c=!0;break}if(c)break}}function pS(a,b){b=new xu({sc:Hu(Lv(a.i.position(),b),[{bb:"end",cb:"bottom",La:"end",Sa:"top"}]),maxHeight:"calc(100% - 70px)",Sb:!0,bc:"cdk-overlay-transparent-backdrop",tc:a.i.i.i(),gb:"graph-selector-panel"});const c=a.i.create(b);a.Jd=new Ov(eS,a.wb);c.bd().subscribe(()=>{c.dispose()});return c}
function qS(a,b){const c=pS(a,b);b=c.attach(a.Jd);b.instance.Jh=a.Jh();b.instance.ge.subscribe(()=>{c.dispose()})}
var rS=class{constructor(a,b,c){this.Td=a;this.i=b;this.wb=c;this.Xf=new px;this.Fx=0;this.os="";this.Jh=ys(()=>{var d=this.Td.config();if(!d)return[];var e=this.Td.N();this.nodeLabelsToHide=new Set((d.nodeLabelsToHide||[]).map(g=>g.toLowerCase()));d=[];const f=this.So().toLowerCase();for(const g of e){e={label:g.label,collection:g,graphs:[]};for(const k of g.graphs){if(""!==f&&!k.id.toLowerCase().includes(f))continue;const m=k.nodes.filter(t=>!this.nodeLabelsToHide.has(t.label.toLowerCase())).length,
p=nS(` ${k.id}    ${m} nodes`)+30;e.graphs.push({id:k.id,graph:k,yr:m,width:p})}0<e.graphs.length&&(d.push(e),nS(g.label,12,!0))}return d});this.VB=ys(()=>{let d=0;const e=this.Td.N();for(const f of e)d+=f.graphs.length;return d});this.nodeLabelsToHide=new Set;this.So=ur("");this.Jd=null;this.selectedGraphId=ys(()=>{const d=jJ(this.Td);return d&&d.modelGraph?d.modelGraph.id:""});Gs(()=>{const d=this.selectedGraphId();d&&oS(this,d)})}Nq(a){this.So.set(a)}Jq(a,b){a.stopPropagation();this.SC.close();
$I(this.Td,b.graph)}get us(){return 1===this.Td.Ma().length}};rS.J=function(a){return new (a||rS)(y(NJ),y(Wv),y(ip))};
rS.Ca=Gf({type:rS,ga:[["graph-selector"]],eb:function(a,b){a&1&&(rr(HD,5),rr(fS,5));if(a&2){let c;sr(c=tr())&&(b.SC=c.first);sr(c=tr())&&(b.NB=c.first)}},ja:!0,features:[Jr],ya:21,za:6,Ba:[["selector",""],["input",""],[1,"container"],[1,"collection-label"],[1,"graph-selector-label",3,"click"],[1,"selector-label-container"],[1,"selector-label-content"],[1,"option-label"],["class","node-count-label",4,"ngIf"],[1,"triangle"],["matTooltip","Download processed graphs json",1,"mat-icon-container",3,"click"],
[1,"select-form"],["color","primary","panelClass","graph-selector-panel",3,"selectionChange","openedChange","formControl"],["class","graph-search-optgroup",4,"ngIf"],[3,"label",4,"ngFor","ngForOf"],[1,"node-count-label"],[1,"graph-search-optgroup"],["placeholder","Filter graphs",3,"click","keydown.space","input"],[3,"label"],[3,"selected","value",4,"ngFor","ngForOf"],[3,"value"],[1,"option-wrapper"],[1,"option-container"],["class","action-button","matTooltip","Open in split pane","matTooltipPosition",
"right",3,"click",4,"ngIf"],["matTooltip","Open in split pane","matTooltipPosition","right",1,"action-button",3,"click"],[1,"block-container"],[1,"right-block"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",2)(1,"div",3);Z(2);S();R(3,"div",4,0);V("click",function(){u(c);const d=wr(4);return x(qS(b,d))});R(5,"div",5)(6,"div",6)(7,"div",7);Z(8);S();yp(9,gS,2,1,"div",8);S();R(10,"div",9);Z(11,"\u25bc");S()()();R(12,"div",10);V("click",function(){u(c);if(null!=b.Ex){var d=document.createElement("a");
d.download=`${b.os}.json`;var e=`data:text/json;charset=utf-8, ${encodeURIComponent(JSON.stringify(b.Ex,null,2))}`;ud(d,rd(e));d.click()}return x()});R(13,"mat-icon");Z(14,"download");S()();R(15,"mat-form-field",11)(16,"mat-label");Z(17,"Select an option");S();R(18,"mat-select",12);V("selectionChange",function(){u(c);b.Xf.value&&(oS(b,b.Xf.value.id),iJ(b.Td,b.Xf.value),b.Td.K.set(void 0),oJ(b.Td,b.Td.G()),b.Td.F.set(void 0),kJ(b.Td,!1));return x()})("openedChange",function(d){u(c);d||(b.NB.P.value=
"",b.So.set(""));return x()});yp(19,hS,4,0,"mat-optgroup",13)(20,kS,2,2,"mat-optgroup",14);S()()()}a&2&&(D(2),yr(" ",b.os," "),D(6),xr((null==b.Xf.value?null:b.Xf.value.id)||"-"),D(),H("ngIf",b.Xf.value),D(9),H("formControl",b.Xf),D(),H("ngIf",1<b.VB()),D(),H("ngForOf",b.Jh()))},Ga:[et,Ws,$s,$F,tE,YF,WA,VA,jA,aI,$H,ID,HD,Oz,oz,wx,Gw,rx],styles:[".container[_ngcontent-%COMP%]{font-size:12px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;line-height:14px;position:relative}.container[_ngcontent-%COMP%]   .collection-label[_ngcontent-%COMP%]{font-weight:700;margin-right:6px}.container[_ngcontent-%COMP%]   .select-form[_ngcontent-%COMP%]{height:0;max-height:0;position:absolute;top:26px;right:28px}.container[_ngcontent-%COMP%]   .select-form[_ngcontent-%COMP%]    >*{height:0}.container[_ngcontent-%COMP%]   .selector-label-content[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.container[_ngcontent-%COMP%]   .option-label[_ngcontent-%COMP%]{overflow:hidden;white-space:nowrap;text-overflow:ellipsis;margin-right:2px}.container[_ngcontent-%COMP%]   .node-count-label[_ngcontent-%COMP%]{color:#999;margin-left:12px}.container[_ngcontent-%COMP%]   .triangle[_ngcontent-%COMP%]{font-size:10px;margin-left:8px}.container[_ngcontent-%COMP%]   .graph-selector-label[_ngcontent-%COMP%]{font-size:12px;border:1px solid #aaa;border-radius:3px;padding:2px 4px;cursor:pointer;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;height:24px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-moz-box-sizing:border-box;box-sizing:border-box}.container[_ngcontent-%COMP%]   .graph-selector-label[_ngcontent-%COMP%]   .selector-label-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.container[_ngcontent-%COMP%]   .graph-selector-label[_ngcontent-%COMP%]:hover{border-color:#ea8600}.container[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;margin-left:4px;cursor:pointer;opacity:.6}.container[_ngcontent-%COMP%]   .mat-icon-container[_ngcontent-%COMP%]:hover{opacity:1}  .graph-selector-panel{background-color:#fff}  .graph-selector-panel mat-option{height:24px;font-size:12px;min-height:unset;padding:1px 0;padding-left:20px!important;background-color:none!important}  .graph-selector-panel mat-option .option-wrapper{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}  .graph-selector-panel mat-option .option-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;letter-spacing:normal;font-family:Google Sans Text,Arial,Helvetica,sans-serif;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}  .graph-selector-panel mat-option .option-container .option-label{overflow:hidden;white-space:nowrap;text-overflow:ellipsis;color:#000!important}  .graph-selector-panel mat-option .option-container .node-count-label{color:#999}  .graph-selector-panel mat-option .action-button{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;width:16px;height:16px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;margin-left:4px;opacity:.8;cursor:pointer}  .graph-selector-panel mat-option .action-button:hover{opacity:1}  .graph-selector-panel mat-option .action-button .block-container{border-radius:3px;border:1px solid #999;height:100%;width:100%;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:end;-webkit-justify-content:flex-end;-moz-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;padding:1px}  .graph-selector-panel mat-option .action-button .block-container .right-block{height:100%;width:50%;background-color:#999;border-top-right-radius:2px;border-bottom-right-radius:2px}  .graph-selector-panel mat-option span{white-space:break-spaces!important;word-break:break-all;line-height:14px!important;width:100%;-moz-box-sizing:border-box;box-sizing:border-box;padding-right:10px}  .graph-selector-panel mat-option mat-pseudo-checkbox{display:none}  .graph-selector-panel mat-option.selected{background-color:#fff1de!important}  .graph-selector-panel mat-optgroup span{min-height:unset;font-size:12px;font-weight:700;padding-left:8px}  .graph-selector-panel mat-optgroup.graph-search-optgroup{pointer-events:none}  .graph-selector-panel mat-optgroup.graph-search-optgroup span{padding:0}  .graph-selector-panel mat-optgroup.graph-search-optgroup mat-option{padding-left:16px!important;padding-right:12px!important;height:28px}  .graph-selector-panel mat-optgroup.graph-search-optgroup input{font-size:12px;width:100%;-moz-box-sizing:border-box;box-sizing:border-box;pointer-events:all;border:1px solid #ccc;height:20px;border-radius:4px;padding:0 2px}"],
Qa:0});function sS(a){a&1&&(R(0,"div",2),Z(1," Model Explorer "),R(2,"span",3),Z(3),S(),Z(4," is available. You are running "),R(5,"span",3),Z(6),S(),Z(7,". "),Kq(8,"br")(9,"br"),Z(10," Run the following command in your console to upgrade: "),R(11,"div",4),Z(12," pip install -U ai-edge-model-explorer "),S()());a&2&&(a=Y(2),D(3),yr("v",a.info().version,""),D(3),yr("v",a.info().runningVersion,""))}
function tS(a){a&1&&(R(0,"div",1)(1,"mat-icon"),Z(2,"upgrade"),S(),Z(3," New version available "),S(),yp(4,sS,13,2,"ng-template",null,0,Nr));a&2&&(a=wr(5),H("xapInlineDialog",a)("hoverDelayMs",100))}function uS(a){sa(function*(){try{const b=yield fetch("/api/v1/check_new_version");if(b.ok){const c=yield b.json();a.info.set(c)}}catch(b){}})}var vS=class{constructor(){this.info=ur({version:"",runningVersion:""});uS(this)}};vS.J=function(a){return new (a||vS)};vS.oa=Ld({la:vS,aa:vS.J,da:"root"});
var wS=class{constructor(a){this.i=a;this.info=this.i.info}};wS.J=function(a){return new (a||wS)(y(vS))};wS.Ca=Gf({type:wS,ga:[["new-version-chip"]],ja:!0,features:[Jr],ya:1,za:1,Ba:[["upgrade",""],["dialogLabel","upgrade",1,"container",3,"xapInlineDialog","hoverDelayMs"],[1,"model-explorer-upgrade-popup"],[1,"bold"],[1,"code"]],sa:function(a,b){a&1&&yp(0,tS,6,2);a&2&&Cq(""!==b.info().version?0:-1)},Ga:[et,aI,$H,zG,wG],styles:[".container[_ngcontent-%COMP%] {\n  font-size: 12px;\n  display: flex;\n  align-items: center;\n  color: #ab6c17;\n  background-color: #ffefd9;\n  line-height: 18px;\n  border-radius: 99px;\n  font-weight: 500;\n  padding: 2px 10px 2px 4px;\n  cursor: pointer;\n\n  mat-icon {\n    font-size: 16px;\n    width: 16px;\n    height: 16px;\n  }\n}\n\n  .model-explorer-upgrade-popup {\n  padding: 8px;\n  font-size: 12px;\n  background-color: white;\n  line-height: normal;\n\n  .bold {\n    font-weight: 500;\n  }\n\n  .code {\n    background-color: #f1f1f1;\n    font-family: monospace;\n    margin-top: 8px;\n    padding: 4px;\n    font-size: 11px;\n  }\n}"]});function xS(a){a&1&&Kq(0,"mat-spinner",6)}function yS(a){a&1&&(R(0,"mat-icon"),Z(1,"add_circle_outline"),S())}function zS(a){a&1&&(R(0,"div",8),Z(1," Add custom data and styles to the nodes in the current model "),S())}
function AS(a){if(a&1){const b=Tg();R(0,"div",16)(1,"div",17);Z(2,"OR");S()();R(3,"div",18)(4,"div",13);Z(5,"From CNS");S();R(6,"textarea",19,3);V("focus",function(){u(b);const c=wr(7);return x(c.select())})("input",function(){u(b);const c=Y(2);Zm(c.ez);return x()})("change",function(){u(b);const c=wr(7),d=Y(2);HI("extension_dropdown_json_cns_path",c.value);d.Wq=c.value;return x()});S();R(8,"button",20);V("click",function(){u(b);const c=wr(7),d=Y(2);return x(BS(d,c))});Z(9);S()()}if(a&2){a=wr(7);
const b=Y(2);D(6);H("value",b.Wq);D(2);H("disabled",CS(b,a));D();yr(" ",b.di()?"Loading...":"Load"," ")}}
function DS(a){if(a&1){const b=Tg();R(0,"div",9)(1,"div",10)(2,"div");Z(3,"Load json data file");S();R(4,"a",11);Z(5," Guide ");S()();R(6,"div",12)(7,"div",13);Z(8,"From computer");S();R(9,"button",14);V("click",function(){u(b);const c=wr(12);return x(c.click())});Z(10," Upload ");S()();R(11,"input",15,2);V("change",function(){u(b);const c=wr(12),d=Y();return x(d.Kq(c))});S();yp(13,AS,10,3);S()}a&2&&(a=Y(),D(13),Cq(a.de?13:-1))}
function BS(a,b){return sa(function*(){const c=pJ(a.C);if(c){var d=b.value.trim();yield wL(a.i,d,c);var e;null==(e=a.Jv)||jG(e)}})}function CS(a,b){b=b.value.trim();return a.di()||""===b||!b.startsWith("/cns")||!b.endsWith(".json")}
var ES=class{constructor(a,b,c,d){this.C=a;this.ez=b;this.i=d;this.extensions=[];this.Bw=!0;this.Wq="";this.fd={minWidth:0,minHeight:0};this.FB={minWidth:0,minHeight:0,maxHeight:500};this.di=this.i.di;this.Wq=window.localStorage.getItem("extension_dropdown_json_cns_path")||""}Kq(a){var b=a.files;if(b){var c=pJ(this.C);if(c){for(const d of b)b=new FileReader,b.onload=e=>{const f=lI();try{let k;var g=null==(k=e.target)?void 0:k.result;const m=JSON.parse(g);e={};null!=m.results&&null==m.results.results?
c&&(e[c.id]=m):e=m;tL(this.i,f,d.name,c,e)}catch(k){tL(this.i,f,d.name,c),uL(this.i,f,{[c.id]:{results:{}}},c,`Failed to process JSON file. ${k}`)}finally{let k;null==(k=this.Jv)||jG(k)}},b.readAsText(d);a.value=""}}}get de(){return!1}};ES.J=function(a){return new (a||ES)(y(NJ),y(Pr),y(II),y(CL))};
ES.Ca=Gf({type:ES,ga:[["node-data-provider-dropdown"]],eb:function(a,b){a&1&&rr(yG,5);if(a&2){let c;sr(c=tr())&&(b.Jv=c.first)}},ja:!0,features:[Jr],ya:10,za:6,Ba:[["help",""],["dropdown",""],["input",""],["textarea",""],["dialogLabel","help",1,"container",3,"xapInlineDialog","overlaySize","hoverDelayMs"],["dialogLabel","dropdown",1,"icon-container",3,"xapInlineDialogClick","overlaySize"],["color","primary","diameter","18"],[1,"label"],[1,"model-explorer-help-popup"],[1,"model-explorer-node-data-provider-dropdown"],
[1,"section-label","upload"],["href","https://github.com/google-ai-edge/model-explorer/wiki/2.-User-Guide#custom-node-data","target","_blank"],[1,"upload-container"],[1,"description"],["mat-flat-button","","color","primary",1,"upload-json-file-button","upload",3,"click"],["type","file","multiple","","accept",".json",1,"upload-per-node-data-input",3,"change"],[1,"or-divider"],[1,"or-label"],[1,"load-json-from-cns-container"],[3,"focus","input","change","value"],["mat-flat-button","","color","primary",
1,"upload-json-file-button",3,"click","disabled"]],sa:function(a,b){a&1&&(R(0,"div",4)(1,"div",5),yp(2,xS,1,0,"mat-spinner",6)(3,yS,2,0,"mat-icon"),R(4,"span",7),Z(5,"Add per-node data"),S()()(),yp(6,zS,2,0,"ng-template",null,0,Nr)(8,DS,14,1,"ng-template",null,1,Nr));if(a&2){a=wr(7);const c=wr(9);H("xapInlineDialog",a)("overlaySize",b.fd)("hoverDelayMs",10);D();H("xapInlineDialogClick",c)("overlaySize",b.FB);D();Cq(b.di()?2:3)}},Ga:[et,uB,tB,oB,pD,oD,lD,aI,$H,ZF,zG,wG,yG],styles:[".container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;cursor:pointer;color:#666;padding-bottom:12px;margin-bottom:-12px}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{margin-right:4px}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-spinner[_ngcontent-%COMP%]{margin-right:6px}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{font-size:13px}.container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{color:#444}  .model-explorer-node-data-provider-dropdown{font-size:12px;background-color:#fff;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;padding-bottom:8px}  .model-explorer-node-data-provider-dropdown .section-label{padding:8px 12px;font-size:11px;background:#f1f1f1;font-weight:500;text-transform:uppercase}  .model-explorer-node-data-provider-dropdown .section-label .address-container{text-transform:none;font-weight:400;letter-spacing:normal;color:#777;line-height:12px;padding-bottom:5px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:start;-webkit-align-items:flex-start;-moz-box-align:start;-ms-flex-align:start;align-items:flex-start;margin-top:-4px;margin-left:-2px}  .model-explorer-node-data-provider-dropdown .section-label .address-container .address-label{overflow:hidden;line-break:anywhere;line-height:12px;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;padding-top:3px}  .model-explorer-node-data-provider-dropdown .section-label .address-container .settings-icon-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;margin-right:4px;pointer-events:all;cursor:pointer;opacity:.7}  .model-explorer-node-data-provider-dropdown .section-label .address-container .settings-icon-container:hover{opacity:1}  .model-explorer-node-data-provider-dropdown .section-label .address-container .settings-icon-container mat-icon{font-size:16px;width:16px;height:16px}  .model-explorer-node-data-provider-dropdown .section-label.upload{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;min-width:180px}  .model-explorer-node-data-provider-dropdown .section-label.upload a{font-size:11px;letter-spacing:normal;text-transform:none;pointer-events:all}  .model-explorer-node-data-provider-dropdown .description{font-size:12px;color:#777;line-height:18px;letter-spacing:normal}  .model-explorer-node-data-provider-dropdown .upload-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:start;-webkit-align-items:flex-start;-moz-box-align:start;-ms-flex-align:start;align-items:flex-start;padding:0 16px;margin-top:12px}  .model-explorer-node-data-provider-dropdown .load-json-from-cns-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:start;-webkit-align-items:flex-start;-moz-box-align:start;-ms-flex-align:start;align-items:flex-start;padding:0 16px;margin-top:10px;width:200px;-moz-box-sizing:border-box;box-sizing:border-box}  .model-explorer-node-data-provider-dropdown .load-json-from-cns-container textarea{width:100%;height:48px;-moz-box-sizing:border-box;box-sizing:border-box;margin:2px 0;resize:none;border-radius:3px;font-family:Google Sans Text,Google Sans,Arial,Helvetica,sans-serif;font-size:11px;padding:2px}  .model-explorer-node-data-provider-dropdown .upload-json-file-button{margin:4px 0;width:90px;height:30px;font-size:12px!important;letter-spacing:normal!important}  .model-explorer-node-data-provider-dropdown .upload-json-file-button.upload{margin-top:2px}  .model-explorer-node-data-provider-dropdown .upload-json-file-button   .mat-mdc-button-touch-target{display:none}  .model-explorer-node-data-provider-dropdown .or-divider{height:1px;border-top:1px solid #eee;position:relative;margin-top:12px}  .model-explorer-node-data-provider-dropdown .or-divider .or-label{font-size:10px;top:-9px;color:#aaa;position:absolute;padding:2px;background-color:#fff;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;width:16px;left:calc(50% - 8px)}  .model-explorer-node-data-provider-dropdown .upload-per-node-data-input{display:none}  .model-explorer-node-data-provider-dropdown .loading-extension,   .model-explorer-node-data-provider-dropdown .no-extension{padding:12px 0 4px 16px;color:#999;font-size:13px;letter-spacing:normal}"],
Qa:0});const FS=(a,b)=>b.type;
function GS(a,b){if(a&1){const c=Tg();R(0,"div",18);V("click",function(){var d=u(c).ca,e=Y(2).Bb,f=Y();d=d.type;var g=f.Pc[e];if(1!==g.matchTypes.length||g.matchTypes[0]!==d)e=f.Pc[e],g=e.matchTypes.indexOf(d),0<=g?e.matchTypes.splice(g,1):e.matchTypes.push(d),f.ci.emit([...f.Pc]);return x()});R(1,"mat-icon");Z(2);S()()}a&2&&(a=b.ca,b=Y(2).ca,Y(),lq("selected",b.matchTypes.includes(a.type))("disabled",1===b.matchTypes.length&&b.matchTypes[0]===a.type),H("matTooltip",a.Md),D(2),xr(a.type))}
function HS(a){if(a&1){const b=Tg();R(0,"div",12)(1,"div",13);Z(2,"R");S();R(3,"div",14);Z(4,"E");S()();R(5,"input",15,1);V("change",function(){u(b);const c=wr(6),d=Y().Bb,e=Y();e.Pc[d].queryRegex=c.value.trim();e.ci.emit([...e.Pc]);return x()});S();R(7,"div",16);Hq(8,GS,3,6,"div",17,FS);S()}if(a&2){a=Y().ca;const b=Y();D(5);H("value",a.queryRegex);D(3);Jq(b.Du)}}
function IS(a){if(a&1){const b=Tg();R(0,"div",19);Z(1," [\u00b7\u00b7] ");S();R(2,"div",20)(3,"input",21,2);V("change",function(){u(b);const c=wr(4),d=wr(8),e=wr(12),f=Y().Bb,g=Y();return x(JS(g,f,c.value.trim(),d.value.trim(),e.value.trim()))});S();R(5,"div",22);Z(6,":");S();R(7,"input",23,3);V("change",function(){u(b);const c=wr(4),d=wr(8),e=wr(12),f=Y().Bb,g=Y();return x(JS(g,f,c.value.trim(),d.value.trim(),e.value.trim()))});S();R(9,"div",24);Z(10,",");S();R(11,"input",25,4);V("change",function(){u(b);
const c=wr(4),d=wr(8),e=wr(12),f=Y().Bb,g=Y();return x(JS(g,f,c.value.trim(),d.value.trim(),e.value.trim()))});S()()}a&2&&(a=Y().ca,Y(),D(3),H("value",a.attrName),D(4),H("value",KS(a.min)),D(4),H("value",KS(a.max)))}function LS(a,b){a&1&&(R(0,"option",28),Z(1),S());a&2&&(a=b.ca,b=Y(2).ca,H("value",a.type)("selected",a.type===b.nodeType),D(),yr(" ",a.label," "))}
function MS(a){if(a&1){const b=Tg();R(0,"div",26)(1,"mat-icon");Z(2,"device_hub");S()();R(3,"select",27,5);V("change",function(){u(b);const c=wr(4),d=Y().Bb,e=Y();return x(e.aw(d,c.value))});Hq(5,LS,2,3,"option",28,FS);S()}a&2&&(a=Y(2),D(5),Jq(a.Eu))}function NS(a){if(a&1){const b=Tg();R(0,"div",29);V("click",function(){u(b);const c=Y().Bb,d=Y();d.Pc.splice(c,1);d.ci.emit([...d.Pc]);return x()});R(1,"mat-icon");Z(2,"delete");S()()}}
function OS(a,b){a&1&&(R(0,"div",7),yp(1,HS,10,1)(2,IS,13,3)(3,MS,7,0)(4,NS,3,0,"div",11),S());if(a&2){let c;a=b.ca;b=Y();D();Cq((c=a.type)===b.gk.dt?1:c===b.gk.Us?2:c===b.gk.lz?3:-1);D(3);Cq("node_type"!==a.type?4:-1)}}function PS(a){a&1&&(R(0,"div",31)(1,"div",13),Z(2,"R"),S(),R(3,"div",14),Z(4,"E"),S()())}function QS(a){a&1&&(R(0,"div",32),Z(1," [\u00b7\u00b7] "),S())}
function RS(a,b){if(a&1){const c=Tg();R(0,"div",30);V("click",function(){var d=u(c).ca,e=Y();d=d.type;switch(d){case "regex":e.Pc.push({type:d,queryRegex:"",matchTypes:["title"]});break;case "attr_value_range":e.Pc.push({type:d,attrName:"",min:Number.NEGATIVE_INFINITY,max:Number.POSITIVE_INFINITY});break;case "node_type":e.Pc.push({type:d,nodeType:"op_nodes"})}e.ci.emit([...e.Pc]);return x()});yp(1,PS,5,0,"div",31)(2,QS,2,0,"div",32);R(3,"div",33);Z(4);S()()}if(a&2){let c;a=b.ca;b=Y();D();Cq((c=a.type)===
b.gk.dt?1:c===b.gk.Us?2:-1);D(3);xr(a.label)}}function JS(a,b,c,d,e){let f=Number.NEGATIVE_INFINITY,g=Number.POSITIVE_INFINITY;""===d||isNaN(Number(d))||(f=Number(d));""===e||isNaN(Number(e))||(g=Number(e));b=a.Pc[b];b.attrName=c;b.min=f;b.max=g;a.ci.emit([...a.Pc])}function KS(a){return null==a||a===Number.NEGATIVE_INFINITY||a===Number.POSITIVE_INFINITY?"":`${a}`}
var SS=class{constructor(){this.queries=[];this.ci=new Dk;this.gk=eI;this.Du=[{type:"title",Md:"Match label"},{type:"list",Md:"Match attributes"},{type:"input",Md:"Match inputs (op node only)"},{type:"output",Md:"Match outputs (op node only)"}];this.Eu=[{type:"op_nodes",label:"Op nodes only"},{type:"layer_nodes",label:"Layer nodes only"},{type:"op_and_layer_nodes",label:"Op and layer nodes"}];this.Bu=[{type:"regex",label:"Regex"},{type:"attr_value_range",label:"Attribute value range"}];this.Pc=[]}Eb(){this.Pc=
JSON.parse(JSON.stringify(this.queries))}aw(a,b){this.Pc[a].nodeType=b;this.ci.emit([...this.Pc])}};SS.J=function(a){return new (a||SS)(y(Pr))};
SS.Ca=Gf({type:SS,ga:[["complex-queries"]],inputs:{queries:"queries"},outputs:{ci:"queriesUpdated"},ja:!0,features:[Jr],ya:11,za:1,Ba:[["menu","matMenu"],["queryInput",""],["inputAttrName",""],["inputMin",""],["inputMax",""],["select",""],[1,"container"],[1,"query-container"],[1,"btn-add-query",3,"matMenuTriggerFor"],[1,"model-explorer-add-query-menu"],[1,"menu-item"],["matTooltip","Delete query","matTooltipPosition","right",1,"icon-container","delete"],["matTooltip","Regex","n","","matTooltipPosition",
"left",1,"model-explorer-regex-icon"],[1,"r"],[1,"e"],["placeholder","Regex",1,"regex","common-input",3,"change","value"],[1,"targets-container"],[1,"icon-container","match-type",3,"matTooltip","selected","disabled"],[1,"icon-container","match-type",3,"click","matTooltip"],["matTooltip","Attribute value range","matTooltipPosition","left",1,"model-explorer-attr-value-range-icon"],[1,"attrs-value-range-container"],["placeholder","Attr name",1,"common-input","attr-name",3,"change","value"],[1,"colon"],
["placeholder","min",1,"common-input","min",3,"change","value"],[1,"to"],["placeholder","max",1,"common-input","max",3,"change","value"],["matTooltip","Node type","matTooltipPosition","left",1,"model-explorer-node-type-icon"],[1,"node-type-selector",3,"change"],[3,"value","selected"],["matTooltip","Delete query","matTooltipPosition","right",1,"icon-container","delete",3,"click"],[1,"menu-item",3,"click"],[1,"model-explorer-regex-icon"],[1,"model-explorer-attr-value-range-icon"],[1,"label"]],sa:function(a,
b){a&1&&(R(0,"div",6),Hq(1,OS,5,2,"div",7,Fq),R(3,"div",8)(4,"mat-icon"),Z(5,"add"),S(),Z(6," Add query "),S(),R(7,"mat-menu",9,0),Hq(9,RS,5,2,"div",10,FS),S()());a&2&&(a=wr(8),D(),Jq(b.Pc),D(2),H("matMenuTriggerFor",a),D(6),Jq(b.Bu))},Ga:[et,TC,vC,JC,RC,$F,tE,YF,aI,$H,zG],styles:[".query-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;gap:6px;margin-bottom:4px;position:relative;padding-right:36px}.query-container[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]{height:22px;border:1px solid #ccc;border-radius:4px;-moz-box-sizing:border-box;box-sizing:border-box;padding:0 4px;outline:none}.query-container[_ngcontent-%COMP%]   input.regex[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.query-container[_ngcontent-%COMP%]   .attrs-value-range-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;width:240px}.query-container[_ngcontent-%COMP%]   .attrs-value-range-container[_ngcontent-%COMP%]   .colon[_ngcontent-%COMP%], .query-container[_ngcontent-%COMP%]   .attrs-value-range-container[_ngcontent-%COMP%]   .to[_ngcontent-%COMP%]{font-weight:700;margin:0 2px;height:22px}.query-container[_ngcontent-%COMP%]   .attrs-value-range-container[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]{min-width:0}.query-container[_ngcontent-%COMP%]   .attrs-value-range-container[_ngcontent-%COMP%]   input.attr-name[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.query-container[_ngcontent-%COMP%]   .attrs-value-range-container[_ngcontent-%COMP%]   input.max[_ngcontent-%COMP%], .query-container[_ngcontent-%COMP%]   .attrs-value-range-container[_ngcontent-%COMP%]   input.min[_ngcontent-%COMP%]{width:50px}.query-container[_ngcontent-%COMP%]   .node-type-selector[_ngcontent-%COMP%]{border:1px solid #ccc;border-radius:4px;outline:none;height:23px;cursor:pointer;-moz-box-sizing:border-box;box-sizing:border-box;width:160px}.query-container[_ngcontent-%COMP%]   .icon-container.delete[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;position:absolute;right:0;top:4px;cursor:pointer;opacity:.6}.query-container[_ngcontent-%COMP%]   .icon-container.delete[_ngcontent-%COMP%]:hover{opacity:1}.query-container[_ngcontent-%COMP%]   .icon-container.delete[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;width:16px;height:16px}.targets-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;gap:2px}.targets-container[_ngcontent-%COMP%]   .icon-container.match-type[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;background-color:#ddd;border-radius:4px;cursor:pointer;padding:4px}.targets-container[_ngcontent-%COMP%]   .icon-container.match-type.selected[_ngcontent-%COMP%]{background-color:#a3c9ff}.targets-container[_ngcontent-%COMP%]   .icon-container.match-type.disabled[_ngcontent-%COMP%]{cursor:default}.targets-container[_ngcontent-%COMP%]   .icon-container.match-type[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:14px;width:14px;height:14px;color:#333}.btn-add-query[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;line-height:16px;opacity:.6;white-space:nowrap;margin-top:2px;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;margin-left:19px}.btn-add-query[_ngcontent-%COMP%]:hover{opacity:1}.btn-add-query[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;width:16px;height:16px;margin-right:2px}  .model-explorer-add-query-menu .menu-item{letter-spacing:normal!important;font-family:Google Sans Text,Arial,Helvetica,sans-serif!important;font-size:12px;padding:0 8px;cursor:pointer;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}  .model-explorer-add-query-menu .menu-item .label{margin-left:6px}  .model-explorer-add-query-menu .menu-item:hover{background-color:#eee}  .model-explorer-regex-icon{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;width:16px;height:16px;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;font-weight:700;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#aaa}  .model-explorer-regex-icon .r{font-size:12px}  .model-explorer-regex-icon .e{font-size:8px;margin-top:2px}  .model-explorer-attr-value-range-icon{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;width:16px;height:16px;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;font-size:10px;font-weight:700;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;color:#aaa}  .model-explorer-node-type-icon{width:16px;height:16px}  .model-explorer-node-type-icon mat-icon{font-size:16px;width:16px;height:16px;color:#aaa}"],
Qa:0});function TS(a){a&1&&(R(0,"div",3),Kq(1,"io-tree",4),S());a&2&&(a=Y(),D(),H("data",a.nv)("rendererId",a.rendererId)("tooltipPosition","right"))}var US=class{constructor(){this.nodes=[];this.rendererId="";this.xw="node";this.Pr={minWidth:320,maxWidth:640,minHeight:0};this.nv=[]}rc(a){a.nodes&&(this.nv=SK(this.nodes,"incoming"))}get label(){const a=this.nodes.length;return`${a} ${this.xw}${1===a?"":"s"}`}};US.J=function(a){return new (a||US)};
US.Ca=Gf({type:US,ga:[["node-list-viewer"]],inputs:{nodes:"nodes",rendererId:"rendererId",xw:"labelSuffix"},ja:!0,features:[Cg,Jr],ya:5,za:5,Ba:[["nodeList",""],[1,"container"],["panelClass","model-explorer-node-list-panel","dialogLabel","nodeList",1,"label-container",3,"xapInlineDialogClick","overlaySize"],[1,"model-explorer-node-list"],[3,"data","rendererId","tooltipPosition"]],sa:function(a,b){a&1&&(R(0,"div",1)(1,"div",2),Z(2),S(),yp(3,TS,2,3,"ng-template",null,0,Nr),S());a&2&&(a=wr(4),D(),lq("disabled",
0===b.nodes.length),H("xapInlineDialogClick",a)("overlaySize",b.Pr),D(),yr(" ",b.label," "))},Ga:[et,RK,aI,zG,yG],styles:[".container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;position:relative}.label-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;padding:4px 6px;border-radius:4px;background-color:#a3c9ff;line-height:14px;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;opacity:.8}.label-container[_ngcontent-%COMP%]:hover{opacity:1}.label-container.disabled[_ngcontent-%COMP%]{pointer-events:none;background-color:#ddd}  .model-explorer-node-list{font-size:12px;background-color:#fff;line-height:normal}  .model-explorer-node-list-panel xap-inline-dialog-container{width:100%}"],
Qa:0});var VS=new df("CDK_DRAG_PARENT");var WS=new df("CdkDragHandle"),XS=class{get disabled(){return this.Hb}set disabled(a){this.Hb=a;this.i.next(this)}constructor(a,b){this.element=a;this.C=b;this.i=new aj;this.Hb=!1;null==b||b.R(this)}ua(){let a;null==(a=this.C)||a.ba(this);this.i.complete()}};XS.J=function(a){return new (a||XS)(y(qi),y(VS,12))};XS.Ea=Of({type:XS,ga:[["","cdkDragHandle",""]],Ja:[1,"cdk-drag-handle"],inputs:{disabled:[2,"cdkDragHandleDisabled","disabled",ws]},ja:!0,features:[Hr([{na:WS,zb:XS}]),Hp]});var YS=new df("CDK_DRAG_CONFIG");const ZS=Ht({passive:!1,capture:!0});function $S(a,b){a.C.add(b);1===a.C.size&&Kk(a.pa,()=>{a.ha.addEventListener("touchmove",a.O,ZS)})}function aT(a,b){b=a.i.indexOf(b);-1<b&&(a.i.splice(b,1),0===a.i.length&&a.K())}function bT(a,b){a.C.delete(b);aT(a,b);0===a.C.size&&a.ha.removeEventListener("touchmove",a.O,ZS)}
function cT(a,b,c){-1<a.i.indexOf(b)||(a.i.push(b),1===a.i.length&&(b=c.type.startsWith("touch"),a.D.set(b?"touchend":"mouseup",{handler:d=>a.G.next(d),options:!0}).set("scroll",{handler:d=>a.scroll.next(d),options:!0}).set("selectstart",{handler:a.T,options:ZS}),b||a.D.set("mousemove",{handler:d=>a.F.next(d),options:ZS}),Kk(a.pa,()=>{a.D.forEach((d,e)=>{a.ha.addEventListener(e,d.handler,d.options)})})))}
function dT(a,b){const c=[a.scroll];b&&b!==a.ha&&c.push(new Vi(d=>Kk(a.pa,()=>{const e=f=>{a.i.length&&d.next(f)};b.addEventListener("scroll",e,!0);return()=>{b.removeEventListener("scroll",e,!0)}})));return pk(...c)}
var eT=class{constructor(a,b){this.pa=a;this.N=new Set;this.C=new Set;this.i=[];this.D=new Map;this.R=c=>c.ce();this.F=new aj;this.G=new aj;this.scroll=new aj;this.T=c=>{0<this.i.length&&c.preventDefault()};this.O=c=>{0<this.i.length&&(this.i.some(this.R)&&c.preventDefault(),this.F.next(c))};this.ha=b}ce(a){return-1<this.i.indexOf(a)}ua(){this.C.forEach(a=>bT(this,a));this.N.forEach(a=>{this.N.delete(a)});this.K();this.F.complete();this.G.complete()}K(){this.D.forEach((a,b)=>{this.ha.removeEventListener(b,
a.handler,a.options)});this.D.clear()}};eT.J=function(a){return new (a||eT)(q(Ok),q(gt))};eT.oa=Ld({la:eT,aa:eT.J,da:"root"});function fT(a){const b=a.cloneNode(!0),c=b.querySelectorAll("[id]"),d=a.nodeName.toLowerCase();b.removeAttribute("id");for(let e=0;e<c.length;e++)c[e].removeAttribute("id");"canvas"===d?gT(a,b):("input"===d||"select"===d||"textarea"===d)&&hT(a,b);iT("canvas",a,b,gT);iT("input, textarea, select",a,b,hT);return b}function iT(a,b,c,d){b=b.querySelectorAll(a);if(b.length)for(a=c.querySelectorAll(a),c=0;c<b.length;c++)d(b[c],a[c])}let jT=0;
function hT(a,b){"file"!==b.type&&(b.value=a.value);"radio"===b.type&&b.name&&(b.name=`mat-clone-${b.name}-${jT++}`)}function gT(a,b){if(b=b.getContext("2d"))try{b.drawImage(a,0,0)}catch(c){}};function kT(a){a=a.getBoundingClientRect();return{top:a.top,right:a.right,bottom:a.bottom,left:a.left,width:a.width,height:a.height,x:a.x,y:a.y}}function lT(a,b,c){a.top+=b;a.bottom=a.top+a.height;a.left+=c;a.right=a.left+a.width};function mT(a,b){const c=Pt(b);b=a.he.get(c);if(!b)return null;b=b.ls;let d;if(c===a.ha){var e=window.scrollX;d=window.scrollY}else d=c.scrollTop,e=c.scrollLeft;const f=b.top-d,g=b.left-e;a.he.forEach((k,m)=>{k.Wu&&c!==m&&c.contains(m)&&lT(k.Wu,f,g)});b.top=d;b.left=e;return{top:f,left:g}}
var nT=class{constructor(a){this.ha=a;this.he=new Map}clear(){this.he.clear()}cache(a){this.clear();this.he.set(this.ha,{ls:{top:window.scrollY,left:window.scrollX}});a.forEach(b=>{this.he.set(b,{ls:{top:b.scrollTop,left:b.scrollLeft},Wu:kT(b)})})}};function oT(a,b){a=a.rootNodes;if(1===a.length&&a[0].nodeType===b.ELEMENT_NODE)return a[0];const c=b.createElement("div");a.forEach(d=>c.appendChild(d));return c};function pT(a,b,c){for(let d in b)if(b.hasOwnProperty(d)){const e=b[d];if(e){let f;a.setProperty(d,e,(null==(f=c)?0:f.has(d))?"important":"")}else a.removeProperty(d)}}function qT(a,b){const c=b?"":"none";pT(a.style,{"touch-action":b?"":"none","-webkit-user-drag":b?"":"none","-webkit-tap-highlight-color":b?"":"transparent","user-select":c,"-ms-user-select":c,"-webkit-user-select":c,"-moz-user-select":c})}
function rT(a,b){pT(a.style,{position:b?"":"fixed",top:b?"":"0",opacity:b?"":"0",left:b?"":"-999em"},sT)}function tT(a,b){return b&&"none"!=b?a+" "+b:a}function uT(a,b){a.style.width=`${b.width}px`;a.style.height=`${b.height}px`;a.style.transform=vT(b.left,b.top)}function vT(a,b){return`translate3d(${Math.round(a)}px, ${Math.round(b)}px, 0)`};function wT(a){return parseFloat(a)*(-1<a.toLowerCase().indexOf("ms")?1:1E3)}function xT(a){a=getComputedStyle(a);var b=yT(a,"transition-property"),c=b.find(d=>"transform"===d||"all"===d);if(!c)return 0;b=b.indexOf(c);c=yT(a,"transition-duration");a=yT(a,"transition-delay");return wT(c[b])+wT(a[b])}function yT(a,b){return a.getPropertyValue(b).split(",").map(c=>c.trim())};const zT=new Set(["position"]);
var AT=class{constructor(a,b,c,d,e,f,g,k,m){this.ha=a;this.O=b;this.K=c;this.C=d;this.N=e;this.T=f;this.F=g;this.D=k;this.ba=m}attach(a){this.i=this.R();a.appendChild(this.i);"showPopover"in this.i&&this.i.showPopover()}destroy(){this.i.remove();let a;null==(a=this.G)||a.destroy();this.i=this.G=null}getBoundingClientRect(){return this.i.getBoundingClientRect()}Ri(a){this.i.classList.add(a)}addEventListener(a,b){this.i.addEventListener(a,b)}removeEventListener(a,b){this.i.removeEventListener(a,b)}R(){const a=
this.N,b=this.T;var c=a?a.sa:null;let d;if(c&&a){const e=a.Xn?this.C:null;c=a.eg.vd(c,a.context);$m(c);d=oT(c,this.ha);this.G=c;a.Xn?uT(d,e):d.style.transform=vT(this.F.x,this.F.y)}else d=fT(this.O),uT(d,this.C),this.D&&(d.style.transform=this.D);pT(d.style,{"pointer-events":"none",margin:"0",position:"fixed",top:"0",left:"0","z-index":this.ba+""},zT);qT(d,!1);d.classList.add("cdk-drag-preview");d.setAttribute("popover","manual");d.setAttribute("dir",this.K);b&&(Array.isArray(b)?b.forEach(e=>d.classList.add(e)):
d.classList.add(b));return d}};const BT=Ht({passive:!0}),CT=Ht({passive:!1}),DT=Ht({passive:!1,capture:!0}),sT=new Set(["position"]);function ET(a,b){const c=Ps(b);c!==a.i&&(a.i&&a.jh(a.i),Kk(a.pa,()=>{c.addEventListener("mousedown",a.Jb,CT);c.addEventListener("touchstart",a.Jb,BT);c.addEventListener("dragstart",a.fh,CT)}),a.ba=void 0,a.i=c);"undefined"!==typeof SVGElement&&a.i instanceof SVGElement&&(a.kb=a.i.ownerSVGElement);return a}function FT(a,b){a.Gc=b}
function GT(a,b){a.D=b.map(d=>Ps(d));a.D.forEach(d=>qT(d,a.disabled));a.Kb();const c=new Set;a.R.forEach(d=>{-1<a.D.indexOf(d)&&c.add(d)});a.R=c}function HT(a,b){a.ea=b?Ps(b):null;a.Nb.unsubscribe();b&&(a.Nb=a.wi.vb(10).subscribe(()=>a.zi()));return a}function IT(a,b){a.K={x:0,y:0};a.O.x=b.x;a.O.y=b.y;a.C||a.Cc(b.x,b.y)}function JT(a){void 0===a.Vc&&(a.Vc=Nt(a.i));return a.Vc}
var MT=class{get disabled(){return this.Hb||!(!this.C||!this.C.disabled)}set disabled(a){a!==this.Hb&&(this.Hb=a,this.Kb(),this.D.forEach(b=>qT(b,a)))}constructor(a,b,c,d,e,f){this.xa=b;this.ha=c;this.pa=d;this.wi=e;this.N=f;this.O={x:0,y:0};this.K={x:0,y:0};this.Ia=!1;this.fb=new aj;this.Nb=this.qd=this.ih=this.hh=Li.EMPTY;this.ea=null;this.gh=!0;this.D=[];this.R=new Set;this.Wc="ltr";this.hj=0;this.Hb=!1;this.Ra=new aj;this.ji=new aj;this.released=new aj;this.ended=new aj;this.kj=new aj;this.mj=
new aj;this.jj=new aj;this.xj=this.fb;this.Jb=g=>{this.Ra.next();if(this.D.length){const k=this.Rd(g);!k||this.R.has(k)||this.disabled||this.Ne(k,g)}else this.disabled||this.Ne(this.i,g)};this.dl=g=>{var k=this.Ta(g);if(this.Ia){g.cancelable&&g.preventDefault();var m=this.Qd(k);this.Vd=!0;this.fg=k;this.Dl(m);if(this.C)this.kh(m,k);else{k=this.se?this.ia:this.F;var p=this.K;p.x=m.x-k.x+this.O.x;p.y=m.y-k.y+this.O.y;this.Cc(p.x,p.y)}this.fb.kc.length&&this.pa.run(()=>{this.fb.next({source:this,bx:m,
event:g,distance:this.Fc(m),delta:this.Hc})})}else Math.abs(k.x-this.F.x)+Math.abs(k.y-this.F.y)>=this.xa.nn&&((k=Date.now()>=this.jk+this.Gk(g),p=this.C,k)?p&&(p.ce()||p.R())||(g.cancelable&&g.preventDefault(),this.Ia=!0,this.pa.run(()=>this.xl(g))):this.Pd(g))};this.ml=g=>{this.Pd(g)};this.fh=g=>{if(this.D.length){const k=this.Rd(g);!k||this.R.has(k)||this.disabled||g.preventDefault()}else this.disabled||g.preventDefault()};FT(ET(this,a),b.gG||null);this.va=new nT(c);$S(f,this)}dispose(){this.jh(this.i);
if(this.ce()){let b;null==(b=this.i)||b.remove()}let a;null==(a=this.Da)||a.remove();this.Od();this.sd();bT(this.N,this);this.Ic();this.Ra.complete();this.ji.complete();this.released.complete();this.ended.complete();this.kj.complete();this.mj.complete();this.jj.complete();this.fb.complete();this.D=[];this.R.clear();this.C=void 0;this.Nb.unsubscribe();this.va.clear();this.ea=this.i=this.kb=this.jd=this.Oa=this.Da=this.Gc=null}ce(){return this.Ia&&this.N.ce(this)}reset(){this.i.style.transform=this.ba||
"";this.K={x:0,y:0};this.O={x:0,y:0}}Gl(a){this.C=a}Ar(){const a=this.fg;a&&this.C&&this.kh(this.Qd(a),a)}Ic(){this.hh.unsubscribe();this.ih.unsubscribe();this.qd.unsubscribe();let a;null==(a=JT(this))||a.removeEventListener("selectstart",KT,DT)}Od(){let a;null==(a=this.G)||a.destroy();this.G=null}sd(){let a;null==(a=this.Mb)||a.remove();let b;null==(b=this.rb)||b.destroy();this.Mb=this.rb=null}Pd(a){if(this.N.ce(this)&&(this.Ic(),aT(this.N,this),this.Kb(),this.D&&(this.i.style.webkitTapHighlightColor=
this.wl),this.Ia))if(this.released.next({source:this,event:a}),this.C)this.C.K(),this.xi().then(()=>{this.yi(a);this.rd();aT(this.N,this)});else{this.O.x=this.K.x;const b=this.Ta(a);this.O.y=this.K.y;this.pa.run(()=>{this.ended.next({source:this,distance:this.Fc(b),ij:b,event:a})});this.rd();aT(this.N,this)}}xl(a){LT(a)&&(this.eh=Date.now());this.Kb();const b=JT(this),c=this.C;b&&Kk(this.pa,()=>{b.addEventListener("selectstart",KT,DT)});if(c){const d=this.i,e=d.parentNode,f=this.Mb=this.ik(),g=this.Da=
this.Da||this.ha.createComment("");e.insertBefore(g,d);this.ba=d.style.transform||"";this.G=new AT(this.ha,this.i,this.Wc,this.ia,this.Oa||null,this.Ol||null,this.F,this.ba,this.xa.zIndex||1E3);this.G.attach(this.Nk(e,b));rT(d,!1);this.ha.body.appendChild(e.replaceChild(f,d));this.ji.next({source:this,event:a});c.start();this.T=c;this.ab=c.i(this)}else this.ji.next({source:this,event:a}),this.T=this.ab=void 0;this.va.cache(c?c.O():[])}Ne(a,b){this.Gc&&b.stopPropagation();var c=this.ce(),d=LT(b);const e=
!d&&0!==b.button,f=this.i,g=Pt(b),k=!d&&this.eh&&this.eh+800>Date.now();d=d?yx(b):xx(b);g&&g.draggable&&"mousedown"===b.type&&b.preventDefault();c||e||k||d||(this.D.length&&(c=f.style,this.wl=c.webkitTapHighlightColor||"",c.webkitTapHighlightColor="transparent"),this.Ia=this.Vd=!1,this.Ic(),this.ia=this.i.getBoundingClientRect(),this.hh=this.N.F.subscribe(this.dl),this.ih=this.N.G.subscribe(this.ml),this.qd=dT(this.N,JT(this)).subscribe(m=>this.zl(m)),this.ea&&(this.ma=kT(this.ea)),this.ra=(c=this.Oa)&&
c.sa&&!c.Xn?{x:0,y:0}:this.Ik(this.ia,a,b),a=this.F=this.fg=this.Ta(b),this.Hc={x:0,y:0},this.gl={x:a.x,y:a.y},this.jk=Date.now(),cT(this.N,this,b))}yi(a){rT(this.i,!0);this.Da.parentNode.replaceChild(this.i,this.Da);this.Od();this.sd();this.ia=this.ma=this.ta=this.ba=void 0;this.pa.run(()=>{const b=this.C,c=b.i(this),d=this.Ta(a),e=this.Fc(d),f=b.C(d.x,d.y);this.ended.next({source:this,distance:e,ij:d,event:a});this.jj.next({item:this,dd:c,He:this.ab,Za:b,ix:this.T,vw:f,distance:e,ij:d,event:a});
b.N(this,c,this.ab,this.T,f,e,d,a);this.C=this.T})}kh({x:a,y:b},{x:c,y:d}){let e=this.T.D(this,a,b);!e&&this.C!==this.T&&this.T.C(a,b)&&(e=this.T);e&&e!==this.C&&this.pa.run(()=>{this.mj.next({item:this,Za:this.C});this.C.Dq(this);this.C=e;this.C.rn(this,a,b,e===this.T&&e.T?this.ab:void 0);this.kj.next({item:this,Za:e,dd:e.i(this)})});this.ce()&&(this.C.G(c,d),this.C.F(this,a,b,this.Hc),this.se?this.uc(a,b):this.uc(a-this.ra.x,b-this.ra.y))}xi(){if(!this.Vd)return Promise.resolve();const a=this.Mb.getBoundingClientRect();
this.G.Ri("cdk-drag-animating");this.uc(a.left,a.top);const b=xT(this.G.i);return 0===b?Promise.resolve():Kk(this.pa,()=>new Promise(c=>{const d=f=>{if(!f||Pt(f)===this.G&&"transform"===f.propertyName){let g;null==(g=this.G)||g.removeEventListener("transitionend",d);c();clearTimeout(e)}},e=setTimeout(d,1.5*b);this.G.addEventListener("transitionend",d)}))}ik(){var a=this.jd;const b=a?a.sa:null;b?(this.rb=a.eg.vd(b,a.context),$m(this.rb),a=oT(this.rb,this.ha)):a=fT(this.i);a.style.pointerEvents="none";
a.classList.add("cdk-drag-placeholder");return a}Ik(a,b,c){b=(b=b===this.i?null:b)?b.getBoundingClientRect():a;c=LT(c)?c.targetTouches[0]:c;const d=this.Ud();return{x:b.left-a.left+(c.pageX-b.left-d.left),y:b.top-a.top+(c.pageY-b.top-d.top)}}Ta(a){var b=this.Ud(),c=LT(a)?a.touches[0]||a.changedTouches[0]||{pageX:0,pageY:0}:a;a=c.pageX-b.left;b=c.pageY-b.top;if(this.kb&&(c=this.kb.getScreenCTM())){const d=this.kb.createSVGPoint();d.x=a;d.y=b;return d.matrixTransform(c.inverse())}return{x:a,y:b}}Qd(a){var b=
this.C?this.C.Mh:null;let {x:c,y:d}=this.se?this.se(a,this,this.ia,this.ra):a;if("x"===this.Mh||"x"===b)d=this.F.y-(this.se?this.ra.y:0);else if("y"===this.Mh||"y"===b)c=this.F.x-(this.se?this.ra.x:0);if(this.ma){const {x:e,y:f}=this.se?{x:0,y:0}:this.ra;a=this.ma;const {width:g,height:k}=this.al();b=a.top+f;const m=a.bottom-(k-f);c=Math.max(a.left+e,Math.min(a.right-(g-e),c));d=Math.max(b,Math.min(m,d))}return{x:c,y:d}}Dl(a){const b=a.x;a=a.y;const c=this.Hc,d=this.gl,e=Math.abs(a-d.y);Math.abs(b-
d.x)>this.xa.Ml&&(c.x=b>d.x?1:-1,d.x=b);e>this.xa.Ml&&(c.y=a>d.y?1:-1,d.y=a);return c}Kb(){if(this.i&&this.D){var a=0<this.D.length||!this.ce();a!==this.gh&&(this.gh=a,qT(this.i,a))}}jh(a){a.removeEventListener("mousedown",this.Jb,CT);a.removeEventListener("touchstart",this.Jb,BT);a.removeEventListener("dragstart",this.fh,CT)}Cc(a,b){a=vT(a,b);b=this.i.style;null==this.ba&&(this.ba=b.transform&&"none"!=b.transform?b.transform:"");b.transform=tT(a,this.ba)}uc(a,b){let c;const d=(null==(c=this.Oa)?
0:c.sa)?void 0:this.ba;this.G.i.style.transform=tT(vT(a,b),d)}Fc(a){const b=this.F;return b?{x:a.x-b.x,y:a.y-b.y}:{x:0,y:0}}rd(){this.ma=this.ta=void 0;this.va.clear()}zi(){let {x:a,y:b}=this.O;if(!(0===a&&0===b||this.ce())&&this.ea){var c=this.i.getBoundingClientRect(),d=this.ea.getBoundingClientRect();if(!(0===d.width&&0===d.height||0===c.width&&0===c.height)){var e=d.left-c.left,f=c.right-d.right,g=d.top-c.top,k=c.bottom-d.bottom;d.width>c.width?(0<e&&(a+=e),0<f&&(a-=f)):a=0;d.height>c.height?
(0<g&&(b+=g),0<k&&(b-=k)):b=0;a===this.O.x&&b===this.O.y||IT(this,{y:b,x:a})}}}Gk(a){const b=this.hj;return"number"===typeof b?b:LT(a)?b.yG:b?b.Gd:0}zl(a){const b=mT(this.va,a);b&&(a=Pt(a),this.ma&&a!==this.ea&&a.contains(this.ea)&&lT(this.ma,b.top,b.left),this.F.x+=b.left,this.F.y+=b.top,this.C||(this.K.x-=b.left,this.K.y-=b.top,this.Cc(this.K.x,this.K.y)))}Ud(){let a;return(null==(a=this.va.he.get(this.ha))?void 0:a.ls)||{top:window.scrollY,left:window.scrollX}}Nk(a,b){const c=this.sl||"global";
return"parent"===c?a:"global"===c?(a=this.ha,b||a.fullscreenElement||a.webkitFullscreenElement||a.mozFullScreenElement||a.msFullscreenElement||a.body):Ps(c)}al(){this.ta&&(this.ta.width||this.ta.height)||(this.ta=this.G?this.G.getBoundingClientRect():this.ia);return this.ta}Rd(a){return this.D.find(b=>a.target&&(a.target===b||b.contains(a.target)))}};function LT(a){return"t"===a.type[0]}function KT(a){a.preventDefault()};const NT={nn:5,Ml:5},OT=new Set;var Ks=class{};Ks.J=function(a){return new (a||Ks)};Ks.Ca=Gf({type:Ks,ga:[["ng-component"]],Ja:["cdk-drag-resets-container",""],ja:!0,features:[Jr],ya:0,za:0,sa:function(){},styles:["@layer cdk-resets{.cdk-drag-preview{background:none;border:none;padding:0;color:inherit}}\n"],ob:2,Qa:0});function PT(a,b,c=NT){a.G();return new MT(b,c,a.ha,a.pa,a.D,a.C)}
var QT=class{constructor(a,b,c,d){this.ha=a;this.pa=b;this.D=c;this.C=d;this.i=lf(dp);this.F=lf(ig)}G(){if(!OT.has(this.i)){OT.add(this.i);const a=Js({Nf:this.F});this.i.nb(()=>{OT.delete(this.i);0===OT.size&&a.destroy()})}}};QT.J=function(a){return new (a||QT)(q(gt),q(Ok),q(tu),q(eT))};QT.oa=Ld({la:QT,aa:QT.J,da:"root"});var RT=new df("CdkDropList");function ST(a,b){const c=b.Mh,d=b.hj,e=b.se,f=b.Ol,g=b.bq,k=b.GF,m=b.Mj;b=b.Qr;a.disabled=null==k?!1:k;a.hj=d||0;c&&(a.Mh=c);e&&(a.se=e);f&&(a.Ol=f);g&&(a.bq=g);m&&(a.Mj=m);b&&(a.Qr=b)}
function TT(a,b){b.ji.subscribe(c=>{a.ji.emit({source:a,event:c.event});Zm(a.Aa)});b.released.subscribe(c=>{a.released.emit({source:a,event:c.event})});b.ended.subscribe(c=>{a.ended.emit({source:a,distance:c.distance,ij:c.ij,event:c.event});Zm(a.Aa)});b.kj.subscribe(c=>{a.kj.emit({Za:c.Za.data,item:a,dd:c.dd})});b.mj.subscribe(c=>{a.mj.emit({Za:c.Za.data,item:a})});b.jj.subscribe(c=>{a.jj.emit({He:c.He,dd:c.dd,ix:c.ix.data,Za:c.Za.data,vw:c.vw,item:a,distance:c.distance,ij:c.ij,event:c.event})})}
var VT=class{get disabled(){return this.Hb||this.F&&this.F.disabled}set disabled(a){this.Hb=a;this.Zc.disabled=this.Hb}constructor(a,b,c,d,e,f,g,k,m,p,t){this.element=a;this.F=b;this.pa=d;this.K=e;this.O=g;this.Aa=m;this.ea=p;this.G=t;this.Fa=new aj;this.i=new cj([]);this.ji=new Dk;this.released=new Dk;this.ended=new Dk;this.kj=new Dk;this.mj=new Dk;this.jj=new Dk;this.xj=new Vi(v=>{const B=C(this.Zc.xj,vj(G=>({source:this,bx:G.bx,event:G.event,delta:G.delta,distance:G.distance}))).subscribe(v);return()=>
{B.unsubscribe()}});this.Ya=lf(Vh);this.Zc=PT(k,a,{nn:f&&null!=f.nn?f.nn:5,Ml:f&&null!=f.Ml?f.Ml:5,zIndex:null==f?void 0:f.zIndex});this.Zc.data=this;UT.push(this);f&&ST(this,f);b&&this.Zc.Gl(b.i);this.ma(this.Zc);TT(this,this.Zc)}reset(){this.Zc.reset()}nd(){Zk(()=>{this.N();this.ia();this.zn&&IT(this.Zc,this.zn)},{wa:this.Ya})}rc(a){const b=a.rootElementSelector;a=a.freeDragPosition;b&&!b.vn&&this.N();a&&!a.vn&&this.zn&&IT(this.Zc,this.zn)}ua(){this.F&&this.F.removeItem(this);const a=UT.indexOf(this);
-1<a&&UT.splice(a,1);Kk(this.pa,()=>{this.i.complete();this.Fa.next();this.Fa.complete();this.Zc.dispose()})}R(a){const b=bj(this.i);b.push(a);this.i.next(b)}ba(a){const b=bj(this.i);a=b.indexOf(a);-1<a&&(b.splice(a,1),this.i.next(b))}Da(a){this.C=a}ta(a){a===this.C&&(this.C=null)}va(a){this.D=a}ra(a){a===this.D&&(this.D=null)}N(){const a=this.element.P;let b=a;if(this.Mj){let c;b=void 0!==a.closest?a.closest(this.Mj):null==(c=a.parentElement)?void 0:c.closest(this.Mj)}ET(this.Zc,b||a)}T(){const a=
this.bq;return a?"string"===typeof a?this.element.P.closest(a):Ps(a):null}ma(a){a.Ra.subscribe(()=>{if(!a.ce()){const c=this.O;var b=this.hj;const d=this.D?{sa:this.D.cg,context:this.D.data,eg:this.K}:null,e=this.C?{sa:this.C.cg,context:this.C.data,Xn:this.C.Xn,eg:this.K}:null;a.disabled=this.disabled;a.Mh=this.Mh;a.hj="object"===typeof b&&b?b:Qs(b);a.se=this.se;a.Ol=this.Ol;b=HT(a,this.T());b.jd=d;b.Oa=e;b.sl=this.Qr||"global";c&&(a.Wc=c.value)}});C(a.Ra,co()).subscribe(()=>{if(this.G)a.Gc=this.G.Zc;
else for(var b=this.element.P.parentElement;b;){if(b.classList.contains("cdk-drag")){let c;FT(a,(null==(c=UT.find(d=>d.element.P===b))?void 0:c.Zc)||null);break}b=b.parentElement}})}ia(){C(this.i,No(a=>{a=a.map(b=>b.element);this.ea&&this.Mj&&a.push(this.element);GT(this.Zc,a)}),Go(a=>pk(...a.map(b=>C(b.i,Fo(b))))),Jo(this.Fa)).subscribe(a=>{const b=this.Zc,c=a.element.P;a.disabled?!b.R.has(c)&&-1<b.D.indexOf(c)&&(b.R.add(c),qT(c,!0)):b.R.has(c)&&(b.R.delete(c),qT(c,b.disabled))})}},UT=[];
VT.J=function(a){return new (a||VT)(y(qi),y(RT,12),y(gt),y(Ok),y(ip),y(YS,8),y(lu,8),y(QT),y(Pr),y(WS,10),y(VS,12))};
VT.Ea=Of({type:VT,ga:[["","cdkDrag",""]],Ja:[1,"cdk-drag"],Xa:4,Ha:function(a,b){a&2&&lq("cdk-drag-disabled",b.disabled)("cdk-drag-dragging",b.Zc.ce())},inputs:{data:[0,"cdkDragData","data"],Mh:[0,"cdkDragLockAxis","lockAxis"],Mj:[0,"cdkDragRootElement","rootElementSelector"],bq:[0,"cdkDragBoundary","boundaryElement"],hj:[0,"cdkDragStartDelay","dragStartDelay"],zn:[0,"cdkDragFreeDragPosition","freeDragPosition"],disabled:[2,"cdkDragDisabled","disabled",ws],se:[0,"cdkDragConstrainPosition","constrainPosition"],
Ol:[0,"cdkDragPreviewClass","previewClass"],Qr:[0,"cdkDragPreviewContainer","previewContainer"]},outputs:{ji:"cdkDragStarted",released:"cdkDragReleased",ended:"cdkDragEnded",kj:"cdkDragEntered",mj:"cdkDragExited",jj:"cdkDragDropped",xj:"cdkDragMoved"},hb:["cdkDrag"],ja:!0,features:[Hr([{na:VS,zb:VT}]),Hp,Cg]});new df("CdkDragPlaceholder");new df("CdkDragPreview");new df("CdkDropListGroup");var WT=class{};WT.J=function(a){return new (a||WT)};WT.Wa=Mf({type:WT});WT.Va=Md({Ua:[QT],imports:[uu]});const XT=(a,b)=>b.type;function YW(a){a&1&&(R(0,"div",24),Z(1," Rules use your defined queries to match nodes for styling. All queries within a rule are connected with "),R(2,"span",25),Z(3,"AND"),S(),Z(4," logic. "),S())}function ZW(a){a&1&&(R(0,"div",28),Kq(1,"node-list-viewer",36),S());if(a&2){a=Y().Bb;const b=Y(2);D();H("nodes",(b.mm[a]||{})[0]||[])("rendererId",b.zw)}}
function $W(a){a&1&&(R(0,"div",28)(1,"div",37),Z(2,"Left pane"),S(),Kq(3,"node-list-viewer",36),S(),R(4,"div",28)(5,"div",37),Z(6,"Right pane"),S(),Kq(7,"node-list-viewer",36),S());if(a&2){a=Y().Bb;const b=Y(2);D(3);H("nodes",(b.mm[a]||{})[0]||[])("rendererId",b.zw);D(4);H("nodes",(b.mm[a]||{})[1]||[])("rendererId",b.JD)}}
function aX(a){if(a&1){const b=Tg();R(0,"div",41)(1,"label")(2,"input",42,3);V("change",function(){u(b);const c=wr(3),d=Y(2).ca,e=Y().Bb,f=Y(2);return x(bX(f,e,d,c.value))});S()();R(4,"input",43,4);V("change",function(){u(b);const c=wr(5),d=Y(2).ca,e=Y().Bb,f=Y(2);return x(bX(f,e,d,c.value))});S()()}if(a&2){a=Y(2).ca;const b=Y().ca;Y(2);D();jq("background-color",cX(b,a));D();H("value",cX(b,a));D(2);H("value",cX(b,a))}}
function dX(a){a&1&&yp(0,aX,6,4,"div",41);if(a&2){a=Y().ca;const b=Y().ca;Y(2);Cq(null!=b.styles[a.id]?0:-1)}}function eX(a){if(a&1){const b=Tg();R(0,"div",44)(1,"input",45,5);V("change",function(){u(b);const c=wr(2),d=Y(2).ca,e=Y().Bb,f=Y(2);return x(bX(f,e,d,c.value))});S()()}if(a&2){a=Y(2).ca;const b=Y().ca;Y(2);D();H("value",cX(b,a))}}function fX(a){a&1&&yp(0,eX,3,1,"div",44);if(a&2){a=Y().ca;const b=Y().ca;Y(2);Cq(null!=b.styles[a.id]?0:-1)}}
function gX(a,b){if(a&1){const c=Tg();R(0,"div",30)(1,"div",38)(2,"input",39,2);V("change",function(){const d=u(c).ca,e=wr(3),f=Y().Bb,g=Y(2);fL(g.td,f,d,e.checked);return x()});S();R(4,"div",40);V("click",function(){const d=u(c).ca,e=Y().Bb,f=Y(2);fL(f.td,e,d);return x()});Z(5);S()();yp(6,dX,1,1)(7,fX,1,1);S()}if(a&2){let c;a=b.ca;b=Y().ca;const d=Y(2);D(2);H("checked",null!=b.styles[a.id]);D(3);yr(" ",a.label," ");D();Cq((c=a.type)===d.ft.COLOR?6:c===d.ft.Uo?7:-1)}}
function hX(a){if(a&1){const b=Tg();R(0,"div",46);V("click",function(){u(b);const c=Y().Bb,d=Y(2);bL(d.td,c);return x()});R(1,"mat-icon");Z(2,"arrow_upward_alt");S()()}}function iX(a){if(a&1){const b=Tg();R(0,"div",47);V("click",function(){u(b);const c=Y().Bb,d=Y(2);cL(d.td,c);return x()});R(1,"mat-icon");Z(2,"arrow_downward_alt");S()()}}
function jX(a,b){if(a&1){const c=Tg();R(0,"tr")(1,"td",19)(2,"complex-queries",26);V("queriesUpdated",function(d){const e=u(c).Bb,f=Y(2);eL(f.td,e,d);return x()});S();R(3,"div",27);yp(4,ZW,2,2,"div",28)(5,$W,8,4);S()();R(6,"td",22)(7,"div",29);Hq(8,gX,8,3,"div",30,XT);S()();R(10,"td",23)(11,"div",31);yp(12,hX,3,0,"div",32)(13,iX,3,0,"div",33);R(14,"div",34);V("click",function(){const d=u(c).Bb,e=Y(2);dL(e.td,d);return x()});R(15,"mat-icon");Z(16,"content_copy");S()();R(17,"div",35);V("click",function(){const d=
u(c).Bb,e=Y(2);iL(e.td,d);return x()});R(18,"mat-icon");Z(19,"delete");S()()()()()}if(a&2){a=b.ca;const c=b.Bb;b=b.Ty;const d=Y(2);D(2);H("queries",a.queries);D(2);Cq(1===d.Xw?4:2===d.Xw?5:-1);D(4);Jq(d.WA);D(4);Cq(0!==c?12:-1);D();Cq(c!==b-1?13:-1)}}
function kX(a){a&1&&(R(0,"table",10)(1,"thead")(2,"th",19)(3,"div",20),Z(4," Queries to match nodes "),R(5,"div",21)(6,"mat-icon"),Z(7,"help_outline"),S()(),yp(8,YW,5,0,"ng-template",null,1,Nr),S()(),R(10,"th",22),Z(11,"Styles to apply"),S(),Kq(12,"th",23),S(),R(13,"tbody"),Hq(14,jX,20,4,"tr",null,Fq),S()());if(a&2){a=wr(9);const b=Y();D(5);H("xapInlineDialog",a)("overlaySize",b.fd)("hoverDelayMs",10);D(9);Jq(b.rules())}}
function lX(a){a&1&&(R(0,"div",11),Z(1,' No rules configured. Click the "Add rule" button below to get started. '),S())}function bX(a,b,c,d){let e=d;d.startsWith("rgb")?e=mX(d):d.startsWith("#")||(e=dI[d]||d);hL(a.td,b,c,e)}function cX(a,b){let c;return(null==(c=a.styles[b.id])?void 0:c.value)||""}function nX(a,b){if(b.files&&0!==b.files.length){var c=new FileReader;c.onload=d=>{let e;d=JSON.parse(null==(e=d.target)?void 0:e.result);ZK(a.td,d)};c.readAsText(b.files[0])}}
function mX(a){return(a=a.match(/^rgba?\((\d+),\s*(\d+),\s*(\d+)(?:,\s*(\d+\.{0,1}\d*))?\)$/))?(a=a.slice(1,4).map(b=>Number(b).toString(16).padStart(2,"0")).join(""),a[0]===a[1]&&a[2]===a[3]&&a[4]===a[5]?`#${a[0]}${a[2]}${a[4]}`:`#${a}`):"unknown"}
var oX=class{constructor(a,b,c){this.i=a;this.C=b;this.td=c;this.rules=this.td.rules;this.jl=this.td.jl;this.bC=ys(()=>0<this.rules().length);this.ft=WK;this.WA=XK;this.Du=[{type:"title",Md:"Match label"},{type:"list",Md:"Match attributes"},{type:"input",Md:"Match inputs (op node only)"},{type:"output",Md:"Match outputs (op node only)"}];this.Eu=[{type:"op_nodes",label:"Ops only"},{type:"layer_nodes",label:"Layers only"},{type:"op_and_layer_nodes",label:"Ops & layers"}];this.Bu=[{type:"regex",label:"Regex"},
{type:"attr_value_range",label:"Attribute value range"}];this.fd={minWidth:0,minHeight:0,maxWidth:340};this.mm={};Gs(()=>{this.mm=this.td.C();Zm(this.C)})}aw(a,b){gL(this.td,a,b)}get Xw(){return this.i.Ma().length}get zw(){return this.i.Ma()[0].id}get JD(){return this.i.Ma()[1].id}};oX.J=function(a){return new (a||oX)(y(NJ),y(Pr),y(jL))};
oX.Ca=Gf({type:oX,ga:[["node-styler-dialog"]],ja:!0,features:[Jr],ya:26,za:1,Ba:[["input",""],["helpQuery",""],["cb",""],["colorPicker",""],["colorInput",""],["numberInput",""],["mat-dialog-title","","cdkDrag","","cdkDragRootElement",".cdk-overlay-pane","cdkDragHandle","",1,"title-container"],[1,"title"],[1,"description"],["mat-dialog-content","",1,"dialog-content"],["border","0","cellspacing","0","cellpadding","0",1,"rules-table"],[1,"no-rules-message"],["mat-dialog-actions","",1,"btns-container"],
[1,"left-btns"],["mat-flat-button","","color","primary",1,"action-button","add-rule",3,"click"],["mat-flat-button","","color","primary",1,"action-button","load-rules",3,"click"],["mat-flat-button","","color","primary",1,"action-button","save-rules",3,"click"],["type","file","accept","application/JSON",1,"import-rules-input",3,"change"],["mat-button","","mat-dialog-close","",1,"close"],[1,"query"],[1,"query-header-container"],["dialogLabel","help",1,"icon-container",3,"xapInlineDialog","overlaySize",
"hoverDelayMs"],[1,"styles"],[1,"action-btns"],[1,"model-explorer-help-popup"],[1,"bold"],[3,"queriesUpdated","queries"],[1,"node-list-viewers-container"],[1,"node-list-viewer-container"],[1,"styles-container"],[1,"color-style-container"],[1,"action-buttons-container"],["matTooltip","Move up",1,"icon-container","move-up"],["matTooltip","Move down",1,"icon-container","move-down"],["matTooltip","Duplicate rule",1,"icon-container","duplicate-rule",3,"click"],["matTooltip","Delete rule",1,"icon-container",
"delete-rule",3,"click"],["labelSuffix","matched node",3,"nodes","rendererId"],[1,"label"],[1,"style-name-container"],["type","checkbox",3,"change","checked"],[3,"click"],[1,"color-picker-container"],["type","color",3,"change","value"],["type","text",3,"change","value"],[1,"number-editor-container"],[3,"change","value"],["matTooltip","Move up",1,"icon-container","move-up",3,"click"],["matTooltip","Move down",1,"icon-container","move-down",3,"click"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",
6)(1,"div",7);Z(2,"Node styler");S();R(3,"div",8);Z(4," Use the buttons below to apply styling rules to this graph ");S()();R(5,"div",9);yp(6,kX,16,3,"table",10)(7,lX,2,0,"div",11);S();R(8,"div",12)(9,"div",13)(10,"button",14);V("click",function(){u(c);aL(b.td);return x()});R(11,"mat-icon");Z(12,"add");S();Z(13," Add rule ");S();R(14,"button",15);V("click",function(){u(c);const d=wr(23);return x(d.click())});R(15,"mat-icon");Z(16,"file_upload");S();Z(17," Import rules ");S();R(18,"button",16);V("click",
function(){u(c);const d=document.createElement("a");d.download="node_styler_rules.json";const e=`data:text/json;charset=utf-8, ${encodeURIComponent(JSON.stringify(b.rules(),null,2))}`;ud(d,rd(e));d.click();return x()});R(19,"mat-icon");Z(20,"file_download");S();Z(21," Export rules ");S();R(22,"input",17,0);V("change",function(){u(c);const d=wr(23);return x(nX(b,d))});S()();R(24,"button",18);Z(25,"Done");S()()}a&2&&(D(6),Cq(b.bC()?6:7))},Ga:[et,SS,WT,VT,XS,uB,tB,oB,sC,lC,nC,pC,oC,TC,$F,tE,YF,aI,$H,
US,zG,wG],styles:["[_ngcontent-%COMP%]:not(mat-icon){font-family:Google Sans Text,Arial,Helvetica,sans-serif!important;letter-spacing:normal!important}.title-container[_ngcontent-%COMP%]{position:relative}.title[_ngcontent-%COMP%]{font-size:24px;font-weight:500;margin-top:-30px}.description[_ngcontent-%COMP%]{line-height:14px;font-size:12px;color:#777;margin-top:6px;margin-bottom:4px;font-weight:400}.btns-container[_ngcontent-%COMP%]{width:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;padding:0 24px}.action-button[_ngcontent-%COMP%]{height:30px;padding:0 10px;font-size:13px}.action-button[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{margin-right:2px}.import-rules-input[_ngcontent-%COMP%]{display:none}.dialog-content[_ngcontent-%COMP%]{padding:0;-moz-box-sizing:border-box;box-sizing:border-box;border-top:1px solid #e6e6e6;border-bottom:1px solid #e6e6e6;background-color:#f9f9f9;overflow:hidden auto}.dialog-content[_ngcontent-%COMP%]   .no-rules-message[_ngcontent-%COMP%]{padding:12px 24px;font-size:12px;color:#777}.common-input[_ngcontent-%COMP%]{padding:0 4px;border:1px solid #ccc;border-radius:4px;height:22px;-moz-box-sizing:border-box;box-sizing:border-box;outline:none}.common-input[_ngcontent-%COMP%]:focus{border-color:#1a73e8;outline:1px solid #1a73e8}.rules-table[_ngcontent-%COMP%]{width:100%;font-size:12px}.rules-table[_ngcontent-%COMP%]   td[_ngcontent-%COMP%]:not(.action-btns), .rules-table[_ngcontent-%COMP%]   th[_ngcontent-%COMP%]:not(.action-btns){border-right:1px solid #e6e6e6}.rules-table[_ngcontent-%COMP%]   tr[_ngcontent-%COMP%]   td[_ngcontent-%COMP%]{border-bottom:1px solid #e6e6e6}.rules-table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]{text-align:left;height:32px;position:-webkit-sticky;position:sticky;top:0;background-color:#f1f1f1;z-index:100}.rules-table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   th[_ngcontent-%COMP%]{font-weight:500;border-bottom:1px solid #e6e6e6}.rules-table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   th.query[_ngcontent-%COMP%]{padding-left:24px;width:410px}.rules-table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   th.query[_ngcontent-%COMP%]   .query-header-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.rules-table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   th.query[_ngcontent-%COMP%]   .query-header-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{width:16px;height:16px;opacity:.6;cursor:pointer;margin-left:4px}.rules-table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   th.query[_ngcontent-%COMP%]   .query-header-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:1}.rules-table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   th.query[_ngcontent-%COMP%]   .query-header-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;width:16px;height:16px}.rules-table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   th.target[_ngcontent-%COMP%]{padding-left:12px}.rules-table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   th.styles[_ngcontent-%COMP%]{padding-left:12px;min-width:254px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td[_ngcontent-%COMP%]{padding-top:8px;padding-bottom:8px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.query[_ngcontent-%COMP%]{padding-left:24px;padding-right:12px;vertical-align:top}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.query[_ngcontent-%COMP%]   .node-list-viewers-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;gap:12px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.query[_ngcontent-%COMP%]   .node-list-viewer-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;margin-top:12px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.query[_ngcontent-%COMP%]   .node-list-viewer-container[_ngcontent-%COMP%]   .label[_ngcontent-%COMP%]{line-height:18px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.target[_ngcontent-%COMP%]{vertical-align:top;padding-left:12px;padding-right:12px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.styles[_ngcontent-%COMP%]{padding-left:12px;padding-right:18px;vertical-align:top}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.styles[_ngcontent-%COMP%]   .styles-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;gap:2px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.action-btns[_ngcontent-%COMP%]{vertical-align:top;padding-right:12px;width:80px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.action-btns[_ngcontent-%COMP%]   .action-buttons-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-pack:end;-webkit-justify-content:flex-end;-moz-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;gap:2px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.action-btns[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;opacity:.6;cursor:pointer;margin-top:2px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.action-btns[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:1}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   td.action-btns[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;width:16px;height:16px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]   .style-name-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none;width:100px}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]   .style-name-container[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]{cursor:pointer}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]   .color-picker-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;overflow:hidden;border-radius:4px;border:1px solid #ccc;margin-left:4px;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;background-color:#fff;-moz-box-sizing:border-box;box-sizing:border-box;height:24px;position:relative}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]   .color-picker-container[_ngcontent-%COMP%]:focus-within{border-color:#1a73e8;outline:1px solid #1a73e8}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]   .color-picker-container[_ngcontent-%COMP%]   label[_ngcontent-%COMP%]{display:inline-block;width:16px;height:16px;margin:2px;background-color:red;border-radius:4px;cursor:pointer;border:1px solid #ddd}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]   .color-picker-container[_ngcontent-%COMP%]   label[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]{visibility:hidden}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]   .color-picker-container[_ngcontent-%COMP%]   input[type=text][_ngcontent-%COMP%]{width:100px;border:none;height:100%;background-color:transparent;outline:none}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]   .number-editor-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;overflow:hidden;margin-left:4px;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content}.rules-table[_ngcontent-%COMP%]   tbody[_ngcontent-%COMP%]   .color-style-container[_ngcontent-%COMP%]   .number-editor-container[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]{width:80px;height:28px;border:1px solid #ccc;border-radius:4px;background-color:transparent;-moz-box-sizing:border-box;box-sizing:border-box;padding:0 4px;outline:none}"],
Qa:0});var pX=class{constructor(a,b,c){this.Gh=a;this.i=b;this.wb=c;this.jl=this.i.jl}};pX.J=function(a){return new (a||pX)(y(iC),y(jL),y(ip))};
pX.Ca=Gf({type:pX,ga:[["node-styler"]],ja:!0,features:[Jr],ya:3,za:2,Ba:[["mat-icon-button","","aria-label","node-styler","matTooltip","Style nodes with custom rules",3,"click"]],sa:function(a,b){a&1&&(R(0,"button",0),V("click",function(){b.Gh.open(oX,{width:"800px",height:"600px",wb:b.wb,Sb:!1,Sm:!1})}),R(1,"mat-icon"),Z(2,"palette"),S()());a&2&&(D(),lq("highlight",b.jl()))},Ga:[et,uB,tB,rB,$F,tE,YF,qC,aI,$H,zG],styles:["button[_ngcontent-%COMP%]   mat-icon.highlight[_ngcontent-%COMP%]{background:-webkit-linear-gradient(45deg,#0089ff 0 30%,#f1af00 70% 100%);background:linear-gradient(45deg,#0089ff 0 30%,#f1af00 70% 100%);background-clip:text;-webkit-background-clip:text;-webkit-text-fill-color:transparent}"],
Qa:0});function qX(a){a&1&&(R(0,"div",5)(1,"a",6)(2,"button",7)(3,"mat-icon"),Z(4,"bug_report"),S()()(),R(5,"a",8)(6,"button",9)(7,"mat-icon"),Z(8,"article"),S()()()())}function rX(a){a&1&&(R(0,"div",5)(1,"a",10)(2,"button",11)(3,"mat-icon"),Z(4,"article"),S()()(),R(5,"a",12)(6,"button",13)(7,"mat-icon"),Z(8,"bug_report"),S()()()(),Kq(9,"open-in-new-tab-button"))}var sX=class{constructor(a){this.i=a;this.em=new Dk}get de(){return!1}get yd(){return!0}get BB(){return this.i.i}};
sX.J=function(a){return new (a||sX)(y(NJ))};
sX.Ca=Gf({type:sX,ga:[["title-bar"]],outputs:{em:"titleClicked"},ja:!0,features:[Jr],Yb:["*"],ya:14,za:3,Ba:[[1,"container"],["matTooltip","Back home",1,"title",3,"click","matTooltipDisabled"],[1,"right-container"],[1,"divider"],[1,"divider","tighter-right"],[1,"icons-container"],["href","https://b.corp.google.com/issues/new?component=1338731&template=1850894","target","_blank",1,"bug-report"],"mat-icon-button;;aria-label;bug;matTooltip;File bug or feature request".split(";"),["href","http://go/model-explorer-doc",
"target","_blank"],"mat-icon-button  aria-label doc matTooltip g3doc".split(" "),["href","https://github.com/google-ai-edge/model-explorer","target","_blank"],"mat-icon-button  aria-label doc matTooltip GitHub".split(" "),["href","https://github.com/google-ai-edge/model-explorer/issues","target","_blank"],"mat-icon-button;;aria-label;bug;matTooltip;File issue or feature request".split(";")],sa:function(a,b){a&1&&(Vq(),R(0,"div",0)(1,"div",1),V("click",function(){return b.em.emit()}),Kq(2,"me-logo"),
Z(3," Model Explorer "),Kq(4,"new-version-chip"),S(),R(5,"div",2),Kq(6,"node-data-provider-dropdown")(7,"div",3)(8,"graph-selector")(9,"div",4)(10,"node-styler"),yp(11,qX,9,0,"div",5)(12,rX,10,0),Wq(13),S()());a&2&&(D(),H("matTooltipDisabled",b.BB),D(10),Cq(b.de?11:-1),D(),Cq(b.yd?12:-1))},Ga:[et,uB,tB,rB,$F,tE,YF,rS,OJ,aI,$H,ZF,wS,ES,pX,cI],styles:[".container[_ngcontent-%COMP%]{width:100%;height:100%;padding:8px;padding-left:12px;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;border-bottom:1px solid #ddd}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]{font-weight:400;cursor:pointer;color:#444746;font-size:20px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   me-logo[_ngcontent-%COMP%]{margin-right:6px}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   new-version-chip[_ngcontent-%COMP%]{margin-left:16px}.container[_ngcontent-%COMP%]   .right-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .divider[_ngcontent-%COMP%]{width:1px;height:28px;border-left:1px solid #ccc;margin:0 16px}.container[_ngcontent-%COMP%]   .divider.tighter-right[_ngcontent-%COMP%]{margin-right:4px}.container[_ngcontent-%COMP%]   .icons-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .icons-container[_ngcontent-%COMP%]   a[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;color:#000}.container[_ngcontent-%COMP%]   open-in-new-tab-button[_ngcontent-%COMP%]{margin-left:8px}"],
Qa:0});function tX(a){a&1&&Kq(0,"benchmark-runner")}function uX(a){if(a&1){const b=Tg();R(0,"title-bar",4);V("titleClicked",function(){u(b);const c=Y(3);return x(c.em.emit())});Wq(1);S()}}function vX(a){a&1&&(R(0,"div",3),Z(1,"No graphs"),S())}function wX(a){a&1&&Kq(0,"split-panes-container")}function xX(a){a&1&&(yp(0,uX,2,0,"title-bar"),R(1,"div",2),yp(2,vX,2,0,"div",3)(3,wX,1,0,"split-panes-container"),S());a&2&&(a=Y(2),Cq(a.jE?0:-1),D(2),Cq(a.aC?2:3))}
function yX(a){if(a&1){const b=Tg();R(0,"div",1);V("dragover",function(c){u(b);const d=Y();return x(d.Lq(c))})("drop",function(c){u(b);const d=Y();return x(d.Mq(c))});yp(1,tX,1,0,"benchmark-runner")(2,xX,4,2,"div",2);S()}a&2&&(a=Y(),D(),Cq(a.yc?1:2))}HH`https://fonts.googleapis.com/icon?family=Material+Icons`;function zX(a){sa(function*(){yield a.K.K;a.ready=!0;Zm(a.D)})}
function AX(a,b,c){for(const d of a.graphCollections)for(const e of d.graphs)if(e.id===c&&(""===b||e.collectionLabel===b))return e}function BX(a,b,c){const d=rJ(a.i);d?tL(a.C,lI(),b,d,{[d.id]:c},!1):console.warn("Model graph in pane with index 0 doesn't exist")}function CX(a,b,c){const d=rJ(a.i);d?tL(a.C,lI(),b,d,c,!1):console.warn("Model graph in pane with index 0 doesn't exist")}function DX(a,b,c){sa(function*(){yield Promise.all(b.map(d=>wL(a.C,d,c)))})}
var EX=class{constructor(a,b,c,d,e,f,g){this.i=a;this.D=b;this.F=c;this.G=d;this.K=e;this.N=f;this.C=g;this.yc=!1;this.aD=[];this.em=new Dk;this.vy=new Dk;this.Gw=new Dk;this.ux=new Dk;this.ready=!1;Gs(()=>{const k=this.N.i();k&&this.vy.emit(k)});Gs(()=>{this.ux.emit(this.i.Mg())});window.addEventListener("message",k=>{k=k.data;switch(k.cmd){case "model-explorer-load-node-data-file":if(k=k.path){const m=rJ(this.i);m?DX(this,[k],m):console.warn("Model graph in pane with index 0 doesn't exist")}}});
C(this.i.ta,kL(this.F)).subscribe(k=>{this.Gw.next(k)});zX(this)}Eb(){this.i.config.set(this.config||{});ZI(this.i,this.graphCollections);this.i.K.set(this.Be);if(!this.Be||0===this.Be.paneStates.length){if(0<this.graphCollections.length&&0<this.graphCollections[0].graphs.length){var a=[...this.graphCollections[0].graphs].sort((d,e)=>e.nodes.length-d.nodes.length)[0];iJ(this.i,a)}}else if(1===this.Be.paneStates.length){var b=this.Be.paneStates[0];a=AX(this,b.selectedCollectionLabel,b.selectedGraphId);
b=!0===b.flattenLayers;a?iJ(this.i,a,b):iJ(this.i,this.graphCollections[0].graphs[0],b);kJ(this.i,b)}else if(2===this.Be.paneStates.length){a=this.Be.paneStates[0];b=AX(this,a.selectedCollectionLabel,a.selectedGraphId);var c=!0===a.flattenLayers;b?iJ(this.i,b,c):iJ(this.i,this.graphCollections[0].graphs[0],c);kJ(this.i,c);b=this.Be.paneStates[1];c=!0===b.flattenLayers;const d=AX(this,b.selectedCollectionLabel,b.selectedGraphId);d?$I(this.i,d,c):$I(this.i,this.graphCollections[0].graphs[0],c);a.selected?
nJ(this.i,0):b.selected&&nJ(this.i,1);sJ(this.i,a.widthFraction)}}Oq(a){if(" "===a.key)qI()||this.i.ea.next({});else if("f"===a.key&&(a.ctrlKey||a.metaKey)){let b;(null==(b=this.config)?0:b.hideTitleBar)||a.preventDefault();this.i.va.next({})}}Lq(a){a.preventDefault()}Mq(a){const b=this;return sa(function*(){if(a.dataTransfer){a.stopPropagation();a.preventDefault();var c=[],d;if(null==(d=a.dataTransfer)?0:d.items)[...a.dataTransfer.items].forEach(f=>{"file"===f.kind&&(f=f.getAsFile())&&c.push(f)});
else{var e;c.push(...((null==(e=a.dataTransfer)?void 0:e.files)||[]))}d=!1;if(0!==c.length)for(const f of c){if(!f.name.endsWith(".json"))continue;const g=new FileReader;e=yield new Promise(k=>{g.onload=m=>{let p;m=JSON.parse(null==(p=m.target)?void 0:p.result);k(m)};g.readAsText(f)});null!=e.results&&null==e.results.results?(BX(b,f.name,e),d=!0):Object.values(e).some(k=>null!=k.results)&&(CX(b,f.name,e),d=!0)}d||b.G.open("File(s) not supported","Dismiss")}})}get aC(){return 0===this.graphCollections.reduce((a,
b)=>a+b.graphs.length,0)}get jE(){let a;return!(null==(a=this.config)?0:a.hideTitleBar)}};EX.J=function(a){return new (a||EX)(y(NJ),y(Pr),y(wi),y(oE),y(rM),y(TI),y(CL))};
EX.Ca=Gf({type:EX,ga:[["model-graph-visualizer"]],Ha:function(a,b){a&1&&V("keydown",function(c){return b.Oq(c)},!1,Ai)},inputs:{graphCollections:"graphCollections",config:"config",Be:"initialUiState",yc:"benchmark",aD:"nodeDataSources"},outputs:{em:"titleClicked",vy:"uiStateChanged",Gw:"modelGraphProcessed",ux:"remoteNodeDataPathsChanged"},ja:!0,features:[Hr([NJ,YN,CL,jL,TI,UI]),Jr],Yb:["*"],ya:1,za:1,Ba:[["class","container",3,"dragover","drop",4,"ngIf"],[1,"container",3,"dragover","drop"],[1,"main"],
[1,"no-graphs-message"],[3,"titleClicked"]],sa:function(a,b){a&1&&(Vq(),yp(0,yX,3,1,"div",0));a&2&&H("ngIf",b.ready)},Ga:[XN,et,$s,sX,WR],styles:[".container[_ngcontent-%COMP%]{width:100%;height:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;position:relative}.container[_ngcontent-%COMP%]   benchmark-runner[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.container[_ngcontent-%COMP%]   title-bar[_ngcontent-%COMP%]{height:48px;min-height:48px}.container[_ngcontent-%COMP%]   .main[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;position:relative;overflow:hidden}.container[_ngcontent-%COMP%]   .main[_ngcontent-%COMP%]   .no-graphs-message[_ngcontent-%COMP%]{position:absolute;top:0;left:0;width:100%;height:100%;z-index:200;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;color:#999}.container[_ngcontent-%COMP%]   .main[_ngcontent-%COMP%]   split-panes-container[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1}.container[_ngcontent-%COMP%]   .main[_ngcontent-%COMP%]   graph-selector[_ngcontent-%COMP%]{position:absolute;top:12px;left:12px;z-index:100}  .model-explorer-help-popup{font-size:12px;padding:8px;background-color:#fff;line-height:normal}  .model-explorer-help-popup .bold{font-weight:700}  .model-explorer-help-popup .shortcut{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;color:#777;margin-top:8px}  .model-explorer-help-popup .shortcut mat-icon{font-size:20px;width:20px;height:20px;margin-right:2px;color:#777}  .model-explorer-help-popup .description{color:#777;margin-top:8px}"],
Qa:0});const FX=/^\/cns\/(.*)|^\/placer\/(.*)|^\/tfhub\/(.*)|^\/google_src\/(.*)|^\/google3\/(.*)|^google3\/(.*)/;function GX(a){return sa(function*(){return new Promise((b,c)=>{const d=new FileReader;d.onload=()=>{const e=JSON.parse(d.result),{graphCollections:f,error:g}=HX(a.name,e);g?c(g):f&&b(f)};d.readAsText(a)})})}
function HX(a,b){var c;null==b.modelTopology?c=null!=b.label&&null!=b.graphs?{graphCollections:[b]}:Array.isArray(b)&&null!=b[0].subgraphs?{graphCollections:IX(b,a)}:Array.isArray(b)&&(0===b.length||0<b.length&&null!=b[0].id&&null!=b[0].nodes)?{graphCollections:[{label:a,graphs:b}]}:{error:"Unsupported JSON format"}:c={graphCollections:[JX(a,b)]};return c}
function JX(a,b){b={id:"default",nodes:b.modelTopology.node.map(c=>({id:c.name,label:c.op,namespace:c.name,incomingEdges:(c.input||[]).map(d=>{const e=d.split(":");return{sourceNodeId:d,sourceNodeOutputId:2===e.length?e[1]:"0",targetNodeInputId:"0"}})}))};return{label:a,graphs:[b]}}function IX(a,b){return a.map(c=>({label:""===c.label?b:`${b} (${c.label})`,graphs:c.subgraphs}))};var KX={eF:"Not started",fF:"Converting",kF:"Uploading",DONE:"Done",ZE:"Error"};const LX=(a,b)=>b.id;function MX(a){a&1&&(R(0,"span",4),Z(1,"Default"),S())}function NX(a,b){if(a&1){const c=Tg();R(0,"div",2);V("click",function(){const d=u(c).ca;Y().ge.next(d);return x()});R(1,"div",3);Z(2);yp(3,MX,2,0,"span",4);S();R(4,"div",5);Z(5);S()()}if(a&2){a=b.ca;b=b.Bb;const c=Y();lq("selected",(null==c.Qc?null:c.Qc.id)===a.id);D(2);yr(" ",a.name||a.id," ");D();Cq(0===b?3:-1);D(2);yr(" ",a.description||"-"," ")}}var OX=class{constructor(){this.cq=[];this.ge=new Dk}};
OX.J=function(a){return new (a||OX)};
OX.Ca=Gf({type:OX,ga:[["adapter-selector-panel"]],inputs:{cq:"candidates",Qc:"selectedAdapter"},outputs:{ge:"onClose"},ja:!0,features:[Jr],ya:3,za:1,Ba:[[1,"container"],[1,"candidate-container",3,"selected"],[1,"candidate-container",3,"click"],[1,"name"],[1,"default-label"],[1,"description"]],sa:function(a,b){a&1&&(R(0,"div",0),Hq(1,NX,6,5,"div",1,LX),S());a&2&&(H("@transformPanel","showing"),D(),Jq(b.cq))},Ga:[et,$F,WA,aI,ID,wx],styles:[".container[_ngcontent-%COMP%]{box-shadow:0 2px 6px 2px rgba(0,0,0,.15),0 1px 2px 0 rgba(0,0,0,.3);-webkit-transform-origin:top center;transform-origin:top center;font-size:13px;padding:8px 0;border-radius:8px;background-color:#fff}.container[_ngcontent-%COMP%]   .candidate-container[_ngcontent-%COMP%]{padding:8px 16px}.container[_ngcontent-%COMP%]   .candidate-container.selected[_ngcontent-%COMP%]{background-color:#c2e7ff}.container[_ngcontent-%COMP%]   .candidate-container[_ngcontent-%COMP%]:hover:not(.selected){background-color:#f2f2f2;cursor:pointer}.container[_ngcontent-%COMP%]   .candidate-container[_ngcontent-%COMP%]   .name[_ngcontent-%COMP%]{font-size:14px;color:#1f1f1f;line-height:20px;margin-bottom:2px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .candidate-container[_ngcontent-%COMP%]   .name[_ngcontent-%COMP%]   .default-label[_ngcontent-%COMP%]{display:inline-block;padding:0 10px;-moz-box-sizing:border-box;box-sizing:border-box;background-color:#f3e0b4;color:#70571e;border:1px solid #dbac41;font-size:11px;line-height:14px;border-radius:99px;margin-left:8px}.container[_ngcontent-%COMP%]   .candidate-container[_ngcontent-%COMP%]   .description[_ngcontent-%COMP%]{font-size:12px;color:#444746}"],data:{animation:[Ry("transformPanel",
[Uy("void",Ty({opacity:0,transform:"scale(1, 0.8)"})),Vy("void => showing",Sy("120ms cubic-bezier(0, 0, 0.2, 1)",Ty({opacity:1,transform:"scale(1, 1)"}))),Vy("* => void",Sy("100ms linear",Ty({opacity:0})))])]},Qa:0});function PX(a,b){a=a.split("/").filter(c=>""!==c);a=a[a.length-1].split(".");return 1<a.length?b.i[a[a.length-1]]||[]:[]};function QX(a){sa(function*(){let b;b=yield RX();a.extensions=b;a.hd.set(!1)})}function SX(a){return sa(function*(){const b={method:"POST",headers:{"Content-Type":"application/json"}};b.body=JSON.stringify(a);try{const c=yield fetch("/apipost/v1/send_command",b);return c.ok?{hB:yield c.json()}:{Sw:`Failed to convert model. ${c.status}`}}catch(c){return{Sw:c}}})}
function RX(){return sa(function*(){try{const a=yield fetch("/api/v1/get_extensions",{credentials:"include"});return a.ok?yield a.json():(console.error(`Failed to get extensions: ${a.status}`),[])}catch(a){return console.error("Failed to get extensions.",a),[]}})}var TX=class{constructor(){this.hd=ur(!0);this.extensions=[];QX(this)}};TX.J=function(a){return new (a||TX)};TX.oa=Ld({la:TX,aa:TX.J,da:"root"});function UX(a,b){for(const c of Object.values(a.i))for(const d of c)if(d.id===b)return d}var VX=class{constructor(){this.i={}}register(a){for(const b of a.fileExts){null==this.i[b]&&(this.i[b]=[]);const c=this.i[b];null!=c.find(d=>d.id===a.id)?console.warn("Adapter extension exists",a):c.push(a)}}},WX=class extends VX{constructor(a){super();this.C=a;Gs(()=>{if(!this.C.hd())for(const b of this.C.extensions)"adapter"===b.type&&this.register(b)})}};WX.J=function(a){return new (a||WX)(q(TX))};
WX.oa=Ld({la:WX,aa:WX.J,da:"root"});var XX=Symbol("RouteTitle");function YX(a,b,c){const d=c.path.split("/");if(d.length>a.length||"full"===c.Yw&&(0<b.i||d.length<a.length))return null;b={};for(c=0;c<d.length;c++){const e=d[c],f=a[c];if(":"===e[0])b[e.substring(1)]=f;else if(e!==f.path)return null}return{Qk:a.slice(0,d.length),gx:b}};function ZX(a,b){const c=a?$X(a):void 0;var d=b?$X(b):void 0;if(!c||!d||c.length!=d.length)return!1;for(let e=0;e<c.length;e++)if(d=c[e],!aY(a[d],b[d]))return!1;return!0}function $X(a){return[...Object.keys(a),...Object.getOwnPropertySymbols(a)]}function aY(a,b){if(Array.isArray(a)&&Array.isArray(b)){if(a.length!==b.length)return!1;a=[...a].sort();const c=[...b].sort();return a.every((d,e)=>c[e]===d)}return a===b}function bY(a){return Ck(a)?a:pn(a)?Qj(Promise.resolve(a)):hj(a)};const eY={exact:cY,subset:dY},hY={exact:fY,subset:gY,ignored:()=>!0};function iY(a,b,c){return eY[c.paths](a.root,b.root,c.Fw)&&hY[c.sb](a.sb,b.sb)&&!("exact"===c.Xb&&a.Xb!==b.Xb)}function fY(a,b){return ZX(a,b)}function cY(a,b,c){if(!jY(a.segments,b.segments)||!kY(a.segments,b.segments,c)||a.i!==b.i)return!1;for(const d in b.children)if(!a.children[d]||!cY(a.children[d],b.children[d],c))return!1;return!0}
function gY(a,b){return Object.keys(b).length<=Object.keys(a).length&&Object.keys(b).every(c=>aY(a[c],b[c]))}function dY(a,b,c){return lY(a,b,b.segments,c)}
function lY(a,b,c,d){if(a.segments.length>c.length)return a=a.segments.slice(0,c.length),!jY(a,c)||0<b.i||!kY(a,c,d)?!1:!0;if(a.segments.length===c.length){if(!jY(a.segments,c)||!kY(a.segments,c,d))return!1;for(var e in b.children)if(!a.children[e]||!dY(a.children[e],b.children[e],d))return!1;return!0}e=c.slice(0,a.segments.length);c=c.slice(a.segments.length);return jY(a.segments,e)&&kY(a.segments,e,d)&&a.children.primary?lY(a.children.primary,b,c,d):!1}
function kY(a,b,c){return b.every((d,e)=>hY[c](a[e].parameters,d.parameters))}var oY=class{constructor(a=new mY([],{}),b={},c=null){this.root=a;this.sb=b;this.Xb=c}toString(){return nY(this)}},mY=class{constructor(a,b){this.segments=a;this.children=b;this.parent=null;Object.values(b).forEach(c=>c.parent=this)}get i(){return Object.keys(this.children).length}toString(){return pY(this)}},rY=class{constructor(a,b){this.path=a;this.parameters=b}toString(){return qY(this)}};
function sY(a,b){return jY(a,b)&&a.every((c,d)=>ZX(c.parameters,b[d].parameters))}function jY(a,b){return a.length!==b.length?!1:a.every((c,d)=>c.path===b[d].path)}function tY(a,b){let c=[];Object.entries(a.children).forEach(([d,e])=>{"primary"===d&&(c=c.concat(b(e,d)))});Object.entries(a.children).forEach(([d,e])=>{"primary"!==d&&(c=c.concat(b(e,d)))});return c}var uY=class{};uY.J=function(a){return new (a||uY)};uY.oa=Ld({la:uY,aa:()=>new vY,da:"root"});
function nY(a){const b=`/${wY(a.root,!0)}`,c=xY(a.sb);a="string"===typeof a.Xb?`#${encodeURI(a.Xb)}`:"";return`${b}${c}${a}`}
var vY=class{parse(a){a=new yY(a);zY(a,"/");var b=""===a.i||a.i.startsWith("?")||a.i.startsWith("#")?new mY([],{}):new mY([],AY(a));const c={};if(zY(a,"?")){do{var d,e,f=a.i.match(BY);if(e=f?f[0]:"")a.capture(e),f="",zY(a,"=")&&(d=(d=a.i.match(CY))?d[0]:"")&&(f=d,a.capture(f)),e=decodeURIComponent(e.replace(/\+/g,"%20")),f=decodeURIComponent(f.replace(/\+/g,"%20")),c.hasOwnProperty(e)?(d=c[e],Array.isArray(d)||(d=[d],c[e]=d),d.push(f)):c[e]=f}while(zY(a,"&"))}return new oY(b,c,zY(a,"#")?decodeURIComponent(a.i):
null)}};function pY(a){return a.segments.map(b=>qY(b)).join("/")}
function wY(a,b){if(!(0<a.i))return pY(a);if(b){b=a.children.primary?wY(a.children.primary,!1):"";const c=[];Object.entries(a.children).forEach(([d,e])=>{"primary"!==d&&c.push(`${d}:${wY(e,!1)}`)});return 0<c.length?`${b}(${c.join("//")})`:b}b=tY(a,(c,d)=>"primary"===d?[wY(a.children.primary,!1)]:[`${d}:${wY(c,!1)}`]);return 1===Object.keys(a.children).length&&null!=a.children.primary?`${pY(a)}/${b[0]}`:`${pY(a)}/(${b.join("//")})`}
function DY(a){return encodeURIComponent(a).replace(/%40/g,"@").replace(/%3A/gi,":").replace(/%24/g,"$").replace(/%2C/gi,",")}function EY(a){return DY(a).replace(/%3B/gi,";")}function FY(a){return DY(a).replace(/\(/g,"%28").replace(/\)/g,"%29").replace(/%26/gi,"&")}function qY(a){return`${FY(a.path)}${GY(a.parameters)}`}function GY(a){return Object.entries(a).map(([b,c])=>`;${FY(b)}=${FY(c)}`).join("")}
function xY(a){a=Object.entries(a).map(([b,c])=>Array.isArray(c)?c.map(d=>`${EY(b)}=${EY(d)}`).join("&"):`${EY(b)}=${EY(c)}`).filter(b=>b);return a.length?`?${a.join("&")}`:""}const HY=/^[^\/()?;#]+/;function IY(a){return(a=a.match(HY))?a[0]:""}const JY=/^[^\/()?;=#]+/,BY=/^[^=?&#]+/,CY=/^[^&#]+/;function zY(a,b){return a.i.startsWith(b)?(a.i=a.i.substring(b.length),!0):!1}
function AY(a){if(""===a.i)return{};zY(a,"/");const b=[];for(a.i.startsWith("(")||b.push(KY(a));a.i.startsWith("/")&&!a.i.startsWith("//")&&!a.i.startsWith("/(");)a.capture("/"),b.push(KY(a));let c={};a.i.startsWith("/(")&&(a.capture("/"),c=LY(a,!0));let d={};a.i.startsWith("(")&&(d=LY(a,!1));if(0<b.length||0<Object.keys(c).length)d.primary=new mY(b,c);return d}
function KY(a){var b=IY(a.i);if(""===b&&a.i.startsWith(";"))throw new Yd(4009,!1);a.capture(b);b=decodeURIComponent(b);const c={};for(;zY(a,";");){var d,e=a;if(d=(d=e.i.match(JY))?d[0]:""){e.capture(d);var f="";if(zY(e,"=")){const g=IY(e.i);g&&(f=g,e.capture(f))}c[decodeURIComponent(d)]=decodeURIComponent(f)}}return new rY(b,c)}
function LY(a,b){const c={};for(a.capture("(");!zY(a,")")&&0<a.i.length;){var d=IY(a.i),e=a.i[d.length];if("/"!==e&&")"!==e&&";"!==e)throw new Yd(4010,!1);e=void 0;-1<d.indexOf(":")?(e=d.slice(0,d.indexOf(":")),a.capture(e),a.capture(":")):b&&(e="primary");d=AY(a);c[e]=1===Object.keys(d).length?d.primary:new mY([],d);zY(a,"//")}return c}class yY{constructor(a){this.i=this.url=a}capture(a){if(!zY(this,a))throw new Yd(4011,!1);}}function MY(a){return 0<a.segments.length?new mY([],{primary:a}):a}
function NY(a){var b={};for(const [c,d]of Object.entries(a.children)){const e=c,f=NY(d);if("primary"===e&&0===f.segments.length&&0<f.i)for(const [g,k]of Object.entries(f.children))b[g]=k;else if(0<f.segments.length||0<f.i)b[e]=f}a=new mY(a.segments,b);1===a.i&&a.children.primary&&(b=a.children.primary,a=new mY(a.segments.concat(b.segments),b.children));return a}function OY(a){return a instanceof oY};function PY(a,b=null,c=null){a=QY(a);return RY(a,[],b,c)}function QY(a){function b(f){var g={};for(const k of f.children){const m=b(k);g[k.lb]=m}g=new mY(f.url,g);f===a&&(c=g);return g}let c;var d=b(a.root);d=MY(d);let e;return null!=(e=c)?e:d}
function RY(a,b,c,d){let e=a;for(;e.parent;)e=e.parent;if(0===b.length)return SY(e,e,e,c,d);b=TY(b);if(b.C&&1===b.i.length&&"/"==b.i[0])return SY(e,e,new mY([],{}),c,d);var f=e;if(b.C)a=new UY(f,!0,0);else if(a)if(null===a.parent)a=new UY(a,!0,0);else{f=a;a=a.segments.length-1+(VY(b.i[0])?0:1);let g=b.D;for(;g>a;){g-=a;f=f.parent;if(!f)throw new Yd(4005,!1);a=f.segments.length}a=new UY(f,!1,a-g)}else a=new UY(f,!1,NaN);b=a.i?WY(a.qf,a.index,b.i):XY(a.qf,a.index,b.i);return SY(e,a.qf,b,c,d)}
function VY(a){return"object"===typeof a&&null!=a&&!a.Fg&&!a.Dx}function YY(a){return"object"===typeof a&&null!=a&&a.Fg}function SY(a,b,c,d,e){let f={};d&&Object.entries(d).forEach(([g,k])=>{f[g]=Array.isArray(k)?k.map(m=>`${m}`):`${k}`});a=a===b?c:ZY(a,b,c);a=MY(NY(a));return new oY(a,f,e)}function ZY(a,b,c){const d={};Object.entries(a.children).forEach(([e,f])=>{d[e]=f===b?c:ZY(f,b,c)});return new mY(a.segments,d)}
class $Y{constructor(a,b,c){this.C=a;this.D=b;this.i=c;if(a&&0<c.length&&VY(c[0]))throw new Yd(4003,!1);if((a=c.find(YY))&&a!==(0<c.length?c[c.length-1]:null))throw new Yd(4004,!1);}}
function TY(a){if("string"===typeof a[0]&&1===a.length&&"/"===a[0])return new $Y(!0,0,a);let b=0,c=!1;a=a.reduce((d,e,f)=>{if("object"===typeof e&&null!=e){if(e.Fg){const g={};Object.entries(e.Fg).forEach(([k,m])=>{g[k]="string"===typeof m?m.split("/"):m});return[...d,{Fg:g}]}if(e.Dx)return[...d,e.Dx]}return"string"!==typeof e?[...d,e]:0===f?(e.split("/").forEach((g,k)=>{if(0!=k||"."!==g)0==k&&""===g?c=!0:".."===g?b++:""!=g&&d.push(g)}),d):[...d,e]},[]);return new $Y(c,b,a)}
class UY{constructor(a,b,c){this.qf=a;this.i=b;this.index=c}}
function XY(a,b,c){null!=a||(a=new mY([],{}));if(0===a.segments.length&&0<a.i)return WY(a,b,c);a:{var d=a;var e=0;let k=b;const m={match:!1,oo:0,ev:0};for(;k<d.segments.length;){if(e>=c.length){d=m;break a}const p=d.segments[k];var f=c[e];if(YY(f))break;f=`${f}`;var g=e<c.length-1?c[e+1]:null;if(0<k&&void 0===f)break;if(f&&g&&"object"===typeof g&&void 0===g.Fg){if(f!=p.path||!ZX(g,p.parameters)){d=m;break a}e+=2}else{g={};if(f!=p.path||!ZX(g,p.parameters)){d=m;break a}e++}k++}d={match:!0,oo:k,ev:e}}e=
c.slice(d.ev);return d.match&&d.oo<a.segments.length?(b=new mY(a.segments.slice(0,d.oo),{}),b.children.primary=new mY(a.segments.slice(d.oo),a.children),WY(b,0,e)):d.match&&0===e.length?new mY(a.segments,{}):!d.match||0<a.i?d.match?WY(a,0,e):aZ(a,b,c):aZ(a,b,c)}
function WY(a,b,c){if(0===c.length)return new mY(a.segments,{});const d=YY(c[0])?c[0].Fg:{primary:c},e={};if(Object.keys(d).some(f=>"primary"!==f)&&a.children.primary&&1===a.i&&0===a.children.primary.segments.length)return c=WY(a.children.primary,b,c),new mY(a.segments,c.children);Object.entries(d).forEach(([f,g])=>{"string"===typeof g&&(g=[g]);null!==g&&(e[f]=XY(a.children[f],b,g))});Object.entries(a.children).forEach(([f,g])=>{void 0===d[f]&&(e[f]=g)});return new mY(a.segments,e)}
function aZ(a,b,c){const d=a.segments.slice(0,b);let e=0;for(;e<c.length;){var f=c[e];if(YY(f))return a=bZ(f.Fg),new mY(d,a);if(0===e&&VY(c[0])){d.push(new rY(a.segments[b].path,cZ(c[0])));e++;continue}f=YY(f)?f.Fg.primary:`${f}`;const g=e<c.length-1?c[e+1]:null;f&&g&&VY(g)?(d.push(new rY(f,cZ(g))),e+=2):(d.push(new rY(f,{})),e++)}return new mY(d,{})}function bZ(a){const b={};Object.entries(a).forEach(([c,d])=>{"string"===typeof d&&(d=[d]);null!==d&&(b[c]=aZ(new mY([],{}),0,d))});return b}
function cZ(a){const b={};Object.entries(a).forEach(([c,d])=>b[c]=`${d}`);return b};var dZ=class{constructor(a,b){this.id=a;this.url=b}},eZ=class extends dZ{constructor(a,b,c=null){super(a,b);this.type=0;this.Lj=c}toString(){return`NavigationStart(id: ${this.id}, url: '${this.url}')`}},fZ=class extends dZ{constructor(a,b,c){super(a,b);this.Zb=c;this.type=1}toString(){return`NavigationEnd(id: ${this.id}, url: '${this.url}', urlAfterRedirects: '${this.Zb}')`}},gZ=class extends dZ{constructor(a,b,c,d){super(a,b);this.reason=c;this.code=d;this.type=2}toString(){return`NavigationCancel(id: ${this.id}, url: '${this.url}')`}},
hZ=class extends dZ{constructor(a,b){super(a,b);this.reason="";this.code=0;this.type=16}},iZ=class extends dZ{constructor(a,b,c,d){super(a,b);this.error=c;this.target=d;this.type=3}toString(){return`NavigationError(id: ${this.id}, url: '${this.url}', error: ${this.error})`}},jZ=class extends dZ{constructor(a,b,c,d){super(a,b);this.Zb=c;this.state=d;this.type=4}toString(){return`RoutesRecognized(id: ${this.id}, url: '${this.url}', urlAfterRedirects: '${this.Zb}', state: ${this.state})`}},kZ=class extends dZ{constructor(a,
b,c,d){super(a,b);this.Zb=c;this.state=d;this.type=7}toString(){return`GuardsCheckStart(id: ${this.id}, url: '${this.url}', urlAfterRedirects: '${this.Zb}', state: ${this.state})`}},lZ=class extends dZ{constructor(a,b,c,d,e){super(a,b);this.Zb=c;this.state=d;this.i=e;this.type=8}toString(){return`GuardsCheckEnd(id: ${this.id}, url: '${this.url}', urlAfterRedirects: '${this.Zb}', state: ${this.state}, shouldActivate: ${this.i})`}},mZ=class extends dZ{constructor(a,b,c,d){super(a,b);this.Zb=c;this.state=
d;this.type=5}toString(){return`ResolveStart(id: ${this.id}, url: '${this.url}', urlAfterRedirects: '${this.Zb}', state: ${this.state})`}},nZ=class extends dZ{constructor(a,b,c,d){super(a,b);this.Zb=c;this.state=d;this.type=6}toString(){return`ResolveEnd(id: ${this.id}, url: '${this.url}', urlAfterRedirects: '${this.Zb}', state: ${this.state})`}},oZ=class{constructor(a){this.i=a;this.type=9}toString(){return`RouteConfigLoadStart(path: ${this.i.path})`}},pZ=class{constructor(a){this.i=a;this.type=
10}toString(){return`RouteConfigLoadEnd(path: ${this.i.path})`}},qZ=class{constructor(a){this.jb=a;this.type=11}toString(){return`ChildActivationStart(path: '${this.jb.ib&&this.jb.ib.path||""}')`}},rZ=class{constructor(a){this.jb=a;this.type=12}toString(){return`ChildActivationEnd(path: '${this.jb.ib&&this.jb.ib.path||""}')`}},sZ=class{constructor(a){this.jb=a;this.type=13}toString(){return`ActivationStart(path: '${this.jb.ib&&this.jb.ib.path||""}')`}},tZ=class{constructor(a){this.jb=a;this.type=
14}toString(){return`ActivationEnd(path: '${this.jb.ib&&this.jb.ib.path||""}')`}},uZ=class{},vZ=class{constructor(a,b){this.url=a;this.Fl=b}};var xZ=class{constructor(a){this.wa=a;this.i=this.lb=null;this.children=new wZ(this.wa);this.C=null}};function yZ(a,b){let c=a.getContext(b);c||(c=new xZ(a.Cj),a.i.set(b,c));return c}function zZ(a,b){if(a=a.getContext(b))a.lb=null,a.C=null}var wZ=class{constructor(a){this.Cj=a;this.i=new Map}getContext(a){return this.i.get(a)||null}};wZ.J=function(a){return new (a||wZ)(q(ig))};wZ.oa=Ld({la:wZ,aa:wZ.J,da:"root"});function AZ(a,b){return BZ(b,a.ub).map(c=>c.value)}var DZ=class{constructor(a){this.ub=a}get root(){return this.ub.value}parent(a){a=AZ(this,a);return 1<a.length?a[a.length-2]:null}children(a){return(a=CZ(a,this.ub))?a.children.map(b=>b.value):[]}firstChild(a){return(a=CZ(a,this.ub))&&0<a.children.length?a.children[0].value:null}};function CZ(a,b){if(a===b.value)return b;for(const c of b.children)if(b=CZ(a,c))return b;return null}
function BZ(a,b){if(a===b.value)return[b];for(const c of b.children){const d=BZ(a,c);if(d.length)return d.unshift(b),d}return[]}var EZ=class{constructor(a,b){this.value=a;this.children=b}toString(){return`TreeNode(${this.value})`}};function FZ(a){const b={};a&&a.children.forEach(c=>b[c.value.lb]=c);return b};var HZ=class extends DZ{constructor(a,b){super(a);this.jb=b;GZ(this,a)}toString(){return this.jb.toString()}},IZ=class{constructor(a,b,c,d,e,f,g,k){this.K=a;this.F=b;this.G=c;this.D=d;this.C=e;this.lb=f;this.component=g;this.i=k;let m,p;this.title=null!=(p=null==(m=this.C)?void 0:C(m,vj(t=>t[XX])))?p:hj(void 0);this.url=a;this.params=b;this.sb=c;this.Xb=d;this.data=e}get ib(){return this.i.ib}get root(){return this.kg.root}get parent(){return this.kg.parent(this)}get firstChild(){return this.kg.firstChild(this)}get children(){return this.kg.children(this)}toString(){return this.jb?
this.jb.toString():`Future(${this.i})`}};
function JZ(a,b,c="emptyOnly"){const d=a.ib;let e;if(null===b||"always"!==c&&""!==(null==d?void 0:d.path)&&(b.component||(null==(e=b.ib)?0:e.Al))){let f;a={params:Object.assign({},a.params),data:Object.assign({},a.data),resolve:Object.assign({},a.data,null!=(f=a.i)?f:{})}}else a={params:Object.assign({},b.params,a.params),data:Object.assign({},b.data,a.data),resolve:Object.assign({},a.data,b.data,null==d?void 0:d.data,a.i)};!d||"string"!==typeof d.title&&null!==d.title||(a.resolve[XX]=d.title);return a}
var KZ=class{get title(){let a;return null==(a=this.data)?void 0:a[XX]}constructor(a,b,c,d,e,f,g,k,m){this.url=a;this.params=b;this.sb=c;this.Xb=d;this.data=e;this.lb=f;this.component=g;this.ib=k;this.C=m}get root(){return this.kg.root}get parent(){return this.kg.parent(this)}get firstChild(){return this.kg.firstChild(this)}get children(){return this.kg.children(this)}toString(){return`Route(url:'${this.url.map(a=>a.toString()).join("/")}', path:'${this.ib?this.ib.path:""}')`}},MZ=class extends DZ{constructor(a){super(a);
this.url="";GZ(this,a)}toString(){return LZ(this.ub)}};function GZ(a,b){b.value.kg=a;b.children.forEach(c=>GZ(a,c))}function LZ(a){const b=0<a.children.length?` { ${a.children.map(LZ).join(", ")} } `:"";return`${a.value}${b}`}
function NZ(a){if(a.jb){const d=a.jb,e=a.i;a.jb=e;ZX(d.sb,e.sb)||a.G.next(e.sb);d.Xb!==e.Xb&&a.D.next(e.Xb);ZX(d.params,e.params)||a.F.next(e.params);a:{var b=d.url;var c=e.url;if(b.length!==c.length)b=!1;else{for(let f=0;f<b.length;++f)if(!ZX(b[f],c[f])){b=!1;break a}b=!0}}b||a.K.next(e.url);ZX(d.data,e.data)||a.C.next(e.data)}else a.jb=a.i,a.C.next(a.i.data)}function OZ(a,b){const c=ZX(a.params,b.params)&&sY(a.url,b.url),d=!a.parent!==!b.parent;return c&&!d&&(!a.parent||OZ(a.parent,b.parent))};function PZ(a,b){let c;return(null==(c=a.C.getContext(b))?void 0:c.lb)===a}function QZ(a){var b=a.C,c=a.name;const d=yZ(b,c);d.lb=a;b.i.set(c,d);!a.i&&(b=a.C.getContext(a.name),null==b?0:b.i)&&(b.C?a.attach(b.C,b.i):RZ(a,b.i,b.wa))}function RZ(a,b,c){if(a.er)throw new Yd(4013,!1);a.D=b;const d=a.location,e=b.jb.component,f=yZ(a.C,a.name).children;a.i=op(d,e,{index:d.length,wa:new SZ(b,f,d.wa),Nf:c});Zm(a.G);let g;null==(g=a.F)||g.i(a);a.Au.emit(a.i.instance)}
var UZ=class{constructor(){this.D=this.i=null;this.name="primary";this.Au=new Dk;this.xv=new Dk;this.Ju=new Dk;this.Bv=new Dk;this.C=lf(wZ);this.location=lf(ip);this.G=lf(Pr);this.F=lf(TZ,{optional:!0})}rc(a){if(a.name){const {vn:b,jx:c}=a.name;b||(PZ(this,c)&&(this.hn(),zZ(this.C,c)),QZ(this))}}ua(){PZ(this,this.name)&&zZ(this.C,this.name);let a;null==(a=this.F)||a.C(this)}Eb(){QZ(this)}get er(){return!!this.i}get component(){if(!this.i)throw new Yd(4012,!1);return this.i.instance}detach(){if(!this.i)throw new Yd(4012,
!1);this.location.detach();const a=this.i;this.D=this.i=null;this.Bv.emit(a.instance);return a}attach(a,b){this.i=a;this.D=b;this.location.ar(a.i);let c;null==(c=this.F)||c.i(this);this.Ju.emit(a.instance)}hn(){if(this.i){const a=this.component;this.i.destroy();this.D=this.i=null;this.xv.emit(a)}}};UZ.J=function(a){return new (a||UZ)};UZ.Ea=Of({type:UZ,ga:[["router-outlet"]],inputs:{name:"name"},outputs:{Au:"activate",xv:"deactivate",Ju:"attach",Bv:"detach"},hb:["outlet"],ja:!0,features:[Cg]});
class SZ{D(a){return new SZ(this.i,this.C,a)}constructor(a,b,c){this.i=a;this.C=b;this.parent=c}get(a,b){return a===IZ?this.i:a===wZ?this.C:this.parent.get(a,b)}}var TZ=new df("");function VZ(a,b,c){if(c&&b.value.ib===c.value.jb.ib){var d=c.value;d.i=b.value;b=WZ(a,b,c);return new EZ(d,b)}d=XZ(b.value);b=b.children.map(e=>VZ(a,e));return new EZ(d,b)}function WZ(a,b,c){return b.children.map(d=>{for(const e of c.children)if(d.value.ib===e.value.jb.ib)return VZ(a,d,e);return VZ(a,d)})}function XZ(a){return new IZ(new cj(a.url),new cj(a.params),new cj(a.sb),new cj(a.Xb),new cj(a.data),a.lb,a.component,a)};function YZ(a){const {Pl:b,Fl:c}=OY(a)?{Pl:a,Fl:void 0}:a;a=ZZ(0);a.url=b;a.Fl=c;return a}function ZZ(a){const b=Error("NavigationCancelingError: ");b.ngNavigationCancelingError=!0;b.ZA=a;return b}function $Z(a){return!!a&&a.ngNavigationCancelingError};var a_=class{};a_.J=function(a){return new (a||a_)};a_.Ca=Gf({type:a_,ga:[["ng-component"]],ja:!0,features:[Jr],ya:1,za:0,sa:function(a){a&1&&Kq(0,"router-outlet")},Ga:[UZ],ob:2});function b_(a,b){a.Ua&&!a.Ya&&(a.Ya=on(a.Ua,b,`Route: ${a.path}`));let c;return null!=(c=a.Ya)?c:b}function c_(a){const b=a.children&&a.children.map(c_);a=b?Object.assign({},a,{children:b}):Object.assign({},a);a.component||a.Al||!b&&!a.Wn||!a.lb||"primary"===a.lb||(a.component=a_);return a}function d_(a){return a.lb||"primary"}function e_(a,b){const c=a.filter(d=>d_(d)===b);c.push(...a.filter(d=>d_(d)!==b));return c}
function f_(a){if(!a)return null;var b;if(null==(b=a.ib)?0:b.Ya)return a.ib.Ya;for(a=a.parent;a;a=a.parent){b=a.ib;let c;if(null==(c=b)?0:c.wk)return b.wk;let d;if(null==(d=b)?0:d.Ya)return b.Ya}return null};var j_=(a,b,c)=>vj(d=>{var e=new g_(b,d.dm,d.oq,c);const f=e.D.ub,g=e.i?e.i.ub:null;h_(e,f,g,a);NZ(e.D.root);i_(e,f,g,a);return d});function h_(a,b,c,d){const e=FZ(c);b.children.forEach(f=>{const g=f.value.lb;var k=e[g],m=f.value;const p=k?k.value:null;m===p?m.component?(m=d.getContext(m.lb))&&h_(a,f,k,m.children):h_(a,f,k,d):p&&k_(a,k,d);delete e[g]});Object.values(e).forEach(f=>{k_(a,f,d)})}
function i_(a,b,c,d){const e=FZ(c);b.children.forEach(f=>{var g=e[f.value.lb],k=f.value,m=g?g.value:null;NZ(k);k===m?k.component?(k=yZ(d,k.lb),i_(a,f,g,k.children)):i_(a,f,g,d):k.component?(g=yZ(d,k.lb),m=f_(k.jb),g.C=null,g.i=k,g.wa=null!=m?m:g.wa,g.lb&&RZ(g.lb,k,g.wa),i_(a,f,null,g.children)):i_(a,f,null,d);a.C(new tZ(f.value.jb))});b.children.length&&a.C(new rZ(b.value.jb))}
function k_(a,b,c){const d=c.getContext(b.value.lb);c=d&&b.value.component?d.children:c;b=FZ(b);for(const e of Object.values(b))k_(a,e,c);d&&(d.lb&&(d.lb.hn(),d.children.i=new Map),d.C=null,d.i=null)}var g_=class{constructor(a,b,c,d){this.hs=a;this.D=b;this.i=c;this.C=d}};const l_=Symbol("INITIAL_VALUE");function m_(){return Go(a=>C(Nj(a.map(b=>C(b,co(),Fo(l_)))),vj(b=>{for(const c of b)if(!0!==c){if(c===l_)return l_;if(!1===c||OY(c))return c}return!0}),rk(b=>b!==l_),co()))};var n_=class{constructor(a){this.path=a;this.i=this.path[this.path.length-1]}},o_=class{constructor(a,b){this.component=a;this.i=b}};function p_(a,b){const c=Symbol(),d=b.get(a,c);return d===c?"function"!==typeof a||null!==Nd(a)?b.get(a):a:d}function q_(a,b,c,d,e={canDeactivateChecks:[],canActivateChecks:[]}){const f=FZ(b);a.children.forEach(g=>{r_(g,f[g.value.lb],c,d.concat([g.value]),e);delete f[g.value.lb]});Object.entries(f).forEach(([g,k])=>s_(k,c.getContext(g),e));return e}
function r_(a,b,c,d,e={canDeactivateChecks:[],canActivateChecks:[]}){const f=a.value,g=b?b.value:null,k=c?c.getContext(a.value.lb):null;if(g&&f.ib===g.ib){const m=t_(g,f,f.ib.sG);m?e.canActivateChecks.push(new n_(d)):(f.data=g.data,f.i=g.i);f.component?q_(a,b,k?k.children:null,d,e):q_(a,b,c,d,e);m&&k&&k.lb&&k.lb.er&&e.canDeactivateChecks.push(new o_(k.lb.component,g))}else g&&s_(b,k,e),e.canActivateChecks.push(new n_(d)),f.component?q_(a,null,k?k.children:null,d,e):q_(a,null,c,d,e)}
function t_(a,b,c){if("function"===typeof c)return c(a,b);switch(c){case "pathParamsChange":return!jY(a.url,b.url);case "pathParamsOrQueryParamsChange":return!jY(a.url,b.url)||!ZX(a.sb,b.sb);case "always":return!0;case "paramsOrQueryParamsChange":return!OZ(a,b)||!ZX(a.sb,b.sb);default:return!OZ(a,b)}}
function s_(a,b,c){const d=FZ(a),e=a.value;Object.entries(d).forEach(([f,g])=>{e.component?b?s_(g,b.children.getContext(f),c):s_(g,null,c):s_(g,b,c)});e.component?b&&b.lb&&b.lb.er?c.canDeactivateChecks.push(new o_(b.lb.component,e)):c.canDeactivateChecks.push(new o_(null,e)):c.canDeactivateChecks.push(new o_(null,e))};function u_(a){return"function"===typeof a}function v_(a){return a instanceof nj||"EmptyError"===(null==a?void 0:a.name)};function w_(a,b){return Rj(c=>{const d=c.od,e=c.Dh;var f=c.pj;const g=f.canActivateChecks;f=f.canDeactivateChecks;return 0===f.length&&0===g.length?hj(Object.assign({},c,{Of:!0})):C(x_(f,d,e,a),Rj(k=>k&&"boolean"===typeof k?y_(d,g,a,b):hj(k)),vj(k=>Object.assign({},c,{Of:k})))})}function x_(a,b,c,d){return C(Qj(a),Rj(e=>z_(e.component,e.i,c,b,d)),mo(e=>!0!==e,!0))}
function y_(a,b,c,d){return C(Qj(b),Rj(e=>{var f=e.i.parent;null!==f&&d&&d(new qZ(f));f=hj(!0);var g=e.i;null!==g&&d&&d(new sZ(g));g=hj(!0);return fk(f,g,A_(a,e.path,c),B_(a,e.i,c))},1),mo(e=>!0!==e,!0))}function B_(a,b,c){var d=b.ib?b.ib.Pu:null;if(!d||0===d.length)return hj(!0);d=d.map(e=>gk(()=>{var f;const g=null!=(f=f_(b))?f:c,k=p_(e,g);f=k&&u_(k.Pu)?k.Pu(b,a):wg(g,()=>k(b,a));return C(bY(f),mo())}));return C(hj(d),m_())}
function A_(a,b,c){const d=b[b.length-1];b=b.slice(0,b.length-1).reverse().map(e=>{const f=e.ib?e.ib.Qu:null;return f&&0!==f.length?{node:e,pj:f}:null}).filter(e=>null!==e).map(e=>gk(()=>{const f=e.pj.map(g=>{let k;const m=null!=(k=f_(e.node))?k:c,p=p_(g,m);g=p&&u_(p.Qu)?p.Qu(d,a):wg(m,()=>p(d,a));return C(bY(g),mo())});return C(hj(f),m_())}));return C(hj(b),m_())}
function z_(a,b,c,d,e){var f=b&&b.ib?b.ib.Ru:null;if(!f||0===f.length)return hj(!0);f=f.map(g=>{let k;const m=null!=(k=f_(b))?k:e,p=p_(g,m);g=p&&u_(p.Ru)?p.Ru(a,b,c,d):wg(m,()=>p(a,b,c,d));return C(bY(g),mo())});return C(hj(f),m_())}function C_(a,b,c){var d=b.Su;if(void 0===d||0===d.length)return hj(!0);d=d.map(e=>{const f=p_(e,a);e=f&&u_(f.Su)?f.Su(b,c):wg(a,()=>f(b,c));return bY(e)});return C(hj(d),m_(),D_())}
function D_(){return Si([No(a=>{if("boolean"!==typeof a)throw YZ(a);}),vj(a=>!0===a)])}function E_(a,b,c){var d=b.Tu;if(!d||0===d.length)return hj(!0);d=d.map(e=>{const f=p_(e,a);e=f&&u_(f.Tu)?f.Tu(b,c):wg(a,()=>f(b,c));return bY(e)});return C(hj(d),m_(),D_())};var F_=class{constructor(a){this.qf=a||null}},G_=class extends Error{constructor(a){super();this.i=a}};function H_(a){return ij(new F_(a))}function I_(a){let b=[];for(a=a.root;;){b=b.concat(a.segments);if(0===a.i)return hj(b);if(1<a.i||!a.children.primary)return ij(new Yd(4E3,!1));a=a.children.primary}}function J_(a,b,c,d,e){b=K_(a,b,c.root,d,e);return new oY(b,L_(c.sb,a.C.sb),c.Xb)}
function M_(a,b,c,d,e,f){if("string"!==typeof c){const g=c,k=e.sb,m=e.Xb,p=e.ib,t=e.url,v=e.lb,B=e.params,G=e.data,K=e.title;c=wg(f,()=>g({params:B,data:G,sb:k,Xb:m,ib:p,url:t,lb:v,title:K}));if(c instanceof oY)throw new G_(c);}a=J_(a,c,a.i.parse(c),b,d);if("/"===c[0])throw new G_(a);return a}function K_(a,b,c,d,e){const f=N_(c.segments,d,e);let g={};Object.entries(c.children).forEach(([k,m])=>{g[k]=K_(a,b,m,d,e)});return new mY(f,g)}
function L_(a,b){const c={};Object.entries(a).forEach(([d,e])=>{c[d]="string"===typeof e&&":"===e[0]?b[e.substring(1)]:e});return c}function N_(a,b,c){return a.map(d=>{if(":"===d.path[0]){if(d=c[d.path.substring(1)],!d)throw new Yd(4001,!1);}else a:{let e=0;for(const f of b){if(f.path===d.path){b.splice(e);d=f;break a}e++}}return d})}var O_=class{constructor(a,b){this.i=a;this.C=b}};const P_={Nh:!1,Rk:[],Rl:[],parameters:{},so:{}};function Q_(a,b,c,d){const e=R_(a,b,c);if(!e.Nh)return hj(e);d=b_(b,d);return C(E_(d,b,c),vj(f=>!0===f?e:Object.assign({},P_)))}
function R_(a,b,c){if("**"===b.path)return{Nh:!0,parameters:0<c.length?(0<c.length?c[c.length-1]:null).parameters:{},Rk:c,Rl:[],so:{}};if(""===b.path)return"full"===b.Yw&&(0<a.i||0<c.length)?Object.assign({},P_):{Nh:!0,Rk:[],Rl:c,parameters:{},so:{}};a=(b.lr||YX)(c,a,b);if(!a)return Object.assign({},P_);const d={};var e;Object.entries(null!=(e=a.gx)?e:{}).forEach(([g,k])=>{d[g]=k.path});e=0<a.Qk.length?Object.assign({},d,a.Qk[a.Qk.length-1].parameters):d;let f;return{Nh:!0,Rk:a.Qk,Rl:c.slice(a.Qk.length),
parameters:e,so:null!=(f=a.gx)?f:{}}}function S_(a,b,c,d){if(0<c.length&&T_(a,c,d)){var e=mY;a=new mY(c,a.children);c={};c.primary=a;for(var f of d)""===f.path&&"primary"!==d_(f)&&(d=new mY([],{}),c[d_(f)]=d);c={qf:new e(b,c),xs:[]}}else if(0===c.length&&U_(a,c,d)){b=mY;f=a.segments;var g=a.children;const k={};for(e of d)V_(a,c,e)&&!g[d_(e)]&&(d=new mY([],{}),k[d_(e)]=d);d=Object.assign({},g,k);c={qf:new b(f,d),xs:c}}else c={qf:new mY(a.segments,a.children),xs:c};return c}
function T_(a,b,c){return c.some(d=>V_(a,b,d)&&"primary"!==d_(d))}function U_(a,b,c){return c.some(d=>V_(a,b,d))}function V_(a,b,c){return(0<a.i||0<b.length)&&"full"===c.Yw?!1:""===c.path};class W_{}function X_(a,b,c,d,e,f,g="emptyOnly"){return(new Y_(a,b,c,d,e,g,f)).recognize()}function Z_(a,b,c,d,e,f){return 0===d.segments.length&&0<d.i?$_(a,b,c,d,f):C(a0(a,b,c,d,d.segments,e,!0,f),vj(g=>g instanceof EZ?[g]:[]))}
function $_(a,b,c,d,e){const f=[];for(const g of Object.keys(d.children))"primary"===g?f.unshift(g):f.push(g);return C(Qj(f),Rj(g=>{const k=d.children[g],m=e_(c,g);return Z_(a,b,m,k,g,e)},1),uo((g,k)=>{g.push(...k);return g}),Sn(null),qo(),Rj(g=>{if(null===g)return H_(d);g=b0(g);c0(g);return hj(g)}))}
function a0(a,b,c,d,e,f,g,k){return C(Qj(c),Rj(m=>{let p;return C(d0(a,null!=(p=m.Ya)?p:b,c,m,d,e,f,g,k),Kn(t=>{if(t instanceof F_)return hj(null);throw t;}))},1),mo(m=>!!m),Kn(m=>{if(v_(m))return 0!==e.length||d.children[f]?H_(d):hj(new W_);throw m;}))}function d0(a,b,c,d,e,f,g,k,m){return(d_(d)===g||"primary"!==g&&V_(e,f,d))&&R_(e,d,f).Nh?void 0===d.Pl?e0(a,b,e,d,f,g,m):a.D&&k?f0(a,b,e,c,d,f,g,m):H_(e):H_(e)}
function e0(a,b,c,d,e,f,g){const k=Q_(c,d,e,b);"**"===d.path&&(c.children={});return C(k,Go(m=>{if(!m.Nh)return H_(c);let p;b=null!=(p=d.Ya)?p:b;return C(g0(a,b,d,e),Go(({Nj:t})=>{var v;const B=null!=(v=d.wk)?v:b;v=m.Rk;const G=m.Rl;var K;let N;const aa=new KZ(v,m.parameters,Object.freeze(Object.assign({},a.i.sb)),a.i.Xb,d.data||{},d_(d),null!=(N=null!=(K=d.component)?K:d.vk)?N:null,d,d.resolve||{});K=JZ(aa,g,a.Bj);aa.params=Object.freeze(K.params);aa.data=Object.freeze(K.data);const {qf:ca,xs:ia}=
S_(c,v,G,t);return 0===ia.length&&0<ca.i?C($_(a,B,t,ca,aa),vj(O=>new EZ(aa,O))):0===t.length&&0===ia.length?hj(new EZ(aa,[])):C(a0(a,B,t,ca,ia,d_(d)===f?"primary":f,!0,aa),vj(O=>new EZ(aa,O instanceof EZ?[O]:[])))}))}))}
function f0(a,b,c,d,e,f,g,k){const {Nh:m,parameters:p,Rk:t,so:v,Rl:B}=R_(c,e,f);if(!m)return H_(c);"string"===typeof e.Pl&&"/"===e.Pl[0]&&(a.C++,31<a.C&&(a.D=!1));var G;let K;f=new KZ(f,p,Object.freeze(Object.assign({},a.i.sb)),a.i.Xb,e.data||{},d_(e),null!=(K=null!=(G=e.component)?G:e.vk)?K:null,e,e.resolve||{});G=JZ(f,k,a.Bj);f.params=Object.freeze(G.params);f.data=Object.freeze(G.data);e=M_(a.N,t,e.Pl,v,f,b);return C(I_(e),Rj(N=>a0(a,b,d,c,N.concat(B),g,!1,k)))}
function g0(a,b,c,d){return c.children?hj({Nj:c.children,wa:b}):c.Wn?void 0!==c.Cm?hj({Nj:c.Cm,wa:c.wk}):C(C_(b,c,d),Rj(e=>e?C(a.F.Wn(b,c),No(f=>{c.Cm=f.Nj;c.wk=f.wa})):ij(ZZ(3)))):hj({Nj:[],wa:b})}
var Y_=class{constructor(a,b,c,d,e,f,g){this.wa=a;this.F=b;this.G=c;this.config=d;this.i=e;this.Bj=f;this.K=g;this.N=new O_(this.K,this.i);this.C=0;this.D=!0}recognize(){const a=S_(this.i.root,[],[],this.config).qf;return C(this.match(a),vj(({children:b,LD:c})=>{b=new MZ(new EZ(c,b));c=PY(c,this.i.sb,this.i.Xb);c.sb=this.i.sb;b.url=nY(c);return{state:b,qy:c}}))}match(a){const b=new KZ([],Object.freeze({}),Object.freeze(Object.assign({},this.i.sb)),this.i.Xb,Object.freeze({}),"primary",this.G,null,
{});return C(Z_(this,this.wa,this.config,a,"primary",b),vj(c=>({children:c,LD:b})),Kn(c=>{if(c instanceof G_)return this.i=c.i,this.match(c.i.root);if(c instanceof F_)throw new Yd(4002,`'${c.qf}'`);throw c;}))}};function c0(a){a.sort((b,c)=>"primary"===b.value.lb?-1:"primary"===c.value.lb?1:b.value.lb.localeCompare(c.value.lb))}function h0(a){return(a=a.value.ib)&&""===a.path}
function b0(a){const b=[],c=new Set;for(const d of a)h0(d)?(a=b.find(e=>d.value.ib===e.value.ib),void 0!==a?(a.children.push(...d.children),c.add(a)):b.push(d)):b.push(d);for(const d of c)a=b0(d.children),b.push(new EZ(d.value,a));return b.filter(d=>!c.has(d))};function i0(a,b,c,d,e,f){return Rj(g=>C(X_(a,b,c,d,g.ed,e,f),vj(({state:k,qy:m})=>Object.assign({},g,{od:k,Zb:m}))))};function j0(a,b){return Rj(c=>{const d=c.od,e=c.pj.canActivateChecks;if(!e.length)return hj(c);const f=new Set(e.map(m=>m.i)),g=new Set;for(const m of f)if(!g.has(m))for(const p of k0(m))g.add(p);let k=0;return C(Qj(g),Rj(m=>{if(f.has(m))return l0(m,d,a,b);m.data=JZ(m,m.parent,a).resolve;return hj(void 0)},1),No(()=>k++),no(),Rj(()=>k===g.size?hj(c):dj))})}function k0(a){const b=a.children.map(c=>k0(c)).flat();return[a,...b]}
function l0(a,b,c,d){const e=a.ib,f=a.C;void 0!==(null==e?void 0:e.title)&&"string"!==typeof e.title&&null!==e.title&&(f[XX]=e.title);return C(m0(f,a,b,d),vj(g=>{a.i=g;a.data=JZ(a,a.parent,c).resolve;return null}))}function m0(a,b,c,d){const e=$X(a);if(0===e.length)return hj({});const f={};return C(Qj(e),Rj(g=>C(n0(a[g],b,c,d),mo(),No(k=>{f[g]=k}))),no(),ro(f),Kn(g=>v_(g)?dj:ij(g)))}
function n0(a,b,c,d){let e;const f=null!=(e=f_(b))?e:d,g=p_(a,f);a=g.resolve?g.resolve(b,c):wg(f,()=>g(b,c));return bY(a)};function o0(a){return Go(b=>{const c=a(b);return c?C(Qj(c),vj(()=>b)):hj(b)})};function p0(a){let b;for(a=a.root;void 0!==a;){let c;b=null!=(c=a.data[XX])?c:b;a=a.children.find(d=>"primary"===d.lb)}return b}var q0=class{};q0.J=function(a){return new (a||q0)};q0.oa=Ld({la:q0,aa:()=>lf(r0),da:"root"});var r0=class extends q0{constructor(a){super();this.title=a}};r0.J=function(a){return new (a||r0)(q(nH))};r0.oa=Ld({la:r0,aa:r0.J,da:"root"});var s0=new df("",{da:"root",aa:()=>({})});var t0=new df(""),w0=class{constructor(){this.C=new WeakMap;this.i=new WeakMap;lf(ms)}Al(a){if(this.C.get(a))return this.C.get(a);if(a.vk)return hj(a.vk);this.D&&this.D(a);var b=C(bY(a.Al()),vj(u0),No(c=>{this.F&&this.F(a);a.vk=c}),ko(()=>{this.C.delete(a)}));b=C(new sj(b,()=>new aj),qj());this.C.set(a,b);return b}Wn(a,b){if(this.i.get(b))return this.i.get(b);if(b.Cm)return hj({Nj:b.Cm,wa:b.wk});this.D&&this.D(b);a=C(v0(b,a,this.F),ko(()=>{this.i.delete(b)}));a=C(new sj(a,()=>new aj),qj());this.i.set(b,
a);return a}};w0.J=function(a){return new (a||w0)};w0.oa=Ld({la:w0,aa:w0.J,da:"root"});function v0(a,b,c){return C(bY(a.Wn()),vj(u0),Rj(d=>d instanceof Zh||Array.isArray(d)?hj(d):Qj(Promise.resolve(new mn(d)))),vj(d=>{c&&c(a);let e;Array.isArray(d)||(e=d.create(b).wa,d=e.get(t0,[],{optional:!0,self:!0}).flat());return{Nj:d.map(c_),wa:e}}))}function u0(a){return a&&"object"===typeof a&&"default"in a?a["default"]:a};var x0=class{};x0.J=function(a){return new (a||x0)};x0.oa=Ld({la:x0,aa:()=>lf(y0),da:"root"});var y0=class{merge(a){return a}};y0.J=function(a){return new (a||y0)};y0.oa=Ld({la:y0,aa:y0.J,da:"root"});var z0=new df("");new df("");var A0=new df("");function B0(a,b){const c=++a.Uh;let d;null==(d=a.Yg)||d.next(Object.assign({},a.Yg.value,b,{id:c}))}function C0(a,b,c){c=new gZ(b.id,nY(b.ed),"",c);a.ec.next(c);b.resolve(!1)}function D0(a){let b,c;return(null==(b=a.i)?void 0:b.ed.toString())!==(null==(c=a.i)?void 0:c.Rb.toString())}function E0(a){let b,c;return a.K.parse(a.location.path(!0)).toString()!==(null==(b=a.i)?void 0:b.ed.toString())&&!(null==(c=a.i)?0:c.extras.Sj)}
function F0(a,b,c,d){a.Yg=new cj({id:0,Rb:c,wv:c,ed:c,Zb:c,vo:c,extras:{},resolve:()=>{},reject:()=>{},promise:Promise.resolve(!0),source:"imperative",Lj:null,Dh:d.jb,od:null,oq:d,dm:null,pj:{canActivateChecks:[],canDeactivateChecks:[]},Of:null});return C(a.Yg,rk(e=>0!==e.id),vj(e=>Object.assign({},e,{ed:e.vo})),Go(e=>{let f=!1,g=!1;return C(hj(e),Go(k=>{if(a.Uh>e.id)return C0(a,e,1),dj;a.i=e;a.C={id:k.id,Xq:k.vo,ed:k.ed,Ke:k.source,extras:k.extras,AD:a.F?Object.assign({},a.F,{AD:null}):null};const m=
!b.bo||D0(a)||E0(a);let p;const t=null!=(p=k.extras.Dr)?p:b.Dr;return m||"reload"===t?C(hj(k),Go(v=>{let B;const G=null==(B=a.Yg)?void 0:bj(B);a.ec.next(new eZ(v.id,nY(v.ed),v.Lj));let K;return G!==(null==(K=a.Yg)?void 0:bj(K))?dj:Promise.resolve(v)}),i0(a.Nf,a.D,a.G,b.config,a.K,a.Bj),No(v=>{e.od=v.od;e.Zb=v.Zb;a.C=Object.assign({},a.C,{el:v.Zb});v=new jZ(v.id,nY(v.ed),nY(v.Zb),v.od);a.ec.next(v)})):(a.ec.next(new hZ(k.id,nY(k.vo))),k.resolve(!1),dj)}),No(k=>{k=new kZ(k.id,nY(k.ed),nY(k.Zb),k.od);
a.ec.next(k)}),vj(k=>{var m=Object,p=m.assign;var t=k.Dh;const v=k.od.ub;t=q_(v,t?t.ub:null,a.N,[v.value]);return a.i=e=p.call(m,{},k,{pj:t})}),w_(a.Nf,k=>a.ec.next(k)),No(k=>{if((e.Of=k.Of)&&"boolean"!==typeof k.Of)throw YZ(k.Of);k=new lZ(k.id,nY(k.ed),nY(k.Zb),k.od,!!k.Of);a.ec.next(k)}),rk(k=>k.Of?!0:(C0(a,k,3),!1)),o0(k=>{if(k.pj.canActivateChecks.length)return C(hj(k),No(m=>{m=new mZ(m.id,nY(m.ed),nY(m.Zb),m.od);a.ec.next(m)}),Go(m=>{let p=!1;return C(hj(m),j0(a.Bj,a.Nf),No({next:()=>p=!0,complete:()=>
{p||C0(a,m,2)}}))}),No(m=>{m=new nZ(m.id,nY(m.ed),nY(m.Zb),m.od);a.ec.next(m)}))}),o0(k=>{const m=p=>{const t=[];let v;(null==(v=p.ib)?0:v.Al)&&!p.ib.vk&&t.push(C(a.D.Al(p.ib),No(B=>{p.component=B}),vj(()=>{})));for(const B of p.children)t.push(...m(B));return t};return C(Nj(m(k.od.root)),Sn(null),co())}),o0(()=>a.R()),Go(()=>{const k=e.Dh,m=e.od;let p;const t=null==(p=a.T)?void 0:p.call(a,a.Nf,k.root,m.root);return t?C(Qj(t),vj(()=>e)):hj(e)}),vj(k=>{var m=k.od;var p=k.oq;p=VZ(b.hs,m.ub,p?p.ub:void 0);
m=new HZ(p,m);a.i=e=Object.assign({},k,{dm:m});a.C.dm=m;return e}),No(()=>{a.ec.next(new uZ)}),j_(a.N,b.hs,k=>a.ec.next(k)),co(),No({next:k=>{f=!0;a.F=a.C;a.ec.next(new fZ(k.id,nY(k.ed),nY(k.Zb)));let m;if(null!=(m=a.ia)){const p=p0(k.dm.jb);void 0!==p&&(m.title.i.title=p||"")}k.resolve(!0)},complete:()=>{f=!0}}),Jo(C(a.O,No(k=>{throw k;}))),ko(()=>{f||g||C0(a,e,1);let k;(null==(k=a.i)?void 0:k.id)===e.id&&(a.C=null,a.i=null)}),Kn(k=>{g=!0;if($Z(k))a.ec.next(new gZ(e.id,nY(e.ed),k.message,k.ZA)),
$Z(k)&&OY(k.url)?a.ec.next(new vZ(k.url,k.Fl)):e.resolve(!1);else{let m;const p=new iZ(e.id,nY(e.ed),k,null!=(m=e.od)?m:void 0);try{wg(a.Nf,()=>{let v;return null==(v=a.ea)?void 0:v.call(a,p)});a.ec.next(p);const t=b.sn(k);e.resolve(!!t)}catch(t){a.options.pG?e.resolve(!1):e.reject(t)}}return dj}))}))}
var G0=class{get ba(){return 0!==this.Uh}constructor(){this.F=this.i=this.C=null;this.ec=new aj;this.O=new aj;this.D=lf(w0);this.Nf=lf(ig);this.K=lf(uY);this.N=lf(wZ);this.location=lf(Bt);lf(TZ,{optional:!0});this.ia=lf(q0);this.options=lf(s0,{optional:!0})||{};this.Bj=this.options.Bj||"emptyOnly";lf(x0);this.T=lf(z0,{optional:!0});this.ea=lf(A0,{optional:!0});this.Uh=0;this.R=()=>hj(void 0);this.G=null;this.D.F=a=>this.ec.next(new pZ(a));this.D.D=a=>this.ec.next(new oZ(a))}complete(){let a;null==
(a=this.Yg)||a.complete()}};G0.J=function(a){return new (a||G0)};G0.oa=Ld({la:G0,aa:G0.J,da:"root"});var H0=class{};H0.J=function(a){return new (a||H0)};H0.oa=Ld({la:H0,aa:()=>lf(I0),da:"root"});var J0=class{store(){}},I0=class extends J0{};I0.J=(()=>{let a;return function(b){return(a||(a=Lh(I0)))(b||I0)}})();I0.oa=Ld({la:I0,aa:I0.J,da:"root"});var K0=class{};K0.J=function(a){return new (a||K0)};K0.oa=Ld({la:K0,aa:()=>lf(L0),da:"root"});function M0(a){return{Je:a.Je,Rb:a.Rb,Ld:a.Ld}}function N0(a,b){return a.location.subscribe(c=>{"popstate"===c.type&&b(c.url,c.state)})}function O0(a,b,c){b=nY(b);var d=a.location;d.path()==d.normalize(b+qt(""))||c.extras.Tl?(c=Object.assign({},c.extras.state,P0(a,c.id,a.C)),yt(a.location,b,c)):(c=Object.assign({},c.extras.state,P0(a,c.id,a.C+1)),xt(a.location,b,c))}
function Q0(a,b,c=!1){"computed"===a.Mk?(c=a.i-a.C,0!==c?zt(a.location,c):a.Rb===b.el&&0===c&&(R0(a,b),S0(a))):"replace"===a.Mk&&(c&&R0(a,b),S0(a))}function P0(a,b,c){return"computed"===a.Mk?{Uh:b,Sy:c}:{Uh:b}}function R0(a,b){a.Ld=a.F.Ld;a.Rb=a.F.Rb;let c;a.Je=a.D.merge(a.Rb,null!=(c=b.el)?c:a.Je)}function S0(a){yt(a.location,nY(a.Je),P0(a,a.G,a.i))}
var L0=class extends K0{constructor(){super(...arguments);this.location=lf(Bt);lf(uY);this.options=lf(s0,{optional:!0})||{};this.Mk=this.options.Mk||"replace";this.D=lf(x0);this.Wj=this.options.Wj||"deferred";this.Je=this.Rb=new oY;this.i=0;this.G=-1;const a=new MZ(new EZ(new KZ([],{},{},"",{},"primary",null,null,{}),[])),b=new IZ(new cj([new rY("",{})]),new cj({}),new cj({}),new cj(""),new cj({}),"primary",null,a.root);b.jb=a.root;this.Ld=new HZ(new EZ(b,[]),a);this.F=M0(this)}Lj(){return this.location.getState()}get C(){if("computed"!==
this.Mk)return this.i;let a,b;return null!=(b=null==(a=this.Lj())?void 0:a.Sy)?b:this.i}};L0.J=(()=>{let a;return function(b){return(a||(a=Lh(L0)))(b||L0)}})();L0.oa=Ld({la:L0,aa:L0.J,da:"root"});function T0(a,b){C(a.ec,rk(c=>c instanceof fZ||c instanceof gZ||c instanceof iZ||c instanceof hZ),vj(c=>c instanceof fZ||c instanceof hZ?0:c instanceof gZ&&(0===c.code||1===c.code)?2:1),rk(c=>2!==c),co()).subscribe(()=>{b()})};function U0(a){throw a;}var V0={paths:"exact",Xb:"ignored",Fw:"ignored",sb:"exact"},W0={paths:"subset",Xb:"ignored",Fw:"ignored",sb:"subset"};
function X0(a){const b=a.i.ec.subscribe(c=>{try{const e=a.i.i,f=a.i.C;if(null!==e&&null!==f){var d=a.C;if(c instanceof eZ)d.F=M0(d);else if(c instanceof hZ)d.Je=f.Xq;else if(c instanceof jZ){if("eager"===d.Wj&&!f.extras.Sj){const g=d.D.merge(f.el,f.Xq);O0(d,g,f)}}else c instanceof uZ?(d.Rb=f.el,d.Je=d.D.merge(f.el,f.Xq),d.Ld=f.dm,"deferred"===d.Wj&&(f.extras.Sj||O0(d,d.Je,f))):c instanceof gZ&&(3===c.code||2===c.code)?Q0(d,f):c instanceof iZ?Q0(d,f,!0):c instanceof fZ&&(d.G=c.id,d.i=d.C);if(c instanceof
gZ&&0!==c.code&&1!==c.code)a.bo=!0;else if(c instanceof fZ)a.bo=!0;else if(c instanceof vZ){const g=c.Fl,k=a.G.merge(c.url,e.wv),m=Object.assign({},{info:e.extras.info,Sj:e.extras.Sj,Tl:e.extras.Tl||"eager"===a.Wj||"imperative"!==e.source},g);Y0(a,k,"imperative",null,m,{resolve:e.resolve,reject:e.reject,promise:e.promise})}}c instanceof uZ||c instanceof vZ||a.Ab.next(c)}catch(e){a.i.O.next(e)}});a.O.add(b)}
function Y0(a,b,c,d,e,f){if(a.N)return Promise.resolve(!1);let g,k;f?(g=f.resolve,k=f.reject,f=f.promise):f=new Promise((p,t)=>{g=p;k=t});const m=a.F.add();T0(a,()=>{queueMicrotask(()=>a.F.remove(m))});B0(a.i,{source:c,Lj:d,Rb:a.Rb,wv:a.Rb,vo:b,extras:e,resolve:g,reject:k,promise:f,Dh:a.Ld.jb,oq:a.Ld});return f.catch(p=>Promise.reject(p))}function Z0(a){null!=a.D||(a.D=N0(a.C,(b,c)=>{setTimeout(()=>{$0(a,b,"popstate",c)},0)}))}
function $0(a,b,c,d){const e={Tl:!0},f=(null==d?0:d.Uh)?d:null;d&&(d=Object.assign({},d),delete d.Uh,delete d.Sy,0!==Object.keys(d).length&&(e.state=d));b=a1(a,b);Y0(a,b,c,f,e)}function a1(a,b){try{return a.K.parse(b)}catch(c){return a.K.parse("/")}}function b1(a){return Object.entries(a).reduce((b,[c,d])=>{null!==d&&void 0!==d&&(b[c]=d);return b},{})}
function c1(a,b,c={}){const d=c.nG,e=c.sb;var f=c.Xb;f=c.kG?a.Rb.Xb:f;switch(c.px){case "merge":c=Object.assign({},a.Rb.sb,e);break;case "preserve":c=a.Rb.sb;break;default:c=e||null}null!==c&&(c=b1(c));let g;try{g=QY(d?d.jb:a.Ld.jb.root)}catch(k){if("string"!==typeof b[0]||"/"!==b[0][0])b=[];g=a.Rb.root}return RY(g,b,c,null!=f?f:null)}function d1(a,b,c={Sj:!1}){b=OY(b)?b:a1(a,b);b=a.G.merge(b,a.Je);return Y0(a,b,"imperative",null,c)}
var e1=class{get Rb(){return this.C.Rb}get Je(){return this.C.Je}get ec(){return this.Ab}get Ld(){return this.C.Ld}constructor(){this.N=!1;this.console=lf(tn);this.C=lf(K0);this.options=lf(s0,{optional:!0})||{};this.F=lf(un);this.Wj=this.options.Wj||"deferred";this.i=lf(G0);this.K=lf(uY);this.location=lf(Bt);this.G=lf(x0);this.Ab=new aj;this.sn=this.options.sn||U0;this.bo=!1;this.hs=lf(H0);this.Dr=this.options.Dr||"ignore";let a,b;this.config=null!=(b=null==(a=lf(t0,{optional:!0}))?void 0:a.flat())?
b:[];lf(TZ,{optional:!0});this.O=new Li;this.config=this.config.map(c_);this.bo=!1;F0(this.i,this,this.Rb,this.Ld).subscribe({error:c=>{this.console.warn(c)}});X0(this)}get url(){return nY(this.Rb)}ua(){this.dispose()}dispose(){this.i.complete();this.D&&(this.D.unsubscribe(),this.D=void 0);this.N=!0;this.O.unsubscribe()}navigate(a,b={Sj:!1}){for(let c=0;c<a.length;c++)if(null==a[c])throw new Yd(4008,!1);return d1(this,c1(this,a,b),b)}isActive(a,b){let c;!0===b?c=Object.assign({},V0):!1===b?c=Object.assign({},
W0):c=b;if(OY(a))return iY(this.Rb,a,c);a=a1(this,a);return iY(this.Rb,a,c)}};e1.J=function(a){return new (a||e1)};e1.oa=Ld({la:e1,aa:e1.J,da:"root"});var f1=new df("");function g1(a){return a.Ld.root}new df("",{da:"root",aa:()=>!1});function h1(){const a=lf(Vh);return b=>{var c=a.get(dp);if(b===c.Jf[0]){b=a.get(e1);var d=a.get(i1);1===a.get(j1)&&(Z0(b),b.i.ba||$0(b,b.location.path(!0),"imperative",b.C.Lj()));var e;null==(e=a.get(k1,null,8))||e.uG();var f;null==(f=a.get(f1,null,8))||f.init();c=c.R[0];b.Ld.root.component=c;b.i.G=c;d.closed||(d.next(),d.complete(),d.unsubscribe())}}}const i1=new df("",{aa:()=>new aj}),j1=new df("",{da:"root",aa:()=>1}),k1=new df("");var l1=new df("ROUTER_FORROOT_GUARD"),m1=class{};m1.J=function(a){return new (a||m1)(q(l1,8))};m1.Wa=Mf({type:m1});m1.Va=Md({});new df("");function n1(a){const b={};a.yc?b.benchmark="1":(b.data=JSON.stringify({models:a.models,nodeData:a.nodeData,uiState:a.uiState}),b.renderer=a.i,b.show_open_in_new_tab=a.Co?"1":"0");const c=JSON.stringify(b);c!==a.C&&(a.C=c,a.D.navigate([],{sb:b,px:"",Tl:!1}))}function o1(a,b){a.models=b;n1(a)}function p1(a,b){a.uiState=b;n1(a)}
var q1=class{constructor(a){this.D=a;this.models=[];this.nodeData=[];this.C="";this.i="webgl";this.yc=this.Co=!1;a=new URLSearchParams(document.location.search);var b=a.get("data");if(b){let c=b=JSON.parse(b);null!=b.modelUrl&&(c={models:[{url:b.modelUrl}],uiState:{paneStates:[{deepestExpandedGroupNodeIds:b.deepestExpandedGroupNodeIds||[],selectedNodeId:b.selectedNodeId||"",selectedGraphId:b.selectedGraphId||"",selectedCollectionLabel:"",widthFraction:1}]}});this.models=c.models;this.uiState=c.uiState;
this.nodeData=c.nodeData}this.i=a.get("renderer")||"webgl";this.Co="1"===a.get("show_open_in_new_tab");this.yc="1"===a.get("benchmark")}};q1.J=function(a){return new (a||q1)(q(e1))};q1.oa=Ld({la:q1,aa:q1.J,da:"root"});const r1=["modelPathInput"];
function s1(a){a&1&&(R(0,"div",19),Z(1," Select models from your comupter or enter the file paths directly (up to 10 in total)."),Kq(2,"br"),Z(3," Supported model formats: "),R(4,"a",32),Z(5,"TF"),S(),Z(6," (.pb, .pbtxt, .graphdef), "),R(7,"a",33),Z(8,"TFLite"),S(),Z(9," (.tflite), "),R(10,"a",34),Z(11,"TFJS"),S(),Z(12," (.json), "),R(13,"a",35),Z(14,"JAX"),S(),Z(15," (.pb), "),R(16,"a",36),Z(17,"PyTorch ExportedProgram"),S(),Z(18," (.pt2), "),R(19,"span",37),Z(20," MLIR "),S(),Z(21," (.mlir, .mlirbc). "),
S());if(a&2){a=Y();const b=wr(37);D(19);H("xapInlineDialog",b)("overlaySize",a.Th)("hoverDelayMs",50)}}
function t1(a){a&1&&(R(0,"div",19),Z(1," Enter model CNS/"),R(2,"span",38),Z(3,"TFHub"),S(),Z(4," paths/urls or select models from your computer (up to 10). Supported model format: "),R(5,"span",39),Z(6," TF "),S(),R(7,"span",40),Z(8," TFLite "),S(),R(9,"span",41),Z(10," TFJS "),S(),R(11,"span",42),Z(12," JAX "),S(),R(13,"span",43),Z(14," MLIR "),S(),R(15,"span",44),Z(16," JSON graphs "),S()());if(a&2){a=Y();const b=wr(27),c=wr(29),d=wr(31),e=wr(33),f=wr(35),g=wr(39);D(5);H("xapInlineDialog",b)("overlaySize",
a.Th)("hoverDelayMs",50);D(2);H("xapInlineDialog",c)("overlaySize",a.Th)("hoverDelayMs",50);D(2);H("xapInlineDialog",d)("overlaySize",a.Th)("hoverDelayMs",50);D(2);H("xapInlineDialog",e)("overlaySize",a.Th)("hoverDelayMs",50);D(2);H("xapInlineDialog",f)("overlaySize",a.Th)("hoverDelayMs",50);D(2);H("xapInlineDialog",g)("overlaySize",a.Th)("hoverDelayMs",50)}}
function u1(a,b){if(a&1){const c=Tg();R(0,"mat-option",23)(1,"div",45);Z(2);R(3,"div",46)(4,"div",47);V("click",function(d){const e=u(c).Bb,f=Y();d.stopPropagation();f.tg.setValue(f.wj[e].path);f.Hw.P.focus();return x()});R(5,"mat-icon");Z(6,"edit");S()();R(7,"div",47);V("click",function(d){const e=u(c).Bb,f=Y();d.stopPropagation();f.wj.splice(e,1);v1(f);HI("model_explorer_model_paths",JSON.stringify(f.wj));return x()});R(8,"mat-icon");Z(9,"delete");S()()()()()}a&2&&(a=b.ca,H("value",a),D(2),yr(" ",
a," "))}function w1(a){a&1&&(R(0,"div",29),Z(1," You have selected maximum number of models "),S())}function x1(a){a&1&&Kq(0,"mat-spinner",57)}function y1(a){a&1&&(R(0,"div",63),Z(1),S());a&2&&(a=Y(2).ca,D(),yr(" ",a.errorMessage," "))}function z1(a){a&1&&(R(0,"div",62)(1,"mat-icon"),Z(2,"info"),S()(),yp(3,y1,2,1,"ng-template",null,13,Nr));if(a&2){a=wr(4);const b=Y(3);H("xapInlineDialog",a)("overlaySize",b.KB)("hoverDelayMs",50)}}
function A1(a){if(a&1){const b=Tg();R(0,"div",64,14);V("click",function(){u(b);const c=wr(1),d=Y().ca,e=Y(2);return x(B1(e,d,c))});R(2,"div",65);Z(3);S();R(4,"mat-icon");Z(5,"arrow_drop_down");S()()}if(a&2){a=Y().ca;const b=Y(2);lq("disabled",b.hd());D(3);yr(" ",C1(a)," ")}}function D1(a){a&1&&(R(0,"div",60),Z(1," No supported adapter "),S())}
function E1(a,b){if(a&1){const c=Tg();R(0,"tr")(1,"td")(2,"div",53)(3,"mat-checkbox",54,12);V("change",function(d){const e=u(c).ca;Y(2);e.selected=d.checked;return x()});S();R(5,"div",55);V("click",function(){const d=u(c).ca,e=wr(4);Y(2);d.selected=!e.checked;return x()});Z(6);S()()();R(7,"td")(8,"div",56);yp(9,x1,1,0,"mat-spinner",57);R(10,"div",58);Z(11);S();yp(12,z1,5,3);S()();R(13,"td");yp(14,A1,6,3,"div",59)(15,D1,2,0,"div",60);S();R(16,"td")(17,"button",61);V("click",function(){const d=u(c).index,
e=Y(2);e.md.splice(d,1);Zm(e.ek);return x()});R(18,"mat-icon");Z(19,"delete");S()()()()}a&2&&(a=b.ca,b=Y(2),D(2),lq("disabled",!(0<(a.Ff||[]).length)),D(),H("checked",a.selected)("disabled",!(0<(a.Ff||[]).length)||b.hd()),D(2),lq("disabled",!(0<(a.Ff||[]).length)||b.hd()),D(),yr(" ",a.path," "),D(3),Cq("Converting"===a.status()||"Uploading"===a.status()?9:-1),D(),lq("done",a.status()===b.jz.DONE)("error",b.ye(a)),D(),yr(" ",F1(a)," "),D(),Cq(b.ye(a)?12:-1),D(2),Cq(0<(a.Ff||[]).length?14:15),D(3),
H("disabled",b.hd()))}function G1(a){a&1&&(R(0,"div",30)(1,"table")(2,"thead")(3,"tr")(4,"th",48),Z(5,"Model name"),S(),R(6,"th"),Z(7,"Status"),S(),R(8,"th")(9,"div",49),Z(10," Adapter "),R(11,"div",50)(12,"mat-icon",51),Z(13,"help_outline"),S()()()(),R(14,"th"),Z(15,"Delete"),S()()(),R(16,"tbody"),yp(17,E1,20,16,"tr",52),S()()());if(a&2){a=Y();const b=wr(43);D(11);H("xapInlineDialog",b)("overlayPositions",a.TA)("hoverDelayMs",100);D(6);H("ngForOf",a.md)("ngForTrackBy",a.zE)}}
function H1(a){if(a&1){const b=Tg();R(0,"div",31)(1,"div",66)(2,"button",67);V("click",function(){u(b);const c=Y();for(const d of c.md)d.selected=!1;return x()});R(3,"mat-icon");Z(4,"close");S()();Z(5);S();R(6,"button",68);V("click",function(){u(b);const c=Y();return x(I1(c))});Z(7," View selected models ");S()()}a&2&&(a=Y(),D(),lq("hide",0===a.ps),D(),H("disabled",a.hd()),D(3),yr(" ",a.ps," selected "),D(),H("disabled",0===a.ps||a.hd()))}
function J1(a){a&1&&(R(0,"div",69)(1,"div"),Z(2," Enter the "),R(3,"b"),Z(4,"CNS path"),S(),Z(5,", "),R(6,"b"),Z(7,"Placer path"),S(),Z(8,", "),R(9,"b")(10,"a",70),Z(11,"Piper path"),S()(),Z(12,", "),R(13,"b"),Z(14,"TFHub path"),S(),Z(15,", or "),R(16,"b"),Z(17,"CNS Viewer url"),S(),Z(18," to a TF model "),R(19,"b"),Z(20,"directory"),S(),Z(21,", or upload the "),R(22,"b"),Z(23,".pb"),S(),Z(24," file from your computer. "),Kq(25,"br")(26,"br"),R(27,"span",71),Z(28,"When using CNS/Placer/TFHub, the model file inside is required to be named "),
R(29,"b"),Z(30,"saved_model.pb"),S(),Z(31,"."),S(),Kq(32,"br")(33,"br"),S(),R(34,"div",72),Z(35," Examples: "),R(36,"ul")(37,"li"),Z(38,"/cns/ok-d/home/odml-tooling-team/mgv/models/coco-ssd-tf/"),S(),R(39,"li"),Z(40,"/tfhub/prod/tfhub.dev/tensorflow/tutorials/spam-detection/1/"),S(),R(41,"li"),Z(42,"google3/path/to/tf/model/on/piper/"),S()()()())}
function K1(a){a&1&&(R(0,"div",69)(1,"div"),Z(2," Enter the "),R(3,"b"),Z(4,"CNS path"),S(),Z(5,", "),R(6,"b"),Z(7,"Placer path"),S(),Z(8,", "),R(9,"b")(10,"a",70),Z(11,"Piper path"),S()(),Z(12,", "),R(13,"b"),Z(14,"TFHub path"),S(),Z(15,", or "),R(16,"b"),Z(17,"CNS Viewer url"),S(),Z(18," to a TFLite model "),R(19,"b"),Z(20,"file"),S(),Z(21,", or upload the "),R(22,"b"),Z(23,".tflite"),S(),Z(24," file from your computer. "),S(),R(25,"div",72),Z(26," Examples: "),R(27,"ul")(28,"li"),Z(29,"/cns/ok-d/home/odml-tooling-team/mgv/models/coco-ssd.tflite"),
S(),R(30,"li"),Z(31,"/tfhub/prod/tfhub.dev/tensorflow/lite-model/tutorials/spam-detection/tflite/1/1.tflite"),S(),R(32,"li"),Z(33,"google3/path/to/tflite/model/on/piper.tflite"),S()()()())}function L1(a){a&1&&(R(0,"div",69)(1,"div"),Z(2," Enter the "),R(3,"b"),Z(4,"url"),S(),Z(5," for the model.json file, or upload it from your computer. "),S(),R(6,"div",72),Z(7," Example: https://tfhub.dev/tensorflow/tfjs-model/ssd_mobilenet_v2/1/default/1/model.json?tfjs-format=file "),S()())}
function M1(a){a&1&&(R(0,"div",69)(1,"div"),Z(2," JAX models must be convereted to TF, TFLite, or TFJS prior to loading in Model Explorer. Check out the "),R(3,"a",73),Z(4,"JAX to TF"),S(),Z(5," or "),R(6,"a",74),Z(7,"JAX to TFLite/TFJS"),S(),Z(8," documentation for conversion instructions. "),S()())}
function N1(a){a&1&&(R(0,"div",69)(1,"div"),Z(2," Enter the "),R(3,"b"),Z(4,"CNS path"),S(),Z(5,", "),R(6,"b"),Z(7,"Placer path"),S(),Z(8,", "),R(9,"b")(10,"a",70),Z(11,"Piper path"),S()(),Z(12,", "),R(13,"b"),Z(14,"TFHub path"),S(),Z(15,", or "),R(16,"b"),Z(17,"CNS Viewer url"),S(),Z(18," to a MLIR model "),R(19,"b"),Z(20,"file"),S(),Z(21,", or upload the "),R(22,"b"),Z(23,".mlir"),S(),Z(24," or "),R(25,"b"),Z(26,".mlirbc"),S(),Z(27," file from your computer. Only support TF, TFL and StableHLO dialect. "),
S(),R(28,"div",72),Z(29," Examples: "),R(30,"ul")(31,"li"),Z(32,"/cns/sandbox/home/yijieyang/mlir/tfl_ssd_debug_info.mlir"),S()()()())}function O1(a){a&1&&(R(0,"div",69)(1,"div"),Z(2," Support TF, TFL and StableHLO dialect. "),S()())}
function P1(a){a&1&&(R(0,"div",69)(1,"div"),Z(2," Enter the "),R(3,"b"),Z(4,"url"),S(),Z(5," for the JSON graphs file (downloadable from "),R(6,"a",75),Z(7,"here"),S(),Z(8,", or convert your graphs into "),R(9,"a",76),Z(10,"this format"),S(),Z(11,"), or upload it from your computer. Using JSON graphs file has a much faster processing time. "),S(),R(12,"div",72),Z(13," Example: https://storage.googleapis.com/tfweb/model-explorer-models/mobilebert_fp32.tflite.json "),S()())}
function Q1(a){a&1&&(R(0,"div",77),Z(1," Max upload size: 256 MB. "),Kq(2,"br")(3,"br"),Z(4," Model too large? Try "),R(5,"a",78),Z(6,"converting"),S(),Z(7," it to JSON graphs and upload the JSON file instead. "),S())}
function R1(a){a&1&&(R(0,"div",79)(1,"span",80),Z(2,"Adapters"),S(),Z(3,' transform model files into an intermediate format that Model Explorer can understand and visualize. For certain model types, multiple adapters may exist, offering different transformation approaches. The "default" adapter should cover the majority of common scenarios. '),Kq(4,"br")(5,"br"),Z(6," You can also create your own "),R(7,"span",80),Z(8,"adapter extensions"),S(),Z(9," to add support for more model formats. See "),R(10,
"a",81),Z(11,"this guide"),S(),Z(12," for instructions. "),S())}function B1(a,b,c){let d;const e=null==(d=b.Qc)?void 0:d.id,f=S1(a,c);c=f.attach(a.Jd);c.instance.Qc=b.Qc;c.instance.cq=b.Ff||[];c.instance.ge.subscribe(g=>{f.dispose();(null==g?void 0:g.id)!==e&&null!=b.errorMessage&&(b.status.set("Not started"),b.errorMessage=void 0,b.selected=!0);b.Qc=g;Zm(a.ek)})}function C1(a){if(null==a.Qc)return"?";let b;return 0===(a.Ff||[]).indexOf(a.Qc)?"Default":(null==(b=a.Qc)?void 0:b.name)||"?"}
function F1(a){a=a.status();return"Uploading"===a?"Processing":a}function I1(a){a.hd.set(!0);const b=a.md.filter(c=>c.selected);T1(a.G,b).then(()=>{a.hd.set(!1)});p1(a.D);o1(a.D,b.filter(c=>"remote"===c.type||"graphs_json_from_server"===c.type||"file_path"===c.type).map(c=>{let d;return{url:c.path,adapterId:null==(d=c.Qc)?void 0:d.id}}));a.rj.set(b.some(c=>"local"===c.type))}
function v1(a){const b=(a.tg.value||"").toLowerCase();a.Qv=a.wj.filter(c=>c.path.toLowerCase().includes(b)).map(c=>c.path);Zm(a.ek)}function U1(){return JSON.parse(window.localStorage.getItem("model_explorer_model_paths")||"[]")}
function V1(a,b){a.md=b.map(c=>{if(c.url.startsWith("graphs://")){var d=UX(a.i,"builtin_json"),e=null==d?[]:[d];return{path:c.url,type:"graphs_json_from_server",status:ur("Not started"),selected:0<e.length,Ff:e,Qc:d}}d=PX(c.url,a.i);(e=UX(a.i,c.converterId||c.adapterId||""))||(e=0<d.length?d[0]:void 0);return{path:c.url,type:"file_path",status:ur("Not started"),selected:0<d.length,Ff:d,Qc:e}});$m(a.ek);a.md.some(c=>c.selected)&&I1(a)}
function W1(a,b){b=b.filter(c=>null==a.md.find(d=>{let e,f,g,k;return d.path===c.path&&(null==(e=d.file)?void 0:e.size)===(null==(f=c.file)?void 0:f.size)&&(null==(g=d.file)?void 0:g.lastModified)===(null==(k=c.file)?void 0:k.lastModified)}));a.md.push(...b);10<a.md.length&&a.md.splice(10);Zm(a.ek)}
function X1(a,b){const c=U1();for(const d of b)b=c.findIndex(e=>e.path===d),0<=b?(b=c.splice(b,1))&&0<b.length&&(b[0].ts=Date.now(),c.unshift(b[0])):c.unshift({path:d,ts:Date.now()});50<c.length&&c.splice(50);HI("model_explorer_model_paths",JSON.stringify(c));a.wj=c}
function Y1(a){return sa(function*(){yield new Promise(c=>{setTimeout(c)});var b=a.tg.value;null!=b&&(b=b.trim().split(",").filter(c=>""!==c.trim()).map(c=>{const d=PX(c,a.i);return{path:c,type:a.de?"remote":"file_path",status:ur("Not started"),selected:0<d.length,Ff:d,Qc:0<d.length?d[0]:void 0}}),W1(a,b),X1(a,b.map(c=>c.path)),a.tg.setValue(""),setTimeout(()=>{let c;null==(c=a.LC)||bB(c);a.Hw.P.blur()}))})}
function Z1(a,b){const c=[];for(let d=0;d<b.length;d++){const e=b[d],f=PX(e.name,a.i);c.push({path:e.name,type:"local",status:ur("Not started"),selected:0<f.length,file:e,Ff:f,Qc:0<f.length?f[0]:void 0})}W1(a,c)}
function S1(a,b){b=new xu({sc:Hu(Lv(a.C.position(),b),[{bb:"start",cb:"bottom",La:"start",Sa:"top"}]),Sb:!0,bc:"cdk-overlay-transparent-backdrop",tc:a.C.i.i(),maxWidth:"380px",gb:"graph-selector-panel"});const c=a.C.create(b);a.Jd=new Ov(OX,a.wb);c.bd().subscribe(()=>{c.dispose()});return c}
var $1=class{constructor(a,b,c,d,e,f,g,k){this.ek=a;this.i=b;this.F=c;this.G=e;this.C=f;this.D=g;this.wb=k;this.tg=new px("");this.md=[];this.wj=[];this.Qv=[];this.jz=KX;this.Th={maxWidth:400,minHeight:0};this.KB={minHeight:0};this.TA=[{bb:"start",cb:"top",La:"start",Sa:"bottom",offsetY:-4}];this.hd=ur(!1);this.rj=ur(!1);this.Jd=null;C(this.tg.ah,kL(this.F)).subscribe(()=>{v1(this)});this.wj=U1();v1(this)}Kq(a){const b=a.files;if(b){var c=[];for(let d=0;d<b.length;d++){const e=b.item(d);e&&c.push(e)}Z1(this,
c);a.value=""}}zE(a,b){let c,d;return`${b.path}_${null==(c=b.file)?void 0:c.size}_${null==(d=b.file)?void 0:d.lastModified}`}ye(a){return"Error"===a.status()}get sq(){if(this.Rq)return!0;if(this.de){var a=(this.tg.value||"").toLowerCase().trim();return""!==a&&!FX.test(a)&&!a.startsWith("http")||""===a}a=(this.tg.value||"").trim();return""===a||""!==a&&!a.startsWith("/")&&!a.startsWith("~")}get yd(){return!0}get de(){return!1}get ps(){return this.md.filter(a=>a.selected).length}get Rq(){return 10===
this.md.length}get PC(){return this.yd?"Absolute file paths":"Model CNS/TFHub paths or urls"}};$1.J=function(a){return new (a||$1)(y(Pr),y(WX),y(wi),y(II),y("ModelLoaderService"),y(Wv),y(q1),y(ip))};
$1.Ca=Gf({type:$1,ga:[["model-source-input"]],eb:function(a,b){a&1&&(rr(r1,5),rr(XA,5));if(a&2){let c;sr(c=tr())&&(b.Hw=c.first);sr(c=tr())&&(b.LC=c.first)}},ja:!0,features:[Jr],ya:44,za:17,Ba:[["auto","matAutocomplete"],["modelPathInput",""],["uploadInput",""],["tfHelp",""],["tfliteHelp",""],["tfjsHelp",""],["jaxHelp",""],["mlirHelp",""],["externalMlirHelp",""],["graphsJsonHelp",""],["uploadHelp",""],["adapterHelp",""],["checkbox",""],["errorInfo",""],["selector",""],[1,"container"],[1,"content"],
[1,"title"],[1,"description-container"],[1,"description"],[1,"source-input-container"],[1,"input-container"],[1,"model-path-autocomplete",3,"optionSelected"],[3,"value"],[3,"keydown.enter","placeholder","formControl","matAutocomplete"],["mat-raised-button","",1,"btn-add-model-path",3,"click","disabled"],[1,"or-label"],["mat-flat-button","","dialogLabel","uploadHelp",1,"btn-upload",3,"click","disabled","xapInlineDialog","xapInlineDialogDisabled","hoverDelayMs"],["type","file","multiple","",1,"upload-input",
3,"change"],[1,"model-count-warning"],[1,"models-table"],[1,"table-action-bar"],["href","https://www.tensorflow.org/","target","_blank"],["href","https://www.tensorflow.org/lite","target","_blank"],["href","https://www.tensorflow.org/js","target","_blank"],["href","https://www.tensorflow.org/guide/jax2tf","target","_blank"],["href","https://github.com/google-ai-edge/model-explorer/wiki/2.-User-Guide#how-to-select-pytorch-models","target","_blank"],["dialogLabel","externalMlirHelp",1,"help-trigger",
"external",3,"xapInlineDialog","overlaySize","hoverDelayMs"],["matTooltip","In the form of /tfhub/...",1,"tfhub"],["dialogLabel","tfHelp",1,"help-trigger",3,"xapInlineDialog","overlaySize","hoverDelayMs"],["dialogLabel","tfliteHelp",1,"help-trigger",3,"xapInlineDialog","overlaySize","hoverDelayMs"],["dialogLabel","tfjsHelp",1,"help-trigger",3,"xapInlineDialog","overlaySize","hoverDelayMs"],["dialogLabel","jaxHelp",1,"help-trigger",3,"xapInlineDialog","overlaySize","hoverDelayMs"],["dialogLabel","mlirHelp",
1,"help-trigger",3,"xapInlineDialog","overlaySize","hoverDelayMs"],["dialogLabel","graphsJsonHelp",1,"help-trigger",3,"xapInlineDialog","overlaySize","hoverDelayMs"],[1,"option-container"],[1,"icons-container"],[1,"mat-icon-container",3,"click"],[1,"model-name-col"],[1,"adapter-header"],["dialogLabel","adapterHelp",1,"icon-container",3,"xapInlineDialog","overlayPositions","hoverDelayMs"],["fontSet","google-material-icons"],[4,"ngFor","ngForOf","ngForTrackBy"],[1,"model-name-container"],[3,"change",
"checked","disabled"],[1,"model-path",3,"click"],[1,"model-status-container"],["color","primary","diameter","16"],[1,"model-status-label-container"],[1,"selected-adapter-container",3,"disabled"],[1,"no-supported-adapter-msg"],["mat-icon-button","",1,"btn-delete-model-item",3,"click","disabled"],["dialogLabel","errorInfo",1,"error-info-container",3,"xapInlineDialog","overlaySize","hoverDelayMs"],[1,"model-explorer-error-info-popup"],[1,"selected-adapter-container",3,"click"],[1,"selected-adapter-label"],
[1,"selection-status"],["mat-icon-button","",1,"btn-deselect-all",3,"click","disabled"],["mat-flat-button","","color","primary",1,"btn-view-models",3,"click","disabled"],[1,"model-explorer-model-format-help-popup"],["href","http://go/google-src","target","_blank"],[1,"info"],[1,"example"],["href","https://g3doc.corp.google.com/third_party/py/jax/experimental/jax2tf/README.md","target","_blank"],["href","https://g3doc.corp.google.com/third_party/tensorflow/google/g3doc/jax_production/g3doc/guides/mobile.md",
"target","_blank"],["href","https://screenshot.googleplex.com/8u9evbbgNDiNmJX","target","_blank"],["href","https://source.corp.google.com/piper///depot/google3/learning/brain/mobile/lite/tooling/model_graph_visualizer/module/common/input_graph.ts?q=symbol:%5CbGraphCollection%5Cb","target","_blank"],[1,"model-explorer-upload-help-popup"],["href","https://source.corp.google.com/piper///depot/google3/third_party/tensorflow/compiler/mlir/lite/experimental/google/tooling/","target","_blank"],[1,"model-explorer-adapter-help-popup"],
[1,"bold"],["href","https://github.com/google-ai-edge/model-explorer/wiki/6.-Develop-Adapter-Extension","target","_blank"]],sa:function(a,b){if(a&1){const c=Tg();R(0,"div",15)(1,"div",16)(2,"div",17);Z(3," Select Models ");S();R(4,"div",18);yp(5,s1,22,3,"div",19)(6,t1,17,18,"div",19);S();R(7,"div",20)(8,"div",21)(9,"mat-autocomplete",22,0);V("optionSelected",function(d){u(c);b.sq||(Nz(d.Pw),Y1(b));return x()});Hq(11,u1,10,2,"mat-option",23,Fq);S();R(13,"input",24,1);V("keydown.enter",function(){u(c);
return x(!b.sq&&Y1(b))});S();R(15,"button",25);V("click",function(){u(c);return x(Y1(b))});Z(16," Add ");S()();R(17,"div",26);Z(18,"or");S();R(19,"button",27);V("click",function(){u(c);const d=wr(22);return x(d.click())});Z(20," Select from your computer ");S();R(21,"input",28,2);V("change",function(){u(c);const d=wr(22);return x(b.Kq(d))});S()();yp(23,w1,2,0,"div",29)(24,G1,18,5,"div",30);S();yp(25,H1,8,5,"div",31);S();yp(26,J1,43,0,"ng-template",null,3,Nr)(28,K1,34,0,"ng-template",null,4,Nr)(30,
L1,8,0,"ng-template",null,5,Nr)(32,M1,9,0,"ng-template",null,6,Nr)(34,N1,33,0,"ng-template",null,7,Nr)(36,O1,3,0,"ng-template",null,8,Nr)(38,P1,14,0,"ng-template",null,9,Nr)(40,Q1,8,0,"ng-template",null,10,Nr)(42,R1,13,0,"ng-template",null,11,Nr)}if(a&2){a=wr(10);const c=wr(41);D();lq("no-models",0===b.md.length);D(4);Cq(b.yd?5:-1);D();Cq(b.de?6:-1);D();lq("reverse",b.yd);D(4);Jq(b.Qv);D(2);H("placeholder",b.PC)("formControl",b.tg)("matAutocomplete",a);D(2);H("disabled",b.sq||b.hd());D(4);H("disabled",
b.Rq||b.hd())("xapInlineDialog",c)("xapInlineDialogDisabled",b.yd)("hoverDelayMs",50);D(4);Cq(b.Rq?23:-1);D();Cq(0<b.md.length?24:-1);D();Cq(0<b.md.length?25:-1)}},Ga:[et,Ws,iB,gw,fA,Oz,XA,uB,tB,oB,rB,HB,wB,BB,tC,pD,oD,lD,KD,$F,tE,YF,aI,$H,wx,mw,Gw,rx,zG,wG],styles:[".container[_ngcontent-%COMP%]{width:100%;height:100%;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:start;-webkit-align-items:flex-start;-moz-box-align:start;-ms-flex-align:start;align-items:flex-start;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;border:1px solid #dadce0;border-radius:8px;overflow:hidden}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]{width:100%;-moz-box-sizing:border-box;box-sizing:border-box;padding:24px;padding-bottom:0;overflow:hidden;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column}.container[_ngcontent-%COMP%]   .content.no-models[_ngcontent-%COMP%]{padding-bottom:24px}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]{color:#1f1f1f;font-size:24px}.container[_ngcontent-%COMP%]   .description-container[_ngcontent-%COMP%]{color:#444746;font-size:14px;margin-top:8px}.container[_ngcontent-%COMP%]   .description-container[_ngcontent-%COMP%]   .description[_ngcontent-%COMP%]{line-height:20px}.container[_ngcontent-%COMP%]   .description-container[_ngcontent-%COMP%]   .description[_ngcontent-%COMP%]   .tfhub[_ngcontent-%COMP%]{display:inline-block;text-decoration:underline;-webkit-text-decoration-color:#aaa;-moz-text-decoration-color:#aaa;text-decoration-color:#aaa;cursor:help}.container[_ngcontent-%COMP%]   .description-container[_ngcontent-%COMP%]   .description[_ngcontent-%COMP%]   .help-trigger[_ngcontent-%COMP%]{display:inline-block;margin-right:6px;text-decoration:underline;-webkit-text-decoration-color:#aaa;-moz-text-decoration-color:#aaa;text-decoration-color:#aaa;cursor:help}.container[_ngcontent-%COMP%]   .description-container[_ngcontent-%COMP%]   .description[_ngcontent-%COMP%]   .help-trigger.external[_ngcontent-%COMP%]{margin-right:0}.container[_ngcontent-%COMP%]   .description-container[_ngcontent-%COMP%]   .description[_ngcontent-%COMP%]   a[_ngcontent-%COMP%]{color:inherit}.container[_ngcontent-%COMP%]   .source-input-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;height:56px;-moz-box-sizing:border-box;box-sizing:border-box;width:100%;margin-top:8px;padding:8px 0;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0}.container[_ngcontent-%COMP%]   .source-input-container.reverse[_ngcontent-%COMP%]{-webkit-box-orient:horizontal;-webkit-box-direction:reverse;-webkit-flex-direction:row-reverse;-moz-box-orient:horizontal;-moz-box-direction:reverse;-ms-flex-direction:row-reverse;flex-direction:row-reverse}.container[_ngcontent-%COMP%]   .source-input-container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]{height:100%;-moz-box-sizing:border-box;box-sizing:border-box;background-color:#f0f4f9;border-radius:99px;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;padding-left:18px}.container[_ngcontent-%COMP%]   .source-input-container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]{height:100%;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;border:none;outline:none;background-color:transparent;color:#444746;font-size:14px;margin-right:16px}.container[_ngcontent-%COMP%]   .source-input-container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   .btn-add-model-path[_ngcontent-%COMP%]{background-color:#fff;border-radius:99px;color:#0b57d0;height:40px}.container[_ngcontent-%COMP%]   .source-input-container[_ngcontent-%COMP%]   .input-container[_ngcontent-%COMP%]   .btn-add-model-path[disabled][_ngcontent-%COMP%]{background-color:rgba(31,31,31,.12);color:rgba(31,31,31,.38)}.container[_ngcontent-%COMP%]   .source-input-container[_ngcontent-%COMP%]   .or-label[_ngcontent-%COMP%]{font-size:14px;margin:0 20px;color:#5f6368}.container[_ngcontent-%COMP%]   .source-input-container[_ngcontent-%COMP%]   .btn-upload[_ngcontent-%COMP%]{height:100%;background-color:#c2e7ff;border-radius:99px;color:#001d35}.container[_ngcontent-%COMP%]   .source-input-container[_ngcontent-%COMP%]   .btn-upload[disabled][_ngcontent-%COMP%]{background-color:rgba(31,31,31,.12);color:rgba(31,31,31,.38)}.container[_ngcontent-%COMP%]   .source-input-container[_ngcontent-%COMP%]   .upload-input[_ngcontent-%COMP%]{display:none}.container[_ngcontent-%COMP%]   .model-count-warning[_ngcontent-%COMP%]{color:#ab6c17;background-color:#ffefd9;margin:4px 0;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;padding:2px 9px;border-radius:4px;font-size:13px;font-weight:500}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]{width:100%;color:#1f1f1f;font-size:14px;margin-top:18px;overflow:hidden auto}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]{width:100%;border-spacing:0;border-collapse:collapse;padding:0}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]{position:-webkit-sticky;position:sticky;top:0;z-index:100;box-shadow:inset 0 -1px 0 #c4c7c5;background-color:#fff}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   .model-name-col[_ngcontent-%COMP%]{width:100%}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   .adapter-header[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;gap:4px}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   .adapter-header[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;cursor:pointer;opacity:.8}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   .adapter-header[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:1}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   thead[_ngcontent-%COMP%]   .adapter-header[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:20px;width:20px;height:20px;color:#777}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   th[_ngcontent-%COMP%]{height:49px;text-align:left;padding:0;font-weight:500}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   tr[_ngcontent-%COMP%]{height:49px;text-align:left;padding:0}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   tr[_ngcontent-%COMP%]:not(:last-child){border-bottom:1px solid #c4c7c5}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   td[_ngcontent-%COMP%]{padding:0}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-name-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;padding-left:12px;margin-right:12px;word-break:break-all}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-name-container.disabled[_ngcontent-%COMP%]{pointer-events:none}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-name-container[_ngcontent-%COMP%]   mat-checkbox[_ngcontent-%COMP%]{margin-right:2px}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-name-container[_ngcontent-%COMP%]   .model-path[_ngcontent-%COMP%]{cursor:pointer;line-height:16px;padding:8px 0}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-name-container[_ngcontent-%COMP%]   .model-path.disabled[_ngcontent-%COMP%]{pointer-events:none}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .selected-adapter-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;cursor:pointer;height:48px;margin-right:24px;white-space:nowrap}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .selected-adapter-container.disabled[_ngcontent-%COMP%]{opacity:.5;pointer-events:none}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .selected-adapter-container[_ngcontent-%COMP%]:hover   mat-icon[_ngcontent-%COMP%]{opacity:1}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .selected-adapter-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{opacity:.7}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .no-supported-adapter-msg[_ngcontent-%COMP%]{color:#ab6c17;background-color:#ffefd9;padding:2px 8px;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;border-radius:4px;font-size:12px;margin-right:24px;white-space:nowrap;font-weight:500}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-status-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;margin-right:32px}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-status-container[_ngcontent-%COMP%]   mat-spinner[_ngcontent-%COMP%]{margin-right:4px}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-status-container[_ngcontent-%COMP%]   .model-status-label-container[_ngcontent-%COMP%]{font-size:12px;padding:2px 8px;background-color:#f1f3f4;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;color:#3c4043;width:-webkit-fit-content;width:-moz-fit-content;width:fit-content;border-radius:4px;white-space:nowrap;font-weight:500}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-status-container[_ngcontent-%COMP%]   .model-status-label-container.done[_ngcontent-%COMP%]{color:#0d652d;background-color:#e6f4ea}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-status-container[_ngcontent-%COMP%]   .model-status-label-container.error[_ngcontent-%COMP%]{color:#a50e0e;background-color:#fce8e6}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-status-container[_ngcontent-%COMP%]   .error-info-container[_ngcontent-%COMP%]{width:20px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;margin-left:4px;cursor:pointer}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .model-status-container[_ngcontent-%COMP%]   .error-info-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{width:20px;height:20px;font-size:20px}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .btn-delete-model-item[_ngcontent-%COMP%]{width:36px;height:36px;padding:0;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .btn-delete-model-item[disabled][_ngcontent-%COMP%]{opacity:.5}.container[_ngcontent-%COMP%]   .models-table[_ngcontent-%COMP%]   table[_ngcontent-%COMP%]   .btn-delete-model-item[_ngcontent-%COMP%]     mat-icon{font-size:20px;width:20px;height:20px;color:#444746}.container[_ngcontent-%COMP%]   .table-action-bar[_ngcontent-%COMP%]{-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;height:60px;width:100%;-moz-box-sizing:border-box;box-sizing:border-box;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;background-color:#f0f4f9;padding:0 24px 0 38px}.container[_ngcontent-%COMP%]   .table-action-bar[_ngcontent-%COMP%]   .selection-status[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;font-size:14px;color:#444746}.container[_ngcontent-%COMP%]   .table-action-bar[_ngcontent-%COMP%]   .selection-status.hide[_ngcontent-%COMP%]{visibility:hidden}.container[_ngcontent-%COMP%]   .table-action-bar[_ngcontent-%COMP%]   .btn-deselect-all[_ngcontent-%COMP%]{width:36px;height:36px;padding:0;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .table-action-bar[_ngcontent-%COMP%]   .btn-deselect-all[_ngcontent-%COMP%]     mat-icon{font-size:20px;width:20px;height:20px;color:#444746}.container[_ngcontent-%COMP%]   .table-action-bar[_ngcontent-%COMP%]   .btn-view-models[_ngcontent-%COMP%]{height:40px;border-radius:99px}.container[_ngcontent-%COMP%]   .instructions-container[_ngcontent-%COMP%]{font-size:13px;color:#555;margin-top:24px;display:none}.container[_ngcontent-%COMP%]   .instructions-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:18px;width:18px;height:18px;margin-right:4px}.container[_ngcontent-%COMP%]   .instructions-container[_ngcontent-%COMP%]   .instruction-title[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .instructions-container[_ngcontent-%COMP%]   .instruction-title[_ngcontent-%COMP%]   .model-format[_ngcontent-%COMP%]{color:#333;margin-right:4px;margin-left:4px;border:1px solid #ccc;border-radius:4px;padding:2px 4px;cursor:pointer}.container[_ngcontent-%COMP%]   .instructions-container[_ngcontent-%COMP%]   .instruction-title[_ngcontent-%COMP%]   .model-format[_ngcontent-%COMP%]:hover{background-color:#eee}  .model-explorer-upload-help-popup{padding:12px;font-weight:400;color:#555;line-height:14px;font-size:12px;font-family:Google Sans Text,Arial,Helvetica,sans-serif}  .model-explorer-adapter-help-popup{padding:12px;font-weight:400;color:#555;line-height:15px;font-size:12px;font-family:Google Sans Text,Arial,Helvetica,sans-serif}  .model-explorer-adapter-help-popup .bold{font-weight:700}  .model-explorer-model-format-help-popup{padding:12px;font-weight:400;color:#555;line-height:15px;font-size:12px;font-family:Google Sans Text,Arial,Helvetica,sans-serif;letter-spacing:normal}  .model-explorer-model-format-help-popup a{color:inherit}  .model-explorer-model-format-help-popup .example{margin-top:8px;color:#aaa}  .model-explorer-model-format-help-popup .example ul{margin:4px 0;-webkit-padding-start:28px;-moz-padding-start:28px;padding-inline-start:28px}  .model-explorer-model-format-help-popup .example li{margin-top:4px}  .model-explorer-model-format-help-popup .info{display:inline-block;background-color:#ffd1a8}  .model-explorer-error-info-popup{padding:12px;font-weight:400;background-color:#f0f4f9;line-height:14px;font-size:12px;font-family:Google Sans Text,Arial,Helvetica,sans-serif}  .model-path-autocomplete mat-option{min-height:13px;font-size:13px;line-height:13px;padding-top:5px;padding-bottom:5px}  .model-path-autocomplete mat-option:hover .option-container .mat-icon-container{visibility:visible}  .model-path-autocomplete mat-option>span{width:100%}  .model-path-autocomplete mat-option .option-container{width:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;word-break:break-all}  .model-path-autocomplete mat-option .option-container .icons-container{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;gap:4px;min-width:50px;-webkit-box-pack:end;-webkit-justify-content:flex-end;-moz-box-pack:end;-ms-flex-pack:end;justify-content:flex-end}  .model-path-autocomplete mat-option .option-container .mat-icon-container{visibility:hidden;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;opacity:.6;width:18px}  .model-path-autocomplete mat-option .option-container .mat-icon-container:hover{opacity:1}  .model-path-autocomplete mat-option .option-container .mat-icon-container mat-icon{font-size:18px;width:18px;height:18px}"],
Qa:0});const a2=(a,b)=>b.name;function b2(a){if(a&1){const b=Tg();R(0,"div",11);V("click",function(){u(b);const c=Y().ca;return x(c.expanded=!c.expanded)});R(1,"mat-icon");Z(2,"unfold_more");S()()}}function c2(a,b){a&1&&(R(0,"div",3)(1,"div",6),Z(2),S(),R(3,"div",7),Z(4),S(),R(5,"div",8)(6,"div",9),Z(7),S(),yp(8,b2,3,0,"div",10),S()());a&2&&(a=b.ca,D(2),xr(a.name),D(2),xr(a.copyright),D(),lq("expanded",a.expanded),D(2),xr(a.Un),D(),Cq(a.expanded?-1:8))}
var d2=class{constructor(){this.HC=[{name:"Angular",copyright:"Copyright (c) 2010-2024 Google LLC.",Un:'The MIT License\n\nCopyright (c) 2010-2024 Google LLC. https://angular.io/license\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in\nall copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\nTHE SOFTWARE.'},
{name:"d3 (v5.7.0)",copyright:"Copyright 2010-2017 Mike Bostock",Un:'Copyright 2010-2017 Mike Bostock\nAll rights reserved.\n\nRedistribution and use in source and binary forms, with or without modification,\nare permitted provided that the following conditions are met:\n\n* Redistributions of source code must retain the above copyright notice, this\n  list of conditions and the following disclaimer.\n\n* Redistributions in binary form must reproduce the above copyright notice,\n  this list of conditions and the following disclaimer in the documentation\n  and/or other materials provided with the distribution.\n\n* Neither the name of the author nor the names of contributors may be used to\n  endorse or promote products derived from this software without specific prior\n  written permission.\n\nTHIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND\nANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED\nWARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE\nDISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS BE LIABLE FOR\nANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES\n(INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;\nLOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON\nANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT\n(INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS\nSOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.'},
{name:"dagre (v0.8.5)",copyright:"Copyright (c) 2012-2014 Chris Pettitt",Un:'Copyright (c) 2012-2014 Chris Pettitt\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in\nall copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\nTHE SOFTWARE.'},
{name:"three.js (r134)",copyright:"Copyright \u00a9 2010-2021 three.js authors",Un:'The MIT License\n\nCopyright \u00a9 2010-2021 three.js authors\n\nPermission is hereby granted, free of charge, to any person obtaining a copy\nof this software and associated documentation files (the "Software"), to deal\nin the Software without restriction, including without limitation the rights\nto use, copy, modify, merge, publish, distribute, sublicense, and/or sell\ncopies of the Software, and to permit persons to whom the Software is\nfurnished to do so, subject to the following conditions:\n\nThe above copyright notice and this permission notice shall be included in\nall copies or substantial portions of the Software.\n\nTHE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR\nIMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,\nFITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE\nAUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER\nLIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,\nOUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN\nTHE SOFTWARE.'}]}};
d2.J=function(a){return new (a||d2)};
d2.Ca=Gf({type:d2,ga:[["open-source-libs-dialog"]],ja:!0,features:[Jr],ya:9,za:0,Ba:[["mat-dialog-title",""],[1,"title"],["mat-dialog-content","",1,"dialog-content"],[1,"lib-container"],["mat-dialog-actions","","align","end"],["mat-button","","mat-dialog-close",""],[1,"name"],[1,"copyright"],[1,"license-container"],[1,"license-content"],[1,"icon-container"],[1,"icon-container",3,"click"]],sa:function(a,b){a&1&&(R(0,"div",0)(1,"div",1),Z(2,"Open source libraries"),S()(),R(3,"div",2),Hq(4,c2,9,6,"div",
3,a2),S(),R(6,"div",4)(7,"button",5),Z(8,"Close"),S()());a&2&&(D(4),Jq(b.HC))},Ga:[et,uB,tB,oB,sC,lC,nC,pC,oC,aI,$H],styles:["[_ngcontent-%COMP%]:not(mat-icon){font-family:Google Sans Text,Arial,Helvetica,sans-serif!important;letter-spacing:normal!important}.title[_ngcontent-%COMP%]{font-size:24px;font-weight:500;margin-top:-16px}.dialog-content[_ngcontent-%COMP%]{padding-bottom:0}.lib-container[_ngcontent-%COMP%]{margin:18px 0}.lib-container[_ngcontent-%COMP%]   .name[_ngcontent-%COMP%]{font-size:16px;font-weight:700;color:#333}.lib-container[_ngcontent-%COMP%]   .copyright[_ngcontent-%COMP%]{font-size:12px;color:#777}.lib-container[_ngcontent-%COMP%]   .license-container[_ngcontent-%COMP%]{width:520px;font-size:11px;border:1px solid #ccc;margin-top:8px;background-color:#f9f9f9;height:100px;overflow:hidden;position:relative}.lib-container[_ngcontent-%COMP%]   .license-container.expanded[_ngcontent-%COMP%]{height:-webkit-fit-content;height:-moz-fit-content;height:fit-content}.lib-container[_ngcontent-%COMP%]   .license-container[_ngcontent-%COMP%]   .license-content[_ngcontent-%COMP%]{white-space:pre-wrap;line-height:14px;padding:8px;overflow:hidden;height:100%;-moz-box-sizing:border-box;box-sizing:border-box}.lib-container[_ngcontent-%COMP%]   .license-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{position:absolute;right:8px;top:8px;cursor:pointer;opacity:.8}.lib-container[_ngcontent-%COMP%]   .license-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:1}"]});var e2={Vy:0,Uo:1,vz:2,0:"BOOLEAN",1:"NUMBER",2:"TEXT_MULTILINE"},f2={label:"Maximum element count for constant tensor values",key:"const_element_count_limit",type:1,defaultValue:16,help:"Controls the number of values extracted from the constant tensors during model processing. Increasing this number may impact performance due to larger payload sizes."},g2={label:"Hide op nodes with labels below (comma separated)",key:"hide_op_nodes_with_labels",type:2,defaultValue:"Const,pseudo_const,pseudo_qconst,ReadVariableOp",
help:"Removes op nodes from model graphs if their label matches any of the labels entered below."},h2={label:"Maximum number of nodes in an artificial layer",key:"artificial_layer_node_count_threshold",type:1,defaultValue:1E3,help:"Controls the maximum number of immediate child nodes displayed under a layer. When the number of child nodes exceeds this limit, Model Explorer automatically groups them into smaller, more manageable artificial layers to improve layout performance and readability."},i2=
{label:"Edge label font size",key:"edge_label_font_size",type:1,defaultValue:7.5},j2={label:"Disallow vertical edge labels",key:"disallow_vertical_edge_labels",type:0,defaultValue:!1,help:"-"},k2=[f2,g2,h2,i2,{label:"Show welcome card",key:"show_welcome_card",type:0,defaultValue:!0},j2];function l2(a,b){return null==a.i[b.key]?!0===b.defaultValue:!0===a.i[b.key]}function m2(a,b){a=a.i[b.key];return null!=a?Number(a):b.defaultValue||0}
function n2(a,b,c){a.i[c]=b;window.localStorage.setItem("model_explorer_settings",JSON.stringify(a.i))}function o2(a,b,c){isNaN(b)||(a.i[c]=b,window.localStorage.setItem("model_explorer_settings",JSON.stringify(a.i)))}function p2(a,b,c){a.i[c]=b;window.localStorage.setItem("model_explorer_settings",JSON.stringify(a.i))}function q2(){return k2.find(a=>"show_welcome_card"===a.key)}
var r2=class{constructor(){const a=window.localStorage.getItem("model_explorer_settings")||"";this.i=""===a?{}:JSON.parse(a)}getStringValue(a){const b=this.i[a.key];return null!=b?b:a.defaultValue||""}};r2.J=function(a){return new (a||r2)};r2.oa=Ld({la:r2,aa:r2.J,da:"root"});function s2(a){a&1&&(Z(0," When "),R(1,"a",17),Z(2,"View tensor shape on edge"),S(),Z(3," is turned on, Model Explorer will try to position the shape along the edge curve. When the edge is close to vertical, the shape may be hard to read. Enabling this option will force the shapes to be rendered horizontally in such situations to improve readbility. "))}function t2(a){a&1&&Z(0);a&2&&(a=Y(3).ca,yr(" ",a.help," "))}
function u2(a){a&1&&(R(0,"div",16),yp(1,s2,4,0)(2,t2,1,1),S());a&2&&(a=Y(2).ca,D(),Cq("disallow_vertical_edge_labels"===a.key?1:2))}function v2(a){a&1&&(R(0,"div",14)(1,"mat-icon",15),Z(2,"help_outline"),S()(),yp(3,u2,3,1,"ng-template",null,0,Nr));if(a&2){a=wr(4);const b=Y(2);H("xapInlineDialog",a)("overlaySize",b.fd)("overlayPositions",b.dC)("hoverDelayMs",100)}}
function w2(a){if(a&1){const b=Tg();Lq(0);R(1,"mat-slide-toggle",18);V("change",function(c){u(b);const d=Y().ca,e=Y();return x(n2(e.Nc,c.checked,d.key))});S();Mq()}if(a&2){a=Y().ca;const b=Y();D();H("checked",l2(b.Nc,a))}}
function x2(a){if(a&1){const b=Tg();Lq(0);R(1,"input",19,1);V("focus",function(){u(b);const c=wr(2);return x(c.select())})("change",function(){u(b);const c=wr(2),d=Y().ca,e=Y();return x(o2(e.Nc,c.valueAsNumber,d.key))});S();R(3,"div",20);V("click",function(){u(b);const c=Y().ca,d=Y();o2(d.Nc,c.defaultValue,c.key);return x()});Z(4,"Reset to default");S();Mq()}if(a&2){a=Y().ca;const b=Y();D();H("value",m2(b.Nc,a))}}
function y2(a){if(a&1){const b=Tg();Lq(0);R(1,"textarea",19,1);V("focus",function(){u(b);const c=wr(2);return x(c.select())})("change",function(){u(b);const c=wr(2),d=Y().ca,e=Y();return x(p2(e.Nc,c.value,d.key))});S();R(3,"div",20);V("click",function(){u(b);const c=Y().ca,d=Y();p2(d.Nc,c.defaultValue,c.key);return x()});Z(4,"Reset to default");S();Mq()}if(a&2){a=Y().ca;const b=Y();D();H("value",b.Nc.getStringValue(a))}}
function z2(a,b){a&1&&(R(0,"div",10),Lq(1,11),R(2,"div",12),Z(3),yp(4,v2,5,4),S(),yp(5,w2,2,1,"ng-container",13)(6,x2,5,1,"ng-container",13)(7,y2,5,1,"ng-container",13),Mq(),S());a&2&&(a=b.ca,b=Y(),D(),H("ngSwitch",a.type),D(2),yr(" ",a.label," "),D(),Cq(a.help?4:-1),D(),H("ngSwitchCase",b.Wo.Vy),D(),H("ngSwitchCase",b.Wo.Uo),D(),H("ngSwitchCase",b.Wo.vz))}
var A2=class{constructor(a){this.Nc=a;this.Wo=e2;this.fd={minWidth:0,minHeight:0,maxWidth:340};this.dC=[{bb:"end",cb:"top",La:"start",Sa:"top",offsetX:4}];this.VA=k2}};A2.J=function(a){return new (a||A2)(y(r2))};
A2.Ca=Gf({type:A2,ga:[["settings-dialog"]],ja:!0,features:[Jr],ya:11,za:1,Ba:[["helpPopup",""],["input",""],["mat-dialog-title",""],[1,"title"],[1,"local-storage-info"],["mat-dialog-content","",1,"dialog-content"],[1,"settings-container"],["class","setting-item",4,"ngFor","ngForOf"],["mat-dialog-actions","","align","end"],["mat-button","","mat-dialog-close",""],[1,"setting-item"],[3,"ngSwitch"],[1,"setting-label"],[4,"ngSwitchCase"],["dialogLabel","help popup",1,"icon-container",3,"xapInlineDialog",
"overlaySize","overlayPositions","hoverDelayMs"],["fontSet","google-material-icons"],[1,"model-explorer-settings-help-popup"],["href","https://github.com/google-ai-edge/model-explorer/wiki/2.-User-Guide#overlay-data-on-nodesedges","target","_blank"],[3,"change","checked"],["type","number",3,"focus","change","value"],[1,"reset",3,"click"]],sa:function(a,b){a&1&&(R(0,"div",2)(1,"div",3),Z(2,"Advanced settings"),S(),R(3,"div",4),Z(4," Settings are stored in current browser's local storage "),S()(),R(5,
"div",5)(6,"div",6),yp(7,z2,8,6,"div",7),S()(),R(8,"div",8)(9,"button",9),Z(10,"Close"),S()());a&2&&(D(7),H("ngForOf",b.VA))},Ga:[et,Ws,bt,ct,uB,tB,oB,sC,lC,nC,pC,oC,VD,MD,QD,aI,$H,zG,wG],styles:["[_ngcontent-%COMP%]:not(mat-icon){font-family:Google Sans Text,Arial,Helvetica,sans-serif}.title[_ngcontent-%COMP%]{font-size:24px;font-weight:500;margin-top:-16px}.local-storage-info[_ngcontent-%COMP%]{font-size:12px;color:#777;margin-top:6px}.dialog-content[_ngcontent-%COMP%]{padding-bottom:0}.settings-container[_ngcontent-%COMP%]{font-size:13px;color:#000;margin-top:20px;margin-bottom:10px}.setting-item[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:start;-webkit-align-items:flex-start;-moz-box-align:start;-ms-flex-align:start;align-items:flex-start;margin-bottom:24px}.setting-item[_ngcontent-%COMP%]   .setting-label[_ngcontent-%COMP%]{line-height:16px;margin-bottom:4px;width:100%;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.setting-item[_ngcontent-%COMP%]   .setting-label[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{width:16px;height:16px;margin-left:12px;opacity:.4;cursor:pointer}.setting-item[_ngcontent-%COMP%]   .setting-label[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:.6}.setting-item[_ngcontent-%COMP%]   .setting-label[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;width:16px;height:16px}.setting-item[_ngcontent-%COMP%]   input[_ngcontent-%COMP%], .setting-item[_ngcontent-%COMP%]   textarea[_ngcontent-%COMP%]{-moz-box-sizing:border-box;box-sizing:border-box;width:100%}.setting-item[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]::-webkit-inner-spin-button, .setting-item[_ngcontent-%COMP%]   input[_ngcontent-%COMP%]::-webkit-outer-spin-button{-webkit-appearance:none;margin:0}.setting-item[_ngcontent-%COMP%]   .reset[_ngcontent-%COMP%]{color:#999;cursor:pointer;margin-top:2px;text-decoration:underline;-webkit-user-select:none;-moz-user-select:none;-ms-user-select:none;user-select:none}.setting-item[_ngcontent-%COMP%]   .reset[_ngcontent-%COMP%]:hover{color:#777}  .model-explorer-settings-help-popup{font-size:12px;padding:8px;background-color:#fff;line-height:normal}  .model-explorer-settings-help-popup .bold{font-weight:700}"]});function B2(a){a&1&&(Lq(0),R(1,"div",6)(2,"a",7)(3,"mat-icon"),Z(4,"open_in_new"),S(),R(5,"span",8),Z(6,"Learn more from GitHub"),S()()(),Mq())}function C2(a){a&1&&(Lq(0),R(1,"div",6)(2,"a",9)(3,"mat-icon"),Z(4,"open_in_new"),S(),R(5,"span",8),Z(6,"Learn more from g3doc"),S()()(),R(7,"div",6)(8,"a",10)(9,"mat-icon"),Z(10,"group"),S(),R(11,"span",8),Z(12,"Join chat space"),S()()(),Mq())}var D2=class{get yd(){return!0}};D2.J=function(a){return new (a||D2)};
D2.Ca=Gf({type:D2,ga:[["welcome-card"]],ja:!0,features:[Jr],ya:9,za:2,Ba:[[1,"container"],[1,"left"],[1,"title"],[1,"description"],[1,"doc-links-container"],[4,"ngIf"],[1,"doc-link"],["href","https://github.com/google-ai-edge/model-explorer","target","_blank"],[1,"doc-text"],["href","http://go/model-explorer-doc","target","_blank"],["href","https://chat.google.com/room/AAAAxS-rXf0?cls=4","target","_blank"]],sa:function(a,b){a&1&&(R(0,"div",0)(1,"div",1)(2,"div",2),Z(3," Welcome to Model Explorer "),
S(),R(4,"div",3),Z(5," A modern model graph visualizer and debugger "),S(),R(6,"div",4),yp(7,B2,7,0,"ng-container",5)(8,C2,13,0,"ng-container",5),S()()());a&2&&(D(7),H("ngIf",b.yd),D(),H("ngIf",!b.yd))},Ga:[et,$s,aI,$H],styles:[".container[_ngcontent-%COMP%]{width:100%;height:100%;-moz-box-sizing:border-box;box-sizing:border-box;border:1px solid #dadce0;border-radius:8px;padding:24px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]{color:#1f1f1f;font-size:24px}.container[_ngcontent-%COMP%]   .description[_ngcontent-%COMP%]{color:#3c4043;margin-top:8px;font-size:14px}.container[_ngcontent-%COMP%]   .doc-links-container[_ngcontent-%COMP%]{margin-top:24px}.container[_ngcontent-%COMP%]   .doc-link[_ngcontent-%COMP%]{font-size:14px;color:#0b57d0;cursor:pointer;opacity:.8;margin-bottom:8px}.container[_ngcontent-%COMP%]   .doc-link[_ngcontent-%COMP%]   .doc-text[_ngcontent-%COMP%]{color:#0b57d0}.container[_ngcontent-%COMP%]   .doc-link[_ngcontent-%COMP%]   a[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;text-decoration:none}.container[_ngcontent-%COMP%]   .doc-link[_ngcontent-%COMP%]   [_ngcontent-%COMP%]:hover{opacity:1}.container[_ngcontent-%COMP%]   .doc-link[_ngcontent-%COMP%]   [_ngcontent-%COMP%]:hover   .doc-text[_ngcontent-%COMP%]{text-decoration:underline}.container[_ngcontent-%COMP%]   .doc-link[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:18px;width:18px;height:18px;margin-right:8px;color:#0b57d0}.container[_ngcontent-%COMP%]   .video-container[_ngcontent-%COMP%]{width:430px;height:100%;border-radius:8px;background-color:#f1f1f1;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;color:#999;font-size:13px}"]});var E2=class{};E2.J=function(a){return new (a||E2)};E2.oa=Ld({la:E2,aa:E2.J,da:"root"});const F2=["modelSourceInput"],G2=["modelGraphVisualizer"],Lr=()=>[];function H2(a){a&1&&(R(0,"a",8)(1,"button",20)(2,"mat-icon"),Z(3,"article"),S()()())}function I2(a){a&1&&(R(0,"a",21)(1,"button",22)(2,"mat-icon"),Z(3,"article"),S()()(),R(4,"a",23)(5,"button",24)(6,"mat-icon"),Z(7,"bug_report"),S()()())}function J2(a){a&1&&(R(0,"a",9)(1,"button",25)(2,"mat-icon"),Z(3,"alternate_email"),S()()())}
function K2(a){if(a&1){const b=Tg();R(0,"button",26)(1,"mat-icon");Z(2,"info_outline");S()();R(3,"mat-menu",null,0)(5,"button",27);V("click",function(){u(b);Y().Gh.open(d2,{});return x()});Z(6," Open source libraries ");S();R(7,"div",28);Z(8);S()();Kq(9,"open-in-new-tab-button")}if(a&2){a=wr(4);const b=Y();H("matMenuTriggerFor",a);D(8);yr("v",b.runningVersion(),"")}}
function L2(a){if(a&1){const b=Tg();R(0,"div",11);Kq(1,"welcome-card");R(2,"div",29);V("click",function(){u(b);const c=Y();n2(c.Nc,!1,"show_welcome_card");return x()});R(3,"mat-icon");Z(4,"close");S()()()}}function M2(a){a&1&&(R(0,"div",12),Kq(1,"mat-spinner",30),S())}function N2(a){a&1&&(R(0,"div",13),Kq(1,"model-source-input",null,1),S())}function O2(a){a&1&&(R(0,"a",15)(1,"mat-icon"),Z(2,"bug_report"),S()())}function P2(a){a&1&&yp(0,O2,3,0,"a",31);a&2&&(a=Y(),H("ngIf",null==a.ee()&&!a.yc))}
function Q2(a){a&1&&(R(0,"div",16),Z(1,"The "),R(2,"a",32),Z(3," Google Terms of Service "),S(),Z(4," apply to your use of this offering "),S())}function R2(a){if(a&1){const b=Tg();R(0,"div",34);Kq(1,"div",35);R(2,"div",36)(3,"button",37);V("click",function(){u(b);const c=Y(2);return x(S2(c))});R(4,"mat-icon");Z(5,"share");S()()()()}a&2&&(a=Y(2),D(2),H("matTooltip",a.Kx()),D(),H("disabled",a.rj()))}
function T2(a){if(a&1){const b=Tg();R(0,"model-graph-visualizer",33,2);V("titleClicked",function(){u(b);const c=Y();return x(U2(c))})("modelGraphProcessed",function(c){u(b);const d=Y();if(d.Mg&&0<d.Mg.length&&!d.tx){let e;null==(e=d.OC)||DX(e,d.Mg,c.modelGraph);d.tx=!0}return x()})("uiStateChanged",function(c){u(b);const d=Y();p1(d.fk,c);return x()})("remoteNodeDataPathsChanged",function(c){u(b);var d=Y().fk;d.nodeData=c;n1(d);return x()});yp(2,R2,6,2,"div",34);S()}a&2&&(a=Y(),H("graphCollections",
a.yc?Kr():a.ee())("benchmark",a.yc)("config",a.pB)("initialUiState",a.Be)("nodeDataSources",a.Mg),D(2),Cq(a.de?2:-1))}
function S2(a){null!=window.gtag&&window.gtag("event","share_clicked",Object.assign({},void 0));const b=window.location.href,c=new URLSearchParams;c.append("url",b);c.append("contains_no_pii","true");fetch("https://shortn.corp.google.com/",{mode:"cors",credentials:"include",method:"POST",headers:{Accept:"application/json","Content-Type":"application/x-www-form-urlencoded"},body:c.toString()}).then(d=>{d.json().then(e=>{navigator.clipboard.writeText(e.url);a.F.open("Sharable URL copied to clipboard",
"Close",{duration:5E3})})}).catch(d=>{console.error(d);navigator.clipboard.writeText(b);a.F.open("Sharable URL copied to clipboard","Close",{duration:5E3})})}function U2(a,b=!1){b?a.D.navigate(["/"]).then(()=>{window.location.reload()}):window.history.back()}function V2(a){a.ee.set(void 0);a.Be=void 0;setTimeout(()=>{a.D.navigate([],{sb:{},px:"",Tl:!0})})}
var W2=class{constructor(a,b,c,d,e,f,g,k,m,p,t){this.Gh=a;this.C=b;this.G=d;this.K=e;this.i=f;this.D=g;this.Nc=k;this.F=m;this.fk=t;this.Bw=this.C.hd;this.ee=this.G.ee;this.runningVersion=ys(()=>this.K.info().runningVersion);this.yc=this.Zk=!1;this.Mg=[];this.rj=ur(!1);this.Kx=ur("");this.tx=!1;this.Be=this.fk.uiState;Gs(()=>{this.C.hd()||setTimeout(()=>{const v=this.fk.models;null!=v&&0<v.length&&V1(this.ao,v)})});Gs(()=>{null!=this.ee()&&window.history.pushState({ts:Date.now()},"")});this.yc="1"===
(new URLSearchParams(document.location.search)).get("benchmark");this.Mg=this.fk.nodeData||[]}nd(){this.ao&&(this.rj=this.ao.rj,this.Kx=ys(()=>this.rj()?"Share is not available for uploaded models":"Share"))}Lq(a){null==this.ee()&&(this.Zk=!0);a.preventDefault()}Mq(a){a.preventDefault();this.Zk=!1;const b=[];let c;if(null==(c=a.dataTransfer)?0:c.items)[...a.dataTransfer.items].forEach(d=>{"file"===d.kind&&(d=d.getAsFile())&&b.push(d)});else{let d;b.push(...((null==(d=a.dataTransfer)?void 0:d.files)||
[]))}Z1(this.ao,b)}get yd(){return!0}get de(){return!1}get lE(){const a=q2();return a?l2(this.Nc,a):!0}get pB(){const a="1"===this.i.jb.sb.show_tflite_consts;return{nodeLabelsToHide:this.Nc.getStringValue(g2).split(",").map(b=>b.trim()).filter(b=>""!==b&&(!a||a&&"pseudo_const"!==b&&"pseudo_qconst"!==b)),artificialLayerNodeCountThreshold:m2(this.Nc,h2),edgeLabelFontSize:m2(this.Nc,i2),maxConstValueCount:m2(this.Nc,f2),disallowVerticalEdgeLabels:l2(this.Nc,j2)}}};
W2.J=function(a){return new (a||W2)(y(iC),y(TX),y(E2),y("ModelLoaderService"),y(vS),y(IZ),y(e1),y(r2),y(oE),y(rM),y(q1))};
W2.Ca=Gf({type:W2,ga:[["home-page"]],eb:function(a,b){a&1&&(rr(F2,5),rr(G2,5));if(a&2){let c;sr(c=tr())&&(b.ao=c.first);sr(c=tr())&&(b.OC=c.first)}},Ha:function(a,b){a&1&&V("popstate",function(){return V2(b)},!1,zi)},ja:!0,features:[Jr],ya:25,za:14,Ba:[["menu","matMenu"],["modelSourceInput",""],["modelGraphVisualizer",""],[1,"container",3,"dragover","dragleave","dragend","drop"],[1,"title"],[1,"name",3,"click"],[1,"icons-container"],["mat-icon-button","","aria-label","settings","matTooltip","Advanced settings",
3,"click"],["href","http://go/model-explorer-doc","target","_blank"],["href","https://moma.corp.google.com/team/1963115384013","target","_blank"],[1,"content"],[1,"welcome-card-container"],[1,"loading-adapter-extension-container"],[1,"model-source-input-container"],[1,"padding"],["href","https://b.corp.google.com/issues/new?component=1338731&template=1850894","target","_blank","matTooltip","File bug or feature request",1,"bug-report"],[1,"utos"],[3,"graphCollections","benchmark","config","initialUiState",
"nodeDataSources","titleClicked","modelGraphProcessed","uiStateChanged","remoteNodeDataPathsChanged",4,"ngIf"],[1,"dragover-overlay"],[1,"msg"],"mat-icon-button  aria-label doc matTooltip g3doc".split(" "),["href","https://github.com/google-ai-edge/model-explorer","target","_blank"],"mat-icon-button  aria-label doc matTooltip GitHub".split(" "),["href","https://github.com/google-ai-edge/model-explorer/issues","target","_blank"],"mat-icon-button;;aria-label;bug;matTooltip;File issue or feature request".split(";"),
"mat-icon-button;;aria-label;contact;matTooltip;Contact us".split(";"),["mat-icon-button","","aria-label","about","matTooltip","About",3,"matMenuTriggerFor"],["mat-menu-item","",3,"click"],[1,"model-explorer-version"],["matTooltip","Dismiss",1,"icon-container",3,"click"],["color","primary","diameter","24"],["href","https://b.corp.google.com/issues/new?component=1338731&template=1850894","class","bug-report","target","_blank","matTooltip","File bug or feature request",4,"ngIf"],["href","https://policies.google.com/terms?hl=en-US#toc-intro",
"target","_blank"],[3,"titleClicked","modelGraphProcessed","uiStateChanged","remoteNodeDataPathsChanged","graphCollections","benchmark","config","initialUiState","nodeDataSources"],[1,"btns-container"],[1,"divider"],[1,"share-button-container",3,"matTooltip"],["mat-icon-button","","aria-label","share",3,"click","disabled"]],sa:function(a,b){a&1&&(R(0,"div",3),V("dragover",function(c){return b.Lq(c)})("dragleave",function(){b.Zk=!1})("dragend",function(){b.Zk=!1})("drop",function(c){return b.Mq(c)}),
R(1,"div",4)(2,"div",5),V("click",function(){return U2(b,!0)}),Kq(3,"me-logo"),Z(4," Model Explorer "),Kq(5,"new-version-chip"),S(),R(6,"div",6)(7,"button",7),V("click",function(){b.Gh.open(A2,{})}),R(8,"mat-icon"),Z(9,"settings"),S()(),yp(10,H2,4,0,"a",8)(11,I2,8,0)(12,J2,4,0,"a",9)(13,K2,10,2),S()(),R(14,"div",10),yp(15,L2,5,0,"div",11)(16,M2,2,0,"div",12)(17,N2,3,0,"div",13),Kq(18,"div",14),S(),yp(19,P2,1,1,"a",15)(20,Q2,5,0,"div",16)(21,T2,3,7,"model-graph-visualizer",17),R(22,"div",18)(23,"div",
19),Z(24,"Drop to add model files"),S()()());a&2&&(lq("dragover",b.Zk),D(),lq("hide",null!=b.ee()||b.yc),D(9),Cq(b.de?10:11),D(2),Cq(b.de?12:-1),D(),Cq(b.yd?13:-1),D(),lq("hide",null!=b.ee()||b.yc),D(),Cq(b.lE?15:-1),D(),Cq(b.Bw()?16:17),D(3),Cq(b.de?19:-1),D(),Cq(null==b.ee()&&b.yd&&!b.yc?20:-1),D(),H("ngIf",null!=b.ee()||b.yc))},Ga:[et,$s,$F,tE,YF,uB,tB,rB,TC,vC,JC,CC,RC,pD,oD,lD,rE,OJ,qC,aI,$H,EX,$1,wS,cI,D2],styles:[".container[_ngcontent-%COMP%]{width:100%;height:100%;overflow:hidden;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;position:relative}.container.dragover[_ngcontent-%COMP%]   .dragover-overlay[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex}.container[_ngcontent-%COMP%]   .dragover-overlay[_ngcontent-%COMP%]{display:none;position:absolute;left:0;top:0;width:100%;height:100%;background-color:rgba(0,0,0,.1);pointer-events:none;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:end;-webkit-justify-content:flex-end;-moz-box-pack:end;-ms-flex-pack:end;justify-content:flex-end;z-index:500}.container[_ngcontent-%COMP%]   .dragover-overlay[_ngcontent-%COMP%]   .msg[_ngcontent-%COMP%]{margin-bottom:16px;color:#fff;padding:4px 12px;border-radius:99px;background-color:#4285f4}@-webkit-keyframes _ngcontent-%COMP%_rotate{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}30%{-webkit-transform:rotate(180deg);transform:rotate(180deg)}60%{-webkit-transform:rotate(1turn);transform:rotate(1turn)}to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}@keyframes _ngcontent-%COMP%_rotate{0%{-webkit-transform:rotate(0deg);transform:rotate(0deg)}30%{-webkit-transform:rotate(180deg);transform:rotate(180deg)}60%{-webkit-transform:rotate(1turn);transform:rotate(1turn)}to{-webkit-transform:rotate(1turn);transform:rotate(1turn)}}@-webkit-keyframes _ngcontent-%COMP%_goUp{0%{-webkit-transform:translateY(10%);transform:translateY(10%);opacity:0}30%{-webkit-transform:translate(0);transform:translate(0);opacity:1}to{-webkit-transform:translateY(-25%);transform:translateY(-25%);opacity:0}}@keyframes _ngcontent-%COMP%_goUp{0%{-webkit-transform:translateY(10%);transform:translateY(10%);opacity:0}30%{-webkit-transform:translate(0);transform:translate(0);opacity:1}to{-webkit-transform:translateY(-25%);transform:translateY(-25%);opacity:0}}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]{padding:8px 12px;-moz-box-sizing:border-box;box-sizing:border-box;height:48px;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:justify;-webkit-justify-content:space-between;-moz-box-pack:justify;-ms-flex-pack:justify;justify-content:space-between;cursor:pointer;color:#444746;border-bottom:1px solid transparent}.container[_ngcontent-%COMP%]   .title.hide[_ngcontent-%COMP%]{display:none}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .name[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;font-size:20px}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .name[_ngcontent-%COMP%]   me-logo[_ngcontent-%COMP%]{margin-right:6px}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .name[_ngcontent-%COMP%]   new-version-chip[_ngcontent-%COMP%]{margin-left:16px}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .icons-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .icons-container[_ngcontent-%COMP%]   a[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;color:#000}.container[_ngcontent-%COMP%]   .title[_ngcontent-%COMP%]   .icons-container[_ngcontent-%COMP%]   open-in-new-tab-button[_ngcontent-%COMP%]{margin-left:8px}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]{-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:start;-webkit-justify-content:flex-start;-moz-box-pack:start;-ms-flex-pack:start;justify-content:flex-start;position:relative;margin-top:16px;overflow:hidden}.container[_ngcontent-%COMP%]   .content.hide[_ngcontent-%COMP%]{display:none}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .welcome-card-container[_ngcontent-%COMP%]{width:1016px;-webkit-flex-shrink:0;-ms-flex-negative:0;flex-shrink:0;position:relative}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .welcome-card-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]{position:absolute;top:6px;right:6px;cursor:pointer;opacity:.5}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .welcome-card-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]:hover{opacity:.8}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .welcome-card-container[_ngcontent-%COMP%]   .icon-container[_ngcontent-%COMP%]   mat-icon[_ngcontent-%COMP%]{font-size:16px;width:16px;height:16px}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .loading-adapter-extension-container[_ngcontent-%COMP%]{margin-top:20px}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .model-source-input-container[_ngcontent-%COMP%]{width:1016px;margin-top:20px;overflow:hidden;z-index:100;background-color:#fff}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .padding[_ngcontent-%COMP%]{width:100%;-webkit-box-flex:1;-webkit-flex-grow:1;-moz-box-flex:1;-ms-flex-positive:1;flex-grow:1;min-height:12px}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .cover[_ngcontent-%COMP%]{position:absolute;top:0;left:0;width:100%;height:100%;z-index:5000;color:#333;background-color:hsla(0,0%,100%,.9);-webkit-backdrop-filter:blur(10px);backdrop-filter:blur(10px);display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-orient:vertical;-webkit-box-direction:normal;-webkit-flex-direction:column;-moz-box-orient:vertical;-moz-box-direction:normal;-ms-flex-direction:column;flex-direction:column;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .cover[_ngcontent-%COMP%]   .loading-subtitle[_ngcontent-%COMP%]{font-size:14px;color:#999;margin-top:20px}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .loading[_ngcontent-%COMP%]   .wait-icon[_ngcontent-%COMP%]{display:inline-block;margin:0 8px;-webkit-animation:_ngcontent-%COMP%_rotate 2s ease-in-out 0s infinite;animation:_ngcontent-%COMP%_rotate 2s ease-in-out 0s infinite}.container[_ngcontent-%COMP%]   .content[_ngcontent-%COMP%]   .uploading[_ngcontent-%COMP%]   .upload-icon[_ngcontent-%COMP%]{display:inline-block;margin:0 8px;-webkit-animation:_ngcontent-%COMP%_goUp 1s ease-in-out 0s infinite;animation:_ngcontent-%COMP%_goUp 1s ease-in-out 0s infinite}.container[_ngcontent-%COMP%]   .utos[_ngcontent-%COMP%]{position:absolute;right:12px;bottom:12px;font-size:12px;color:#999}.container[_ngcontent-%COMP%]   .utos[_ngcontent-%COMP%]   a[_ngcontent-%COMP%]{color:#999}.container[_ngcontent-%COMP%]   model-graph-visualizer[_ngcontent-%COMP%]{width:100%;height:100%}.container[_ngcontent-%COMP%]   .bug-report[_ngcontent-%COMP%]{position:absolute;bottom:8px;left:8px;display:inline-block;display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center;color:#000;opacity:.5}.container[_ngcontent-%COMP%]   .bug-report[_ngcontent-%COMP%]:hover{opacity:.8}.container[_ngcontent-%COMP%]   .btns-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center}.container[_ngcontent-%COMP%]   .btns-container[_ngcontent-%COMP%]   .share-button-container[_ngcontent-%COMP%]{display:-webkit-box;display:-webkit-flex;display:-moz-box;display:-ms-flexbox;display:flex;-webkit-box-align:center;-webkit-align-items:center;-moz-box-align:center;-ms-flex-align:center;align-items:center;-webkit-box-pack:center;-webkit-justify-content:center;-moz-box-pack:center;-ms-flex-pack:center;justify-content:center}.container[_ngcontent-%COMP%]   .btns-container[_ngcontent-%COMP%]   .divider[_ngcontent-%COMP%]{border-left:1px solid #ccc;height:28px;-moz-box-sizing:border-box;box-sizing:border-box;margin-left:8px;margin-right:8px}  .model-explorer-version{font-size:12px;text-align:right;padding:8px 16px 0;color:#999}"]});var X2=class{};X2.J=function(a){return new (a||X2)};X2.Ca=Gf({type:X2,ga:[["app-root"]],ja:!0,features:[Jr],ya:1,za:0,sa:function(a){a&1&&Kq(0,"home-page")},Ga:[W2,m1]});function T1(a,b){return sa(function*(){var c=[];for(const d of b)"local"!==d.type&&"graphs_json_from_server"!==d.type&&"file_path"!==d.type||c.push(Y2(a,d));c=yield Promise.all(c);for(const d of b)null!=d.errorMessage&&(d.errorMessage=AI(d.errorMessage));null==c.find(d=>0===d.length)&&a.ee.set(c.flat())})}
function Y2(a,b){return sa(function*(){b.status.set("Converting");var c=[];if("file_path"===b.type){var d;switch(null==(d=b.Qc)?void 0:d.id){case "builtin_json":try{const f=yield Z2(b.path),g=b.path.split("/").pop()||"untitled",k=JSON.parse(f),m=HX(g,k);if(m.error)throw Error(`Failed to process file: ${m.error})`);m.graphCollections&&(c=m.graphCollections);b.status.set("Done")}catch(f){b.selected=!1,b.status.set("Error"),b.errorMessage=f}break;default:c=b.path;var e=c.split("/").pop()||"untitled";
c=yield $2(a,b,c,e,!1)}}else switch(d=b.file,null==(e=b.Qc)?void 0:e.id){case "builtin_json":try{c="graphs_json_from_server"===b.type?yield a3(b.path):yield GX(d),b.status.set("Done")}catch(k){b.selected=!1,b.status.set("Error"),b.errorMessage=k}break;default:b.status.set("Uploading");const {path:f,error:g}=yield b3(d);if(g)return b.selected=!1,b.status.set("Error"),b.errorMessage=g,[];c=yield $2(a,b,f,d.name,!0)}return c})}
function Z2(a){return sa(function*(){const b=yield(yield fetch(`${"/api/v1/read_text_file"}?path=${a}`)).json();if(b.error)throw Error(`Failed to read file: ${b.error}`);return b.content})}
function $2(a,b,c,d,e){return sa(function*(){let f=[];b.status.set("Converting");var g,k=(null==(g=b.Qc)?void 0:g.id)||"";g=a.Nc;const m={};for(const v of k2)switch(v.type){case 0:m[v.key]=l2(g,v);break;case 1:m[v.key]=m2(g,v)}const {hB:p,Sw:t}=yield SX({cmdId:"convert",extensionId:k,modelPath:c,settings:m,deleteAfterConversion:e});if(k=(null==p?void 0:p.error)||t)return b.selected=!1,b.status.set("Error"),b.errorMessage=k,[];p&&(f=c3(p,d));b.status.set("Done");return f})}
function a3(a){return sa(function*(){var b=a.replace("graphs://","").split("/");const c=b[0];b=yield(yield fetch(`${"/api/v1/load_graphs_json"}?graph_index=${Number(b[1])}`)).json();return c3(b,c)})}function b3(a){return sa(function*(){var b=new FormData;b.append("file",a,a.name);b=yield fetch("/apipost/v1/upload",{method:"POST",body:b});if(b.ok)return{path:JSON.parse(yield b.text()).path};console.error(yield b.text());return{path:"",error:"Failed to upload model. Check console for details"}})}
function c3(a,b){return a.graphs?[{label:b,graphs:a.graphs}]:a.graphCollections?a.graphCollections.map(c=>({label:""===c.label?b:`${b} (${c.label})`,graphs:c.graphs})):[]}var d3=class{constructor(a){this.Nc=a;this.ee=ur()}};d3.J=function(a){return new (a||d3)(q(r2),q(TX))};d3.oa=Ld({la:d3,aa:d3.J,da:"root"});var e3=class{};function f3(){return new Yd(3008,!1)};function g3(a){if("number"==typeof a)return a;a=a.match(/^(-?[\.\d]+)(m?s)/);return!a||2>a.length?0:h3(parseFloat(a[1]),a[2])}function h3(a,b){switch(b){case "s":return 1E3*a;default:return a}}
function i3(a,b,c){if(a.hasOwnProperty("duration"))b=a;else a:{var d=/^(-?[\.\d]+)(m?s)(?:\s+(-?[\.\d]+)(m?s))?(?:\s+([-a-z]+(?:\(.+?\))?))?$/i;let e=0,f="";if("string"===typeof a){d=a.match(d);if(null===d){b.push(new Yd(3E3,!1));b={duration:0,delay:0,easing:""};break a}a=h3(parseFloat(d[1]),d[2]);const g=d[3];null!=g&&(e=h3(parseFloat(g),d[4]));(d=d[5])&&(f=d)}c||(c=!1,d=b.length,0>a&&(b.push(new Yd(3100,!1)),c=!0),0>e&&(b.push(new Yd(3101,!1)),c=!0),c&&b.splice(d,0,new Yd(3E3,!1)));b={duration:a,
delay:e,easing:f}}return b}function j3(a){return a.length?a[0]instanceof Map?a:a.map(b=>new Map(Object.entries(b))):[]}function k3(a,b,c){b.forEach((d,e)=>{const f=l3(e);c&&!c.has(e)&&c.set(e,a.style[f]);a.style[f]=d})}function m3(a,b){b.forEach((c,d)=>{d=l3(d);a.style[d]=""})}function n3(a){if(Array.isArray(a)){var b;1==a.length?b=a[0]:b={type:2,steps:a,options:null};a=b}return a}
function o3(a,b,c){const d=b.params||{};a=p3(a);a.length&&a.forEach(e=>{d.hasOwnProperty(e)||c.push(new Yd(3001,!1))})}const q3=RegExp("{{\\s*(.+?)\\s*}}","g");function p3(a){let b=[];if("string"===typeof a){let c;for(;c=q3.exec(a);)b.push(c[1]);q3.lastIndex=0}return b}function r3(a,b,c){const d=`${a}`,e=d.replace(q3,(f,g)=>{g=b[g];null==g&&(c.push(new Yd(3003,!1)),g="");return g.toString()});return e==d?a:e}const s3=/-+([a-z0-9])/g;function l3(a){return a.replace(s3,(...b)=>b[1].toUpperCase())}
function t3(a,b,c){if(c.size&&b.length){let d=b[0],e=[];c.forEach((f,g)=>{d.has(g)||e.push(g);d.set(g,f)});if(e.length)for(c=1;c<b.length;c++){let f=b[c];e.forEach(g=>f.set(g,u3(a,g)))}}return b}
function v3(a,b,c){switch(b.type){case 7:return a.Ny(b,c);case 0:return a.Ps(b,c);case 1:return a.Qs(b,c);case 2:return a.Ly(b,c);case 3:return a.Jy(b,c);case 4:return a.Gy(b,c);case 5:return a.Jo(b,c);case 6:return a.lm(b,c);case 8:return a.Ko(b,c);case 9:return a.Hy(b,c);case 10:return a.Iy(b,c);case 11:return a.Ky(b,c);case 12:return a.My(b,c);default:throw new Yd(3004,!1);}}function u3(a,b){return window.getComputedStyle(a)[b]};const w3=new Set("width height minWidth minHeight maxWidth maxHeight left top bottom right fontSize outlineWidth outlineOffset paddingTop paddingLeft paddingBottom paddingRight marginTop marginLeft marginBottom marginRight borderRadius borderWidth borderTopWidth borderLeftWidth borderRightWidth borderBottomWidth textIndent perspective".split(" "));
function x3(a,b,c){let d="";const e=b.toString().trim();w3.has(a)&&0!==b&&"0"!==b&&("number"===typeof b?d="px":(a=b.match(/^[+-]?[\d\.]+([a-z]*)$/))&&0==a[1].length&&c.push(new Yd(3005,!1)));return e+d}var y3=class extends e3{};function z3(a){switch(a.length){case 0:return new Zy;case 1:return a[0];default:return new cz(a)}}function A3(a,b=new Map,c=new Map){const d=[],e=[];let f=-1,g=null;a.forEach(k=>{const m=k.get("offset"),p=m==f,t=p&&g||new Map;k.forEach((v,B)=>{let G=B;if("offset"!==B)switch(G=l3(G),v){case "!":v=b.get(B);break;case "*":v=c.get(B);break;default:v=x3(G,v,d)}t.set(G,v)});p||e.push(t);g=t;f=m});if(d.length)throw new Yd(3502,!1);return e}
function B3(a,b,c,d){switch(b){case "start":a.onStart(()=>d(c&&C3(c,"start",a)));break;case "done":a.Id(()=>d(c&&C3(c,"done",a)));break;case "destroy":a.nb(()=>d(c&&C3(c,"destroy",a)))}}function C3(a,b,c){const d=c.totalTime;b=D3(a.element,a.Oc,a.zg,a.le,b||a.tD,void 0==d?a.totalTime:d,c.disabled?!0:!1);a=a._data;null!=a&&(b._data=a);return b}function D3(a,b,c,d,e="",f=0,g){return{element:a,Oc:b,zg:c,le:d,tD:e,totalTime:f,disabled:!!g}}function E3(a,b,c){let d=a.get(b);d||a.set(b,d=c);return d}
function F3(a){const b=a.indexOf(":");return[a.substring(1,b),a.slice(b+1)]}const G3="undefined"===typeof document?null:document.documentElement;function H3(a){a=a.parentNode||a.host||null;return a===G3?null:a}function I3(a,b){for(;b;){if(b===a)return!0;b=H3(b)}return!1};var J3=class{};function K3(a,b){const c=[];"string"==typeof a?a.split(/\s*,\s*/).forEach(d=>{a:{if(":"==d[0]&&(d=L3(d,b),"function"==typeof d)){c.push(d);d=void 0;break a}var e=d.match(/^(\*|[-\w]+)\s*(<?[=-]>)\s*(\*|[-\w]+)$/);if(null==e||4>e.length)b.push(new Yd(3015,!1)),d=c;else{d=e[1];var f=e[2];e=e[3];c.push(M3(d,e));"<"!=f[0]||"*"==d&&"*"==e||c.push(M3(e,d));d=void 0}}return d}):c.push(a);return c}
function L3(a,b){switch(a){case ":enter":return"void => *";case ":leave":return"* => void";case ":increment":return(c,d)=>parseFloat(d)>parseFloat(c);case ":decrement":return(c,d)=>parseFloat(d)<parseFloat(c);default:return b.push(new Yd(3016,!1)),"* => *"}}const N3=new Set(["true","1"]),O3=new Set(["false","0"]);
function M3(a,b){const c=N3.has(a)||O3.has(a),d=N3.has(b)||O3.has(b);return(e,f)=>{let g="*"==a||a==e,k="*"==b||b==f;!g&&c&&"boolean"===typeof e&&(g=e?N3.has(a):O3.has(a));!k&&d&&"boolean"===typeof f&&(k=f?N3.has(b):O3.has(b));return g&&k}};const P3=RegExp("s*:selfs*,?","g");
var V3=class{C(a,b){b=new Q3(b);this.D(b);return v3(this,n3(a),b)}D(a){a.C="";a.F=new Map;a.F.set("",new Map);a.i=0}Ny(a,b){let c=b.Kg=0,d=b.af=0;const e=[],f=[];"@"==a.name.charAt(0)&&b.errors.push(new Yd(3006,!1));a.xB.forEach(g=>{this.D(b);if(0==g.type){var k=g.name;k.toString().split(/\s*,\s*/).forEach(m=>{g.name=m;e.push(this.Ps(g,b))});g.name=k}else 1==g.type?(k=this.Qs(g,b),c+=k.Kg,d+=k.af,f.push(k)):b.errors.push(new Yd(3007,!1))});return{type:7,name:a.name,ki:e,Yg:f,Kg:c,af:d,options:null}}Ps(a,
b){const c=this.lm(a.styles,b),d=a.options&&a.options.params||null;if(c.mB){const e=new Set,f=d||{};c.styles.forEach(g=>{g instanceof Map&&g.forEach(k=>{p3(k).forEach(m=>{f.hasOwnProperty(m)||e.add(m)})})});e.size&&b.errors.push(f3([...e.values()]))}return{type:0,name:a.name,style:c,options:d?{params:d}:null}}Qs(a,b){b.Kg=0;b.af=0;const c=v3(this,n3(a.animation),b);return{type:1,Ew:K3(a.LB,b.errors),animation:c,Kg:b.Kg,af:b.af,options:R3(a.options)}}Ly(a,b){return{type:2,steps:a.steps.map(c=>v3(this,
c,b)),options:R3(a.options)}}Jy(a,b){const c=b.i;let d=0;const e=a.steps.map(f=>{b.i=c;f=v3(this,f,b);d=Math.max(d,b.i);return f});b.i=d;return{type:3,steps:e,options:R3(a.options)}}Gy(a,b){const c=S3(a.dg,b.errors);b.D=c;var d=a.styles?a.styles:Ty({});if(5==d.type)a=this.Jo(d,b);else{d=a.styles;a=!1;d||(a=!0,d={},c.easing&&(d.easing=c.easing),d=Ty(d));b.i+=c.duration+c.delay;const e=this.lm(d,b);e.uC=a;a=e}b.D=null;return{type:4,dg:c,style:a,options:null}}lm(a,b){a=this.i(a,b);this.F(a,b);return a}i(a,
b){const c=[],d=Array.isArray(a.styles)?a.styles:[a.styles];for(let g of d)"string"===typeof g?"*"===g?c.push(g):b.errors.push(new Yd(3002,!1)):c.push(new Map(Object.entries(g)));let e=!1,f=null;c.forEach(g=>{if(g instanceof Map&&(g.has("easing")&&(f=g.get("easing"),g.delete("easing")),!e))for(let k of g.values())if(0<=k.toString().indexOf("{{")){e=!0;break}});return{type:6,styles:c,easing:f,offset:a.offset,mB:e,options:null}}F(a,b){const c=b.D;let d=b.i,e=b.i;c&&0<e&&(e-=c.duration+c.delay);a.styles.forEach(f=>
{"string"!==typeof f&&f.forEach((g,k)=>{const m=b.F.get(b.C),p=m.get(k);let t=!0;p&&(e!=d&&e>=p.startTime&&d<=p.endTime&&(b.errors.push(new Yd(3010,!1)),t=!1),e=p.startTime);t&&m.set(k,{startTime:e,endTime:d});b.options&&o3(g,b.options,b.errors)})})}Jo(a,b){const c={type:5,styles:[],options:null};if(!b.D)return b.errors.push(new Yd(3011,!1)),c;let d=0;const e=[];let f=!1,g=!1,k=0;const m=a.steps.map(K=>{K=this.i(K,b);let N=null!=K.offset?K.offset:T3(K.styles),aa=0;null!=N&&(d++,aa=K.offset=N);g=g||
0>aa||1<aa;f=f||aa<k;k=aa;e.push(aa);return K});g&&b.errors.push(new Yd(3012,!1));f&&b.errors.push(new Yd(3200,!1));a=a.steps.length;let p=0;0<d&&d<a?b.errors.push(new Yd(3202,!1)):0==d&&(p=1/(a-1));const t=a-1,v=b.i,B=b.D,G=B.duration;m.forEach((K,N)=>{N=0<p?N==t?1:p*N:e[N];const aa=N*G;b.i=v+B.delay+aa;B.duration=aa;this.F(K,b);K.offset=N;c.styles.push(K)});return c}Ko(a,b){return{type:8,animation:v3(this,n3(a.animation),b),options:R3(a.options)}}Hy(a,b){b.af++;return{type:9,options:R3(a.options)}}Iy(a,
b){return{type:10,animation:this.Ko(a.animation,b),options:R3(a.options)}}Ky(a,b){const c=b.C,d=a.options||{};b.Kg++;b.G=a;const [e,f]=U3(a.Vl);b.C=c.length?c+" "+e:e;E3(b.F,b.C,new Map);const g=v3(this,n3(a.animation),b);b.G=null;b.C=c;return{type:11,Vl:e,limit:d.limit||0,optional:!!d.optional,lC:f,animation:g,dG:a.Vl,options:R3(a.options)}}My(a,b){b.G||b.errors.push(new Yd(3013,!1));const c="full"===a.dg?{duration:0,delay:0,easing:"full"}:i3(a.dg,b.errors,!0);return{type:12,animation:v3(this,n3(a.animation),
b),dg:c,options:null}}};function U3(a){const b=a.split(/\s*,\s*/).find(c=>":self"==c)?!0:!1;b&&(a=a.replace(P3,""));a=a.replace(/@\*/g,".ng-trigger").replace(/@\w+/g,c=>".ng-trigger-"+c.slice(1)).replace(/:animating/g,".ng-animating");return[a,b]}var Q3=class{constructor(a){this.errors=a;this.af=this.Kg=0;this.D=this.C=this.G=null;this.i=0;this.F=new Map;this.options=null}};
function T3(a){if("string"==typeof a)return null;let b=null;Array.isArray(a)?a.forEach(c=>{c instanceof Map&&c.has("offset")&&(b=parseFloat(c.get("offset")),c.delete("offset"))}):a instanceof Map&&a.has("offset")&&(b=parseFloat(a.get("offset")),a.delete("offset"));return b}
function S3(a,b){if(a.hasOwnProperty("duration"))return a;if("number"==typeof a)return{duration:i3(a,b).duration,delay:0,easing:""};if(a.split(/\s+/).some(c=>"{"==c.charAt(0)&&"{"==c.charAt(1)))return b={duration:0,delay:0,easing:"",dynamic:!0},b.strValue=a,b;a=i3(a,b);return{duration:a.duration,delay:a.delay,easing:a.easing}}function R3(a){if(a){if(a=Object.assign({},a),a.params){var b=a;var c=(c=a.params)?Object.assign({},c):null;b.params=c}}else a={};return a};function W3(a,b,c,d,e,f,g=null,k=!1){return{type:1,element:a,Bg:b,Fj:c,ai:d,duration:e,delay:f,totalTime:e+f,easing:g,sE:k}};var X3=class{constructor(){this.i=new Map}get(a){return this.i.get(a)||[]}append(a,b){let c=this.i.get(a);c||this.i.set(a,c=[]);c.push(...b)}has(a){return this.i.has(a)}clear(){this.i.clear()}};const Y3=RegExp(":enter","g"),Z3=RegExp(":leave","g");function $3(a,b,c,d,e,f=new Map,g=new Map,k,m,p=[]){return a4(a,b,c,d,e,f,g,k,m,p)}
function a4(a,b,c,d,e,f,g,k,m,p=[]){var t=new b4;m=m||new X3;a=new c4(a,b,m,d,e,p,[]);a.options=k;d=k.delay?g3(k.delay):0;d4(a.i,d);e4(a.i,[f],null,a.errors,k);v3(t,c,a);c=a.rf.filter(v=>v.ra());if(c.length&&g.size){let v;for(f=c.length-1;0<=f;f--)if(t=c[f],t.element===b){v=t;break}v&&v.ma===v.i&&e4(v,[g],null,a.errors,k)}return c.length?c.map(v=>v.ia()):[W3(b,[],[],[],0,d,"",!1)]}
var b4=class{Ny(){}Ps(){}Qs(){}Hy(a,b){var c=b.ba.get(b.element);if(c){const d=f4(b,a.options),e=b.i.C;c=this.C(c,d,d.options);e!=c&&g4(b,c)}b.C=a}Iy(a,b){const c=f4(b,a.options);g4(c);this.i([a.options,a.animation.options],b,c);this.Ko(a.animation,c);g4(b,c.i.C);b.C=a}i(a,b,c){for(const d of a){let e;if(a=null==(e=d)?void 0:e.delay){let f,g;a="number"===typeof a?a:g3(r3(a,null!=(g=null==(f=d)?void 0:f.params)?g:{},b.errors));h4(c,a)}}}C(a,b,c){let d=b.i.C;const e=null!=c.duration?g3(c.duration):
null,f=null!=c.delay?g3(c.delay):null;0!==e&&a.forEach(g=>{const k={duration:null!=e?e:g.duration,delay:b.i.C+(null!=f?f:0)+g.delay,easing:""};g=new i4(b.G,g.element,g.Bg,g.Fj,g.ai,k,g.rE);b.rf.push(g);d=Math.max(d,k.duration+k.delay)});return d}Ko(a,b){j4(b,a.options,!0);v3(this,a.animation,b);b.C=a}Ly(a,b){const c=b.K;let d=b;const e=a.options;e&&(e.params||e.delay)&&(d=f4(b,e),g4(d),null!=e.delay&&(6==d.C.type&&(k4(d.i),d.C=l4),h4(d,g3(e.delay))));a.steps.length&&(a.steps.forEach(f=>v3(this,f,
d)),m4(d.i),d.K>c&&g4(d));b.C=a}Jy(a,b){const c=[];let d=b.i.C;const e=a.options&&a.options.delay?g3(a.options.delay):0;a.steps.forEach(f=>{const g=f4(b,a.options);e&&h4(g,e);v3(this,f,g);d=Math.max(d,g.i.C);c.push(g.i)});c.forEach(f=>n4(b.i,f));g4(b,d);b.C=a}D(a,b){return a.dynamic?(a=a.strValue,a=b.params?r3(a,b.params,b.errors):a,i3(a,b.errors)):{duration:a.duration,delay:a.delay,easing:a.easing}}Gy(a,b){const c=b.D=this.D(a.dg,b),d=b.i;c.delay&&(o4(b.i,b.i.duration+c.delay),k4(d));const e=a.style;
5==e.type?this.Jo(e,b):(o4(b.i,b.i.duration+c.duration),this.lm(e,b),m4(d));b.D=null;b.C=a}lm(a,b){const c=b.i;var d=b.D;!d&&0<c.i.size&&(c.duration+=1,c.R());d=d&&d.easing||a.easing;if(a.uC){d&&c.T.set("easing",d);for(let [e,f]of c.D)d=e,c.O.set(d,f||"*"),c.i.set(d,"*");c.ma=c.i}else e4(c,a.styles,d,b.errors,b.options);b.C=a}Jo(a,b){const c=b.D,d=b.i.duration,e=c.duration,f=f4(b).i;f.easing=c.easing;a.styles.forEach(g=>{o4(f,(g.offset||0)*e);e4(f,g.styles,g.easing,b.errors,b.options);m4(f)});n4(b.i,
f);g4(b,d+e);b.C=a}Ky(a,b){var c=b.i.C;const d=a.options||{},e=d.delay?g3(d.delay):0;e&&(6===b.C.type||0==c&&0<b.i.i.size)&&(k4(b.i),b.C=l4);let f=c;c=p4(b,a.Vl,a.limit,a.lC,d.optional?!0:!1,b.errors);b.F=c.length;let g=null;c.forEach((k,m)=>{b.be=m;m=f4(b,a.options,k);e&&h4(m,e);k===b.element&&(g=m.i);v3(this,a.animation,m);m4(m.i);f=Math.max(f,m.i.C)});b.be=0;b.F=0;g4(b,f);g&&(n4(b.i,g),k4(b.i));b.C=a}My(a,b){const c=b.T,d=b.i;var e=a.dg,f=Math.abs(e.duration);const g=f*(b.F-1);f*=b.be;switch(0>
e.duration?"reverse":e.easing){case "reverse":f=g-f;break;case "full":f=c.R}e=b.i;f&&d4(e,f);e=e.C;v3(this,a.animation,b);b.C=a;c.R=d.C-e+(d.startTime-c.i.startTime)}};const l4={};function f4(a,b=null,c){c=c||a.element;c=new c4(a.G,c,a.ba,a.N,a.O,a.errors,a.rf,a.i.fork(c,0));c.C=a.C;c.D=a.D;c.options=a.ea();j4(c,b);c.be=a.be;c.F=a.F;c.T=a;a.K++;return c}function g4(a,b){a.C=l4;a.i=a.i.fork(a.element,b);a.rf.push(a.i)}function h4(a,b){0<b&&d4(a.i,b)}
function j4(a,b,c){if(b){var d=a.options;null!=b.duration&&(d.duration=g3(b.duration));null!=b.delay&&(d.delay=g3(b.delay));var e=b.params;if(e){let f=d.params;f||(f=a.options.params={});Object.keys(e).forEach(g=>{c&&f.hasOwnProperty(g)||(f[g]=r3(e[g],f,a.errors))})}}}
function p4(a,b,c,d,e,f){let g=[];d&&g.push(a.element);0<b.length&&(b=b.replace(Y3,"."+a.N),b=b.replace(Z3,"."+a.O),a=a.G.query(a.element,b,1!=c),0!==c&&(a=0>c?a.slice(a.length+c,a.length):a.slice(0,c)),g.push(...a));e||0!=g.length||f.push(new Yd(3014,!1));return g}
var c4=class{constructor(a,b,c,d,e,f,g,k){this.G=a;this.element=b;this.ba=c;this.N=d;this.O=e;this.errors=f;this.rf=g;this.D=this.T=null;this.C=l4;this.K=0;this.options={};this.R=this.F=this.be=0;this.i=k||new q4(this.G,b,0);g.push(this.i)}get params(){return this.options.params}ea(){const a={};if(this.options){const b=this.options.params;if(b){const c=a.params={};Object.keys(b).forEach(d=>{c[d]=b[d]})}}return a}};
function d4(a,b){const c=1===a.F.size&&a.K.size;a.duration||c?(o4(a,a.C+b),c&&k4(a)):a.startTime+=b}function e4(a,b,c,d,e){c&&a.T.set("easing",c);c=e&&e.params||{};b=r4(b,a.D);for(let [f,g]of b){b=f;e=r3(g,c,d);a.K.set(b,e);if(!a.G.has(b)){let k;a.O.set(b,null!=(k=a.D.get(b))?k:"*")}a.ea(b,e)}}function k4(a){for(let [b,c]of a.G){let d=b,e=c;a.K.set(d,e);a.ea(d,e)}}function m4(a){0!=a.K.size&&(a.K.forEach((b,c)=>{a.i.set(c,b)}),a.K.clear(),a.G.forEach((b,c)=>{a.i.has(c)||a.i.set(c,b)}))}
function n4(a,b){b.ba.forEach((c,d)=>{const e=a.ba.get(d);(!e||c.time>e.time)&&a.ea(d,c.value)})}function o4(a,b){m4(a);a.duration=b;a.R()}
var q4=class{constructor(a,b,c,d){this.ta=a;this.element=b;this.startTime=c;this.N=d;this.duration=0;this.easing=null;this.T=new Map;this.i=new Map;this.F=new Map;this.ba=new Map;this.G=new Map;this.K=new Map;this.O=new Map;this.ma=null;this.N||(this.N=new Map);this.D=this.N.get(b);this.D||(this.D=this.G,this.N.set(b,this.G));this.R()}ra(){switch(this.F.size){case 0:return!1;case 1:return 0<this.i.size;default:return!0}}get C(){return this.startTime+this.duration}fork(a,b){m4(this);return new q4(this.ta,
a,b||this.C,this.N)}R(){this.i&&(this.T=this.i);this.i=this.F.get(this.duration);this.i||(this.i=new Map,this.F.set(this.duration,this.i))}ea(a,b){this.G.set(a,b);this.D.set(a,b);this.ba.set(a,{time:this.C,value:b})}get properties(){const a=[];for(let b in this.i)a.push(b);return a}ia(){m4(this);const a=new Set,b=new Set,c=1===this.F.size&&0===this.duration;let d=[];this.F.forEach((g,k)=>{g=new Map([...this.O,...g]);g.forEach((m,p)=>{"!"===m?a.add(p):"*"===m&&b.add(p)});c||g.set("offset",k/this.duration);
d.push(g)});const e=[...a.values()],f=[...b.values()];if(c){const g=d[0],k=new Map(g);g.set("offset",0);k.set("offset",1);d=[g,k]}return W3(this.element,d,e,f,this.duration,this.startTime,this.easing,!1)}};
class i4 extends q4{constructor(a,b,c,d,e,f,g=!1){super(a,b,f.delay);this.Bg=c;this.Fj=d;this.ai=e;this.va=g;this.dg={duration:f.duration,delay:f.delay,easing:f.easing}}ra(){return 1<this.Bg.length}ia(){let a=this.Bg,{delay:b,duration:c,easing:d}=this.dg;if(this.va&&b){const g=[],k=c+b;var e=b/k,f=new Map(a[0]);f.set("offset",0);g.push(f);f=new Map(a[0]);f.set("offset",s4(e));g.push(f);e=a.length-1;for(f=1;f<=e;f++){let m=new Map(a[f]);const p=m.get("offset");m.set("offset",s4((b+p*c)/k));g.push(m)}c=
k;b=0;d="";a=g}return W3(this.element,a,this.Fj,this.ai,c,b,d,!0)}}function s4(a){const b=Math.pow(10,2);return Math.round(a*b)/b}function r4(a,b){const c=new Map;let d;a.forEach(e=>{if("*"===e){null!=d||(d=b.keys());for(let f of d)c.set(f,"*")}else for(let [f,g]of e)c.set(f,g)});return c};function t4(a,b,c,d,e,f,g,k,m,p,t,v,B){return{type:0,element:a,Oc:b,ww:e,zg:c,Bn:f,le:d,fm:g,rf:k,BD:m,Fj:p,ai:t,totalTime:v,errors:B}};const u4={};function v4(a,b,c,d){let e=a.D.get("*");void 0!==b&&(e=a.D.get(null==b?void 0:b.toString())||e);return e?w4(e,c,d):new Map}
var z4=class{constructor(a,b,c){this.F=a;this.i=b;this.D=c}match(a,b,c,d){return x4(this.i.Ew,a,b,c,d)}C(a,b,c,d,e,f,g,k,m,p){const t=[];var v=this.i.options&&this.i.options.params||u4;g=v4(this,c,g&&g.params||u4,t);const B=k&&k.params||u4;k=v4(this,d,B,t);const G=new Set,K=new Map,N=new Map,aa="void"===d;let ca;v={params:y4(B,v),delay:null==(ca=this.i.options)?void 0:ca.delay};a=p?[]:$3(a,b,this.i.animation,e,f,g,k,v,m,t);let ia=0;a.forEach(O=>{ia=Math.max(O.duration+O.delay,ia)});if(t.length)return t4(b,
this.F,c,d,aa,g,k,[],[],K,N,ia,t);a.forEach(O=>{const U=O.element,Q=E3(K,U,new Set);O.Fj.forEach(F=>Q.add(F));const la=E3(N,U,new Set);O.ai.forEach(F=>la.add(F));U!==b&&G.add(U)});return t4(b,this.F,c,d,aa,g,k,a,[...G.values()],K,N,ia)}};function x4(a,b,c,d,e){return a.some(f=>f(b,c,d,e))}function y4(a,b){const c=Object.assign({},b);Object.entries(a).forEach(([d,e])=>{null!=e&&(c[d]=e)});return c}
function w4(a,b,c){const d=new Map,e=y4(b,a.i);a.styles.styles.forEach(f=>{"string"!==typeof f&&f.forEach((g,k)=>{g&&(g=r3(g,e,c));const m=l3(k);g=x3(m,g,c);d.set(k,g)})});return d}var A4=class{constructor(a,b){this.styles=a;this.i=b}};function B4(a,b,c,d,e){return a.D.find(f=>f.match(b,c,d,e))||null}var E4=class{constructor(a,b){this.name=a;this.i=b;this.D=[];this.ki=new Map;b.ki.forEach(c=>{this.ki.set(c.name,new A4(c.style,c.options&&c.options.params||{}))});C4(this.ki,"true","1");C4(this.ki,"false","0");b.Yg.forEach(c=>{this.D.push(new z4(a,c,this.ki))});this.C=D4(a,this.ki)}};function D4(a,b){return new z4(a,{type:1,animation:{type:2,steps:[],options:null},Ew:[()=>!0],options:null,Kg:0,af:0},b)}
function C4(a,b,c){a.has(b)?a.has(c)||a.set(c,a.get(b)):a.has(c)&&a.set(b,a.get(c))};const F4=new X3;
var G4=class{constructor(a){this.F=a;this.G=new Map;this.D=new Map;this.i=[]}register(a,b){const c=[];b=(new V3).C(b,c,[]);if(c.length)throw new Yd(3503,!1);this.G.set(a,b)}create(a,b,c={}){var d=[];const e=this.G.get(a),f=new Map;e?(b=$3(this.F,b,e,"ng-enter","ng-leave",new Map,new Map,c,F4,d),b.forEach(g=>{const k=E3(f,g.element,new Map);g.ai.forEach(m=>k.set(m,null))})):(d.push(new Yd(3300,!1)),b=[]);if(d.length)throw new Yd(3504,!1);f.forEach((g,k)=>{g.forEach((m,p)=>{g.set(p,u3(k,p))})});d=b.map(g=>
{var k=f.get(g.element);const m=g.element;k=A3(g.Bg,new Map,k);return this.F.animate(m,k,g.duration,g.delay,g.easing,[],!0)});d=z3(d);this.D.set(a,d);d.nb(()=>this.destroy(a));this.i.push(d);return d}destroy(a){const b=this.C(a);b.destroy();this.D.delete(a);a=this.i.indexOf(b);0<=a&&this.i.splice(a,1)}C(a){a=this.D.get(a);if(!a)throw new Yd(3301,!1);return a}Ed(a,b,c,d){b=D3(b,"","","");B3(this.C(a),c,b,d);return()=>{}}};const H4=[],I4={jc:"",hi:!1,ss:!1,Fn:!1,bs:!1},J4={jc:"",ss:!1,hi:!1,Fn:!1,bs:!0};function K4(a,b){const c=b.params;if(c){const d=a.options.params;Object.keys(c).forEach(e=>{null==d[e]&&(d[e]=c[e])})}}class L4{get params(){return this.options.params}constructor(a,b){this.jc=void 0===b?"":b;var c=(b=a&&a.hasOwnProperty("value"))?a.value:a;this.value=null!=c?c:null;b?(a=Object.assign({},a),this.options=(delete a.value,a)):this.options={};this.options.params||(this.options.params={})}}const M4=new L4("void");
function N4(a,b){a.i.i.delete(b);a.F.delete(b);const c=a.i.K.get(b);c&&(c.forEach(d=>d.destroy()),a.i.K.delete(b))}function O4(a,b,c,d,e){const f=a.i.i.get(b),g=new Map;if(f){const k=[];f.forEach((m,p)=>{g.set(p,m.value);a.C.has(p)&&(m=a.Ke(b,p,"void",e))&&k.push(m)});if(k.length)return P4(a.i,a.id,b,!0,c,g),d&&z3(k).Id(()=>Q4(a.i,b)),!0}return!1}
function R4(a,b){const c=a.F.get(b),d=a.i.i.get(b);if(c&&d){const e=new Set;c.forEach(f=>{f=f.name;if(!e.has(f)){e.add(f);var g=a.C.get(f).C,k=d.get(f)||M4,m=new L4("void"),p=new S4(a.id,f,b);a.i.ma++;a.G.push({element:b,Oc:f,transition:g,zg:k,le:m,Yh:p,qw:!0})}})}}
function T4(a,b){const c=[];a.G.forEach(d=>{const e=d.Yh;if(!e.i){var f=d.element,g=a.F.get(f);g&&g.forEach(k=>{if(k.name==d.Oc){const m=D3(f,d.Oc,d.zg.value,d.le.value);m._data=b;B3(d.Yh,k.Xh,m,k.callback)}});e.N?U4(a.i,()=>{e.destroy()}):c.push(d)}});a.G=[];return c.sort((d,e)=>{const f=d.transition.i.af,g=e.transition.i.af;return 0==f||0==g?f-g:I3(d.element,e.element)?1:-1})}
class V4{constructor(a,b,c){this.id=a;this.cf=b;this.i=c;this.D=[];this.C=new Map;this.G=[];this.F=new Map;this.K="ng-tns-"+a;W4(b,this.K)}Ed(a,b,c,d){if(!this.C.has(b))throw new Yd(3302,!1);if(null==c||0==c.length)throw new Yd(3303,!1);if("start"!=c&&"done"!=c)throw new Yd(3400,!1);const e=E3(this.F,a,[]),f={name:b,Xh:c,callback:d};e.push(f);const g=E3(this.i.i,a,new Map);g.has(b)||(W4(a,"ng-trigger"),W4(a,"ng-trigger-"+b),g.set(b,M4));return()=>{U4(this.i,()=>{const k=e.indexOf(f);0<=k&&e.splice(k,
1);this.C.has(b)||g.delete(b)})}}register(a,b){if(this.C.has(a))return!1;this.C.set(a,b);return!0}O(a){a=this.C.get(a);if(!a)throw new Yd(3401,!1);return a}Ke(a,b,c,d){d=void 0===d?!0:d;const e=this.O(b),f=new S4(this.id,b,a);var g=this.i.i.get(a);g||(W4(a,"ng-trigger"),W4(a,"ng-trigger-"+b),this.i.i.set(a,g=new Map));let k=g.get(b);const m=new L4(c,this.id);c&&c.hasOwnProperty("value")||!k||K4(m,k.options);g.set(b,m);k||(k=M4);if("void"!==m.value&&k.value===m.value){if(!X4(k.params,m.params)){d=
[];const t=v4(e.C,k.value,k.params,d),v=v4(e.C,m.value,m.params,d);if(d.length)throw new Yd(3402,!1);U4(this.i,()=>{m3(a,t);k3(a,v)})}}else{c=E3(this.i.K,a,[]);c.forEach(t=>{t.jc==this.id&&t.Oc==b&&t.Kd&&t.destroy()});g=B4(e,k.value,m.value,a,m.params);var p=!1;if(!g){if(!d)return;g=e.C;p=!0}this.i.ma++;this.G.push({element:a,Oc:b,transition:g,zg:k,le:m,Yh:f,qw:p});p||(W4(a,"ng-animate-queued"),f.onStart(()=>{Y4(a,"ng-animate-queued")}));f.Id(()=>{var t=this.D.indexOf(f);0<=t&&this.D.splice(t,1);
if(t=this.i.K.get(a)){let v=t.indexOf(f);0<=v&&t.splice(v,1)}});this.D.push(f);c.push(f);return f}}N(a,b){const c=this.i.D.query(a,".ng-trigger",!0);c.forEach(d=>{if(!d.__ng_removed){var e=Z4(this.i,d);e.size?e.forEach(f=>O4(f,d,b,!1,!0)):N4(this,d)}});$4(this.i,()=>c.forEach(d=>N4(this,d)))}removeNode(a,b){const c=this.i;a.childElementCount&&this.N(a,b);if(!O4(this,a,b,!0)){var d=!1;if(c.Ia){var e=c.ba.length?c.R.get(a):[];if(e&&e.length)d=!0;else for(e=a;e=e.parentNode;)if(c.i.get(e)){d=!0;break}}R4(this,
a);d?P4(c,this.id,a,!1,b):(d=a.__ng_removed,d&&d!==I4||(U4(c,()=>N4(this,a)),a5(c,a),c.va(a,b)))}}destroy(a){this.D.forEach(b=>b.destroy());this.N(this.cf,a)}}function U4(a,b){a.ta.push(b)}function Z4(a,b){const c=new Set;if(b=a.i.get(b))for(let d of b.values())d.jc&&(b=a.G(d.jc))&&c.add(b);return c}function $4(a,b){a.ea.push(b)}function P4(a,b,c,d,e,f){a.C.push(c);c.__ng_removed={jc:b,hi:e,Fn:d,bs:!1,Sr:f}}
function Q4(a,b){const c=b.__ng_removed;if(c&&c.hi){b.__ng_removed=I4;if(c.jc){a5(a,b);const e=a.G(c.jc);e&&N4(e,b)}a.va(b,c.hi)}let d;(null==(d=b.classList)?0:d.contains("ng-animate-disabled"))&&b5(a,b,!1);a.D.query(b,".ng-animate-disabled",!0).forEach(e=>{b5(a,e,!1)})}function a5(a,b){let c=a.D.query(b,".ng-trigger",!0);c.forEach(d=>c5(a,d));0!=a.R.size&&(c=a.D.query(b,".ng-animating",!0),c.forEach(d=>d5(a,d)))}
function e5(a,b,c,d){if(f5(c)){var e=c.__ng_removed;e&&e.hi&&(e.hi=!1,e.ss=!0,e=a.C.indexOf(c),0<=e&&a.C.splice(e,1));b&&(b=a.G(b))&&W4(c,b.K);d&&a.F.push(c)}}function b5(a,b,c){c?a.O.has(b)||(a.O.add(b),W4(b,"ng-animate-disabled")):a.O.has(b)&&(a.O.delete(b),Y4(b,"ng-animate-disabled"))}function c5(a,b){(a=a.K.get(b))&&a.forEach(c=>{c.Kd?c.N=!0:c.destroy()})}function d5(a,b){(a=a.R.get(b))&&a.forEach(c=>c.finish())}
function g5(a,b,c,d){return 0<c.length?a.D.animate(b.element,c,b.duration,b.delay,b.easing,d):new Zy(b.duration,b.delay)}
var o5=class{va(a,b){this.Oa(a,b)}constructor(a,b){this.ra=a;this.D=b;this.ba=[];this.ia=new Map;this.K=new Map;this.R=new Map;this.i=new Map;this.O=new Set;this.ma=this.Ia=0;this.T={};this.N=[];this.ta=[];this.ea=[];this.Da=new Map;this.F=[];this.C=[];this.Oa=()=>{}}Ra(a,b){const c=this.N,d=this.Da;if(0<=c.length-1){let e=!1,f=H3(b);for(;f;){const g=d.get(f);if(g){c.splice(c.indexOf(g)+1,0,a);e=!0;break}f=H3(f)}e||c.unshift(a)}else c.push(a);d.set(b,a);return a}register(a,b){var c=this.T[a];c||(c=
new V4(a,b,this),this.ra&&I3(this.ra,b)?this.Ra(c,b):(this.ia.set(b,c),this.F.push(b)),c=this.T[a]=c);return c}destroy(a,b){a&&(U4(this,()=>{}),$4(this,()=>{const c=this.G(a);this.Da.delete(c.cf);const d=this.N.indexOf(c);0<=d&&this.N.splice(d,1);c.destroy(b);delete this.T[a]}))}G(a){return this.T[a]}Ke(a,b,c,d){return f5(b)&&(a=this.G(a))?(a.Ke(b,c,d),!0):!1}removeNode(a,b,c){if(f5(b)){var d=a?this.G(a):null;d?d.removeNode(b,c):P4(this,a,b,!1,c);(d=this.Da.get(b))&&d.id!==a&&d.removeNode(b,c)}else this.va(b,
c)}Ed(a,b,c,d,e){return f5(b)?this.G(a).Ed(b,c,d,e):()=>{}}kb(a,b,c,d,e){return a.transition.C(this.D,a.element,a.zg.value,a.le.value,c,d,a.zg.options,a.le.options,b,e)}flush(a){a=void 0===a?-1:a;let b=[];this.ia.size&&(this.ia.forEach((d,e)=>this.Ra(d,e)),this.ia.clear());if(this.Ia&&this.F.length)for(var c=0;c<this.F.length;c++)W4(this.F[c],"ng-star-inserted");if(this.N.length&&(this.ma||this.C.length)){c=[];try{b=this.rb(c,a)}finally{for(a=0;a<c.length;a++)c[a]()}}else for(a=0;a<this.C.length;a++)Q4(this,
this.C[a]);this.ma=0;this.F.length=0;this.C.length=0;this.ta.forEach(d=>d());this.ta=[];if(this.ea.length){const d=this.ea;this.ea=[];b.length?z3(b).Id(()=>{d.forEach(e=>e())}):d.forEach(e=>e())}}rb(a,b){const c=new X3,d=[],e=new Map,f=[],g=new Map,k=new Map,m=new Map,p=new Set;this.O.forEach(qa=>{p.add(qa);qa=this.D.query(qa,".ng-animate-queued",!0);for(let T=0;T<qa.length;T++)p.add(qa[T])});const t=this.ra;var v=Array.from(this.i.keys());const B=h5(v,this.F),G=new Map;let K=0;B.forEach((qa,T)=>
{const ea="ng-enter"+K++;G.set(T,ea);qa.forEach(na=>W4(na,ea))});const N=[],aa=new Set;var ca=new Set;for(var ia=0;ia<this.C.length;ia++){var O=this.C[ia];const qa=O.__ng_removed;qa&&qa.hi&&(N.push(O),aa.add(O),qa.Fn?this.D.query(O,".ng-star-inserted",!0).forEach(T=>aa.add(T)):ca.add(O))}const U=new Map,Q=h5(v,Array.from(aa));Q.forEach((qa,T)=>{const ea="ng-leave"+K++;U.set(T,ea);qa.forEach(na=>W4(na,ea))});a.push(()=>{B.forEach((qa,T)=>{const ea=G.get(T);qa.forEach(na=>Y4(na,ea))});Q.forEach((qa,
T)=>{const ea=U.get(T);qa.forEach(na=>Y4(na,ea))});N.forEach(qa=>{Q4(this,qa)})});const la=[],F=[];for(a=this.N.length-1;0<=a;a--)T4(this.N[a],b).forEach(qa=>{const T=qa.Yh,ea=qa.element;la.push(T);if(this.F.length){var na=ea.__ng_removed;if(na&&na.ss){if(na.Sr&&na.Sr.has(qa.Oc)){na=na.Sr.get(qa.Oc);var Ka=this.i.get(qa.element);if(Ka&&Ka.has(qa.Oc)){var Qa=Ka.get(qa.Oc);Qa.value=na;Ka.set(qa.Oc,Qa)}}T.destroy();return}}na=!t||!I3(t,ea);Ka=U.get(ea);Qa=G.get(ea);const Ia=this.kb(qa,c,Qa,Ka,na);if(Ia.errors&&
Ia.errors.length)F.push(Ia);else if(na)T.onStart(()=>m3(ea,Ia.Bn)),T.nb(()=>k3(ea,Ia.fm)),d.push(T);else if(qa.qw)T.onStart(()=>m3(ea,Ia.Bn)),T.nb(()=>k3(ea,Ia.fm)),d.push(T);else{var ib=[];Ia.rf.forEach(pa=>{pa.rE=!0;this.O.has(pa.element)||ib.push(pa)});Ia.rf=ib;c.append(ea,Ia.rf);f.push({kw:Ia,Yh:T,element:ea});Ia.BD.forEach(pa=>E3(g,pa,[]).push(T));Ia.Fj.forEach((pa,Ga)=>{if(pa.size){let Sa=k.get(Ga);Sa||k.set(Ga,Sa=new Set);pa.forEach((db,Xb)=>Sa.add(Xb))}});Ia.ai.forEach((pa,Ga)=>{let Sa=m.get(Ga);
Sa||m.set(Ga,Sa=new Set);pa.forEach((db,Xb)=>Sa.add(Xb))})}});if(F.length){const qa=[];F.forEach(()=>{qa.push(new Yd(3505,!1))});la.forEach(T=>T.destroy());throw new Yd(3402,!1);}const M=new Map,W=new Map;f.forEach(qa=>{const T=qa.element;c.has(T)&&(W.set(T,T),this.ab(qa.Yh.jc,qa.kw,M))});d.forEach(qa=>{const T=qa.element;this.Ta(T,!1,qa.jc,qa.Oc,null).forEach(ea=>{E3(M,T,[]).push(ea);ea.destroy()})});const Aa=N.filter(qa=>i5(qa,k,m)),qb=new Map;j5(qb,ca,m).forEach(qa=>{i5(qa,k,m)&&Aa.push(qa)});
const wb=new Map;B.forEach(qa=>{j5(wb,new Set(qa),k)});Aa.forEach(qa=>{const T=qb.get(qa),ea=wb.get(qa);let na,Ka;qb.set(qa,new Map([...(null!=(na=null==T?void 0:T.entries())?na:[]),...(null!=(Ka=null==ea?void 0:ea.entries())?Ka:[])]))});const Ja=[],Ub=[],Na={};f.forEach(qa=>{const T=qa.element,ea=qa.Yh,na=qa.kw;if(c.has(T))if(p.has(T))ea.nb(()=>k3(T,na.fm)),ea.disabled=!0,ea.totalTime=na.totalTime,d.push(ea);else{var Ka=Na;if(1<W.size){qa=T;const Qa=[];for(;qa=qa.parentNode;){const Ia=W.get(qa);
if(Ia){Ka=Ia;break}Qa.push(qa)}Qa.forEach(Ia=>W.set(Ia,Ka))}qa=this.fb(ea.jc,na,M,e,wb,qb);k5(ea,qa);Ka===Na?Ja.push(ea):((qa=this.K.get(Ka))&&qa.length&&(ea.D=z3(qa)),d.push(ea))}else m3(T,na.Bn),ea.nb(()=>k3(T,na.fm)),Ub.push(ea),p.has(T)&&d.push(ea)});Ub.forEach(qa=>{var T=e.get(qa.element);T&&T.length&&(T=z3(T),k5(qa,T))});d.forEach(qa=>{qa.D?l5(qa,qa.D):qa.destroy()});for(b=0;b<N.length;b++)if(ca=N[b],a=ca.__ng_removed,Y4(ca,"ng-leave"),!a||!a.Fn){a=[];if(g.size)for((v=g.get(ca))&&v.length&&
a.push(...v),v=this.D.query(ca,".ng-animating",!0),ia=0;ia<v.length;ia++)(O=g.get(v[ia]))&&O.length&&a.push(...O);a=a.filter(qa=>!qa.i);a.length?m5(this,ca,a):Q4(this,ca)}N.length=0;Ja.forEach(qa=>{this.ba.push(qa);qa.Id(()=>{qa.destroy();this.ba.splice(this.ba.indexOf(qa),1)});qa.play()});return Ja}Ta(a,b,c,d,e){let f=[];if(b)(e=this.R.get(a))&&(f=e);else if(a=this.K.get(a)){const g=!e||"void"==e;a.forEach(k=>{k.Kd||(g||k.Oc==d)&&f.push(k)})}if(c||d)f=f.filter(g=>c&&c!=g.jc||d&&d!=g.Oc?!1:!0);return f}ab(a,
b,c){var d=b.Oc;const e=b.element;a=b.ww?void 0:a;d=b.ww?void 0:d;for(const f of b.rf){const g=f.element,k=g!==e,m=E3(c,g,[]);this.Ta(g,k,a,d,b.le).forEach(p=>{const t=p.C;t.Jk&&t.Jk();p.destroy();m.push(p)})}m3(e,b.Bn)}fb(a,b,c,d,e,f){const g=b.Oc,k=b.element,m=[],p=new Set,t=new Set,v=b.rf.map(G=>{const K=G.element;p.add(K);var N=K.__ng_removed;if(N&&N.bs)return new Zy(G.duration,G.delay);N=K!==k;var aa=n5((c.get(K)||H4).map(O=>O.C)).filter(O=>O.element?O.element===K:!1),ca=e.get(K);const ia=f.get(K);
ca=A3(G.Bg,ca,ia);aa=g5(this,G,ca,aa);G.sE&&d&&t.add(K);N&&(G=new S4(a,g,K),k5(G,aa),m.push(G));return aa});m.forEach(G=>{E3(this.R,G.element,[]).push(G);G.Id(()=>{var K=this.R,N=G.element;let aa=K.get(N);aa&&(aa.length&&aa.splice(aa.indexOf(G),1),0==aa.length&&K.delete(N));return aa})});p.forEach(G=>W4(G,"ng-animating"));const B=z3(v);B.nb(()=>{p.forEach(G=>Y4(G,"ng-animating"));k3(k,b.fm)});t.forEach(G=>{E3(d,G,[]).push(B)});return B}};
function k5(a,b){a.K||(a.C=b,a.G.forEach((c,d)=>{c.forEach(e=>B3(b,d,void 0,e))}),a.G.clear(),a.K=!0,a.totalTime=b.totalTime,a.Kd=!1)}function l5(a,b){const c=a.C;if(c.oi)b.onStart(()=>c.oi("start"));b.Id(()=>a.finish());b.nb(()=>a.destroy())}
var S4=class{constructor(a,b,c){this.jc=a;this.Oc=b;this.element=c;this.C=new Zy;this.K=!1;this.G=new Map;this.i=!1;this.D=null;this.disabled=this.N=!1;this.Kd=!0;this.totalTime=0}F(a,b){E3(this.G,a,[]).push(b)}Id(a){this.Kd&&this.F("done",a);this.C.Id(a)}onStart(a){this.Kd&&this.F("start",a);this.C.onStart(a)}nb(a){this.Kd&&this.F("destroy",a);this.C.nb(a)}init(){this.C.init()}Pf(){return this.Kd?!1:this.C.Pf()}play(){!this.Kd&&this.C.play()}pause(){!this.Kd&&this.C.pause()}ke(){!this.Kd&&this.C.ke()}finish(){this.C.finish()}destroy(){this.i=
!0;this.C.destroy()}reset(){!this.Kd&&this.C.reset()}setPosition(a){this.Kd||this.C.setPosition(a)}oi(a){const b=this.C;b.oi&&b.oi(a)}};function f5(a){return a&&1===a.nodeType}function p5(a,b){const c=a.style.display;a.style.display=null!=b?b:"none";return c}
function j5(a,b,c){const d=[];b.forEach(g=>d.push(p5(g)));const e=[];c.forEach((g,k)=>{const m=new Map;g.forEach(p=>{const t=u3(k,p);m.set(p,t);t&&0!=t.length||(k.__ng_removed=J4,e.push(k))});a.set(k,m)});let f=0;b.forEach(g=>p5(g,d[f++]));return e}
function h5(a,b){function c(g){if(!g)return 1;let k=f.get(g);if(k)return k;const m=g.parentNode;d.has(m)?k=m:e.has(m)?k=1:k=c(m);f.set(g,k);return k}const d=new Map;a.forEach(g=>d.set(g,[]));if(0==b.length)return d;const e=new Set(b),f=new Map;b.forEach(g=>{const k=c(g);1!==k&&d.get(k).push(g)});return d}function W4(a,b){let c;null==(c=a.classList)||c.add(b)}function Y4(a,b){let c;null==(c=a.classList)||c.remove(b)}function m5(a,b,c){z3(c).Id(()=>Q4(a,b))}
function n5(a){const b=[];q5(a,b);return b}function q5(a,b){for(let c=0;c<a.length;c++){const d=a[c];d instanceof cz?q5(d.i,b):b.push(d)}}function X4(a,b){const c=Object.keys(a);var d=Object.keys(b);if(c.length!=d.length)return!1;for(d=0;d<c.length;d++){const e=c[d];if(!b.hasOwnProperty(e)||a[e]!==b[e])return!1}return!0}function i5(a,b,c){const d=c.get(a);if(!d)return!1;let e=b.get(a);e?d.forEach(f=>e.add(f)):b.set(a,d);c.delete(a);return!0};function r5(a,b){$4(a.i,b)}
var s5=class{constructor(a,b){this.F={};this.C=()=>{};this.i=new o5(a.body,b);this.D=new G4(b);this.i.Oa=(c,d)=>{this.C(c,d)}}register(a,b){this.i.register(a,b)}destroy(a,b){this.i.destroy(a,b)}process(a,b,c,d){if("@"==c.charAt(0)){const [f,g]=F3(c);a=this.D;c=f;var e=g;if("register"==e)a.register(c,d[0]);else if("create"==e)a.create(c,b,d[0]||{});else switch(b=a.C(c),e){case "play":b.play();break;case "pause":b.pause();break;case "reset":b.reset();break;case "restart":b.ke();break;case "finish":b.finish();
break;case "init":b.init();break;case "setPosition":b.setPosition(parseFloat(d[0]));break;case "destroy":a.destroy(c)}}else this.i.Ke(a,b,c,d)}Ed(a,b,c,d,e){if("@"==c.charAt(0)){const [f,g]=F3(c);return this.D.Ed(f,b,g,e)}return this.i.Ed(a,b,c,d,e)}flush(a=-1){this.i.flush(a)}};function t5(a,b){let c=null,d=null;Array.isArray(b)&&b.length?(c=u5(b[0]),1<b.length&&(d=u5(b[b.length-1]))):b instanceof Map&&(c=u5(b));return c||d?new v5(a,c,d):null}
var v5=class{constructor(a,b,c){this.i=a;this.D=b;this.C=c;this.nc=0;let d=w5.get(a);d||w5.set(a,d=new Map);this.F=d}start(){1>this.nc&&(this.D&&k3(this.i,this.D,this.F),this.nc=1)}finish(){this.start();2>this.nc&&(k3(this.i,this.F),this.C&&(k3(this.i,this.C),this.C=null),this.nc=1)}destroy(){this.finish();3>this.nc&&(w5.delete(this.i),this.D&&(m3(this.i,this.D),this.C=null),this.C&&(m3(this.i,this.C),this.C=null),k3(this.i,this.F),this.nc=3)}},w5=new WeakMap;
function u5(a){let b=null;a.forEach((c,d)=>{if("display"===d||"position"===d)b=b||new Map,b.set(d,c)});return b};function x5(a){a.K||(a.K=!0,a.F.forEach(b=>b()),a.F=[])}function y5(a){if(!a.ba){a.ba=!0;var b=a.Bg;a.i=a.Da(a.element,b,a.options);a.ta=b.length?b[b.length-1]:new Map;var c=()=>x5(a);a.i.addEventListener("finish",c);a.nb(()=>{a.i.removeEventListener("finish",c)})}}
var z5=class{constructor(a,b,c,d){this.element=a;this.Bg=b;this.options=c;this.C=d;this.F=[];this.G=[];this.N=[];this.Fa=this.O=this.K=this.ba=!1;this.ea=[];this.ia=[];this.time=0;this.D=null;this.Dh=new Map;this.ma=c.duration;this.R=c.delay||0;this.time=this.ma+this.R}init(){y5(this);this.va()}va(){this.R?this.T():this.i.pause()}ra(a){const b=[];a.forEach(c=>{b.push(Object.fromEntries(c))});return b}Da(a,b,c){return a.animate(this.ra(b),c)}onStart(a){this.ia.push(a);this.G.push(a)}Id(a){this.ea.push(a);
this.F.push(a)}nb(a){this.N.push(a)}play(){y5(this);this.Pf()||(this.G.forEach(a=>a()),this.G=[],this.O=!0,this.C&&this.C.start());this.i.play()}pause(){this.init();this.i.pause()}finish(){this.init();this.C&&this.C.finish();x5(this);this.i.finish()}reset(){this.T();this.O=this.K=this.Fa=!1;this.G=this.ia;this.F=this.ea}T(){this.i&&this.i.cancel()}ke(){this.reset();this.play()}Pf(){return this.O}destroy(){this.Fa||(this.Fa=!0,this.T(),x5(this),this.C&&this.C.destroy(),this.N.forEach(a=>a()),this.N=
[])}setPosition(a){void 0===this.i&&this.init();this.i.currentTime=a*this.time}get totalTime(){return this.R+this.ma}Jk(){const a=new Map;this.Pf()&&this.ta.forEach((b,c)=>{"offset"!==c&&a.set(c,this.K?b:u3(this.element,c))});this.Dh=a}oi(a){a="start"===a?this.G:this.F;a.forEach(b=>b());a.length=0}};var A5=class{query(a,b,c){a=c?Array.from(a.querySelectorAll(b)):(a=a.querySelector(b))?[a]:[];return a}animate(a,b,c,d,e,f=[]){const g={duration:c,delay:d,fill:0==d?"both":"forwards"};e&&(g.easing=e);const k=new Map;e=f.filter(p=>p instanceof z5);0!==c&&0!==d||e.forEach(p=>{p.Dh.forEach((t,v)=>k.set(v,t))});let m=j3(b).map(p=>new Map(p));m=t3(a,m,k);b=t5(a,m);return new z5(a,m,g,b)}};var B5=class{constructor(a,b,c,d){this.jc=a;this.qb=b;this.i=c;this.C=d}get data(){return this.qb.data}Xk(a){let b,c;null==(c=(b=this.qb).Xk)||c.call(b,a)}destroy(){this.i.destroy(this.jc,this.qb);r5(this.i,()=>{queueMicrotask(()=>{this.qb.destroy()})});let a;null==(a=this.C)||a.call(this)}createElement(a,b){return this.qb.createElement(a,b)}createComment(a){return this.qb.createComment(a)}lq(a){return this.qb.lq(a)}appendChild(a,b){this.qb.appendChild(a,b);e5(this.i.i,this.jc,b,!1)}insertBefore(a,
b,c,d=!0){this.qb.insertBefore(a,b,c);e5(this.i.i,this.jc,b,d)}removeChild(a,b){this.i.i.removeNode(this.jc,b,this.qb)}ns(a,b){return this.qb.ns(a,b)}parentNode(a){return this.qb.parentNode(a)}nextSibling(a){return this.qb.nextSibling(a)}setAttribute(a,b,c,d){this.qb.setAttribute(a,b,c,d)}removeAttribute(a,b,c){this.qb.removeAttribute(a,b,c)}Ri(a,b){this.qb.Ri(a,b)}wo(a,b){this.qb.wo(a,b)}setStyle(a,b,c,d){this.qb.setStyle(a,b,c,d)}Zr(a,b,c){this.qb.Zr(a,b,c)}setProperty(a,b,c){"@"==b.charAt(0)&&
"@.disabled"==b?b5(this.i.i,a,!!c):this.qb.setProperty(a,b,c)}setValue(a,b){this.qb.setValue(a,b)}Ed(a,b,c){return this.qb.Ed(a,b,c)}},F5=class extends B5{constructor(a,b,c,d){super(b,c,d);this.aa=a;this.jc=b}setProperty(a,b,c){"@"==b.charAt(0)?"."==b.charAt(1)&&"@.disabled"==b?b5(this.i.i,a,void 0===c?!0:!!c):this.i.process(this.jc,a,b.slice(1),c):this.qb.setProperty(a,b,c)}Ed(a,b,c){if("@"==b.charAt(0)){a=C5(a);b=b.slice(1);let d="";"@"!=b.charAt(0)&&([b,d]=D5(b));return this.i.Ed(this.jc,a,b,d,
e=>{E5(this.aa,e._data||-1,c,e)})}return this.qb.Ed(a,b,c)}};function C5(a){switch(a){case "body":return document.body;case "document":return document;case "window":return window;default:return a}}function D5(a){const b=a.indexOf(".");return[a.substring(0,b),a.slice(b+1)]};function E5(a,b,c,d){if(0<=b&&b<a.D)a.xb.run(()=>c(d));else{var e=a.F;0==e.length&&queueMicrotask(()=>{a.xb.run(()=>{e.forEach(f=>{const [g,k]=f;g(k)});a.F=[]})});e.push([c,d])}}
var G5=class{constructor(a,b,c){this.qb=a;this.i=b;this.xb=c;this.G=0;this.D=1;this.F=[];this.K=new Map;this.C=0;b.C=(d,e)=>{const f=null==e?void 0:e.parentNode(d);f&&e.removeChild(f,d)}}Uk(a,b){const c=this.qb.Uk(a,b);let d;if(!a||!(null==b?0:null==(d=b.data)?0:d.animation)){const k=this.K;a=k.get(c);a||(a=new B5("",c,this.i,()=>k.delete(c)),k.set(c,a));return a}const e=b.id,f=b.id+"-"+this.G;this.G++;this.i.register(f,a);const g=k=>{if(Array.isArray(k))k.forEach(g);else{var m=this.i,p=k.name,t=
e+"-"+p,v=m.F[t];if(!v){v=[];k=(new V3).C(k,v,[]);if(v.length)throw new Yd(3404,!1);v=new E4(p,k);m.F[t]=v}m=m.i;(t=m.T[f])&&t.register(p,v)&&m.Ia++}};b.data.animation.forEach(g);return new F5(this,f,c,this.i)}Um(){this.C++;this.qb.Um&&this.qb.Um()}N(){queueMicrotask(()=>{this.D++})}end(){this.C--;0==this.C&&Kk(this.xb,()=>{this.N();this.i.flush(this.D)});this.qb.end&&this.qb.end()}};var H5=class extends s5{constructor(a,b,c){super(a,b,c)}ua(){this.flush()}};H5.J=function(a){return new (a||H5)(q(gt),q(J3),q(e3))};H5.oa=Ld({la:H5,aa:H5.J});const I5=[{na:e3,Ec:function(){return new y3}},{na:s5,Dc:H5},{na:si,Ec:function(a,b,c){return new G5(a,b,c)},zc:[XG,s5,Ok]}];var J5=[{na:J3,Ec:()=>new A5},{na:ki,mb:"BrowserAnimations"},...I5];[...I5];var K5=class{};K5.J=function(a){return new (a||K5)};K5.Wa=Mf({type:K5});K5.Va=Md({Ua:J5,imports:[LH]});var L5={Ua:[Wf([K5]),function(a,...b){return{Zj:[{na:t0,Db:!0,mb:a},[],{na:IZ,Ec:g1,zc:[e1]},{na:Xo,Db:!0,Ec:h1},b.map(c=>c.Zj)]}}([]),{na:"ModelLoaderService",Dc:d3}]},M5=Object,N5=M5.assign,O5,P5={Ua:[(null==L5?void 0:L5.Ua)||[],KH]};let Q5;O5={XA:[...lH,...(null!=(Q5=null==P5?void 0:P5.Ua)?Q5:[])],vD:iH};
(function(a){try{const b=a.KD,c=a.XA,d=vs(a.vD),e=[hs(),...(c||[])],f=(new nn({Ua:e,parent:d,yv:"",zx:!1})).wa,g=f.get(Ok);return g.run(()=>{ng(f);const k=f.get(ui,null);let m;Kk(g,()=>{m=g.onError.subscribe({next:v=>{k.handleError(v)}})});const p=()=>f.destroy(),t=d.get(ns);t.add(p);f.nb(()=>{m.unsubscribe();t.delete(p)});return Zo(k,g,()=>{const v=f.get(sn);rn(v);return v.D.then(()=>{f.get(ls,"en-US");const B=f.get(dp);void 0!==b&&B.Kk(b);return B})})})}catch(b){return Promise.reject(b)}})(N5.call(M5,
{},{KD:X2},O5)).catch(a=>{console.error(a)});
